@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,12 +16,14 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef OGDF_LAYOUT_PLUGIN_BASE
 #define OGDF_LAYOUT_PLUGIN_BASE
 
 #include <tulip/tulipconf.h>
-#include <tulip/TulipPlugin.h>
-#include <tulip/LayoutAlgorithm.h>
+#include <tulip/TulipPluginHeaders.h>
+#include <tulip/PropertyAlgorithm.h>
 
 #include <ogdf/basic/Graph_d.h>
 #include <ogdf/basic/GraphAttributes.h>
@@ -30,10 +32,8 @@
 #include "TulipToOGDF.h"
 
 class TLP_OGDF_SCOPE OGDFLayoutPluginBase: public tlp::LayoutAlgorithm {
-
 public:
-
-  OGDFLayoutPluginBase(const tlp::PropertyContext &context, ogdf::LayoutModule *ogdfLayoutAlgo);
+  OGDFLayoutPluginBase(const tlp::PluginContext* context, LayoutModule* ogdfLayoutAlgo);
   virtual ~OGDFLayoutPluginBase();
 
   virtual bool run();
@@ -51,3 +51,4 @@ protected:
 };
 
 #endif // OGDF_LAYOUT_PLUGIN_BASE
+///@endcond
\ No newline at end of file
