@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -15,12 +15,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  *
- *
- * Authors: Didier Bathily, Nicolas Bellino, Jonathan Dubois, Christelle Jolly, Antoine Lambert, Nicolas Sorraing
- *
- * Email : didier.bathily@etu.u-bordeaux1.fr, nicolas.bellino@etu.u-bordeaux1.fr, jonathan.dubois@etu.u-bordeaux1.fr, christelle.jolly@etu.u-bordeaux1.fr, antoine.lambert@etu.u-bordeaux1.fr, nicolas.sorraing@etu.u-bordeaux1.fr
- *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef         TULIPTOOGDF_H_
 #define         TULIPTOOGDF_H_
@@ -32,6 +29,7 @@
 #include <tulip/Graph.h>
 #include <tulip/TlpTools.h>
 #include <tulip/StringProperty.h>
+#include <tulip/NumericProperty.h>
 #include <tulip/ForEach.h>
 
 #include <exception>
@@ -65,8 +63,8 @@ public:
 
   tlp::Coord getNodeCoordFromOGDFGraphAttr(unsigned int nodeIndex);
 
-  void copyTlpDoublePropertyToOGDFEdgeLength(tlp::DoubleProperty *);
-  void copyTlpDoublePropertyToOGDFNodeWeight(tlp::DoubleProperty *);
+  void copyTlpNumericPropertyToOGDFEdgeLength(tlp::NumericProperty *);
+  void copyTlpNumericPropertyToOGDFNodeWeight(tlp::NumericProperty *);
   void copyTlpNodeSizeToOGDF(tlp::SizeProperty *);
 
   vector<tlp::Coord> getEdgeCoordFromOGDFGraphAttr(unsigned int edgeIndex);
@@ -81,3 +79,4 @@ private:
 };
 
 #endif      /* !TULIPTOOGDF_H_ */
+///@endcond
