@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,16 +16,34 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef ABSTRACTGLCURVE_H
 #define ABSTRACTGLCURVE_H
 
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+//# if defined(__WIN32__)
+//# include <GL/glext.h>
+//# endif
+#endif
+
 #include <tulip/GlSimpleEntity.h>
-#include <tulip/Coord.h>
 #include <tulip/Color.h>
-#include <tulip/GlShaderProgram.h>
 
 namespace tlp {
 
+class GlShaderProgram;
+class GlShader;
+
 class TLP_GL_SCOPE AbstractGlCurve : public GlSimpleEntity {
 
 public :
@@ -84,17 +102,17 @@ public :
     this->lookDir = lookDir;
   }
 
-  void getXML(xmlNodePtr rootNode);
+  void getXML(std::string &);
 
-  void setWithXML(xmlNodePtr rootNode);
+  void setWithXML(const std::string &,unsigned int &);
 
   virtual void drawCurve(std::vector<Coord> &controlPoints, const Color &startColor, const Color &endColor, const float startSize, const float endSize, const unsigned int nbCurvePoints=100);
 
 protected:
 
-  virtual void setCurveVertexShaderRenderingSpecificParameters() {};
+  virtual void setCurveVertexShaderRenderingSpecificParameters() {}
 
-  virtual void cleanupAfterCurveVertexShaderRendering() {};
+  virtual void cleanupAfterCurveVertexShaderRendering() {}
 
   virtual Coord computeCurvePointOnCPU(const std::vector<Coord> &controlPoints, float t) = 0;
 
@@ -145,3 +163,4 @@ protected:
 
 #endif
 
+///@endcond
