@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,18 +16,32 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef CURVES_H
 #define CURVES_H
 #ifndef DOXYGEN_NOTFOR_DEVEL
+
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
+
 #include <tulip/Coord.h>
 #include <tulip/Color.h>
-#include <tulip/GlTools.h>
+#include <tulip/tulipconf.h>
+
 #include <vector>
 
-
-
-
 namespace tlp {
+
 template<typename T, unsigned int N>
 class Matrix;
 //====================================================================
@@ -47,7 +61,7 @@ TLP_GL_SCOPE void polyQuad(const std::vector<Coord> &, /* polyline vertces */
                            const Coord &,            /* normal to the end curve */
                            bool,         /* if true : use start and end color to border lines, if false : use borderColor*/
                            const Color &,      /* border color */
-                           const std::string &textureName="",      /* textureName */
+                           const std::string &textureName="", /* textureName */
                            const float outlineWidth=0);
 TLP_GL_SCOPE void simpleQuad(const std::vector<Coord> &, /* quad vertces */
                              const Color &,            /* start color */
@@ -84,6 +98,8 @@ TLP_GL_SCOPE void buildCurvePoints (const std::vector<Coord> &vertices,
                                     const Coord &startN,
                                     const Coord &endN,
                                     std::vector<Coord> &result);
+
 }
 #endif //DOXYGEN_NOTFOR_DEVEL
 #endif
+///@endcond
