@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,16 +16,18 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef EDGEEXTREMITYGLYPHMANAGER_H_
 #define EDGEEXTREMITYGLYPHMANAGER_H_
 
 #include <string>
+
 #include <tulip/tulipconf.h>
 #include <tulip/MutableContainer.h>
 
 namespace tlp {
-struct PluginLoader;
 class GlGraphInputData;
 class EdgeExtremityGlyph;
 class Graph;
@@ -33,9 +35,6 @@ class Graph;
 class TLP_GL_SCOPE EdgeExtremityGlyphManager {
 
 public:
-
-
-
   virtual ~EdgeExtremityGlyphManager() {
   }
 
@@ -61,10 +60,6 @@ public:
    * Load glyphs plugins
    */
   void loadGlyphPlugins();
-  /**
-   * Load glyphs plugins with given PluginLoader
-   */
-  void loadPlugins(PluginLoader *plug = 0);
 
   /**
    * Create the glyph list and store it in glyphs parameter
@@ -76,9 +71,6 @@ public:
    */
   void clearGlyphList(Graph **graph, GlGraphInputData* glGraphInputData,
                       MutableContainer<EdgeExtremityGlyph *>& glyphs);
-
-  static const int NoEdgeExtremetiesId;
-
 private:
 
   EdgeExtremityGlyphManager();
@@ -89,3 +81,4 @@ private:
 };
 }
 #endif /* EDGEEXTREMITYGLYPHMANAGER_H_ */
+///@endcond
