@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -17,6 +17,7 @@
  *
  */
 
+
 #ifndef GLABSTRACTPOLYGON_H
 #define GLABSTRACTPOLYGON_H
 
@@ -24,21 +25,31 @@
 
 #include <tulip/Color.h>
 #include <tulip/Coord.h>
-#include <tulip/tulipconf.h>
-
+#include <tulip/Size.h>
 #include <tulip/GlSimpleEntity.h>
-#include <tulip/GlTools.h>
+
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#else
+#include <GL/gl.h>
+#endif
 
 namespace tlp {
+
 /**
- * \addtogroup GlEntities
- */
-/*@{*/
-/**
- * class to create a abstract polygon
+ * @ingroup OpenGL
+ * @brief class to create a abstract polygon
+ * @warning You don't have to use this class, it's only a base class for some others entities
  */
 class TLP_GL_SCOPE GlAbstractPolygon : public GlSimpleEntity {
 public:
+
+  ///@cond DOXYGEN_HIDDEN
+
   /**
    * Constructor
    */
@@ -100,11 +111,15 @@ public:
    */
   void setFillColor(unsigned int i, const Color &color);
 
+  ///@endcond
+
   /**
-   * Set color used to filling the whole polygon
+   * @brief Set color used to filling the whole polygon
    */
   void setFillColor(const Color &color);
 
+  ///@cond DOXYGEN_HIDDEN
+
   /**
    * Get the ith color used to outlining the polygon
    */
@@ -115,31 +130,35 @@ public:
    */
   void setOutlineColor(unsigned int i, const Color &color);
 
+  ///@endcond
+
   /**
-   * Set the color used to outlining the whole polygon
+   * @brief Set the color used to outlining the whole polygon
    */
   void setOutlineColor(const Color &color);
 
   /**
-   * Get the textureName
+   * @brief Get the textureName
    */
   std::string getTextureName();
 
   /**
-   * Set the textureName
+   * @brief Set the textureName
    */
   void setTextureName(const std::string &name);
 
   /**
-   * Get the outline size
+   * @brief Get the outline size
    */
   float getOutlineSize();
 
   /**
-   * Set the outline size
+   * @brief Set the outline size
    */
   void setOutlineSize(float size);
 
+  ///@cond DOXYGEN_HIDDEN
+
   /**
    * Get the lod outline value, below this lod value outline will not be displayed
    */
@@ -150,6 +169,11 @@ public:
    */
   void setHideOutlineLod(float lod);
 
+  /**
+   * Sets if the y texture coordinates have to be inversed
+   */
+  void setInvertYTexture(bool invertYTexture);
+
   /**
    * Draw the polygon
    */
@@ -161,22 +185,31 @@ public:
   virtual void translate(const Coord& mouvement);
 
   /**
-   * Function to export data and type in XML
+   * Scale entity
    */
-  virtual void getXML(xmlNodePtr rootNode);
+  virtual void scale(const tlp::Size& factor);
 
   /**
-   * Function to export data in XML
+   * Function to export data and type in outString (in XML format)
    */
-  virtual void getXMLOnlyData(xmlNodePtr rootNode);
+  virtual void getXML(std::string &outString);
 
   /**
-   * Function to set data with XML
+   * Function to export data in outString (in XML format)
    */
-  virtual void setWithXML(xmlNodePtr rootNode);
+  virtual void getXMLOnlyData(std::string &outString);
+
+  /**
+   * Function to set data with inString (in XML format)
+   */
+  virtual void setWithXML(const std::string &outString, unsigned int &currentPosition);
+
+  ///@endcond
 
 protected:
 
+  ///@cond DOXYGEN_HIDDEN
+
   /**
    * set Coords of the polygon
    */
@@ -207,6 +240,8 @@ protected:
    */
   virtual void clearGenerated();
 
+  ///@endcond
+
   PolygonMode polygonMode;
   std::vector<Coord> points;
   std::vector<Color> fillColors;
@@ -226,49 +261,8 @@ protected:
 
   bool generated;
   GLuint buffers[7];
-
-public :
-
-  //=====================================================
-  // Deprecated
-  //=====================================================
-
-  /**
-   * return the ith color used for filling the polygon
-   * @deprecated use getFillColor
-   */
-  const Color& fcolor(const unsigned int i) const;
-
-  /**
-   * return the ith color used for filling the polygon
-   * @deprecated use getFillColor
-   */
-  Color& fcolor(const unsigned int i);
-
-  /**
-   * Set the ith color used for filling the polygon
-   * @deprecated use setFillColor
-   */
-  void setFColor(const unsigned int i,const Color &color);
-
-  /**
-   * return the ith color used for outlining the polygon
-   * @deprecated use getOutlineColor
-   */
-  const Color& ocolor(const unsigned int i) const;
-
-  /**
-   * return the ith color used for outlining the polygon
-   * @deprecated use getOutlineColor
-   */
-  virtual Color& ocolor(const unsigned int i);
-
-  /**
-   * Set the ith color used for outlining the polygon
-   * @deprecated use setOutlineColor
-   */
-  virtual void setOColor(const unsigned int i,const Color &color);
 };
-/*@}*/
+
 }
 #endif
+
