@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -17,6 +17,7 @@
  *
  */
 
+
 #ifndef GLBEZIERCURVE_H_
 #define GLBEZIERCURVE_H_
 
@@ -25,13 +26,14 @@
 namespace tlp {
 
 /**
- * \brief A class to draw Bézier curves
+ * @ingroup OpenGL
+ * @brief A class to draw Bezier curves
  *
- * This class allows to draw Bézier curves defined by an arbitrary number of control points.
- * Bézier curves are named after their inventor, Dr. Pierre Bézier. He was an engineer with the
- * Renault car company and set out in the early 1960’s to develop a curve formulation which would
+ * This class allows to draw Bezier curves defined by an arbitrary number of control points.
+ * Bezier curves are named after their inventor, Dr. Pierre Bezier. He was an engineer with the
+ * Renault car company and set out in the early 1960's to develop a curve formulation which would
  * lend itself to shape design.
- * Bézier curves are widely used in computer graphics to model smooth curves. A Bézier curve is
+ * Bezier curves are widely used in computer graphics to model smooth curves. A Bezier curve is
  * completely contained in the convex hull of its control points and passes through its first and
  * last control points. The curve is also always tangent to the first and last convex hull polygon segments.
  * In addition, the curve shape tends to follow the polygon shape.
@@ -44,21 +46,21 @@ public:
   GlBezierCurve();
 
   /**
-   * GlBezierCurve constructor
+   * @brief GlBezierCurve constructor
    *
-   * \param controlPoints a vector of control points (size must be greater or equal to 2)
-   * \param startColor the color at the start of the curve
-   * \param endColor the color at the end of the curve
-   * \param startSize the width at the start of the curve
-   * \param endSize the width at the end of the curve
-   * \param nbCurvePoints the number of curve points to generate
+   * @param controlPoints a vector of control points (size must be greater or equal to 2)
+   * @param startColor the color at the start of the curve
+   * @param endColor the color at the end of the curve
+   * @param startSize the width at the start of the curve
+   * @param endSize the width at the end of the curve
+   * @param nbCurvePoints the number of curve points to generate
    */
   GlBezierCurve(const std::vector<Coord> &controlPoints, const Color &startColor, const Color &endColor,
-                const float &startSize, const float &endSize, const unsigned int nbCurvePoints = 100);
+                const float &startSize, const float &endSize, const unsigned int nbCurvePoints = 200);
 
   ~GlBezierCurve();
 
-  void drawCurve(std::vector<Coord> &controlPoints, const Color &startColor, const Color &endColor, const float startSize, const float endSize, const unsigned int nbCurvePoints=100);
+  void drawCurve(std::vector<Coord> &controlPoints, const Color &startColor, const Color &endColor, const float startSize, const float endSize, const unsigned int nbCurvePoints=200);
 
 protected :
 
@@ -68,15 +70,6 @@ protected :
 
   std::string genCurveVertexShaderSpecificCode();
 
-  void setCurveVertexShaderRenderingSpecificParameters();
-
-  void cleanupAfterCurveVertexShaderRendering();
-
-private :
-
-  static void buildPascalTriangleTexture();
-  static GLuint pascalTriangleTextureId;
-
 };
 
 }
