@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,15 +16,14 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLCPULODCALCULATOR_H
 #define Tulip_GLCPULODCALCULATOR_H
 
-#include <map>
-#include <vector>
-
-#include <tulip/BoundingBox.h>
 #include <tulip/Coord.h>
 #include <tulip/GlLODCalculator.h>
+#include <tulip/Matrix.h>
 
 namespace tlp {
 class GlSimpleEntity;
@@ -93,7 +92,7 @@ public:
 
   /**
    * Set if the edge LOD must be calculated
-   * \Warning at default the edge LOD is not calculated and return 10.
+   * \Warning If not calcultated, the default edge LOD is 10.
    */
   void setComputeEdgesLOD(bool state) {
     computeEdgesLOD=state;
@@ -125,3 +124,4 @@ protected:
 }
 
 #endif // Tulip_GLCPULODCALCULATOR_H
+///@endcond
