@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -17,29 +17,29 @@
  *
  */
 
+
 #ifndef GLCIRCLE_H
 #define GLCIRCLE_H
 
 #include <tulip/Color.h>
 #include <tulip/Coord.h>
-
 #include <tulip/GlRegularPolygon.h>
 
 namespace tlp {
 
 /**
- * \addtogroup GlEntities
- */
-/*@{*/
-/**
- * \brief General class used to render circles as GlEntity.
+ * @ingroup OpenGL
+ * @brief Class used to render circles as GlEntity.
  *
- * This class is a generic class to render circles as GlEntity.
+ * If you want a circle : use this class
  */
 class TLP_GL_SCOPE GlCircle : public GlRegularPolygon {
 public:
   /**
-   * Constructor
+   * @brief Constructor
+   *
+   * @param startAngle if start angle is equal to 0, the circle construction begin with the top center point
+   * @param segment number of triangle used to render the circle
    */
   GlCircle(const Coord &center = Coord(0,0,0),
            float radius = 1.,
@@ -51,46 +51,16 @@ public:
            unsigned int segments = 10);
 
   /**
-   * Write-acess Accessor to the center, the radius and the startAngle of the circle.
+   * @brief Write-acess Accessor to the center, the radius and the startAngle of the circle.
    */
   void set(const Coord &center, float radius, float startAngle);
 
   /**
-   * return the fill color of the circle (i parameter is not used)
-   * This is an overload of the GlPolygon function to dismiss its behavior.
+   * @brief Function to export data in XML
    */
-  virtual const Color& fcolor(const unsigned int) const {
-    return GlRegularPolygon::fcolor(0);
-  }
-  /**
-   * return the fill color of the circle (i parameter is not used)
-   * This is an overload of the GlPolygon function to dismiss its behavior.
-   */
-  virtual Color& fcolor(const unsigned int) {
-    return GlRegularPolygon::fcolor(0);
-  }
-
-  /**
-   * return the outline color of the circle (i parameter is not used)
-   * This is an overload of the GlPolygon function to dismiss its behavior.
-   */
-  virtual const Color& ocolor(const unsigned int) const {
-    return GlRegularPolygon::ocolor(0);
-  }
-  /**
-   * return the outline color of the circle (i parameter is not used)
-   * This is an overload of the GlPolygon function to dismiss its behavior.
-   */
-  virtual Color& ocolor(const unsigned int) {
-    return GlRegularPolygon::ocolor(0);
-  }
-
-  /**
-   * Function to export data in XML
-   */
-  virtual void getXML(xmlNodePtr rootNode);
+  virtual void getXML(std::string &outString);
 };
-/*@}*/
+
 }
 
 #endif
