@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,16 +16,21 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef GLCOLORSCALE_H_
 #define GLCOLORSCALE_H_
 
 #include <tulip/Observable.h>
-#include <tulip/GlPolyQuad.h>
-#include <tulip/ColorScale.h>
+#include <tulip/GlSimpleEntity.h>
+#include <tulip/Color.h>
 
 namespace tlp {
 
+class ColorScale;
+class GlPolyQuad;
+
 class TLP_GL_SCOPE GlColorScale : public GlSimpleEntity, public Observable {
 
 public:
@@ -50,10 +55,6 @@ public:
 
   void translate(const Coord &move);
 
-  void getXML(xmlNodePtr) {}
-
-  void setWithXML(xmlNodePtr) {}
-
   Coord getBaseCoord() const {
     return baseCoord;
   }
@@ -76,11 +77,13 @@ public:
     return colorScale;
   }
 
+  void getXML(std::string &) {}
+
+  void setWithXML(const std::string &,unsigned int &) {}
+
 protected :
 
-  void update(std::set<Observable *>::iterator begin ,std::set<Observable *>::iterator end);
-
-  void observableDestroyed(Observable *) {}
+  void treatEvent(const Event &);
 
 private:
 
@@ -96,3 +99,4 @@ private:
 }
 
 #endif /* GLCOLORSCALE_H_ */
+///@endcond
