@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,16 +16,21 @@
  * See the GNU General Public License for more details.
  *
  */
-
 #ifndef GLCOMPLEXPOLYGON_H
 #define GLCOMPLEXPOLYGON_H
 
-#include <tulip/OpenGlConfigManager.h>
-
 #ifdef WIN32
 #include <windows.h>
 #endif
 
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
+
 #ifndef CALLBACK
 #define CALLBACK
 #endif
@@ -37,7 +42,6 @@
 #include <tulip/Color.h>
 #include <tulip/Coord.h>
 #include <tulip/tulipconf.h>
-
 #include <tulip/GlSimpleEntity.h>
 
 namespace tlp {
@@ -53,11 +57,8 @@ void CALLBACK vertexCallback(GLvoid *vertex, GLvoid *polygonData);
 void CALLBACK combineCallback(GLdouble coords[3], VERTEX *d[4], GLfloat w[4], VERTEX** dataOut, GLvoid *polygonData);
 
 /**
- * \addtogroup GlEntities
- */
-/*@{*/
-/**
- * Class to create a complex polygon (concave polygon or polygon with hole)
+ * @ingroup OpenGL
+ * @brief Class to create a complex polygon (concave polygon or polygon with hole)
  * If you want to create a complex polygon you have 4 constructors :
  * Constructors with vector of coords : to create a complex polygon without hole
  *   - In this case you have two constructor : with and without outline color
@@ -110,125 +111,82 @@ class TLP_GL_SCOPE GlComplexPolygon : public GlSimpleEntity {
 
 public:
   /**
-   * Default constructor
+   * @brief Default constructor
+   * @warning don't use this constructor if you want to create a complex polygon, see others constructors
    */
   GlComplexPolygon() {}
-
   /**
-   * Constructor with a vector of coords, a fill color, a polygon edges type(0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves)
-   * and a textureName if you want
+   * @brief Constructor with a vector of coords, a fill color, a polygon edges type(0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you want
    */
   GlComplexPolygon(const std::vector<Coord> &coords,Color fcolor,int polygonEdgesType=0,const std::string &textureName = "");
-
   /**
-   *  Constructor with a vector of coords, a fill color, an outline color, a polygon edges type(0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves)
-   * and a textureName if you want
+   * @brief Constructor with a vector of coords, a fill color, an outline color, a polygon edges type(0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you want
    */
   GlComplexPolygon(const std::vector<Coord> &coords,Color fcolor,Color ocolor,int polygonEdgesType=0,const std::string &textureName = "");
-
   /**
-   * Constructor with a vector of vector of coords (the first vector of coord is the polygon and others vectors are holes in polygon), a fill color,
-   * a polygon edges type(0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you want
+   * @brief Constructor with a vector of vector of coords (the first vector of coord is the polygon and others vectors are holes in polygon), a fill color, a polygon edges type(0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you want
    */
   GlComplexPolygon(const std::vector<std::vector<Coord> >&coords,Color fcolor,int polygonEdgesType=0,const std::string &textureName = "");
-
   /**
-   * Constructor with a vector of vector of coords (the first vector of coord is the polygon and others vectors are holes in polygon), a fill color, an outline color
-   * a polygon edges type(0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you want
+   * @brief Constructor with a vector of vector of coords (the first vector of coord is the polygon and others vectors are holes in polygon), a fill color, an outline color a polygon edges type(0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you want
    */
   GlComplexPolygon(const std::vector<std::vector<Coord> >&coords,Color fcolor,Color ocolor,int polygonEdgesType=0,const std::string &textureName = "");
 
   virtual ~GlComplexPolygon() {}
 
   /**
-   * Define polygon according to one contour and compute tesselation.
-   *
-   * Use this method if your polygon is defined by one contour.
-   * This method resets any previously defined contours and recompute tesselation.
-   *
-   * \param contour a vector of tlp::Coord defining the contour.
-   * \param polygonEdgesType an integer determining the shape of the polygon edges (0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves)
-   */
-  void setPolygonContour(const std::vector<Coord> &contour, int polygonEdgesType=0);
-
-  /**
-   * Define polygon according to several contours and compute tesselation.
-   *
-   * Use this method if your polygon is defined by several contours (e.g. polygon with holes).
-   * This method resets any previously defined contours and recompute tesselation.
-   *
-   * \param contours a vector of vector of tlp::Coord defining the different contours.
-   * \param polygonEdgesType an integer determining the shape of the polygon edges (0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves)
-   */
-  void setPolygonContours(const std::vector<std::vector<Coord> > &contours, int polygonEdgesType=0);
-
-  /**
-   * Returns the contours defining the polygon.
-   */
-  const std::vector<std::vector<Coord> > &getPolygonContours() const;
-
-  /**
-   * Draw the complex polygon
+   * @brief Draw the complex polygon
    */
   virtual void draw(float lod,Camera *camera);
 
   /**
-   * Set if the polygon is outlined or not
+   * @brief Set if the polygon is outlined or not
    */
   void setOutlineMode(const bool);
 
   /**
-   * Set size of outline
+   * @brief Set size of outline
    */
   void setOutlineSize(double size);
 
   /**
-   * Get fill color of GlComplexPolygon
+   * @brief Get fill color of GlComplexPolygon
    */
-  Color getFillColor() {
+  Color getFillColor() const {
     return fillColor;
   }
 
   /**
-   * Set fill color of GlComplexPolygon
+   * @brief Set fill color of GlComplexPolygon
    */
   void setFillColor(const Color &color) {
     fillColor=color;
   }
 
   /**
-   * Get outline color of GlComplexPolygon
+   * @brief Get outline color of GlComplexPolygon
    */
-  Color getOutlineColor() {
+  Color getOutlineColor() const {
     return outlineColor;
   }
 
   /**
-   * Set outline color of GlComplexPolygon
+   * @brief Set outline color of GlComplexPolygon
    */
   void setOutlineColor(const Color &color) {
     outlineColor=color;
   }
 
   /**
-   * Get the texture zoom factor
+   * @brief Get the texture zoom factor
    */
   float getTextureZoom() {
     return textureZoom;
   }
 
   /**
-   * Get the textureName
-   */
-  std::string getTextureName();
-
-  /**
-   * Set the textureName
-   */
-  void setTextureName(const std::string &name);
-
-  /**
-   * Set the texture zoom factor
+   * @brief Set the texture zoom factor
+   *
    * By default if you have a polygon with a size bigger than (1,1,0) the texture will be repeated
    * If you want to don't have this texture repeat you have to modify texture zoom
    * For example if you have a polygon with coords ((0,0,0),(5,0,0),(5,5,0),(0,5,0)) you can set texture zoom to 5. to don't have texture repeat
@@ -239,34 +197,74 @@ public:
   }
 
   /**
-   * Translate entity
+   * @brief Get the textureName
+   */
+  std::string getTextureName();
+
+  /**
+   * @brief Set the textureName
+   */
+  void setTextureName(const std::string &name);
+
+  /**
+   * @brief Draw a thick (textured) border around the polygon.
+   *
+   * The graphic card must support geometry shader to make this feature to work.
+   * The position parameter determines the way the border is drawn (depending on the polygon points ordering):
+   *     - 0 : the border is drawn outside (or inside) the polygon
+   *     - 1 : the border is centered on the polygon outline
+   *     - 2 : the border is drawn inside (or outside) the polygon
+   *
+   * The texCoordFactor parameter determines the way the texture is applied : if < 1, the texture will be expanded and > 1, the texture will be compressed
+   * The polygonId parameter determines on which contour of the polygon, the border will be applied
+   */
+  void activateQuadBorder(const float borderWidth, const Color &color, const std::string &texture = "", const int position = 1,
+                          const float texCoordFactor = 1.f, const int polygonId = 0);
+
+  /**
+   * @brief Desactivate the textured quad border
+   */
+  void desactivateQuadBorder(const int polygonId = 0);
+
+  QStringList propertiesNames() const;
+
+  QVariantList propertiesQVariant() const;
+
+  void setProperty(const QString &name, const QVariant &value);
+
+  /**
+   * @brief Translate entity
    */
   virtual void translate(const Coord& mouvement);
 
   /**
-   * Function to export data and type in XML
+   * @brief Function to export data and type outString (in XML format)
    */
-  virtual void getXML(xmlNodePtr rootNode);
+  virtual void getXML(std::string &outString);
 
   /**
-   * Function to export data in XML
+   * @brief Function to export data in outString (in XML format)
    */
-  virtual void getXMLOnlyData(xmlNodePtr rootNode);
+  virtual void getXMLOnlyData(std::string &outString);
 
   /**
-   * Function to set data with XML
+   * @brief Function to set data with inString (in XML format)
    */
-  virtual void setWithXML(xmlNodePtr rootNode);
+  virtual void setWithXML(const std::string &inString, unsigned int &currentPosition);
+
+  const std::vector<std::vector<Coord> > &getPolygonSides() const {
+    return points;
+  }
 
 
 protected:
 
   /**
-   * Add a new point in polygon
+   * @brief Add a new point in polygon
    */
   virtual void addPoint(const Coord& point);
   /**
-   * Begin a new hole in the polygon
+   * @brief Begin a new hole in the polygon
    */
   virtual void beginNewHole();
 
@@ -277,13 +275,13 @@ protected:
   void addVertex(const Coord &vertexCoord, const Vec2f &vertexTexCoord);
   VERTEX *allocateNewVertex();
 
-  std::vector<std::vector<Coord> > polygonContours;
   std::vector<std::vector<Coord> > points;
+  std::vector<std::vector<GLfloat> > pointsIdx;
   std::set<GLenum> primitivesSet;
   std::map<GLenum, std::vector<Coord> > verticesMap;
   std::map<GLenum, std::vector<Vec2f> > texCoordsMap;
-  std::map<GLenum, std::vector<int> > startIndicesMap;
-  std::map<GLenum, std::vector<int> > verticesCountMap;
+  std::map<GLenum, std::vector<int> >startIndicesMap;
+  std::map<GLenum, std::vector<int> >verticesCountMap;
   std::vector<VERTEX *> allocatedVertices;
   GLenum currentPrimitive;
   int nbPrimitiveVertices;
@@ -294,7 +292,13 @@ protected:
   double outlineSize;
   std::string textureName;
   float textureZoom;
+  std::vector<bool> quadBorderActivated;
+  std::vector<float> quadBorderWidth;
+  std::vector<Color> quadBorderColor;
+  std::vector<std::string> quadBorderTexture;
+  std::vector<int> quadBorderPosition;
+  std::vector<float> quadBorderTexFactor;
 };
-/*@}*/
+
 }
 #endif
