@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,13 +16,12 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLCOMPLEXEENTITY_H
 #define Tulip_GLCOMPLEXEENTITY_H
 
-#include <vector>
-
 #include <tulip/BoundingBox.h>
-
 #include <tulip/GlEntity.h>
 
 namespace tlp {
@@ -45,19 +44,20 @@ public:
   /**
    * return the bounding box of this entity
    */
-  virtual BoundingBox getBoundingBox(GlGraphInputData* data) = 0;
+  virtual BoundingBox getBoundingBox(const GlGraphInputData* data) = 0;
 
   /**
    * Draw this entity with GlGraphInputData and Camera
    */
-  virtual void draw(float lod,GlGraphInputData* data,Camera* camera) = 0;
+  virtual void draw(float lod,const GlGraphInputData* data,Camera* camera) = 0;
 
   /**
    * Draw label of this entity
    */
-  virtual void drawLabel(OcclusionTest* test,GlGraphInputData* data) = 0;
+  virtual void drawLabel(OcclusionTest* test,const GlGraphInputData* data) = 0;
 };
 
 }
 
 #endif // Tulip_GLCOMPLEXEENTITY_H
+///@endcond
