@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,20 +16,20 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef GLCONVEXGRAPHHULL_H_
 #define GLCONVEXGRAPHHULL_H_
 
-#include <tulip/ObservableGraph.h>
 #include <tulip/Color.h>
-#include <tulip/ObservableProperty.h>
+#include <tulip/tulipconf.h>
 
 namespace tlp {
 
 class GlComposite;
 class GlSimpleEntity;
 class Camera;
-class Coord;
 class Graph;
 class LayoutProperty;
 class SizeProperty;
@@ -84,3 +84,4 @@ private:
 }
 
 #endif /* GLCONVEXGRAPHHULL_H_ */
+///@endcond
