@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,20 +16,20 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef GL_CONVEX_HULL_H
 #define GL_CONVEX_HULL_H
 
 #include <vector>
-#include <tulip/BoundingBox.h>
-#include <tulip/Graph.h>
-#include <tulip/Color.h>
-#include <tulip/Coord.h>
 
+#include <tulip/Color.h>
 #include <tulip/GlComposite.h>
 
 namespace tlp {
 
 struct ConvexHullItem;
+class Graph;
 
 /** \brief Class used to represent ConvexHull
  *
@@ -89,7 +89,7 @@ public:
       std::vector<Color> fColors,
       std::vector<Color> oColors,
       bool deduceFromChilds = true,
-      Graph *root = 0,
+      Graph *root = NULL,
       unsigned int depth = 0);
 
   /**
@@ -98,14 +98,14 @@ public:
   virtual void translate(const Coord& mouvement);
 
   /**
-   * Get the data in XML form
+   * Function to export data in outString (in XML format)
    */
-  void getXML(xmlNodePtr rootNode);
+  virtual void getXML(std::string &outString);
 
   /**
-   * Set the data with XML
+   * Function to set data with inString (in XML format)
    */
-  void setWithXML(xmlNodePtr rootNode);
+  virtual void setWithXML(const std::string &inString, unsigned int &currentPosition);
 
   tlp::Graph *_graph;
 
@@ -127,3 +127,4 @@ struct ConvexHullItem {
 
 }
 #endif
+///@endcond
