@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,13 +16,12 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef Tulip_GLCURVE_H
 #define Tulip_GLCURVE_H
 
-#include <tulip/Color.h>
-#include <tulip/Coord.h>
-
 #include <tulip/GlSimpleEntity.h>
 
 namespace tlp {
@@ -76,14 +75,14 @@ public:
   virtual void translate(const Coord& mouvement);
 
   /**
-   * Function to export data in XML
+   * Function to export data in outString (in XML format)
    */
-  virtual void getXML(xmlNodePtr rootNode);
+  virtual void getXML(std::string &outString);
 
   /**
-   * Function to set data with XML
+   * Function to set data with inString (in XML format)
    */
-  virtual void setWithXML(xmlNodePtr rootNode);
+  virtual void setWithXML(const std::string &inString, unsigned int &currentPosition);
 
 protected:
   std::vector<tlp::Coord> _points;
@@ -95,3 +94,4 @@ protected:
 };
 }
 #endif
+///@endcond
