@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,16 +16,29 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLDISPLAYLISTMANAGER_H
 #define Tulip_GLDISPLAYLISTMANAGER_H
 
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
+
 #include <map>
-#include <cassert>
 #include <string>
 
-#include <tulip/OpenGlConfigManager.h>
-#include <tulip/tulipconf.h>
+#include <stdint.h>
 
+#include <tulip/tulipconf.h>
 
 namespace tlp {
 
@@ -37,7 +50,7 @@ namespace tlp {
 class TLP_GL_SCOPE GlDisplayListManager {
 
   typedef std::map<std::string,GLuint> DisplayListMap;
-  typedef std::map<unsigned long, DisplayListMap> ContextAndDisplayListMap;
+  typedef std::map<uintptr_t, DisplayListMap> ContextAndDisplayListMap;
 
 public:
 
@@ -54,12 +67,12 @@ public:
   /**
    * Change OpenGl context because display list can't be shared in different context
    */
-  void changeContext(unsigned long context);
+  void changeContext(uintptr_t context);
 
   /**
    * remove context
    */
-  void removeContext(unsigned long context);
+  void removeContext(uintptr_t context);
 
   /**
    * Begin to record a new display list with name : name
@@ -82,7 +95,7 @@ private:
    */
   GlDisplayListManager() {}
 
-  unsigned long currentContext;
+  uintptr_t currentContext;
 
   static GlDisplayListManager* inst;
 
@@ -93,3 +106,4 @@ private:
 }
 
 #endif // Tulip_GLDISPLAYLISTMANAGER_H
+///@endcond
