@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,15 +16,17 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLEPSFEEDBACKBUILDER_H
 #define Tulip_GLEPSFEEDBACKBUILDER_H
 #ifndef DOXYGEN_NOTFOR_DEVEL
 
-#include <tulip/tulipconf.h>
-
 #include <sstream>
 
 #include <tulip/GlTLPFeedBackBuilder.h>
+#include <tulip/tulipconf.h>
+#include <tulip/Color.h>
 
 namespace tlp {
 
@@ -108,9 +110,7 @@ private:
 
   std::stringstream stream_out;
 
-  GLfloat clearColor[4];
   GLfloat pointSize;
-  GLfloat lineWidth;
 
   Color fillColor;
   Color strokeColor;
@@ -123,3 +123,4 @@ private:
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif // Tulip_GLEPSFEEDBACKBUILDER_H
+///@endcond
