@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,22 +16,24 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLEDGE_H
 #define Tulip_GLEDGE_H
 
 #ifndef DOXYGEN_NOTFOR_DEVEL
-#include <tulip/OpenGlConfigManager.h>
 
 #include <tulip/PropertyTypes.h>
-
+#include <tulip/Size.h>
 #include <tulip/GlComplexeEntity.h>
-#include <tulip/EdgeExtremityGlyph.h>
+#include <tulip/Matrix.h>
 
 namespace tlp {
 
 struct OcclusionTest;
 class TextRenderer;
 class GlLabel;
+class EdgeExtremityGlyph;
 
 /**
  * Class to represent an edge of a graph
@@ -54,63 +56,60 @@ public:
   /**
    * Return the edge bounding box
    */
-  virtual BoundingBox getBoundingBox(GlGraphInputData* data);
+  virtual BoundingBox getBoundingBox(const GlGraphInputData* data);
 
   /**
    * Draw the edge with level of detail : lod and Camera : camera
    */
-  virtual void draw(float lod,GlGraphInputData *data,Camera* camera);
+  virtual void draw(float lod,const GlGraphInputData *data,Camera* camera);
 
   /**
    * Draw the label of the edge if drawEdgesLabel is true and if label selection is equal to drawSelect
    * Use TextRenderer : renderer to draw the label
    */
-  void drawLabel(bool drawSelect,OcclusionTest* test,GlGraphInputData* data, float lod);
+  void drawLabel(bool drawSelect,OcclusionTest* test,const GlGraphInputData* data, float lod);
 
   /**
    * Draw the label of the edge if drawEdgesLabel is true
    * Use TextRenderer : renderer to draw the label
    */
-  void drawLabel(OcclusionTest* test,GlGraphInputData* data);
+  void drawLabel(OcclusionTest* test,const GlGraphInputData* data);
 
   /**
    * Draw the label of the edge if drawEdgesLabel is true
    * Use TextRenderer : renderer to draw the label
    */
-  void drawLabel(OcclusionTest* test,GlGraphInputData* data, float lod, Camera *camera=NULL);
-
-  /**
-   * Deprecate function : see others drawLabel functions
-   */
-  virtual _DEPRECATED void drawLabel(OcclusionTest *test, TextRenderer*, GlGraphInputData* data) {
-    drawLabel(test,data);
-  }
+  void drawLabel(OcclusionTest* test,const GlGraphInputData* data, float lod, Camera *camera=NULL);
 
   /**
    * This function is used by the engine to get line coordinates of the edge
    */
-  void getVertices(GlGraphInputData *data,std::vector<Coord> &linesCoordsArray);
+  void getVertices(const GlGraphInputData *data,std::vector<Coord> &linesCoordsArray);
 
   /**
    * This function is used by the engine to get line colors of the edge
    */
-  void getColors(GlGraphInputData *data,const Coord *vertices,unsigned int numberOfVertices,std::vector<Color> &linesColorsArray);
+  void getColors(const GlGraphInputData *data,const Coord *vertices,unsigned int numberOfVertices,std::vector<Color> &linesColorsArray);
   /**
    * This function is used by the engine to get line colors of the edge
    */
-  void getColors(GlGraphInputData *data,const std::vector<Coord> &vertices,std::vector<Color> &linesColorsArray);
+  void getColors(const GlGraphInputData *data,const std::vector<Coord> &vertices,std::vector<Color> &linesColorsArray);
 
   /**
    * Compute the edge size
    */
-  void getEdgeSize(GlGraphInputData *data,edge e,const Size &srcSize, const Size &tgtSize,const float maxSrcSize,const float maxTgtSize,Size &edgeSize);
+  void getEdgeSize(const GlGraphInputData *data,edge e,const Size &srcSize, const Size &tgtSize,const float maxSrcSize,const float maxTgtSize,Size &edgeSize);
+
+  /**
+   * Compute edge anchor
+   */
+  void getEdgeAnchor(const GlGraphInputData *data,const node &source,const node &target,const LineType::RealType &bends,const Coord &srcCoord,const Coord &tgtCoord,const Size &srcSize,const Size &tgtSize, Coord &srcAnchor, Coord &tgtAnchor);
 
   /**
    * This function must be called before each graph rendering
    * This function clears previously compute edgeWidthLod
-   * FIXME remove the unused bool (was named orthoProjection) ?
    */
-  static void clearEdgeWidthLodSystem(bool) {
+  static void clearEdgeWidthLodSystem() {
     haveToComputeEdgeWidthBaseLod=true;
   }
 
@@ -120,7 +119,6 @@ private :
 
   static GlLabel *label;
   static bool haveToComputeEdgeWidthBaseLod;
-  static bool orthoProjection;
   static float edgeWidthBaseLod;
 
   /**
@@ -129,8 +127,7 @@ private :
   void drawEdge(const Coord &srcNodePos, const Coord &tgtNodePos,
                 const Coord &startPoint, const Coord &endPoint, const LineType::RealType &bends,
                 const Color &startColor, const Color &endColor, const Coord &lookDir, bool colorInterpolate, const Color &borderColor,
-                const Size &size, int shape, bool edge3D, float lod,
-                const std::string &textureName, const float outlineWidth, bool polylines3DAreBicolored);
+                const Size &size, int shape, bool edge3D, float lod,const std::string &textureName, const float outlineWidth);
 
   /**
    * Function used to compute bounding box for edge extremity.
@@ -142,7 +139,7 @@ private :
    * Compute the edge colors and store these colors in srcCol and tgtCol
    * \param data : input data used to compute edge colors
    */
-  void getEdgeColor(GlGraphInputData *data,const edge &e,const node &source,const node &target, bool selected,Color &srcCol, Color &tgtCol);
+  void getEdgeColor(const GlGraphInputData *data,const edge &e,const node &source,const node &target, bool selected,Color &srcCol, Color &tgtCol);
 
 
 
@@ -152,17 +149,12 @@ private :
    */
   float getEdgeWidthLod(const Coord &edgeCoord,const Size &edgeSize,Camera *camera);
 
-  /**
-   * Compute edge anchor
-   */
-  void getEdgeAnchor(GlGraphInputData *data,const node &source,const node &target,const LineType::RealType &bends,const Coord &srcCoord,const Coord &tgtCoord,const Size &srcSize,const Size &tgtSize, Coord &srcAnchor, Coord &tgtAnchor);
-
   /**
    * Thgis function is used to render edge arrows
    */
-  void displayArrow(GlGraphInputData *data,const edge &e,const node &source,const Size &sizeRatio,float edgeSize,const Color &color,float maxSize,bool selected,float selectionOutlineSize,
-                    int srcEdgeGlyph,int tgtEdgeGlyph,size_t numberOfBends,const Coord &anchor,const Coord &tgtCoord,
-                    const Coord &srcAnchor,const Coord &tgtAnchor,Coord &lineAnchor);
+  void displayArrowAndAdjustAnchor(const GlGraphInputData *data,const edge &e,const node &source,const Size &sizeRatio,float edgeSize,const Color &color,float maxSize,bool selected,float selectionOutlineSize,
+                                   int tgtEdgeGlyph,size_t numberOfBends,const Coord &anchor,const Coord &tgtCoord,
+                                   const Coord &srcAnchor,const Coord &tgtAnchor,Coord &lineAnchor, EdgeExtremityGlyph* srcEdgeGlyph = NULL, Camera *camera = NULL);
 
 };
 
@@ -171,3 +163,4 @@ private :
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif // Tulip_GLEDGE_H
+///@endcond
