@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,11 +16,11 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLENTITY_H
 #define Tulip_GLENTITY_H
 
-#include <utility>
-
 #include <tulip/tulipconf.h>
 
 namespace tlp {
@@ -47,3 +47,4 @@ public:
 }
 
 #endif // Tulip_GLENTITY_H
+///@endcond
