@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,14 +16,24 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLFEEDBACKBUILDER_H
 #define Tulip_GLFEEDBACKBUILDER_H
 
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
+
 #include <tulip/tulipconf.h>
-
-#include <string>
-#include <tulip/OpenGlConfigManager.h>
-
 #include <tulip/Vector.h>
 
 namespace tlp {
@@ -73,3 +83,4 @@ public:
 }
 
 #endif // Tulip_GLFEEDBACKBUILDER_H
+///@endcond
