@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,6 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLGRAPHSTATICDATA_H
 #define Tulip_GLGRAPHSTATICDATA_H
 
@@ -25,8 +27,6 @@
 
 namespace tlp {
 
-enum EdgeShape {POLYLINESHAPE = 0, BEZIERSHAPE = 4, SPLINESHAPE = 8, CUBICBSPLINE=16};
-
 class TLP_GL_SCOPE GlGraphStaticData {
 
 public:
@@ -46,3 +46,4 @@ public:
 }
 
 #endif // Tulip_GLGRAPHSTATICDATA_H
+///@endcond
