@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,14 +16,15 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLLODCALCULATOR_H
 #define Tulip_GLLODCALCULATOR_H
 #ifndef DOXYGEN_NOTFOR_DEVEL
 
-#include <tulip/tulipconf.h>
+#include <tulip/BoundingBox.h>
 
-#include <tulip/Matrix.h>
-#include <tulip/Vector.h>
+#include <vector>
 
 namespace tlp {
 
@@ -78,7 +79,7 @@ class TLP_GL_SCOPE GlLODCalculator {
 
 public:
 
-  GlLODCalculator():glScene(NULL),inputData(NULL) {}
+  GlLODCalculator():glScene(NULL),inputData(NULL),attachedLODCalculator(NULL) {}
   virtual ~GlLODCalculator() {}
   virtual GlLODCalculator *clone()=0;
 
@@ -92,7 +93,7 @@ public:
   /**
    * Set input data use to render
    */
-  virtual void setInputData(GlGraphInputData *inputData) {
+  virtual void setInputData(const GlGraphInputData *inputData) {
     this->inputData=inputData;
   }
 
@@ -161,14 +162,20 @@ public:
 
   virtual BoundingBox getSceneBoundingBox()=0;
 
+  void setAttachedLODCalculator(GlLODCalculator *calculator) {
+    attachedLODCalculator=calculator;
+  }
+
 protected :
 
   GlScene *glScene;
-  GlGraphInputData *inputData;
+  const GlGraphInputData *inputData;
 
   RenderingEntitiesFlag renderingEntitiesFlag;
 
   LayersLODVector layersLODVector;
+
+  GlLODCalculator *attachedLODCalculator;
 };
 
 }
@@ -176,3 +183,4 @@ protected :
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif // Tulip_GLLODCALCULATOR_H
+///@endcond
