@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,16 +16,12 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLLODSCENEVISITOR_H
 #define Tulip_GLLODSCENEVISITOR_H
 #ifndef DOXYGEN_NOTFOR_DEVEL
 
-
-#include <vector>
-#include <map>
-
-#include <tulip/BoundingBox.h>
-
 #include <tulip/GlSceneVisitor.h>
 
 namespace tlp {
@@ -43,7 +39,7 @@ public:
   /**
    * Basic constructor
    */
-  GlLODSceneVisitor(GlLODCalculator *calculator,GlGraphInputData* inputData)
+  GlLODSceneVisitor(GlLODCalculator *calculator,const GlGraphInputData* inputData)
     : calculator(calculator),inputData(inputData) {
     threadSafe=true;
   }
@@ -78,7 +74,7 @@ public:
 private:
 
   GlLODCalculator* calculator;
-  GlGraphInputData* inputData;
+  const GlGraphInputData* inputData;
 
 };
 
@@ -87,3 +83,4 @@ private:
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif // Tulip_GLLODSCENEVISITOR_H
+///@endcond
