@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,250 +16,252 @@
  * See the GNU General Public License for more details.
  *
  */
+
 #ifndef Tulip_GLLABEL_H
 #define Tulip_GLLABEL_H
 
-#include <string>
-#include <map>
-
 #include <tulip/Coord.h>
 #include <tulip/Color.h>
 #include <tulip/Size.h>
-
+#include <tulip/Camera.h>
 #include <tulip/GlSimpleEntity.h>
+#include <tulip/TulipViewSettings.h>
 
 class FTGLPolygonFont;
 class FTOutlineFont;
 
 namespace tlp {
 
-class Camera;
 struct OcclusionTest;
 
-enum LabelPosition {ON_CENTER = 0, ON_TOP = 1, ON_BOTTOM = 2, ON_LEFT = 3, ON_RIGHT = 4};
+#define MIN_LABEL_POSITION LabelPosition::Center
+#define MAX_LABEL_POSITION LabelPosition::Right
 
 /**
- * \addtogroup GlEntities
- */
-/*@{*/
-/**
- * Create a entity Label
+ * @ingroup OpenGL
+ * @brief Create a label into Tulip 3D engine
+ *
+ * The shortes way to create a label is :
+ * @code
+ * GlLabel *label=new GlLabel(Coord(0,0,0), Size (1,1,1), Color(1,1,1));
+ * label->setText("example");
+ * @endcode
  */
 class TLP_GL_SCOPE GlLabel : public GlSimpleEntity {
 public :
 
+  /**
+   * @brief Constructor
+   * @warning Don't use this constructor : see other constructor
+   */
   GlLabel();
 
   /**
-   * Contructor with fontPath, centerPosition, size, fontColor and alignment
-   * Use GlLabel(Coord centerPosition,Size size,Color fontColor,bool leftAlign=false) instead.
-   */
-  _DEPRECATED GlLabel(Coord centerPosition,Coord size,Color fontColor,bool leftAlign=false);
-
-  /**
-   * Contructor with fontPath, centerPosition, size, fontColor and alignment
+   * @brief Contructor
+   * @param centerPosition position of the label
+   * @param size size of the label
+   * @param fontColor color of the label
+   * @param leftAlign true if you want a left align label
    */
   GlLabel(Coord centerPosition,Size size,Color fontColor,bool leftAlign=false);
 
   /**
-   * Contructor with fontPath, centerPosition, size, fontColor and alignment
-   * \deprecate this constructor will be remove on Tulip 4 version
+   * @brief Destructor
    */
-  _DEPRECATED GlLabel(const std::string &fontPath,Coord centerPosition,Coord size,Color fontColor,bool leftAlign=false);
-
   ~GlLabel();
 
   /**
-   * Set default parameters of GlLabel
+   * @brief Set default parameters of GlLabel
+   *
+   * This function is call by constructor, so you don't have to call it
    */
   void init();
 
   /**
-   * Set the text of the label
+   * @brief Set the text of the label
    */
   void setText(const std::string& text);
 
-  std::string getText() const;
+  /**
+   * @brief getText gets the text of this label.
+   * @return The text of this label.
+   */
+  const std::string& getText() const;
 
   /**
-   * Set the position used to render the label
+   * @brief Set the position used to render the label
    */
   void setPosition(const Coord &position);
 
   /**
-   * Return the position of the label
+   * @brief Return the position of the label
    */
   Coord getPosition();
 
+  ///@cond DOXYGEN_HIDDEN
+
   /**
-   * Set the translation used after rotation of the label
+   * @brief Set the translation used after rotation of the label
    */
   virtual void setTranslationAfterRotation(Coord translation) {
     translationAfterRotation=translation;
   }
 
   /**
-   * return the translation used after rotation of the label
+   * @brief return the translation used after rotation of the label
    */
   virtual Coord getTranslationAfterRotation() {
     return translationAfterRotation;
   }
 
+  ///@endcond
+
   /**
-   * Set the alignment of the label : ON_CENTER, ON_TOP, ON_BOTTOM, ON_LEFT, ON_RIGHT
+   * @brief Set the alignment of the label : LabelPosition::Center, LabelPosition::Top, LabelPosition::Bottom, LabelPosition::Left, LabelPosition::Right
+   * This function is usefull when you have an entity : you spesify the size of the position of this entity and you tell that you want a label outside this entity
+   * @see LabelPosition
+   * @see setSizeOfOutAlign
    */
   virtual void setAlignment(int alignment) {
     this->alignment=alignment;
   }
 
   /**
-   * Return the bounding box of the label
+   * @brief Return the bounding box of the label
    */
   virtual BoundingBox getBoundingBox();
 
   /**
-   * Return the bounding box of the text of the label
+   * @brief Return the bounding box of the text of the label after transformations
    */
   virtual BoundingBox getTextBoundingBox();
 
   /**
-    * Use setSize(const Size& size instead)
-    **/
-  virtual _DEPRECATED void setSize(const Coord& size);
-
-  /**
-   * Set the size of the label
+   * @brief Set the size of the label
    */
   virtual void setSize(const Size &size);
 
   /**
-   * return the size of the text.
-   * Deprecated use getLabelSize instead.
+   * @brief return the size of the text
    */
-  virtual Coord _DEPRECATED getSize();
+  virtual Size getSize();
 
   /**
-    * return the size of the text.
-    **/
-  virtual Size getLabelSize() const;
-
-  /**
-   * Set the size for alignment outside (left/right/top/bottom)
-   *  Warning : this size is reinit when you call setSize
+   * @brief Set the size for alignment outside (left/right/top/bottom)
+   *
+   * You can have a specific size when you want a label outside
+   * @see setAlignment
+   *
+   * @Warning : this size is reinit when you call setSize
    */
   virtual void setSizeForOutAlign(const Size &size);
 
   /**
-   * Set the size for alignment outside (left/right/top/bottom)
-   *  Warning : this size is reinit when you call setSize
-   * Deprecated use setSizeForOutAlign(const Size &size) instead
+   * @brief return the size for alignment outside (left/right/top/bottom)
+   * @see setAlignment
    */
-  virtual void _DEPRECATED setSizeForOutAlign(const Coord &size);
+  virtual Size getSizeForOutAlign();
 
   /**
-   * return the size for alignment outside (left/right/top/bottom)
-   * Deprecated use getLabelSizeForOutAlign() instead
-   */
-  virtual Coord _DEPRECATED getSizeForOutAlign();
-
-  /**
-   * return the size for alignment outside (left/right/top/bottom)
-   */
-  virtual Size getLabelSizeForOutAlign()const;
-
-  /**
-   * Set color of label
+   * @brief Set color of label
    */
   virtual void setColor(const Color &color) {
     this->color=color;
   }
 
   /**
-   * Get color use to render the label
+   * @brief Get color use to render the label
    */
   virtual Color getColor() {
     return color;
   }
 
   /**
-   * Enable/disable the depth test for the label (default depth test is enable)
+   * @brief Enable/disable the OpenGL depth test for the label (default depth test is enable)
    */
   virtual void enableDepthTest(bool state) {
     depthTestEnabled=state;
   }
 
   /**
-   * Enable/disable if label is scaled to size
+   * @brief Enable/disable if label is scaled to size
    */
   virtual void setScaleToSize(bool state) {
     scaleToSize=state;
   }
 
   /**
-   * Set the stencil and draw the Label, this function is usefull when we directly call draw without tulip engine
+   * @brief Set the stencil and draw the Label, this function is usefull when we directly call draw without tulip engine
    */
-  void drawWithStencil(float lod, Camera *camera=NULL);
+  void drawWithStencil(float lod,Camera *camera=NULL);
 
   /**
-   * Draw the Label
+   * @brief Return the height of the label after scaling in  size box
    */
-  virtual void draw(float lod, Camera *camera=NULL);
+  float getHeightAfterScale();
 
   /**
-   * Translate entity
+   * @brief Draw the Label
+   */
+  virtual void draw(float, Camera *camera=NULL);
+
+  /**
+   * @brief Translate entity
    */
   virtual void translate(const Coord& mouvement);
 
   /**
-   * Rotate Label
+   * @brief Rotate Label
    */
   virtual void rotate(float xRot, float yRot, float zRot);
 
   /**
-   * Function to export data in XML
+   * @brief Function to export data in outString (in XML format)
    */
-  virtual void getXML(xmlNodePtr rootNode);
+  virtual void getXML(std::string &outString);
 
   /**
-   * Function to set data with XML
+   * @brief Function to set data with inString (in XML format)
    */
-  virtual void setWithXML(xmlNodePtr rootNode);
+  virtual void setWithXML(const std::string &inString, unsigned int &currentPosition);
 
   /**
-   * Switch to bold font
+   * @brief Switch to bold font
    */
   virtual void setBoldFont();
 
   /**
-   * Switch to plain font
+   * @brief Switch to plain font
    */
   virtual void setPlainFont();
 
   /**
-   * Change font name
+   * @brief Change font name
    */
   virtual void setFontName(const std::string &name);
 
   /**
-   * Change font name, size and color of the text
+   * @brief Change font name, size and color of the text
    */
   virtual void setFontNameSizeAndColor(const std::string &name, const int &size, const Color &color);
 
+  ///@cond DOXYGEN_HIDDEN
   /**
-   * Switch rendering mode to polygon- or texture-based rendering
+   * @brief This parameters is not used
    */
   virtual void setRenderingMode(int mode);
+  ///@endcond
 
   /**
-   * Set the occlusion tester
-   *  If occlusionTester is NULL : deactivate occlusion test
+   * @brief Set the occlusion tester
+   * If occlusionTester is NULL : deactivate occlusion test
    */
   virtual void setOcclusionTester(OcclusionTest *tester) {
     occlusionTester=tester;
   }
 
   /**
-   * Set if the label is otimized with the lod
+   * @brief Set if the label is otimized with the lod
    */
   virtual void setUseLODOptimisation(bool state,BoundingBox bb=BoundingBox()) {
     useLOD=state;
@@ -267,31 +269,19 @@ public :
   }
 
   /**
-   * Return label border for occlusion test
+   * @brief Return if the label is otimized with the lod
    */
   virtual bool getUseLODOptimisation() {
     return useLOD;
   }
 
   /**
-   * Set label border for occlusion test
-   * \deprecated Use setLabelsDensity instead
-   */
-  virtual void setLabelOcclusionBorder(int size) {
-    labelsDensity=-size;
-  }
-
-  /**
-   * Return label border for occlusion test
-   * \deprecated Use getLabelsDensity instead
-   */
-  virtual int getLabelOcclusionBorder() {
-    return -labelsDensity;
-  }
-
-  /**
-   * Set labels density of occlusion test
+   * @brief Set labels density of occlusion test
    * This density must be in interval -100 100
+   *
+   * - If density is equal to -100 : we don't have occlusion test
+   * - If density is equal to 0 : GlLabels don't overlap
+   * - If density > 0 : GlLabels don't overlap and have space wetween us
    */
   virtual void setLabelsDensity(int density) {
     if(density<-100)
@@ -303,57 +293,61 @@ public :
   }
 
   /**
-   * Return label density of occlusion test
-   * This density must be in interval -100 100
+   * @brief Return label density of occlusion test
+   * This density will be in interval -100 100
    */
   virtual int getLabelDensity() {
     return labelsDensity;
   }
 
   /**
-   * Set min screen size (in pixel) of the label : this size is used in not scaled mode
+   * @brief Set min screen size (in pixel) of the label : this size is used in not scaled mode
+   * @see setUseMinMaxSize
    */
   void setMinSize(int size) {
     minSize=size;
   }
 
   /**
-   * Get min screen size (in pixel) of the label : this size is used in not scaled mode
+   * @brief Get min screen size (in pixel) of the label : this size is used in not scaled mode
+   * @see setUseMinMaxSize
    */
   int getMinSize() {
     return minSize;
   }
 
   /**
-   * Set max screen size (in pixel) of the label : this size is used in not scaled mode
+   * @brief Set max screen size (in pixel) of the label : this size is used in not scaled mode
+   * @see setUseMinMaxSize
    */
   void setMaxSize(int size) {
     maxSize=size;
   }
 
   /**
-   * Get max screen size (in pixel) of the label : this size is used in not scaled mode
+   * @brief Get max screen size (in pixel) of the label : this size is used in not scaled mode
+   * @see setUseMinMaxSize
    */
   int getMaxSize() {
     return maxSize;
   }
 
   /**
-   * Set if the label use min/max screen size in not scaled mode
+   * @brief Set if the label use min/max screen size in not scaled mode
    */
   void setUseMinMaxSize(bool state) {
     useMinMaxSize=state;
   }
 
   /**
-   * Return if the label using min/max screen size in not scaled mode
+   * @brief Return if the label using min/max screen size in not scaled mode
    */
   bool isUsingMinMaxSize() {
     return useMinMaxSize;
   }
 
   /**
-   * @return the font size
+   * @brief Return the font size
    */
   int getFontSize() const {
     return fontSize;
@@ -367,7 +361,7 @@ public :
   }
 
   /**
-   * @return the outline color
+   * @brief Return the outline color
    */
   Color getOutlineColor() const {
     return outlineColor;
@@ -381,7 +375,7 @@ public :
   }
 
   /**
-   * @return the outline size
+   * @brief Return the outline size
    */
   float getOutlineSize() const {
     return outlineSize;
@@ -395,7 +389,7 @@ public :
   }
 
   /**
-   * @return the texture name used to render the label
+   * @brief Return the texture name used to render the label
    */
   std::string getTextureName() const {
     return textureName;
@@ -409,7 +403,7 @@ public :
   }
 
   /**
-   * @return if the label is billboarded
+   * @brief Return if the label is billboarded
    */
   bool isBillboarded() {
     return billboarded;
@@ -424,8 +418,6 @@ public :
 
 private :
 
-  void setTextBeforeRendering(const std::string& text);
-
   std::string text;
   std::string fontName;
   int fontSize;
@@ -456,13 +448,15 @@ private :
   int labelsDensity;
   OcclusionTest *occlusionTester;
 
+  Camera oldCamera;
+  float oldLod;
+  Vec4i oldViewport;
+
   std::vector<std::string> textVector;
   std::vector<float> textWidthVector;
   BoundingBox textBoundingBox;
-
-  static std::map<std::string, FTGLPolygonFont*> fontMap;
-  static std::map<std::string, FTOutlineFont*> borderFontMap;
 };
-/*@}*/
+
 }
 #endif
+
