@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,26 +16,23 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef GLLINE_H
 #define GLLINE_H
 
 #ifndef DOXYGEN_NOTFOR_DEVEL
 
-#include <vector>
-
 #include <tulip/Color.h>
 #include <tulip/Coord.h>
 #include <tulip/tulipconf.h>
-
 #include <tulip/GlSimpleEntity.h>
 
 namespace tlp {
+
 /**
- * \addtogroup GlEntities
- */
-/*@{*/
-/**
+ * @ingroup OpenGL
  * \brief This is a general class to render an OpenGL laine
  * This class is use to render an OpenGl line
  */
@@ -100,14 +97,14 @@ public:
   virtual void translate(const Coord& vec);
 
   /**
-   * Function to export data in XML
+   * Function to export data in outString (in XML format)
    */
-  virtual void getXML(xmlNodePtr rootNode);
+  virtual void getXML(std::string &outString);
 
   /**
-   * Function to set data with XML
+   * Function to set data with inString (in XML format)
    */
-  virtual void setWithXML(xmlNodePtr rootNode);
+  virtual void setWithXML(const std::string &inString, unsigned int &currentPosition);
 
 protected:
   std::vector<Coord> _points;
@@ -116,9 +113,10 @@ protected:
   unsigned char factor;
   unsigned int pattern;
 };
-/*@}*/
+
 }
 
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif
+///@endcond
