@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,17 +16,28 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef _TLP_GLLINES
 #define _TLP_GLLINES
 #ifndef DOXYGEN_NOTFOR_DEVEL
 #include <vector>
 
-#include <tulip/OpenGlConfigManager.h>
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#else
+#include <GL/gl.h>
+#endif
 
-#include <tulip/Size.h>
 #include <tulip/Coord.h>
 #include <tulip/Color.h>
 
+#include <tulip/tulipconf.h>
+
 namespace tlp {
 
 struct TLP_GL_SCOPE GlLines {
@@ -62,3 +73,4 @@ private:
 }
 #endif //DOXYGEN_NOTFOR_DEVEL
 #endif
+///@endcond
