@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,48 +16,57 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLMETANODERENDERER_H
 #define Tulip_GLMETANODERENDERER_H
 
 #include <tulip/tulipconf.h>
+#include <tulip/Observable.h>
+#include <map>
 
-#include <tulip/LayoutProperty.h>
-#include <tulip/DoubleProperty.h>
-#include <tulip/StringProperty.h>
-#include <tulip/BooleanProperty.h>
-#include <tulip/SizeProperty.h>
-#include <tulip/IntegerProperty.h>
-#include <tulip/ColorProperty.h>
 namespace tlp {
 
 class GlGraphInputData;
 class Camera;
+class Graph;
+class GlScene;
 
 /**
- * Class use to render a meta node, this version render nothing
+ * Class used to render a meta node
  */
-class TLP_GL_SCOPE GlMetaNodeRenderer {
+class TLP_GL_SCOPE GlMetaNodeRenderer : public Observable {
 
 public:
 
-  virtual ~GlMetaNodeRenderer() {}
+  GlMetaNodeRenderer(GlGraphInputData *inputData);
 
-  virtual void prerender(node,float,Camera*) {}
-  virtual void render(node,float,Camera*) {}
-  virtual bool havePrerender() {
-    return false;
-  }
-  virtual bool glMetaNodeHaveToRenderLabels() {
-    return true;
-  }
+  virtual ~GlMetaNodeRenderer();
 
-  virtual void setInputData(GlGraphInputData *) {}
-  virtual GlGraphInputData *getInputData() {
-    return NULL;
-  }
+  virtual void render(node,float,Camera*);
+
+  virtual void setInputData(GlGraphInputData *inputData);
+
+  virtual GlGraphInputData *getInputData() const;
+
+  GlScene* getSceneForMetaGraph(Graph *g) const;
+
+protected:
+
+  void clearScenes();
+
+  void treatEvent(const Event&);
+
+  virtual GlScene* createScene(Graph*) const;
+
+private:
+
+  GlGraphInputData *_inputData;
+  std::map<Graph *,GlScene *> _metaGraphToSceneMap;
 
 };
 
 }
 
 #endif // Tulip_GLMETANODERENDERER_H
+///@endcond
