@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,6 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLNODE_H
 #define Tulip_GLNODE_H
 
@@ -23,15 +25,17 @@
 
 #include <tulip/Color.h>
 #include <tulip/Coord.h>
-#include <tulip/GlBox.h>
 #include <tulip/GlComplexeEntity.h>
 
+#include <vector>
+
 namespace tlp {
 
 struct OcclusionTest;
 class TextRenderer;
 class GlSceneVisitor;
 class GlLabel;
+class GlBox;
 
 /**
  * Class to represent a node of a graph
@@ -54,37 +58,30 @@ public:
   /**
    * Return the node bounding box
    */
-  virtual BoundingBox getBoundingBox(GlGraphInputData* data);
+  virtual BoundingBox getBoundingBox(const GlGraphInputData* data);
 
   /**
    * Draw the node with level of detail : lod and Camera : camera
    */
-  virtual void draw(float lod,GlGraphInputData *data,Camera* camera);
+  virtual void draw(float lod,const GlGraphInputData *data,Camera* camera);
 
   /**
    * Draw the label of the node if drawNodesLabel is true and if label selection is equal to drawSelect
    * Use TextRenderer : renderer to draw the label
    */
-  virtual void drawLabel(bool drawSelect,OcclusionTest* test,GlGraphInputData* data,float lod);
+  virtual void drawLabel(bool drawSelect,OcclusionTest* test,const GlGraphInputData* data,float lod);
 
   /**
    * Draw the label of the node if drawEdgesLabel is true
    * Use TextRenderer : renderer to draw the label
    */
-  virtual void drawLabel(OcclusionTest* test,GlGraphInputData* data);
+  virtual void drawLabel(OcclusionTest* test,const GlGraphInputData* data);
 
   /**
    * Draw the label of the node if drawEdgesLabel is true
    * Use TextRenderer : renderer to draw the label
    */
-  virtual void drawLabel(OcclusionTest* test,GlGraphInputData* data,float lod, Camera *camera=NULL);
-
-  /**
-   * Deprecate function : see others drawLabel functions
-  */
-  virtual _DEPRECATED void drawLabel(OcclusionTest *test, TextRenderer*, GlGraphInputData* data) {
-    drawLabel(test,data);
-  }
+  virtual void drawLabel(OcclusionTest* test,const GlGraphInputData* data,float lod,Camera *camera=NULL);
 
   unsigned int id;
 
@@ -110,3 +107,4 @@ protected :
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif // Tulip_GLNODE_H
+///@endcond
