@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,6 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef GLNOMINATIVEAXIS_H_
 #define GLNOMINATIVEAXIS_H_
@@ -45,7 +47,7 @@ public :
    * \axisColor the color of the axis
    */
   GlNominativeAxis(const std::string &axisName, const Coord &axisBaseCoord, const float axisLength,
-                   const AxisOrientation &axisOrientation, const Color &axisColor, const float axisWidth=10);
+                   const AxisOrientation &axisOrientation, const Color &axisColor);
 
 
   /**
@@ -92,3 +94,4 @@ private :
 }
 
 #endif /* GLNOMINATIVEAXIS_H_ */
+///@endcond
