@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,6 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef GLPOLYQUAD_H_
 #define GLPOLYQUAD_H_
@@ -23,7 +25,6 @@
 #include <tulip/tulipconf.h>
 #include <tulip/Coord.h>
 #include <tulip/Color.h>
-#include <tulip/Size.h>
 #include <tulip/GlSimpleEntity.h>
 
 #include <vector>
@@ -32,10 +33,7 @@
 namespace tlp {
 
 /**
- * \addtogroup GlEntities
- */
-/*@{*/
-/**
+ * @ingroup OpenGL
  * \brief General class used to render a connected group of quadrilaterals (textured or not) that shares edges as GlEntity
  *
  * This generic class is used  to render a connected group of quadrilaterals (textured or not) that shares edges as GlEntity
@@ -133,14 +131,14 @@ public :
   void translate(const Coord &move);
 
   /**
-   * Function to export data in XML
+   * Function to export data in outString (in XML format)
    */
-  void getXML(xmlNodePtr rootNode);
+  void getXML(std::string &outString);
 
   /**
-   * Function to set data with XML
+   * Function to set data with inString (in XML format)
    */
-  void setWithXML(xmlNodePtr rootNode);
+  void setWithXML(const std::string &inString,unsigned int &currentPosition);
 
 private :
   std::vector<Coord> polyQuadEdges; // vector which contains polyquad edges, an edge being defined by a pair of Coord
@@ -150,7 +148,8 @@ private :
   int outlineWidth;
   Color outlineColor;
 };
-/*@}*/
+
 
 }
 #endif /* GLPOLYQUAD_H_ */
+///@endcond
