@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,12 +16,16 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef GLPROGRESSBAR_H_
 #define GLPROGRESSBAR_H_
 
 #include <tulip/GlComposite.h>
 #include <tulip/SimplePluginProgress.h>
+#include <tulip/Color.h>
+#include <tulip/Coord.h>
 
 const std::string SLIDER_TEXTURE_NAME = "cylinderTexture.png";
 
@@ -68,3 +72,4 @@ private :
 
 }
 #endif /* GLPROGRESSBAR_H_ */
+///@endcond
