@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,6 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef _GLQUAD_H
 #define _GLQUAD_H
 
@@ -26,10 +28,7 @@
 
 namespace tlp {
 /**
- * \addtogroup GlEntities
- */
-/*@{*/
-/**
+ * @ingroup OpenGL
  * \brief Utility class to render a quadrilateral .
  *
  * This is an utility class class for rendering a quadrilateral.
@@ -74,22 +73,6 @@ public:
   GlQuad(const Coord &p1, const Coord &p2, const Coord &p3, const Coord &p4,
          const Color &c1, const Color &c2, const Color &c3, const Color &c4);
 
-  /**
-   * Constructor
-   *
-   * \param positions Array indicating the position of the points. The first point is the top-left one. The next points are winding in clockwise order.
-   * \param color A single color indicating the color for every point of the Quad.
-   */
-  _DEPRECATED GlQuad(const Coord positions[4], const Color &color);
-
-  /**
-   * Constructor
-   *
-   * \param positions Array indicating the position of the points. The first point is the top-left one. The next points are winding in clockwise order.
-   * \param colors Array indicating the color of the points. The order is the same as for the positions.
-   */
-  _DEPRECATED GlQuad(const Coord positions[4], const Color colors[4]);
-
   /**
    * Destructor
    */
@@ -125,17 +108,18 @@ public:
   const Color& getColor(const int idColor) const;
 
   /**
-   * Function to export data in XML
+   * Function to export data in outString (in XML format)
    */
-  virtual void getXML(xmlNodePtr rootNode);
+  virtual void getXML(std::string &outString);
 
   /**
-   * Function to set data with XML
+   * Function to set data with inString (in XML format)
    */
-  virtual void setWithXML(xmlNodePtr rootNode);
+  virtual void setWithXML(const std::string &inString, unsigned int &currentPosition);
 
 
 };
-/*@}*/
+
 }
 #endif
+///@endcond
