@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,30 +16,31 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_QLQUADTREELODCALCULATOR_H
 #define Tulip_QLQUADTREELODCALCULATOR_H
 
 #include <map>
 #include <vector>
 
-#include <tulip/BoundingBox.h>
-#include <tulip/GlGraphInputData.h>
-#include <tulip/Matrix.h>
-#include <tulip/Vector.h>
-#include <tulip/GlSceneObserver.h>
 #include <tulip/GlCPULODCalculator.h>
+#include <tulip/Observable.h>
+#include <tulip/GlGraphRenderingParameters.h>
 
 namespace tlp {
 
 class Camera;
 template <class TYPE> class QuadTreeNode;
 class GlScene;
+class PropertyInterface;
+class Graph;
+class GlLayer;
 
 /**
  * Class use to compute bounding boxs of a vector of GlEntity
  */
-class TLP_GL_SCOPE GlQuadTreeLODCalculator : public GlCPULODCalculator,
-  private GraphObserver, private PropertyObserver, private Observable {
+class TLP_GL_SCOPE GlQuadTreeLODCalculator : public GlCPULODCalculator, private Observable {
 
 public:
 
@@ -91,7 +92,7 @@ public:
   /**
    * Change the input data used by this LOD calculator
    */
-  void setInputData(GlGraphInputData *newInputData);
+  void setInputData(const GlGraphInputData *newInputData);
 
   /**
    * Clone the calculator
@@ -107,29 +108,6 @@ protected :
 
   void update(PropertyInterface *property);
   void treatEvent(const Event &ev);
-  void observableDestroyed(Observable *) {}
-  void afterSetNodeValue(PropertyInterface*,const node n);
-  void afterSetEdgeValue(PropertyInterface*,const edge e);
-  void afterSetAllNodeValue(PropertyInterface*);
-  void afterSetAllEdgeValue(PropertyInterface*);
-  void addNode(Graph *,const node ) {
-    setHaveToCompute();
-  }
-  void addEdge(Graph *,const edge ) {
-    setHaveToCompute();
-  }
-  void delNode(Graph *,const node ) {
-    setHaveToCompute();
-  }
-  void delEdge(Graph *,const edge ) {
-    setHaveToCompute();
-  }
-  void addLocalProperty(Graph*, const std::string &name);
-  void delLocalProperty(Graph*, const std::string &name);
-  void addInheritedProperty(Graph *, const std::string &name);
-  void afterDelInheritedProperty(Graph *, const std::string &name);
-  void destroy(Graph *);
-  void destroy(const Camera *);
 
   void removeObservers();
   void addObservers();
@@ -145,18 +123,20 @@ protected :
   std::vector<std::vector<SimpleEntityLODUnit> > simpleEntities;
 
   bool haveToCompute;
+  bool haveToInitObservers;
 
   BoundingBox nodesGlobalBoundingBox;
   BoundingBox edgesGlobalBoundingBox;
   BoundingBox entitiesGlobalBoundingBox;
 
   std::vector<Camera *> cameras;
-  std::map<GlLayer*,std::pair<Camera*, Camera> > layerToCamera;
+  std::map<GlLayer*, Camera> layerToCamera;
   Camera *currentCamera;
   Graph *currentGraph;
   PropertyInterface *layoutProperty;
   PropertyInterface *sizeProperty;
   PropertyInterface *selectionProperty;
+  GlGraphRenderingParameters oldParameters;
 
   int quadTreesVectorPosition;
   int simpleEntitiesVectorPosition;
@@ -165,3 +145,4 @@ protected :
 }
 
 #endif // Tulip_QTQUADTREELODCALCULATOR_H
+///@endcond
