@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,6 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef GLQUANTITATIVEAXIS_H_
 #define GLQUANTITATIVEAXIS_H_
@@ -45,7 +47,7 @@ public :
    * \ascendingOrder If true, the min value will be at the bottom end and the max will be at the top end if the axis is vertical (min at the left and max at the right if it is horizontal). If false this positions are switched
    */
   GlQuantitativeAxis(const std::string &axisName, const Coord &axisBaseCoord, const float axisLength,
-                     const AxisOrientation &axisOrientation, const Color &axisColor, const float axisWidth=10,
+                     const AxisOrientation &axisOrientation, const Color &axisColor,
                      const bool addArrow = true, const bool ascendingOrder = true);
 
   /**
@@ -144,3 +146,4 @@ private :
 }
 
 #endif /* GLQUANTITATIVEAXIS_H_ */
+///@endcond
