@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -17,17 +17,17 @@
  *
  */
 
+
 #ifndef GL_RECT_H
 #define GL_RECT_H
 
 #include <tulip/GlPolygon.h>
+#include <tulip/Size.h>
 
 namespace tlp {
+
 /**
- * \addtogroup GlEntities
- */
-/*@{*/
-/**
+ * @ingroup OpenGL
  * \brief This is a general class for the rendering of 2D rectangles.
  *
  * This class is used as a 2D HUD for the rendering of 2D rectangles.
@@ -45,7 +45,8 @@ public:
   /**
    * Constructor : with center coords and size, fill color and outline color
    */
-  GlRect(const Coord &center, const Size &size, const Color &fillColor, const Color &outlineColor);
+  GlRect(const Coord &center, const float width, const float height, const Color &fillColor, const Color &outlineColor);
+
 
   /**
    * Constructor : with GlRect is filled/outlined
@@ -112,22 +113,9 @@ public:
    */
   bool inRect(double x, double y);
 
-  /**
-   * Function to export data in XML
-   */
-  virtual void getXML(xmlNodePtr rootNode);
-
-  /**
-   * Function to set data with XML
-   */
-  virtual void setWithXML(xmlNodePtr rootNode);
-
-  /**
-   * Draw the GlRect
-   */
   virtual void draw(float lod,Camera *camera);
 
 };
-/*@}*/
+
 }
 #endif
