@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,11 +16,12 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef Tulip_GLSCENEOBSERVER_H
 #define Tulip_GLSCENEOBSERVER_H
 
-#include <set>
 #include <string>
 
 #include <tulip/tulipconf.h>
@@ -38,17 +39,19 @@ class GlSimpleEntity;
 class TLP_GL_SCOPE GlSceneEvent : public Event {
 public:
 
-  enum GlSceneEventType {TLP_ADDLAYER=0, TLP_DELLAYER, TLP_MODIFYLAYER, TLP_MODIFYENTITY};
+  enum GlSceneEventType {TLP_ADDLAYER=0, TLP_DELLAYER, TLP_MODIFYLAYER, TLP_MODIFYENTITY, TLP_DELENTITY};
 
   GlSceneEvent(const GlScene &scene,GlSceneEventType sceneEventType,const std::string &layerName,GlLayer *layer);
 
-  GlSceneEvent(const GlScene &scene,GlSimpleEntity *entity);
+  GlSceneEvent(const GlScene &scene, GlSceneEventType sceneEventType, GlSimpleEntity *entity);
 
-  GlSimpleEntity *getGlSimpleEntity();
+  GlSimpleEntity *getGlSimpleEntity() const;
 
-  std::string getLayerName();
+  std::string getLayerName() const;
 
-  GlLayer *getLayer();
+  GlLayer *getLayer() const;
+
+  GlSceneEventType getSceneEventType() const;
 
 protected :
 
@@ -62,3 +65,4 @@ protected :
 
 #endif
 
+///@endcond
