@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,14 +16,19 @@
  * See the GNU General Public License for more details.
  *
  */
-
 #ifndef GLSCENEZOOMANDPAN_H_
 #define GLSCENEZOOMANDPAN_H_
 
-#include <tulip/GlScene.h>
+#include <tulip/tulipconf.h>
+#include <tulip/Vector.h>
+#include <tulip/Coord.h>
 
 namespace tlp {
 
+class GlScene;
+struct BoundingBox;
+class Camera;
+
 /**
  * \brief A class which encapsulate a Tulip OpenGL scene animation
  *  This class aims to encapsulate a Tulip OpenGL scene animation.
@@ -33,11 +38,13 @@ class TLP_GL_SCOPE AdditionalGlSceneAnimation {
 
 public :
 
+  virtual ~AdditionalGlSceneAnimation() {}
+
   /**
    * Method to set the total number of animation steps. No need to call it because the GlSceneZoomAndPan class do that task.
    *
    */
-  void setNbAnimationSteps(int nbAnimationSteps) {
+  inline void setNbAnimationSteps(int nbAnimationSteps) {
     this->nbAnimationSteps = nbAnimationSteps;
   }
 
@@ -56,15 +63,17 @@ protected :
 /** \brief A convenient class to perform Zoom and Pan animation on Tulip OpenGL scene
  *
  *  This class allow to perform a smooth and efficient zooming and panning on Tulip OpenGL scene.
- *  The algorithm used to perform this task is the one published in : Jarke J. van Wijk and Wim A.A. Nuij, "Smooth and efficient zooming and panning"
- *  For more details, the paper can be downloaded at the following url : www.win.tue.nl/~vanwijk/zoompan.pdf
+ *  The algorithm used to perform this task is the one published in: Jarke J. van Wijk and Wim A.A. Nuij, "Smooth and efficient zooming and panning"
+ *  For more details, the paper can be downloaded at the following url: http://www.win.tue.nl/~vanwijk/zoompan.pdf
  *  Even if this class contains the whole Zoom and Pan implementation, it is not aimed to be used directly because its role is only to compute new camera parameters.
- *  Use the derived class QtGlSceneZoomAndPanAnimator in the tulip-qt library instead to perform the animation.
+ *  Use the derived class QtGlSceneZoomAndPanAnimator in the tulip-gui library instead to perform the animation.
  */
 class TLP_GL_SCOPE GlSceneZoomAndPan  {
 
 public :
 
+  virtual ~GlSceneZoomAndPan() {}
+
   /**
    * GlSceneZoomAndPan constructor
    *
@@ -88,14 +97,14 @@ public :
   /**
    * Method which return the number of animation steps
    */
-  int getNbAnimationsStep() const {
+  inline int getNbAnimationsStep() const {
     return nbAnimationSteps;
   }
 
   /**
    * Method to set the number of animation steps
    */
-  void setNbAnimationSteps(const int nbAnimationSteps) {
+  inline void setNbAnimationSteps(const int nbAnimationSteps) {
     this->nbAnimationSteps = nbAnimationSteps;
   }
 
