@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,16 +16,12 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLSELECTSCENEVISITOR_H
 #define Tulip_GLSELECTSCENEVISITOR_H
 
-#include <vector>
-#include <utility>
-
 #include <tulip/GlSceneVisitor.h>
-#include <tulip/GlNode.h>
-#include <tulip/GlEdge.h>
-#include <tulip/GlLODCalculator.h>
 
 namespace tlp {
 
@@ -35,6 +31,9 @@ enum SelectionFlag {
   SelectEdges=4
 };
 
+class GlGraphInputData;
+class GlLODCalculator;
+
 /**
  * This visitor is use when we want to select an entity in scene
  */
@@ -45,8 +44,7 @@ public:
   /**
    * Constructor with SelectionFlac (SelectSimpleEntity, SelectNodes and SelectEdges), GlGraphInputData and GlLODCalculator
    */
-  GlSelectSceneVisitor(SelectionFlag flag,GlGraphInputData* inputData,GlLODCalculator *calculator)
-    :selectionFlag(flag),inputData(inputData),calculator(calculator) {}
+  GlSelectSceneVisitor(SelectionFlag flag,GlGraphInputData* inputData,GlLODCalculator *calculator);
 
   /**
    * Visit a simple entity
@@ -78,3 +76,4 @@ private:
 }
 
 #endif // Tulip_GLSELECTSCENEVISITOR_H
+///@endcond
