@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,17 +16,26 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 
 #ifndef GL_SHADER_PROGRAM
 #define GL_SHADER_PROGRAM
 
-#include <tulip/OpenGlConfigManager.h>
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#else
+#include <GL/gl.h>
+#endif
 
 #include <string>
-#include <map>
+#include <vector>
 
 #include <tulip/tulipconf.h>
-#include <tulip/Vector.h>
 #include <tulip/Matrix.h>
 #include <tulip/Color.h>
 
@@ -522,3 +531,4 @@ private :
 }
 
 #endif // GL_SHADER_PROGRAM
+///@endcond
