@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,91 +16,98 @@
  * See the GNU General Public License for more details.
  *
  */
+
 #ifndef Tulip_GLSPHERE_H
 #define Tulip_GLSPHERE_H
 
 #include <tulip/tulipconf.h>
+
 #include <tulip/Coord.h>
 #include <tulip/Color.h>
+
 #include <tulip/GlSimpleEntity.h>
 
 namespace tlp {
 
 /**
- * \addtogroup GlEntities
- */
-/*@{*/
-/**
- * Class to create a sphere with GlEntity system
+ * @ingroup OpenGL
+ * @brief Class to create a sphere with GlEntity system
  */
 class TLP_GL_SCOPE GlSphere : public GlSimpleEntity {
 
 public:
 
-  GlSphere() {}
   /**
-   * Create a sphere with a position, a radius a fill color and multiple rotation (if you want)
+   * @brief Constructor
+   *
+   * @warning Don't use this constructor
+   */
+  GlSphere() {}
+
+  /**
+   * @brief Create a sphere with a position, a radius a fill color and multiple rotation (if you want)
    */
   GlSphere(const Coord &position,float radius,const Color &color=Color(0,0,0,255),float rotX=0,float rotY=0,float rotZ=0);
+
   /**
-      * Create a sphere with a position, a radius, a texture, an alphe and multiple rotation (if you want)
-      */
+   * @brief Create a sphere with a position, a radius, a texture, an alphe and multiple rotation (if you want)
+   */
   GlSphere(const Coord &position,float radius,const std::string& textureFile,int alpha=255,float rotX=0,float rotY=0,float rotZ=0);
 
   /**
-   * Draw the sphere
+   * @brief Draw the sphere
    */
   virtual void draw(float lod,Camera *camera);
 
   /**
-   * Translate entity
+   * @brief Translate entity
    */
   virtual void translate(const Coord& mouvement);
 
   /**
-   * Get absolute position
+   * @brief Get absolute position
    */
   const Coord& getPosition() const {
     return position;
   }
 
   /**
-   * Set absolute position
+   * @brief Set absolute position
    */
   void setPosition(const Coord& pos) {
     position = pos;
   }
 
   /**
-   * Set the texture name
+   * @brief Set the texture name
    */
   virtual void setTexture(const std::string &texture) {
     textureFile=texture;
   }
 
   /**
-   * Get the color
+   * @brief Get the color
    */
   const Color& getColor() const {
     return color;
   }
 
   /**
-   * Set the color
+   * @brief Set the color
    */
   void setColor(const Color &newColor) {
     color = newColor;
   }
 
   /**
-   * Function to export data in XML
+   * @brief Function to export data in outString (in XML format)
    */
-  virtual void getXML(xmlNodePtr rootNode);
+  virtual void getXML(std::string &outString);
 
   /**
-   * Function to set data with XML
+   * @brief Function to set data with inString (in XML format)
    */
-  virtual void setWithXML(xmlNodePtr rootNode);
+  virtual void setWithXML(const std::string &inString, unsigned int &currentPosition);
 
 private:
 
@@ -111,7 +118,7 @@ private:
   Coord rot;
 
 };
-/*@}*/
+
 
 }
 
