@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,12 +16,24 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLTLPFEEDBACKBUILDER_H
 #define Tulip_GLTLPFEEDBACKBUILDER_H
 
-#include <vector>
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
 
-#include <tulip/Color.h>
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
+
+#include <vector>
 
 #include <tulip/GlFeedBackBuilder.h>
 
@@ -53,7 +65,6 @@ public:
 
   virtual ~GlTLPFeedBackBuilder() {}
 
-  virtual void begin(Vector<float,4>&) {}
   virtual void colorInfo(GLfloat *) {}
   virtual void beginGlEntity(GLfloat) {}
   virtual void endGlEntity() {}
@@ -89,3 +100,4 @@ private:
 }
 
 #endif // Tulip_GLFEEDBACKBUILDER_H
+///@endcond
