@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,23 +16,31 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLTEXTUREMANAGER_H
 #define Tulip_GLTEXTUREMANAGER_H
 
-#include <map>
-
 #include <tulip/tulipconf.h>
 
-// #include <cassert>
-#include <tulip/OpenGlConfigManager.h>
-#include <string>
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#else
+#include <GL/gl.h>
+#endif
+
 #include <set>
-// #include <iostream>
+#include <map>
+#include <string>
+
+#include <stdint.h>
 
 namespace tlp {
 
-class OpenGlErrorViewer;
-
 struct GlTexture {
   GLuint *id;
   int height;
@@ -40,20 +48,13 @@ struct GlTexture {
   unsigned int spriteNumber;
 };
 
-struct TextureInfo {
-  bool hasAlpha;
-  unsigned int  width;
-  unsigned int  height;
-  unsigned char *data;
-};
-
 /** \brief Class to manage textures
  * Singleton class to load/store textures need by OpenGL rendering
  */
 class TLP_GL_SCOPE GlTextureManager {
 
   typedef std::map<std::string,GlTexture> TextureUnit;
-  typedef std::map<unsigned long,TextureUnit> ContextAndTextureMap;
+  typedef std::map<uintptr_t,TextureUnit> ContextAndTextureMap;
 
 public:
 
@@ -71,23 +72,14 @@ public:
     return *inst;
   }
 
-  /**
-   * Change the error viewer and return the old one
-   */
-  OpenGlErrorViewer *setErrorViewer(OpenGlErrorViewer *errorViewer) {
-    OpenGlErrorViewer *oldErrorViewer=this->errorViewer;
-    this->errorViewer=errorViewer;
-    return oldErrorViewer;
-  }
-
   /**
    * Change the current OpenGl context (each OpenGl window have a different OpenGl context)
    */
-  void changeContext(unsigned long context);
+  void changeContext(uintptr_t context);
   /**
    * Remove all textures of an OpenGl context and remove this context
    */
-  void removeContext(unsigned long context);
+  void removeContext(uintptr_t context);
 
   /**
    * Return texture info (id, width and height) for the given name
@@ -98,11 +90,6 @@ public:
    * Check if a texture fo the given name exists in the current context
    */
   bool existsTexture(const std::string& filename);
-
-  /**
-   * Load texture with textureName from Raw data
-   */
-  bool loadTextureFromRawData(const std::string &textureName, int width, int height, bool hasAlpha, unsigned char *data);
   /**
    * Load texture with given name
    */
@@ -165,13 +152,9 @@ private:
    */
   GlTextureManager();
 
-  bool loadTexture(const std::string&,const TextureInfo &,GlTexture &);
-
   static GlTextureManager* inst;
 
-  OpenGlErrorViewer *errorViewer;
-
-  unsigned long currentContext;
+  uintptr_t currentContext;
 
   ContextAndTextureMap texturesMap;
   std::set<std::string> texturesWithError;
@@ -183,3 +166,4 @@ private:
 }
 
 #endif // Tulip_GLTEXTUREMANAGER_H
+///@endcond
