@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,19 +16,33 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef GLTOOLS_H
 #define GLTOOLS_H
 #ifndef DOXYGEN_NOTFOR_DEVEL
-#include <tulip/OpenGlConfigManager.h>
+#include <tulip/tulipconf.h>
 #include <tulip/Color.h>
 #include <tulip/Coord.h>
 #include <tulip/Size.h>
 #include <tulip/Matrix.h>
-#include <tulip/BoundingBox.h>
+
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#else
+#include <GL/gl.h>
+#endif
 
 namespace tlp {
+
+struct BoundingBox;
+
 typedef Matrix<float, 4> MatrixGL;
-TLP_GL_SCOPE void glTest(std::string message = "(no description)");
+TLP_GL_SCOPE void glTest(const std::string &message = std::string("(no description)"));
 TLP_GL_SCOPE void setColor(const Color &c);
 TLP_GL_SCOPE void setColor(GLfloat *);
 TLP_GL_SCOPE void setMaterial(const Color &c);
@@ -47,18 +61,14 @@ TLP_GL_SCOPE Coord projectPoint(const Coord &obj,
 TLP_GL_SCOPE Coord unprojectPoint(const Coord &obj,
                                   const MatrixGL &,
                                   const tlp::Vector<int, 4> &viewport);
-TLP_GL_SCOPE double segmentVisible(const Coord &u, const Coord &v,
-                                   const MatrixGL &, const Vector<int, 4> &viewport);
-TLP_GL_SCOPE double segmentSize(const Coord &u, const Coord &v,
-                                const MatrixGL &, const Vector<int, 4> &viewport);
-inline GLfloat sqr(const GLfloat f);
 TLP_GL_SCOPE GLfloat projectSize(const BoundingBox& bb,
                                  const MatrixGL &, const MatrixGL &,const Vector<int, 4> &viewport);
 TLP_GL_SCOPE GLfloat projectSize(const Coord& position,const Size& size,
                                  const MatrixGL &, const MatrixGL &,const Vector<int, 4> &viewport);
-TLP_GL_SCOPE float calculateAABBSize(const BoundingBox& bb,const Coord& eye,const Matrix<float, 4>& transformMatrix,const Vector<int, 4>& globalViewport,const Vector<int, 4>& currentViewport, bool computeOutScreenLOD=false);
+TLP_GL_SCOPE float calculateAABBSize(const BoundingBox& bb,const Coord& eye,const Matrix<float, 4>& transformMatrix,const Vector<int, 4>& globalViewport,const Vector<int, 4>& currentViewport);
 TLP_GL_SCOPE float calculate2DLod(const BoundingBox& bb,const Vector<int, 4>& globalViewport,const Vector<int, 4>& currentViewport);
 }
 
 #endif //DOXYGEN_NOTFOR_DEVEL
 #endif
+///@endcond
