@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,21 +16,27 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLVERTEXARRAYMANAGER_H
 #define Tulip_GLVERTEXARRAYMANAGER_H
 
-#include <cassert>
-#include <iostream>
-#include <tulip/OpenGlConfigManager.h>
+#if defined(_MSC_VER)
+#include <windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
 
-#include <tulip/tulipconf.h>
 #include <tulip/Coord.h>
 #include <tulip/Color.h>
-#include <tulip/Size.h>
-#include <tulip/tuliphash.h>
 #include <tulip/Observable.h>
-#include <tulip/ObservableGraph.h>
-#include <tulip/ObservableProperty.h>
+#include <tulip/tuliphash.h>
 
 #include <vector>
 
@@ -40,13 +46,18 @@ class Graph;
 class GlEdge;
 class GlNode;
 class GlGraphInputData;
+class PropertyInterface;
+class ColorProperty;
+class LayoutProperty;
+class SizeProperty;
+class IntegerProperty;
+class DoubleProperty;
 
 /** \brief Class used to render edges/nodes with vertex array
  *
  * Class used to render edges/nodes with vertex array
  */
-class TLP_GL_SCOPE GlVertexArrayManager :
-  private GraphObserver, private PropertyObserver, private Observable {
+class TLP_GL_SCOPE GlVertexArrayManager : private Observable {
 
 public:
 
@@ -67,7 +78,7 @@ public:
    * Return if this GlVertexArrayManager is used to render entities of the scene
    */
   inline bool renderingIsBegin() {
-    return isBegin && activated;
+    return isBegin;
   }
 
   /**
@@ -119,6 +130,10 @@ public:
    */
   void activate(bool act);
 
+  bool isActivated() {
+    return activated;
+  }
+
   /**
    * This function is call when you want to activate line rendering of a specific edge
    */
@@ -134,33 +149,33 @@ public:
   /**
    * This function is call when you want to activate point rendering of a specific node
    */
-  void activatePointNodeDisplay(GlNode *node, bool onePixel, bool selected);
+  void activatePointNodeDisplay(GlNode *node, bool selected);
 
 protected:
 
-  void propertyValueChanged(PropertyInterface *property);
-
-  void addEdge(Graph *,const edge);
-  void addNode(Graph *,const node);
-  void afterSetEnds(Graph *, const edge);
-  void beforeSetAllNodeValue(PropertyInterface*);
-  void beforeSetAllEdgeValue(PropertyInterface*);
-  void beforeSetNodeValue(PropertyInterface*, const node);
-  void beforeSetEdgeValue(PropertyInterface*, const edge);
-  void addLocalProperty(Graph*, const std::string&);
-  void delLocalProperty(Graph*, const std::string&);
-
-  void destroy(Graph *);
-  void destroy(PropertyInterface*);
+  void propertyValueChanged(tlp::PropertyInterface *property);
+  void treatEvent(const Event&);
 
   void clearLayoutData();
   void clearColorData();
   void clearData();
   void initObservers();
-  void clearObservers();
+  void clearObservers(PropertyInterface *deletedProperty=NULL);
 
   GlGraphInputData *inputData;
   Graph *graph;
+  //Store properties used to compute the arrays
+  LayoutProperty* layoutProperty;
+  SizeProperty* sizeProperty;
+  IntegerProperty* shapeProperty;
+  DoubleProperty* rotationProperty;
+  ColorProperty* colorProperty;
+  ColorProperty* borderColorProperty;
+  DoubleProperty* borderWidthProperty;
+  IntegerProperty *srcAnchorShapeProperty;
+  IntegerProperty *tgtAnchorShapeProperty;
+  SizeProperty *srcAnchorSizeProperty;
+  SizeProperty *tgtAnchorSizeProperty;
   bool graphObserverActivated;
   bool layoutObserverActivated;
   bool colorObserverActivated;
@@ -175,55 +190,71 @@ protected:
   bool vectorColorSizeInit;
   bool vectorIndexSizeInit;
 
+  bool edgesModified;
   bool colorInterpolate;
   bool sizeInterpolate;
-  bool edgesModified;
+  bool viewArrow;
+
 
   std::vector<Coord> linesCoordsArray;
   std::vector<Color> linesColorsArray;
   std::vector<GLint> linesIndexArray;
   std::vector<GLsizei> linesIndexCountArray;
 
-  std::vector<GLint> linesRenderingStartIndexArray;
-  std::vector<GLsizei> linesRenderingCountArray;
-  std::vector<GLint> linesSelectedRenderingStartIndexArray;
-  std::vector<GLsizei> linesSelectedRenderingCountArray;
+  std::vector<GLuint> linesRenderingIndicesArray;
+  std::vector<GLuint> linesSelectedRenderingIndicesArray;
 
   std::vector<Coord> quadsCoordsArray;
   std::vector<Color> quadsColorsArray;
   std::vector<Color> quadsOutlineColorsArray;
-  std::vector<GLint> quadsIndexArray;
+  std::vector<GLuint> quadsIndexArray;
   std::vector<GLsizei> quadsIndexCountArray;
   std::vector<std::vector<GLuint> > quadsBottomOutlineIndexArray;
   std::vector<std::vector<GLuint> > quadsTopOutlineIndexArray;
 
-  std::vector<GLint> quadsRenderingStartIndexArray;
-  std::vector<GLsizei> quadsRenderingCountArray;
-  std::vector<GLint> quadsSelectedRenderingStartIndexArray;
-  std::vector<GLsizei> quadsSelectedRenderingCountArray;
-  std::map<float, std::vector<const GLuint* > > quadsOutlineRenderingIndexArray;
-  std::map<float, std::vector<GLsizei> > quadsOutlineRenderingCountArray;
-  std::map<float, std::vector<const GLuint* > > quadsOutlineSelectedRenderingIndexArray;
-  std::map<float, std::vector<GLsizei> > quadsOutlineSelectedRenderingCountArray;
+  std::vector<GLuint> quadsRenderingIndicesArray;
+  std::vector<GLuint> quadsSelectedRenderingIndicesArray;
+
+  std::map<float, std::vector<GLuint> > quadsOutlineRenderingIndicesArray;
+  std::map<float, std::vector<GLuint> > quadsSelectedOutlineRenderingIndicesArray;
 
   std::vector<Coord> pointsCoordsArray;
   std::vector<Color> pointsColorsArray;
 
-  std::vector<GLuint> points1PNodesRenderingIndexArray;
-  std::vector<GLuint> points1PNodesSelectedRenderingIndexArray;
-  std::vector<GLuint> points2PNodesRenderingIndexArray;
-  std::vector<GLuint> points2PNodesSelectedRenderingIndexArray;
-  std::vector<GLuint> points1PEdgesRenderingIndexArray;
-  std::vector<GLuint> points1PEdgesSelectedRenderingIndexArray;
+  std::vector<GLuint> pointsNodesRenderingIndexArray;
+  std::vector<GLuint> pointsNodesSelectedRenderingIndexArray;
+  std::vector<GLuint> pointsEdgesRenderingIndexArray;
+  std::vector<GLuint> pointsEdgesSelectedRenderingIndexArray;
+
+  TLP_HASH_MAP<unsigned int, std::pair<unsigned int,unsigned int> > edgeToLineIndexVector;
+  TLP_HASH_MAP<unsigned int, std::pair<unsigned int,unsigned int> > edgeToQuadIndexVector;
+  TLP_HASH_MAP<unsigned int, unsigned int> edgeToBottomOulineIndexVector;
+  TLP_HASH_MAP<unsigned int, unsigned int> edgeToTopOutlineIndexVector;
+  TLP_HASH_MAP<unsigned int, unsigned int> edgeToPointIndexVector;
+  TLP_HASH_MAP<unsigned int, unsigned int> nodeToPointIndexVector;
+
+  GLuint pointsVerticesVBO;
+  GLuint pointsColorsVBO;
+  GLuint linesVerticesVBO;
+  GLuint linesColorsVBO;
+  GLuint quadsVerticesVBO;
+  GLuint quadsColorsVBO;
+  GLuint quadsOutlineColorsVBO;
+
+  bool pointsVerticesUploaded;
+  bool pointsColorsUploaded;
+  bool linesVerticesUploaded;
+  bool linesColorsUploaded;
+  bool quadsVerticesUploaded;
+  bool quadsColorsUploaded;
+  bool quadsOutlineColorsUploaded;
+
+  bool verticesUploadNeeded;
+  bool colorsUploadNeeded;
 
-  std::vector<std::pair<unsigned int,unsigned int> > edgeToLineIndexVector;
-  std::vector<std::pair<unsigned int,unsigned int> > edgeToQuadIndexVector;
-  std::vector<unsigned int> edgeToBottomOulineIndexVector;
-  std::vector<unsigned int> edgeToTopOutlineIndexVector;
-  std::vector<unsigned int> edgeToPointIndexVector;
-  std::vector<unsigned int> nodeToPointIndexVector;
 };
 
 }
 
 #endif
+///@endcond
