@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,6 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLVERTEXARRAYVISITOR_H
 #define Tulip_GLVERTEXARRAYVISITOR_H
 #ifndef DOXYGEN_NOTFOR_DEVEL
@@ -37,7 +39,7 @@ public:
   /**
    * Constructor
    */
-  GlVertexArrayVisitor(GlGraphInputData* inputData):inputData(inputData) {
+  GlVertexArrayVisitor(const GlGraphInputData* inputData):inputData(inputData) {
     threadSafe=true;
   }
 
@@ -56,7 +58,7 @@ public:
 
 private:
 
-  GlGraphInputData* inputData;
+  const GlGraphInputData* inputData;
 
 };
 
@@ -65,3 +67,4 @@ private:
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif // Tulip_GLVERTEXARRAYVISITOR_H
+///@endcond
