@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,31 +16,28 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef GLYPH_H
 #define GLYPH_H
 
 #ifndef DOXYGEN_NOTFOR_DEVEL
 
 #include <tulip/Plugin.h>
-#include <tulip/TulipRelease.h>
-#include <tulip/WithParameter.h>
-#include <tulip/WithDependency.h>
 #include <tulip/Size.h>
 #include <tulip/Coord.h>
-#include <tulip/Color.h>
 #include <tulip/BoundingBox.h>
-#include <tulip/TlpTools.h>
-#include <tulip/TemplateFactory.h>
-
-#include <tulip/GlGraphInputData.h>
-
+#include <tulip/PluginContext.h>
 
 namespace tlp {
 
+static const std::string GLYPH_CATEGORY = "Node shape";
+
 class Graph;
 struct node;
+class GlGraphInputData;
 
-class GlyphContext {
+class GlyphContext : public PluginContext {
 public:
   GlGraphInputData *glGraphInputData;
   ///
@@ -52,10 +49,22 @@ public:
   }
 };
 //==========================================================
-class TLP_GL_SCOPE Glyph : public WithParameter, public WithDependency {
+class TLP_GL_SCOPE Glyph : public tlp::Plugin {
 public:
-  Glyph(GlyphContext *);
+  std::string category() const {
+    return GLYPH_CATEGORY;
+  }
+  std::string icon() const {
+    return ":/tulip/gui/icons/32/plugin_glyph.png";
+  }
+
+  Glyph(const tlp::PluginContext* context);
   virtual ~Glyph();
+
+  virtual std::string getGroup() const {
+    return "";
+  }
+
   virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node) {
     boundingBox[0] = Coord(-0.5,-0.5,-0.5);
     boundingBox[1] = Coord(0.5,0.5,0.5);
@@ -95,66 +104,17 @@ protected:
   virtual Coord getAnchor(const Coord &vector) const;
 };
 
-class TLP_GL_SCOPE GlyphFactory: public PluginInfoInterface {
-public:
-  virtual ~GlyphFactory() {}
-  ///
-  virtual Glyph *createPluginObject(GlyphContext *gc)=0;
-  ///
-  virtual int getId() const=0;
-
-  virtual  std::string getMajor() const {
-    return tlp::getMajor(getRelease());
-  }
-  virtual  std::string getMinor() const  {
-    return tlp::getMinor(getRelease());
-  }
-  virtual  std::string getTulipMajor() const {
-    return tlp::getMajor(getTulipRelease());
-  }
-  virtual  std::string getTulipMinor() const  {
-    return tlp::getMinor(getTulipRelease());
-  }
-
-  static TemplateFactory<GlyphFactory,Glyph,GlyphContext *> *factory;
-  static void initFactory() {
-    if (!factory) {
-      factory = new TemplateFactory<GlyphFactory,Glyph,GlyphContext *>;
-    }
-  }
-};
-
 }
 
-#define GPLUGINFACTORY(T,C,N,A,D,I,R,ID,G)     \
-class C##T##Factory:public tlp::T##Factory   \
-{                                                \
-public:                                          \
-  C##T##Factory(){         \
-    initFactory();               \
-    factory->registerPlugin(this);           \
-  }                  \
-  string getName() const { return string(N);}  \
-  string getGroup() const { return string(G);}   \
-  string getAuthor() const {return string(A);}   \
-  string getDate() const {return string(D);}   \
-  string getInfo() const {return string(I);}   \
-  string getRelease() const {return string(R);}\
-  string getTulipRelease() const {return string(TULIP_RELEASE);}\
-  int    getId() const {return ID;}    \
-  tlp::T * createPluginObject(tlp::GlyphContext *gc)   \
-  {            \
-    C *tmp = new C(gc);        \
-    return ((tlp::T *) tmp);       \
-  }            \
-};                                               \
-extern "C" {                                            \
-  C##T##Factory C##T##FactoryInitializer;               \
-}
+#define GLYPHINFORMATION(NAME, AUTHOR, DATE, INFO, RELEASE, ID) \
+PLUGININFORMATION(NAME, AUTHOR, DATE, INFO, RELEASE, "")\
+int id() const { return ID; }
 
-#define GLYPHPLUGINOFGROUP(C,N,A,D,I,R,ID,G) GPLUGINFACTORY(Glyph,C,N,A,D,I,R,ID,G)
-#define GLYPHPLUGIN(C,N,A,D,I,R,ID) GLYPHPLUGINOFGROUP(C,N,A,D,I,R,ID,"")
+#define GLYPHINFORMATIONS(NAME, AUTHOR, DATE, INFO, RELEASE, ID) \
+PLUGININFORMATION(NAME, AUTHOR, DATE, INFO, RELEASE, "")\
+int id() const { return ID; }
 
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif //GLYPH_H
+///@endcond
