@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,20 +16,24 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_GLYPHMANAGER_H
 #define Tulip_GLYPHMANAGER_H
 
 #ifndef DOXYGEN_NOTFOR_DEVEL
 
-#include <string>
-#include <cassert>
+//#include <string>
 
 #include <tulip/tulipconf.h>
-#include <tulip/PluginLoader.h>
 #include <tulip/Glyph.h>
+#include <tulip/MutableContainer.h>
 
 namespace tlp {
 
+class GlGraphInputData;
+class Graph;
+
 /** \ brief Singleton class use to store Glyphs plugins
  * This class is a singleton use to sore Glyphs plugins
  */
@@ -59,10 +63,6 @@ public:
    * Load glyphs plugins
    */
   void loadGlyphPlugins();
-  /**
-   * Load glyphs plugins with given PluginLoader
-   */
-  void loadPlugins(PluginLoader *plug=0);
 
   /**
    * Create the glyph list and store it in glyphs parameter
@@ -86,3 +86,4 @@ private:
 #endif // DOXYGEN_NOTFOR_DEVEL
 
 #endif // Tulip_GLYPHMANAGER_H
+///@endcond
