@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,12 +16,16 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_OCCLUSIONTEST_H
 #define Tulip_OCCLUSIONTEST_H
 #ifndef DOXYGEN_NOTFOR_DEVEL
-#include <tulip/Rectangle.h>
+
 #include <vector>
 
+#include <tulip/Rectangle.h>
+
 namespace tlp {
 
 typedef Rectangle<int> RectangleInt2D;
@@ -38,7 +42,7 @@ struct TLP_GL_SCOPE OcclusionTest {
   /**
   * Remove all 2D AABB previously added.
   */
-  void reset() {
+  void clear() {
     data.clear();
   }
   /**
@@ -52,10 +56,10 @@ struct TLP_GL_SCOPE OcclusionTest {
   bool addRectangle(const RectangleInt2D &rec) {
     if (!testRectangle(rec)) {
       data.push_back(rec);
-      return false;
+      return true;
     }
 
-    return true;
+    return false;
   }
   /**
   * @brief test wehter or nor the AABB intersect with a AABB already inserted.
@@ -64,9 +68,8 @@ struct TLP_GL_SCOPE OcclusionTest {
   */
   bool testRectangle(const RectangleInt2D &rec) {
     bool intersect=false;
-    std::vector<RectangleInt2D>::const_iterator it;
 
-    for (it=data.begin(); it!=data.end(); ++it) {
+    for (std::vector<RectangleInt2D>::const_iterator it=data.begin(); it!=data.end(); ++it) {
       if (rec.intersect(*it)) {
         intersect=true;
         break;
@@ -82,3 +85,4 @@ struct TLP_GL_SCOPE OcclusionTest {
 
 #endif //DOXYGEN_NOTFOR_DEVEL
 #endif
+///@endcond
