@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,35 +16,20 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef Tulip_OPENGLCONFIGMANAGER_H
 #define Tulip_OPENGLCONFIGMANAGER_H
 
-#include <cassert>
-#include <iostream>
-
-#if defined(_MSC_VER)
-#include <Windows.h>
-#endif
-
-#if defined(__APPLE__)
-#include <OpenGL/gl.h>
-#include <OpenGL/glu.h>
-#else
-#include <GL/gl.h>
-#include <GL/glu.h>
-# if defined(__WIN32__)
-# include <GL/glext.h>
-# endif
-#endif
-
 #include <tulip/tulipconf.h>
 
+#include <map>
+#include <string>
+
 #define BUFFER_OFFSET(bytes) ((GLubyte*) NULL + (bytes))
 
 namespace tlp {
 
-class OpenGlErrorViewer;
-
 /** \brief Singleton used to manage OpenGl configuration
  *
  * Singleton used to manage OpenGl configuration
@@ -56,55 +41,60 @@ public:
   /**
    * Return the current instance. If instance doesn't exist, create it.
    */
-  static OpenGlConfigManager &getInst() {
-    if(!inst)
-      inst=new OpenGlConfigManager();
-
-    return *inst;
-  }
+  static OpenGlConfigManager &getInst();
 
   /**
-   * Change the error viewer and return the old one
+   * Returns the OpenGL version number supported by the host system.
    */
-  OpenGlErrorViewer *setErrorViewer(OpenGlErrorViewer *errorViewer);
+  double getOpenGLVersion();
 
   /**
-   * Check if system has good graphics card drivers
+   * Return the vendor name of the OpenGL driver installed on the host system.
    */
-  void checkDrivers();
+  std::string getOpenGLVendor();
 
   /**
-   * Init Glew
+   * Checks if an OpenGL extension is supported by the driver installed on the host system.
+   * \param extensionName the name of the OpenGL extension to check in the form "GL_.*" (for instance "GL_ARB_vertex_buffer_object")
    */
-  void initGlew();
+  bool isExtensionSupported(const std::string &extensionName);
 
   /**
-   * Glew is init
+   * Returns if vertex buffer objects can be used on the host system.
    */
-  bool glewIsInit() {
-    return glewIsChecked;
-  }
+  bool hasVertexBufferObject();
 
   /**
-   * Return if glew can be used
+   * Enables / disables anti-aliasing rendering.
    */
-  bool canUseGlew() {
-    if(!glewIsChecked)
-      return false;
-
-    return glewIsOk;
-  }
-
   void setAntiAliasing(const bool antialiasing) {
     antialiased = antialiasing;
   }
 
+  /**
+   * Activates the anti-aliasing of lines and points primitives.
+   * This method has no effect if anti-aliasing has been disabled by a call to setAntiAliasing(false).
+   */
   void activateLineAndPointAntiAliasing();
+
+  /**
+   * Desactivates the anti-aliasing of lines and points primitives.
+   * This method has no effect if anti-aliasing has been disabled by a call to setAntiAliasing(false).
+   */
   void desactivateLineAndPointAntiAliasing();
 
+  /**
+   * Activates the anti-aliasing of polygons primitives.
+   * This method has no effect if anti-aliasing has been disabled by a call to setAntiAliasing(false).
+   */
   void activatePolygonAntiAliasing();
+  /**
+   * Desactivates the anti-aliasing of polygons primitives.
+   * This method has no effect if anti-aliasing has been disabled by a call to setAntiAliasing(false).
+   */
   void desactivatePolygonAntiAliasing();
 
+  void initExtensions();
 
 private:
 
@@ -115,15 +105,15 @@ private:
 
   static OpenGlConfigManager* inst;
 
-  OpenGlErrorViewer *errorViewer;
-
-  bool glewIsChecked;
+  bool glewIsInit;
   bool driversAreChecked;
-  bool glewIsOk;
   bool antialiased;
 
+  std::map<std::string, bool> checkedExtensions;
+
 };
 
 }
 
 #endif
+///@endcond
