@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,11 +16,14 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef PARAMETRICCURVES_H_
 #define PARAMETRICCURVES_H_
 
 #include <vector>
 
+#include <tulip/tulipconf.h>
 #include <tulip/Coord.h>
 
 namespace tlp {
@@ -35,7 +38,7 @@ TLP_GL_SCOPE void buildPascalTriangle(unsigned int n, std::vector<std::vector<do
 
 /**
  * Compute the position of a point 'p' at t (0 <= t <= 1)
- * along Bézier curve defined by a set of control points
+ * along Bezier curve defined by a set of control points
  *
  * \param controlPoints a vector of control points
  * \param t curve parameter value (0 <= t <= 1)
@@ -105,3 +108,4 @@ TLP_GL_SCOPE void computeOpenUniformBsplinePoints(const std::vector<Coord> &cont
 }
 
 #endif /* PARAMETRICCURVES_H_ */
+///@endcond
