@@ -1,4 +1,4 @@
-/**
+/*
  *
  * This file is part of Tulip (www.tulip-software.org)
  *
@@ -16,21 +16,12 @@
  * See the GNU General Public License for more details.
  *
  */
+///@cond DOXYGEN_HIDDEN
+
 #ifndef TULIPGPU_H
 #define TULIPGPU_H
 
-#include <tulip/libgpugraph.h>
-
-#include <tulip/Graph.h>
-#include <tulip/Color.h>
-#include <tulip/Coord.h>
-#include <tulip/Size.h>
-#include <tulip/BooleanProperty.h>
-#include <tulip/ColorProperty.h>
-#include <tulip/DoubleProperty.h>
-#include <tulip/IntegerProperty.h>
-#include <tulip/LayoutProperty.h>
-#include <tulip/SizeProperty.h>
+#include <tulip/tulipconf.h>
 
 namespace tlp {
 
@@ -95,3 +86,4 @@ TLP_GL_SCOPE bool getGpuOutPropertyValues(tlp::SizeProperty& prop, const tlp::Gr
 }
 
 #endif
+///@endcond
