@@ -16,6 +16,7 @@
  * See the GNU General Public License for more details.
  *
  */
+
 #include <GL/glew.h>
 
 #include <tulip/OpenGlConfigManager.h>
@@ -23,6 +24,9 @@
 #include <tulip/GlTextureManager.h>
 #include <tulip/Curves.h>
 #include <tulip/TlpTools.h>
+#include <tulip/GlShaderProgram.h>
+
+#include <sstream>
 
 using namespace std;
 
@@ -1012,8 +1016,8 @@ void AbstractGlCurve::translate(const Coord &move) {
   boundingBox.translate(move);
 }
 
-void AbstractGlCurve::getXML(xmlNodePtr) {}
+void AbstractGlCurve::getXML(string &) {}
 
-void AbstractGlCurve::setWithXML(xmlNodePtr) {}
+void AbstractGlCurve::setWithXML(const string &,unsigned int &) {}
 
 }
