@@ -22,8 +22,19 @@
 
 #include <tulip/GlTools.h>
 #include <tulip/GlScene.h>
+#include <tulip/GlXMLTools.h>
 
-#include <iostream>
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
 
 using namespace std;
 
@@ -37,7 +48,6 @@ Camera::Camera(GlScene* scene,Coord center,Coord eyes, Coord up, double zoomFact
   zoomFactor(zoomFactor),
   sceneRadius(sceneRadius),
   scene(scene),
-  objectTransformation(false),
   d3(true) {}
 //====================================================
 Camera::Camera(GlScene* scene,bool d3) :
@@ -49,27 +59,27 @@ Camera::~Camera() {
 //===================================================
 Camera& Camera::operator=(const Camera& camera) {
   matrixCoherent=false;
-  center=camera.center;
-  eyes=camera.eyes;
-  up=camera.up;
-  zoomFactor=camera.zoomFactor;
-  sceneRadius=camera.sceneRadius;
-  sceneBoundingBox=camera.sceneBoundingBox;
-  scene=camera.scene;
-  modelviewMatrix = camera.modelviewMatrix;
-  projectionMatrix = camera.projectionMatrix;
-  transformMatrix = camera.transformMatrix;
-  objectTranslation = camera.objectTranslation;
-  objectScale = camera.objectScale;
-  objectCoord = camera.objectCoord;
-  objectTransformation = camera.objectTransformation;
-  d3=camera.d3;
+  center=camera.getCenter();
+  eyes=camera.getEyes();
+  up=camera.getUp();
+  zoomFactor=camera.getZoomFactor();
+  sceneRadius=camera.getSceneRadius();
+  sceneBoundingBox=camera.getBoundingBox();
+  scene=camera.getScene();
+  d3=camera.is3D();
   return *this;
 }
 //===================================================
 void Camera::setScene(GlScene* scene) {
   this->scene=scene;
 }
+//===================================================
+BoundingBox Camera::getBoundingBox() const {
+  BoundingBox bb;
+  bb.expand(screenTo3DWorld(Coord(scene->getViewport()[0],scene->getViewport()[1],0)));
+  bb.expand(screenTo3DWorld(Coord(scene->getViewport()[0]+scene->getViewport()[2],scene->getViewport()[1]+scene->getViewport()[3],0)));
+  return bb;
+}
 //====================================================
 void Camera::move(float speed) {
   Coord move = eyes - center;
@@ -163,19 +173,23 @@ void Camera::initGl() {
 }
 //====================================================
 void Camera::initLight() {
+
+#ifndef NDEBUG
   GLuint error = glGetError();
 
   if ( error != GL_NO_ERROR)
-    cerr << "[OpenGL Error] => " << gluErrorString(error) << endl << "\tin : " << __PRETTY_FUNCTION__ << " begin" << endl;
+    tlp::warning() << "[OpenGL Error] => " << gluErrorString(error) << endl << "\tin : " << __PRETTY_FUNCTION__ << " begin" << endl;
+
+#endif
 
   GLfloat pos[4];
 
   if(d3) {
     // set positional light for 3D camera
     eyes.get(pos[0],pos[1],pos[2]);
-    pos[0]=pos[0] + ((eyes[0]-center[0])/static_cast<float>(zoomFactor)) + (eyes[0]-center[0])*4;
-    pos[1]=pos[1] + ((eyes[1]-center[1])/static_cast<float>(zoomFactor)) + (eyes[1]-center[1])*4;
-    pos[2]=pos[2] + ((eyes[2]-center[2])/static_cast<float>(zoomFactor)) + (eyes[2]-center[2])*4;
+    pos[0]=pos[0] + ((eyes[0]-center[0])/zoomFactor) + (eyes[0]-center[0])*4;
+    pos[1]=pos[1] + ((eyes[1]-center[1])/zoomFactor) + (eyes[1]-center[1])*4;
+    pos[2]=pos[2] + ((eyes[2]-center[2])/zoomFactor) + (eyes[2]-center[2])*4;
     pos[3]=1;
   }
   else {
@@ -186,12 +200,12 @@ void Camera::initLight() {
     pos[3]=0;
   }
 
-  GLfloat amb[4] = {0.3f, 0.3f, 0.3f, 0.3f};
-  GLfloat dif[4] = {0.5f, 0.5f, 0.5f, 1.0f};
-  GLfloat specular[4] = {0.0f, 0.0f, 0.0f, 1.0f};
-  GLfloat attC[3] = {1.0f, 1.0f, 1.0f};
-  GLfloat attL[3] = {0.0f, 0.0f, 0.0f};
-  GLfloat attQ[3] = {0.0f, 0.0f, 0.0f};
+  GLfloat amb[4] = {0.3f,0.3f , 0.3f ,0.3f};
+  GLfloat dif[4] = {0.5f,0.5f,0.5f,1.0f};
+  GLfloat specular[4] = {0.0f,0.0f,0.0f,1.0f};
+  GLfloat attC[3] = {1.0f,1.0f,1.0f};
+  GLfloat attL[3] = {0.0f,0.0f,0.0f};
+  GLfloat attQ[3] = {0.0f,0.0f,0.0f};
 
   glEnable( GL_LIGHTING );
   glEnable( GL_LIGHT0 );
@@ -203,10 +217,14 @@ void Camera::initLight() {
   glLightfv( GL_LIGHT0, GL_LINEAR_ATTENUATION, attL );
   glLightfv( GL_LIGHT0, GL_QUADRATIC_ATTENUATION, attQ );
   glLightfv( GL_LIGHT0, GL_SPECULAR , specular);
+
+#ifndef NDEBUG
   error = glGetError();
 
   if ( error != GL_NO_ERROR)
-    cerr << "[OpenGL Error] => " << gluErrorString(error) << endl << "\tin : " << __PRETTY_FUNCTION__ << "end" << endl;
+    tlp::warning() << "[OpenGL Error] => " << gluErrorString(error) << endl << "\tin : " << __PRETTY_FUNCTION__ << "end" << endl;
+
+#endif
 }
 //====================================================
 void Camera::initProjection(const Vector<int, 4>& viewport,bool reset) {
@@ -217,7 +235,12 @@ void Camera::initProjection(const Vector<int, 4>& viewport,bool reset) {
   double _near;
   double _far;
 
-  if(sceneBoundingBox.isValid() && sceneBoundingBox[0]!=sceneBoundingBox[1]) {
+
+  bool valid = sceneBoundingBox.isValid();
+  Vec3f v1 = sceneBoundingBox[0];
+  Vec3f v2 = sceneBoundingBox[1];
+
+  if(valid && v1 != v2) {
     sceneBoundingBox.expand(eyes);
     Coord diagCoord(sceneBoundingBox[1]-sceneBoundingBox[0]);
     double diag=2*sqrt(diagCoord[0]*diagCoord[0]+diagCoord[1]*diagCoord[1]+diagCoord[2]*diagCoord[2]);
@@ -230,7 +253,7 @@ void Camera::initProjection(const Vector<int, 4>& viewport,bool reset) {
   }
 
   if(d3) {
-    float ratio = static_cast<float>(viewport[2])/static_cast<float>(viewport[3]);
+    float ratio = double(viewport[2])/double(viewport[3]);
 
     if(scene->isViewOrtho()) {
       if (ratio>1)
@@ -260,10 +283,13 @@ void Camera::initProjection(const Vector<int, 4>& viewport,bool reset) {
     glDisable(GL_DEPTH_TEST);
   }
 
+#ifndef NDEBUG
   GLenum error = glGetError();
 
   if ( error != GL_NO_ERROR)
-    cerr << "[OpenGL Error] => " << gluErrorString(error) << endl << "\tin : " << __PRETTY_FUNCTION__ << endl;
+    tlp::warning() << "[OpenGL Error] => " << gluErrorString(error) << endl << "\tin : " << __PRETTY_FUNCTION__ << endl;
+
+#endif
 }
 //====================================================
 void Camera::initProjection(bool reset) {
@@ -294,10 +320,14 @@ void Camera::initModelView() {
   glGetFloatv(GL_MODELVIEW_MATRIX, (GLfloat*)&transformMatrix);
   glPopMatrix();
   matrixCoherent=true;
+
+#ifndef NDEBUG
   GLenum error = glGetError();
 
   if ( error != GL_NO_ERROR)
-    cerr << "[OpenGL Error] => " << gluErrorString(error) << endl << "\tin : " << __PRETTY_FUNCTION__ << endl;
+    tlp::warning() << "[OpenGL Error] => " << gluErrorString(error) << endl << "\tin : " << __PRETTY_FUNCTION__ << endl;
+
+#endif
 }
 //====================================================
 void Camera::setSceneRadius(double sceneRadius,const BoundingBox sceneBoundingBox) {
@@ -344,24 +374,6 @@ void Camera::setUp(const Coord& up) {
     sendEvent(Event(*this, Event::TLP_MODIFICATION));
 }
 //====================================================
-void Camera::addObjectTransformation(const Coord &translation,const Coord &scale,const Coord &baseCoord ) {
-  objectScale.push_back(scale);
-  objectTranslation.push_back(translation);
-  objectCoord.push_back(baseCoord);
-
-  objectTransformation=true;
-}
-//====================================================
-void Camera::getObjectTransformation(vector<Coord> &translation,vector<Coord> &scale,vector<Coord> &objectCoord) {
-  translation=objectTranslation;
-  scale=objectScale;
-  objectCoord=this->objectCoord;
-}
-//====================================================
-bool Camera::haveObjectTransformation() {
-  return objectTransformation;
-}
-//====================================================
 void Camera::getProjAndMVMatrix(const Vector<int, 4>& viewport,Matrix<float, 4> &projectionMatrix,Matrix<float, 4> &modelviewMatrix) const {
   glMatrixMode(GL_PROJECTION);
   glPushMatrix();
@@ -417,54 +429,53 @@ Coord Camera::worldTo2DScreen(const Coord &obj) const {
   ((Camera *)this)->initModelView();
 
   Vector<int, 4> viewport = getViewport();
-  return projectPoint(obj, transformMatrix, viewport) - Coord(static_cast<float>(viewport[0]), static_cast<float>(viewport[1]));
+  return projectPoint(obj, transformMatrix, viewport) - Coord(viewport[0], viewport[1]);
 }
 //====================================================
 Vector<int, 4> Camera::getViewport() const {
   return scene->getViewport();
 }
 //====================================================
-void Camera::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode= NULL;
-
-  stringstream strZF;
-  stringstream strSR;
-  stringstream strD3;
-
-  GlXMLTools::createDataNode(rootNode,dataNode);
-  GlXMLTools::getXML(dataNode,"center",center);
-  GlXMLTools::getXML(dataNode,"eyes",eyes);
-  GlXMLTools::getXML(dataNode,"up",up);
-  GlXMLTools::getXML(dataNode,"zoomFactor",zoomFactor);
-  GlXMLTools::getXML(dataNode,"sceneRadius",sceneRadius);
-  GlXMLTools::getXML(dataNode,"d3",d3);
+void Camera::getXML(string &outString) {
+  GlXMLTools::beginDataNode(outString);
+  GlXMLTools::getXML(outString,"center",center);
+  GlXMLTools::getXML(outString,"eyes",eyes);
+  GlXMLTools::getXML(outString,"up",up);
+  GlXMLTools::getXML(outString,"zoomFactor",zoomFactor);
+  GlXMLTools::getXML(outString,"sceneRadius",sceneRadius);
+  GlXMLTools::getXML(outString,"d3",d3);
 
   if(sceneBoundingBox.isValid()) {
-    GlXMLTools::getXML(dataNode,"sceneBoundingBox0",Coord(sceneBoundingBox[0]));
-    GlXMLTools::getXML(dataNode,"sceneBoundingBox1",Coord(sceneBoundingBox[1]));
+    GlXMLTools::getXML(outString,"sceneBoundingBox0",Coord(sceneBoundingBox[0]));
+    GlXMLTools::getXML(outString,"sceneBoundingBox1",Coord(sceneBoundingBox[1]));
   }
+
+  GlXMLTools::endDataNode(outString);
 }
 //====================================================
-void Camera::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode= NULL;
+void Camera::setWithXML(const string &inString, unsigned int &currentPosition) {
 
-  GlXMLTools::getDataNodeDirectly(rootNode,dataNode);
+  GlXMLTools::enterDataNode(inString,currentPosition);
 
-  if(dataNode) {
+  Coord bbTmp;
 
-    Coord bbTmp;
+  GlXMLTools::setWithXML(inString,currentPosition,"center",center);
+  GlXMLTools::setWithXML(inString,currentPosition,"eyes",eyes);
+  GlXMLTools::setWithXML(inString,currentPosition,"up",up);
+  GlXMLTools::setWithXML(inString,currentPosition,"zoomFactor",zoomFactor);
+  GlXMLTools::setWithXML(inString,currentPosition,"sceneRadius",sceneRadius);
+  GlXMLTools::setWithXML(inString,currentPosition,"d3",d3);
 
-    GlXMLTools::setWithXML(dataNode,"center",center);
-    GlXMLTools::setWithXML(dataNode,"eyes",eyes);
-    GlXMLTools::setWithXML(dataNode,"up",up);
-    GlXMLTools::setWithXML(dataNode,"zoomFactor",zoomFactor);
-    GlXMLTools::setWithXML(dataNode,"sceneRadius",sceneRadius);
-    GlXMLTools::setWithXML(dataNode,"d3",d3);
-    GlXMLTools::setWithXML(dataNode,"sceneBoundingBox0",bbTmp);
+  if(GlXMLTools::checkNextXMLtag(inString,currentPosition,"sceneBoundingBox0")) {
+    GlXMLTools::setWithXML(inString,currentPosition,"sceneBoundingBox0",bbTmp);
     sceneBoundingBox.expand(bbTmp);
-    GlXMLTools::setWithXML(dataNode,"sceneBoundingBox1",bbTmp);
-    sceneBoundingBox.expand(bbTmp);
-
   }
+
+  if(GlXMLTools::checkNextXMLtag(inString,currentPosition,"sceneBoundingBox1")) {
+    GlXMLTools::setWithXML(inString,currentPosition,"sceneBoundingBox1",bbTmp);
+    sceneBoundingBox.expand(bbTmp);
+  }
+
+  GlXMLTools::leaveDataNode(inString,currentPosition);
 }
 }
