@@ -18,13 +18,14 @@
  */
 #include <tulip/Glyph.h>
 #include <tulip/GlBox.h>
+#include <tulip/GlGraphRenderingParameters.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 
 namespace tlp {
 
-/** \addtogroup glyph */
-/*@{*/
 /// A 3D glyph.
 /** This glyph draws a textured cube using the "viewTexture" node
  * property value. If this property has no value, the cube is then colored
@@ -33,26 +34,23 @@ namespace tlp {
  */
 class CubeOutLined : public Glyph {
 public:
-  CubeOutLined(GlyphContext *gc=NULL);
+  GLYPHINFORMATION("3D - Cube OutLined", "David Auber", "09/07/2002", "Textured cubeOutLined", "1.0", NodeShape::CubeOutlined)
+  CubeOutLined(tlp::PluginContext* context);
   virtual ~CubeOutLined();
   virtual void draw(node n,float lod);
   virtual Coord getAnchor(const Coord & vector) const;
-
 protected:
-
   static GlBox* box;
-
 };
 }
-
-tlp::GlBox* tlp::CubeOutLined::box=0;
+tlp::GlBox* tlp::CubeOutLined::box=NULL;
 
 namespace tlp {
-GLYPHPLUGIN(CubeOutLined, "3D - Cube OutLined", "David Auber", "09/07/2002", "Textured cubeOutLined", "1.0", 1);
-/*@}*/
+PLUGIN(CubeOutLined)
+
 
 //===================================================================================
-CubeOutLined::CubeOutLined(GlyphContext *gc): Glyph(gc) {
+CubeOutLined::CubeOutLined(tlp::PluginContext* context): Glyph(context) {
   if(!box)
     box = new GlBox(Coord(0,0,0),Size(1,1,1),Color(0,0,0,255),Color(0,0,0,255));
 }
@@ -78,7 +76,7 @@ void CubeOutLined::draw(node n, float lod) {
   if(lineWidth < 1e-6)
     lineWidth=1e-6;
 
-  box->setOutlineSize(static_cast<float>(lineWidth));
+  box->setOutlineSize(lineWidth);
 
   box->draw(lod,NULL);
 }
