@@ -25,6 +25,7 @@
 #include <tulip/GlTextureManager.h>
 #include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlShaderProgram.h>
+#include <tulip/GlTools.h>
 
 using namespace std;
 using namespace tlp;
@@ -235,7 +236,7 @@ GLfloat* buildCurvePoints (const vector<Coord> &vertices,
 }
 
 static int computeExtrusion(const Coord &pBefore, const Coord &pCurrent, const Coord &pAfter,
-                            float size, int inversion, vector<Coord> &result, bool lastPoint = false, bool twoPointsCurve=false) {
+                            float size, float inversion, vector<Coord> &result, bool lastPoint = false, bool twoPointsCurve=false) {
 
   Coord u = pBefore - pCurrent;
   Coord v = pAfter - pCurrent;
@@ -244,8 +245,16 @@ static int computeExtrusion(const Coord &pBefore, const Coord &pCurrent, const C
 
   if (fabs(v[2]) < 1e-3) v[2] = 0;
 
-  Coord xu = u / u.norm();
-  Coord xv = v / v.norm();
+  Coord xu(u);
+
+  if(u.norm()!=0)
+    xu /= u.norm();
+
+  Coord xv(v);
+
+  if(v.norm()!=0)
+    xv/=v.norm();
+
   Coord bi_xu_xv = xu+xv;
 
   float newSize=size;
@@ -328,7 +337,9 @@ void buildCurvePoints (const vector<Coord> &vertices,
                        vector<Coord> &result) {
 
   int inversion=1;
-  bool twoPointsCurve=(vertices.size() == 2);
+  bool twoPointsCurve=(vertices.size()==2);
+
+  result.reserve(vertices.size()*2);
 
   if (startN != vertices[0]) {
     inversion = computeExtrusion(startN, vertices[0], vertices[1], sizes[0], inversion, result,false,twoPointsCurve);
@@ -384,7 +395,7 @@ void computeCleanVertices(const vector<Coord> &bends,
                           vector<Coord> &result) {
 
 
-  if (bends.size() > 0) {
+  if (!bends.empty()) {
     result.push_back(startPoint);
     Coord lastPoint = bends[0];
 
@@ -469,60 +480,60 @@ void polyQuad(const vector<Coord> &vertices,
               const string &textureName, const float outlineWidth) {
 
   vector<float> sizes;
+  getSizes(vertices, s1, s2, sizes);
 
   vector<Coord> quadVertices;
   vector<unsigned int> bottomOutlineIndices;
   vector<unsigned int> topOutlineIndices;
   vector<float> texCoords;
 
-  getSizes(vertices, s1, s2,sizes);
   buildCurvePoints(vertices, sizes, startN, endN, quadVertices);
 
   if (GlShaderProgram::getCurrentActiveShader() && GlShaderProgram::getCurrentActiveShader()->getName() == "fisheye") {
     const float nbSubDiv = 20.f;
     vector<Coord> newVertices;
-    vector<float> newSizes;
     newVertices.push_back(quadVertices[0]);
     newVertices.push_back(quadVertices[1]);
-    newSizes.push_back(sizes[0]);
 
     for (size_t i = 0 ; i < quadVertices.size()/2 - 1 ; ++i) {
       for (float j = 1 ; j < nbSubDiv ; ++j) {
         newVertices.push_back(quadVertices[2*i] + (j/(nbSubDiv-1)) * (quadVertices[2*(i+1)] - quadVertices[2*i]));
         newVertices.push_back(quadVertices[2*i+1] + (j/(nbSubDiv-1)) * (quadVertices[2*(i+1)+1] - quadVertices[2*i+1]));
-        newSizes.push_back(sizes[i] + (j/(nbSubDiv-1)) * (sizes[i+1] - sizes[i]));
       }
     }
 
     quadVertices = newVertices;
-    sizes = newSizes;
   }
 
   float length = 0;
   vector<Coord> centerLine;
-  centerLine.reserve(quadVertices.size()/2);
+
+  centerLine.resize(quadVertices.size()/2);
+  bottomOutlineIndices.resize(quadVertices.size()/2);
+  topOutlineIndices.resize(quadVertices.size()/2);
+  texCoords.resize(quadVertices.size()*2);
 
   for (size_t i = 0 ; i < quadVertices.size() / 2 ; ++i) {
-    centerLine.push_back((quadVertices[2*i]+quadVertices[2*i+1])/2);
-    bottomOutlineIndices.push_back(2*i);
-    topOutlineIndices.push_back(2*i+1);
+    centerLine[i]=(quadVertices[2*i]+quadVertices[2*i+1])/2.f;
+    bottomOutlineIndices[i]=2*i;
+    topOutlineIndices[i]=2*i+1;
 
     if (i == 0) {
-      texCoords.push_back(0);
-      texCoords.push_back(0);
-      texCoords.push_back(0);
-      texCoords.push_back(1);
+      texCoords[0]=0;
+      texCoords[1]=0;
+      texCoords[2]=0;
+      texCoords[3]=1;
     }
     else {
       Coord p1_0 = quadVertices[2*(i-1)];
       Coord p1_1 = quadVertices[2*i];
       Coord p2_0 = quadVertices[2*(i-1)+1];
       Coord p2_1 = quadVertices[2*i+1];
-      length += ((p1_1+p2_1)/2.-(p1_0+p2_0)/2.).norm()/(p1_0-p2_0).norm();
-      texCoords.push_back(length);
-      texCoords.push_back(0);
-      texCoords.push_back(length);
-      texCoords.push_back(1);
+      length += ((p1_1+p2_1)/2.f-(p1_0+p2_0)/2.f).norm()/(p1_0-p2_0).norm();
+      texCoords[i*4]=length;
+      texCoords[i*4+1]=0;
+      texCoords[i*4+2]=length;
+      texCoords[i*4+3]=1;
     }
   }
 
@@ -530,11 +541,11 @@ void polyQuad(const vector<Coord> &vertices,
   getColors(centerLine, c1, c2,colors);
 
   vector<Color> quadColors;
-  quadColors.reserve(quadVertices.size());
+  quadColors.resize(quadVertices.size());
 
   for (size_t i = 0 ; i < colors.size() ; ++i) {
-    quadColors.push_back(colors[i]);
-    quadColors.push_back(colors[i]);
+    quadColors[i*2]=colors[i];
+    quadColors[i*2+1]=colors[i];
   }
 
   if(textureName!="") {
@@ -696,7 +707,7 @@ void simpleQuad(const vector<Coord> &vertices,
       Coord p2_0(points[i*3 + size*3 - 3],points[i*3 + size*3-2],points[i*3 + size*3-1]);
       Coord p2_1(points[i*3 + size*3],points[i*3 + size*3+1],points[i*3 + size*3+2]);
 
-      length += ((p1_1+p2_1)/2.-(p1_0+p2_0)/2.).norm()/(p1_0-p2_0).norm();
+      length += ((p1_1+p2_1)/2.f-(p1_0+p2_0)/2.f).norm()/(p1_0-p2_0).norm();
       glMultiTexCoord2f(GL_TEXTURE0,length, 1.0f);
       glMultiTexCoord2f(GL_TEXTURE1,length, 1.0f);
       glVertex3fv(&points[i*3]);
