@@ -17,17 +17,16 @@
  *
  */
 #include <tulip/EdgeExtremityGlyph.h>
+#include <tulip/Glyph.h>
 #include <tulip/Vector.h>
 
-namespace tlp {
-TemplateFactory<EdgeExtremityGlyphFactory, EdgeExtremityGlyph, EdgeExtremityGlyphContext *>
-*EdgeExtremityGlyphFactory::factory;
-EdgeExtremityGlyph::EdgeExtremityGlyph(EdgeExtremityGlyphContext *gc) {
-  if (gc != 0) {
-    edgeExtGlGraphInputData = gc->glGraphInputData;
-  }
-  else {
-    edgeExtGlGraphInputData = 0;
+using namespace tlp;
+
+EdgeExtremityGlyph::EdgeExtremityGlyph(const PluginContext* context) : edgeExtGlGraphInputData(NULL) {
+  if(context != NULL) {
+    const GlyphContext* glyphContext = dynamic_cast<const GlyphContext*>(context);
+    assert(glyphContext != NULL);
+    edgeExtGlGraphInputData = glyphContext->glGraphInputData;
   }
 }
 
@@ -35,16 +34,7 @@ EdgeExtremityGlyph::~EdgeExtremityGlyph() {
 
 }
 
-EdgeExtremityGlyphFrom3DGlyph::EdgeExtremityGlyphFrom3DGlyph(EdgeExtremityGlyphContext *gc) :
-  EdgeExtremityGlyph(gc) {
-
-}
-EdgeExtremityGlyphFrom3DGlyph::~EdgeExtremityGlyphFrom3DGlyph() {
-
-}
-
-void EdgeExtremityGlyphFrom3DGlyph::getTransformationMatrix(const Coord &src, const Coord &dest,
-    const Size &glyphSize, MatrixGL& transformationMatrix, MatrixGL& scalingMatrix) {
+void EdgeExtremityGlyph::get3DTransformationMatrix(const Coord &src, const Coord &dest, const Size &glyphSize, MatrixGL& transformationMatrix, MatrixGL& scalingMatrix) {
   //Vecteur AB
   Vector<float, 3> vAB;
   //Vecteur V
@@ -61,19 +51,19 @@ void EdgeExtremityGlyphFrom3DGlyph::getTransformationMatrix(const Coord &src, co
 
   //vAB * vV = xAB * xV + yAB*yV + zAB * zV = |AB| * |V| * cos(alpha) = 0;
   if (fabs(vAB[2]) < 1E-6) {
-    vV[0] = 0.0f;
-    vV[1] = 0.0f;
-    vV[2] = 1.0f;
+    vV[0] = 0;
+    vV[1] = 0;
+    vV[2] = 1.0;
   }
   else if (fabs(vAB[1]) < 1E-6) {
-    vV[0] = 0.0f;
-    vV[1] = 1.0f;
-    vV[2] = 0.0f;
+    vV[0] = 0;
+    vV[1] = 1.0;
+    vV[2] = 0;
   }
   else {
-    vV[0] = 0.0f;
-    vV[1] = 1.0f / vAB[1];
-    vV[2] = -1.0f / vAB[2];
+    vV[0] = 0;
+    vV[1] = 1. / vAB[1];
+    vV[2] = -1. / vAB[2];
     vV /= vV.norm();
   }
 
@@ -87,7 +77,7 @@ void EdgeExtremityGlyphFrom3DGlyph::getTransformationMatrix(const Coord &src, co
     transformationMatrix[0][i] = vW[i];
     transformationMatrix[1][i] = vV[i];
     transformationMatrix[2][i] = vAB[i];
-    transformationMatrix[3][i] = dest[i] + (-glyphSize[0] * 0.5f * vAB[i]);
+    transformationMatrix[3][i] = dest[i] + (-glyphSize[0] * .5 * vAB[i]);
   }
 
   transformationMatrix[0][3] = 0;
@@ -102,17 +92,7 @@ void EdgeExtremityGlyphFrom3DGlyph::getTransformationMatrix(const Coord &src, co
   scalingMatrix[3][3] = 1;
 }
 
-
-EdgeExtremityGlyphFrom2DGlyph::EdgeExtremityGlyphFrom2DGlyph(EdgeExtremityGlyphContext *gc) :
-  EdgeExtremityGlyph(gc) {
-
-}
-EdgeExtremityGlyphFrom2DGlyph::~EdgeExtremityGlyphFrom2DGlyph() {
-
-}
-
-void EdgeExtremityGlyphFrom2DGlyph::getTransformationMatrix(const Coord &src, const Coord &dest,
-    const Size &glyphSize, MatrixGL& transformationMatrix, MatrixGL& scalingMatrix) {
+void EdgeExtremityGlyph::get2DTransformationMatrix(const Coord &src, const Coord &dest, const Size &glyphSize, MatrixGL& transformationMatrix, MatrixGL& scalingMatrix) {
   //  Vecteur AB
   Vector<float, 3> vAB;
   //Vecteur V
@@ -129,19 +109,19 @@ void EdgeExtremityGlyphFrom2DGlyph::getTransformationMatrix(const Coord &src, co
 
   //vAB * vV = xAB * xV + yAB*yV + zAB * zV = |AB| * |V| * cos(alpha) = 0;
   if (fabs(vAB[2]) < 1E-6) {
-    vV[0] = 0.0f;
-    vV[1] = 0.0f;
-    vV[2] = 1.0f;
+    vV[0] = 0;
+    vV[1] = 0;
+    vV[2] = 1.0;
   }
   else if (fabs(vAB[1]) < 1E-6) {
-    vV[0] = 0.0f;
-    vV[1] = 1.0f;
-    vV[2] = 0.0f;
+    vV[0] = 0;
+    vV[1] = 1.0;
+    vV[2] = 0;
   }
   else {
-    vV[0] = 0.0f;
-    vV[1] = 1.0f / vAB[1];
-    vV[2] = -1.0f / vAB[2];
+    vV[0] = 0;
+    vV[1] = 1. / vAB[1];
+    vV[2] = -1. / vAB[2];
     vV /= vV.norm();
   }
 
@@ -155,7 +135,7 @@ void EdgeExtremityGlyphFrom2DGlyph::getTransformationMatrix(const Coord &src, co
     transformationMatrix[0][i] = vAB[i];
     transformationMatrix[1][i] = vW[i];
     transformationMatrix[2][i] = vV[i];
-    transformationMatrix[3][i] = dest[i] + (-glyphSize[0] * 0.5f * vAB[i]);
+    transformationMatrix[3][i] = dest[i] + (-glyphSize[0] * .5 * vAB[i]);
   }
 
   transformationMatrix[0][3] = 0;
@@ -169,7 +149,3 @@ void EdgeExtremityGlyphFrom2DGlyph::getTransformationMatrix(const Coord &src, co
   scalingMatrix[2][2] = glyphSize[2];
   scalingMatrix[3][3] = 1;
 }
-
-
-}
-
