@@ -19,8 +19,11 @@
 #include <tulip/EdgeExtremityGlyph.h>
 #include <tulip/EdgeExtremityGlyphManager.h>
 #include <tulip/tuliphash.h>
+#include <tulip/ForEach.h>
+#include <tulip/Glyph.h>
+#include <tulip/TulipViewSettings.h>
 
-tlp::EdgeExtremityGlyphManager* tlp::EdgeExtremityGlyphManager::eeinst = 0;
+tlp::EdgeExtremityGlyphManager* tlp::EdgeExtremityGlyphManager::eeinst = NULL;
 
 using namespace std;
 
@@ -28,14 +31,11 @@ namespace tlp {
 static TLP_HASH_MAP<int, std::string> eeglyphIdToName;
 static TLP_HASH_MAP<std::string, int> nameToEeGlyphId;
 
-const int EdgeExtremityGlyphManager::NoEdgeExtremetiesId = UINT_MAX;
-
 EdgeExtremityGlyphManager::EdgeExtremityGlyphManager() {
-  EdgeExtremityGlyphFactory::initFactory();
 }
 //====================================================
 string EdgeExtremityGlyphManager::glyphName(int id) {
-  if (id == NoEdgeExtremetiesId) {
+  if (id == EdgeExtremityShape::None) {
     return string("NONE");
   }
 
@@ -43,103 +43,62 @@ string EdgeExtremityGlyphManager::glyphName(int id) {
     return eeglyphIdToName[id];
   }
   else {
-    cerr << __PRETTY_FUNCTION__ << endl;
-    cerr << "Invalid glyph id" << endl;
+    tlp::warning() << __PRETTY_FUNCTION__ << endl;
+    tlp::warning() << "Invalid glyph id" << endl;
     return string("invalid");
   }
 }
 //====================================================
 int EdgeExtremityGlyphManager::glyphId(string name) {
   if (name.compare("NONE") == 0) {
-    return NoEdgeExtremetiesId;
+    return EdgeExtremityShape::None;
   }
 
   if (nameToEeGlyphId.find(name) != nameToEeGlyphId.end()) {
     return nameToEeGlyphId[name];
   }
   else {
-    cerr << __PRETTY_FUNCTION__ << endl;
-    cerr << "Invalid glyph name" << endl;
+    tlp::warning() << __PRETTY_FUNCTION__ << endl;
+    tlp::warning() << "Invalid glyph name" << endl;
     return 0;
   }
 }
 //====================================================
 void EdgeExtremityGlyphManager::loadGlyphPlugins() {
-  Iterator<string> *itS =
-    EdgeExtremityGlyphFactory::factory->availablePlugins();
+  static std::list<std::string> plugins = PluginLister::instance()->availablePlugins<EdgeExtremityGlyph>();
 
-  while (itS->hasNext()) {
-    string pluginName = itS->next();
-    int pluginId =
-      EdgeExtremityGlyphFactory::factory->objMap[pluginName]->getId();
+  for(std::list<std::string>::const_iterator it = plugins.begin(); it != plugins.end(); ++it) {
+    string pluginName = *it;
+    int pluginId = PluginLister::pluginInformation(pluginName).id();
     eeglyphIdToName[pluginId] = pluginName;
     nameToEeGlyphId[pluginName] = pluginId;
   }
-
-  delete itS;
-
 }
 //====================================================
-void EdgeExtremityGlyphManager::loadPlugins(PluginLoader *plug) {
-  EdgeExtremityGlyphFactory::initFactory();
-  string::const_iterator begin = tlp::TulipPluginsPath.begin();
-  string::const_iterator end = begin;
-  eeglyphIdToName.clear();
-  nameToEeGlyphId.clear();
-
-  while (end != tlp::TulipPluginsPath.end())
-    if ((*end) == tlp::PATH_DELIMITER) {
-      if (begin != end)
-        tlp::loadPluginsFromDir(string(begin, end) + "/glyphs",
-                                "Glyph", plug);
-
-      ++end;
-      begin = end;
-    }
-    else
-      ++end;
-
-  if (begin != end) {
-    tlp::loadPluginsFromDir(string(begin, end) + "/glyphs", "Glyph", plug);
-  }
-
-  loadGlyphPlugins();
-}
-//
 void EdgeExtremityGlyphManager::initGlyphList(Graph **graph,
     GlGraphInputData* glGraphInputData, MutableContainer<
     EdgeExtremityGlyph *>& glyphs) {
-  EdgeExtremityGlyphContext gc = EdgeExtremityGlyphContext(graph,
+  GlyphContext gc = GlyphContext(graph,
                                  glGraphInputData);
   glyphs.setAll(0);
-  Iterator<string> *itS =
-    EdgeExtremityGlyphFactory::factory->availablePlugins();
 
-  while (itS->hasNext()) {
-    string glyphName = itS->next();
-    EdgeExtremityGlyph *newGlyph =
-      EdgeExtremityGlyphFactory::factory->getPluginObject(glyphName,
-          &gc);
-    glyphs.set(
-      EdgeExtremityGlyphFactory::factory->objMap[glyphName]->getId(),
-      newGlyph);
+
+  static std::list<std::string> plugins = PluginLister::instance()->availablePlugins<EdgeExtremityGlyph>();
+
+  for(std::list<std::string>::const_iterator it = plugins.begin(); it != plugins.end(); ++it) {
+    string glyphName = *it;
+    EdgeExtremityGlyph *newGlyph = PluginLister::instance()->getPluginObject<EdgeExtremityGlyph>(glyphName, &gc);
+    glyphs.set(PluginLister::pluginInformation(glyphName).id(), newGlyph);
   }
-
-  delete itS;
 }
 
-void EdgeExtremityGlyphManager::clearGlyphList(Graph **,
-    GlGraphInputData*, MutableContainer<
-    EdgeExtremityGlyph *>& glyphs) {
-  Iterator<string> *itS =
-    EdgeExtremityGlyphFactory::factory->availablePlugins();
+void EdgeExtremityGlyphManager::clearGlyphList(Graph **, GlGraphInputData*, MutableContainer<EdgeExtremityGlyph *>& glyphs) {
+  static std::list<std::string> plugins = PluginLister::instance()->availablePlugins<EdgeExtremityGlyph>();
 
-  while (itS->hasNext()) {
-    string glyphName = itS->next();
-    delete glyphs.get(
-      EdgeExtremityGlyphFactory::factory->objMap[glyphName]->getId());
+  for(std::list<std::string>::const_iterator it = plugins.begin(); it != plugins.end(); ++it) {
+    string glyphName = *it;
+    delete glyphs.get(PluginLister::pluginInformation(glyphName).id());
   }
+}
 
-  delete itS;
-}
 }
