@@ -16,7 +16,6 @@
  * See the GNU General Public License for more details.
  *
  */
-
 #include <cmath>
 #include <cstdlib>
 #include <cassert>
@@ -27,7 +26,7 @@
 using namespace tlp;
 
 //====================================================
-void tlp::Line(float x1,float y1,float z1,float x2, float y2 ,  float z2, Color C1, Color C2) {
+void tlp::Line(float x1, float y1, float z1, float x2, float y2 ,  float z2, Color &C1, Color &C2) {
   glBegin(GL_LINES);
   setColor(C1);
   glVertex3f(x1, y1, z1);
@@ -143,11 +142,11 @@ GLfloat *tlp::spewPrimitiveEPS(FILE * file, GLfloat * loc) {
 
       /* Back up half a step; we want the end points to be
          exactly the their endpoint colors. */
-      xnext -= xstep / 2.0f;
-      ynext -= ystep / 2.0f;
-      rnext -= rstep / 2.0f;
-      gnext -= gstep / 2.0f;
-      bnext -= bstep / 2.0f;
+      xnext -= xstep / 2.0;
+      ynext -= ystep / 2.0;
+      rnext -= rstep / 2.0;
+      gnext -= gstep / 2.0;
+      bnext -= bstep / 2.0;
     }
     else {
       /* Single color line. */
@@ -197,6 +196,7 @@ GLfloat *tlp::spewPrimitiveEPS(FILE * file, GLfloat * loc) {
 
       if (smooth) {
         /* Smooth shaded polygon; varying colors at vetices. */
+
         /* Break polygon into "nvertices-2" triangle fans. */
         for (i = 0; i < nvertices - 2; i++) {
           fprintf(file, "[%g %g %g %g %g %g]",
@@ -349,7 +349,7 @@ void tlp::spewSortedFeedback(FILE * file, GLint size, GLfloat * buffer) {
     case GL_LINE_RESET_TOKEN:
       vertex = (Feedback3Dcolor *) loc;
       depthSum = vertex[0].z + vertex[1].z;
-      prims[item].depth = depthSum / 2.0f;
+      prims[item].depth = depthSum / 2.0;
       loc += 14;
       item++;
       break;
