@@ -19,9 +19,10 @@
 #include <GL/glew.h>
 
 #include <tulip/GlAbstractPolygon.h>
-
+#include <tulip/GlTools.h>
 #include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlTextureManager.h>
+#include <tulip/GlXMLTools.h>
 
 using namespace std;
 
@@ -60,7 +61,6 @@ bool GlAbstractPolygon::getFillMode() {
 //=====================================================
 void GlAbstractPolygon::setFillMode(const bool filled) {
   this->filled = filled;
-  clearGenerated();
 }
 //=====================================================
 bool GlAbstractPolygon::getOutlineMode() {
@@ -69,7 +69,6 @@ bool GlAbstractPolygon::getOutlineMode() {
 //=====================================================
 void GlAbstractPolygon::setOutlineMode(const bool outlined) {
   this->outlined = outlined;
-  clearGenerated();
 }
 //=====================================================
 bool GlAbstractPolygon::getLightingMode() {
@@ -144,9 +143,13 @@ void GlAbstractPolygon::setHideOutlineLod(float lod) {
   hideOutlineLod=lod;
 }
 //=====================================================
+void GlAbstractPolygon::setInvertYTexture(bool invertYTexture) {
+  this->invertYTexture = invertYTexture;
+}
+//=====================================================
 void GlAbstractPolygon::draw(float lod,Camera *) {
 
-  bool canUseGlew=OpenGlConfigManager::getInst().canUseGlew();
+  bool canUseVBO=OpenGlConfigManager::getInst().hasVertexBufferObject();
 
   glDisable(GL_CULL_FACE);
 
@@ -212,7 +215,7 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
     // Expand vector
     if(filled) {
       normalArray.resize(size,normal);
-      assert(fillColors.size()!=0);
+      assert(!fillColors.empty());
 
       if(fillColors.size()!=1)
         fillColors.resize(size,fillColors.back());
@@ -246,7 +249,7 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
       }
     }
 
-    if(canUseGlew) {
+    if(canUseVBO) {
 
       // Generate buffers
       glGenBuffers(7,buffers);
@@ -290,10 +293,12 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
     generated=true;
   }
 
+
+
   // Coord array
   glEnableClientState(GL_VERTEX_ARRAY);
 
-  if(canUseGlew) {
+  if(canUseVBO) {
     glBindBuffer(GL_ARRAY_BUFFER, buffers[0]);
     glVertexPointer(3, GL_FLOAT, 3*sizeof(GLfloat), BUFFER_OFFSET(0));
   }
@@ -301,12 +306,14 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
     glVertexPointer(3, GL_FLOAT, 3*sizeof(GLfloat), &points[0]);
   }
 
+
+
   // Fill
   if (filled) {
     // Normal array
     glEnableClientState(GL_NORMAL_ARRAY);
 
-    if(canUseGlew) {
+    if(canUseVBO) {
       glBindBuffer(GL_ARRAY_BUFFER, buffers[1]);
       glNormalPointer(GL_FLOAT, 3*sizeof(GLfloat), BUFFER_OFFSET(0));
     }
@@ -318,7 +325,7 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
       // fillColor array
       glEnableClientState(GL_COLOR_ARRAY);
 
-      if(canUseGlew) {
+      if(canUseVBO) {
         glBindBuffer(GL_ARRAY_BUFFER, buffers[2]);
         glColorPointer(4,GL_UNSIGNED_BYTE, 4*sizeof(GLubyte), BUFFER_OFFSET(0));
       }
@@ -335,7 +342,7 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
       GlTextureManager::getInst().activateTexture(textureName);
       glEnableClientState(GL_TEXTURE_COORD_ARRAY);
 
-      if(canUseGlew) {
+      if(canUseVBO) {
         glBindBuffer(GL_ARRAY_BUFFER, buffers[4]);
         glTexCoordPointer(2,GL_FLOAT, 2*sizeof(GLfloat), BUFFER_OFFSET(0));
       }
@@ -360,10 +367,13 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
 
     OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
 
+
+
     // Draw
-    if(canUseGlew) {
+    if(canUseVBO) {
       glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, buffers[5]);
       glDrawElements(fillMode, points.size(), GL_UNSIGNED_BYTE, BUFFER_OFFSET(0));
+
     }
     else {
       glDrawElements(fillMode, points.size(), GL_UNSIGNED_BYTE, indices);
@@ -381,6 +391,8 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
     }
   }
 
+
+
   // Outline
   if(outlined && outlineSize!=0) {
     if((outlineSize<1 && lod>=hideOutlineLod) || (lod>=(hideOutlineLod/outlineSize))) {
@@ -392,7 +404,7 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
         // outlineColor
         glEnableClientState(GL_COLOR_ARRAY);
 
-        if(canUseGlew) {
+        if(canUseVBO) {
           glBindBuffer(GL_ARRAY_BUFFER, buffers[3]);
           glColorPointer(4,GL_UNSIGNED_BYTE, 4*sizeof(GLubyte), BUFFER_OFFSET(0));
         }
@@ -408,7 +420,7 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
 
       // Draw
       if(polygonMode!=QUAD_STRIP) {
-        if(canUseGlew) {
+        if(canUseVBO) {
           glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, buffers[5]);
           glDrawElements(GL_LINE_LOOP, points.size(), GL_UNSIGNED_BYTE, BUFFER_OFFSET(0));
         }
@@ -417,7 +429,7 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
         }
       }
       else {
-        if(canUseGlew) {
+        if(canUseVBO) {
           glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, buffers[6]);
           glDrawElements(GL_LINE_LOOP, points.size(), GL_UNSIGNED_BYTE, BUFFER_OFFSET(0));
         }
@@ -435,16 +447,15 @@ void GlAbstractPolygon::draw(float lod,Camera *) {
     }
   }
 
-  GLfloat normalt[3];
-  glGetFloatv(GL_CURRENT_NORMAL,normalt);
-
   glDisableClientState(GL_VERTEX_ARRAY);
 
-  if(canUseGlew) {
+  if(canUseVBO) {
     glBindBuffer(GL_ARRAY_BUFFER, 0);
     glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0);
   }
 
+
+
   glTest(__PRETTY_FUNCTION__);
 }
 //===========================================================
@@ -458,48 +469,50 @@ void GlAbstractPolygon::translate(const Coord& vec) {
   clearGenerated();
 }
 //===========================================================
-void GlAbstractPolygon::getXML(xmlNodePtr rootNode) {
+void GlAbstractPolygon::scale(const Size& factor) {
+  boundingBox.scale(factor);
 
-  GlXMLTools::createProperty(rootNode, "type", "GlPolygon");
+  for(vector<Coord>::iterator it = points.begin(); it!=points.end(); ++it) {
+    (*it) *= factor;
+  }
 
-  getXMLOnlyData(rootNode);
+  clearGenerated();
+}
+//===========================================================
+void GlAbstractPolygon::getXML(string &outString) {
+
+  GlXMLTools::createProperty(outString, "type", "GlPolygon","GlEntity");
+
+  getXMLOnlyData(outString);
 
 }
 //===========================================================
-void GlAbstractPolygon::getXMLOnlyData(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
+void GlAbstractPolygon::getXMLOnlyData(string &outString) {
 
-  GlXMLTools::getDataNode(rootNode,dataNode);
-
-  GlXMLTools::getXML(dataNode,"points",points);
-  GlXMLTools::getXML(dataNode,"fillColors",fillColors);
-  GlXMLTools::getXML(dataNode,"outlineColors",outlineColors);
-  GlXMLTools::getXML(dataNode,"filled",filled);
-  GlXMLTools::getXML(dataNode,"outlined",outlined);
-  GlXMLTools::getXML(dataNode,"textureName",textureName);
-  GlXMLTools::getXML(dataNode,"outlineSize",outlineSize);
+  GlXMLTools::getXML(outString,"points",points);
+  GlXMLTools::getXML(outString,"fillColors",fillColors);
+  GlXMLTools::getXML(outString,"outlineColors",outlineColors);
+  GlXMLTools::getXML(outString,"filled",filled);
+  GlXMLTools::getXML(outString,"outlined",outlined);
+  GlXMLTools::getXML(outString,"textureName",textureName);
+  GlXMLTools::getXML(outString,"outlineSize",outlineSize);
 }
 //============================================================
-void GlAbstractPolygon::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
+void GlAbstractPolygon::setWithXML(const string &inString, unsigned int &currentPosition) {
 
-  GlXMLTools::getDataNode(rootNode,dataNode);
+  points.clear();
+  GlXMLTools::setWithXML(inString,currentPosition,"points",points);
+  fillColors.clear();
+  GlXMLTools::setWithXML(inString,currentPosition,"fillColors",fillColors);
+  outlineColors.clear();
+  GlXMLTools::setWithXML(inString,currentPosition,"outlineColors",outlineColors);
+  GlXMLTools::setWithXML(inString,currentPosition,"filled",filled);
+  GlXMLTools::setWithXML(inString,currentPosition,"outlined",outlined);
+  GlXMLTools::setWithXML(inString,currentPosition,"textureName",textureName);
+  GlXMLTools::setWithXML(inString,currentPosition,"outlineSize",outlineSize);
 
-  // Parse Data
-  if(dataNode) {
-    points.clear();
-    GlXMLTools::setWithXML(dataNode,"points",points);
-    fillColors.clear();
-    GlXMLTools::setWithXML(dataNode,"fillColors",fillColors);
-    outlineColors.clear();
-    GlXMLTools::setWithXML(dataNode,"outlineColors",outlineColors);
-    GlXMLTools::setWithXML(dataNode,"filled",filled);
-    GlXMLTools::setWithXML(dataNode,"outlined",outlined);
-    GlXMLTools::setWithXML(dataNode,"textureName",textureName);
-    GlXMLTools::setWithXML(dataNode,"outlineSize",outlineSize);
-
-    for(vector<Coord>::iterator it= points.begin(); it!=points.end(); ++it)
-      boundingBox.expand(*it);
+  for(vector<Coord>::iterator it= points.begin(); it!=points.end(); ++it) {
+    boundingBox.expand(*it);
   }
 }
 //============================================================
@@ -535,10 +548,10 @@ void GlAbstractPolygon::clearGenerated() {
   texArray=NULL;
   normalArray.clear();
 
-  if(OpenGlConfigManager::getInst().canUseGlew()) {
-    if(generated)
-      glDeleteBuffers(7,buffers);
-  }
+  if(generated)
+    if(OpenGlConfigManager::getInst().hasVertexBufferObject()) {
+      glDeleteBuffers(6,buffers);
+    }
 
   generated=false;
 }
@@ -550,41 +563,4 @@ void GlAbstractPolygon::recomputeBoundingBox() {
     boundingBox.expand(*it);
   }
 }
-
-//=====================================================
-// Deprecated
-//=====================================================
-
-//=====================================================
-const Color& GlAbstractPolygon::fcolor(const unsigned int i) const {
-  cout << __PRETTY_FUNCTION__ << " deprecated : use getFillColor" << endl;
-  return fillColors[i];
-}
-//=====================================================
-Color& GlAbstractPolygon::fcolor(const unsigned int i) {
-  cout << __PRETTY_FUNCTION__ << " deprecated : use getFillColor" << endl;
-  return fillColors[i];
-}
-//=====================================================
-void GlAbstractPolygon::setFColor(const unsigned int i,const Color &color) {
-  cout << __PRETTY_FUNCTION__ << " deprecated : use setFillColor" << endl;
-  fillColors[i]=color;
-  clearGenerated();
-}
-//=====================================================
-const Color& GlAbstractPolygon::ocolor(const unsigned int i) const {
-  cout << __PRETTY_FUNCTION__ << " deprecated : use getOutlineColor" << endl;
-  return outlineColors[i];
-}
-//=====================================================
-Color& GlAbstractPolygon::ocolor(const unsigned int i) {
-  cout << __PRETTY_FUNCTION__ << " deprecated : use getOutlineColor" << endl;
-  return outlineColors[i];
-}
-//=====================================================
-void GlAbstractPolygon::setOColor(const unsigned int i,const Color &color) {
-  cout << __PRETTY_FUNCTION__ << " deprecated : use getOutlineColor" << endl;
-  outlineColors[i]=color;
-  clearGenerated();
-}
 }
