@@ -18,15 +18,9 @@
  */
 #include <tulip/GlBoundingBoxSceneVisitor.h>
 
-#include <iostream>
-
-#include <tulip/GlGraphInputData.h>
 #include <tulip/GlSimpleEntity.h>
 #include <tulip/GlNode.h>
 #include <tulip/GlEdge.h>
-#include <tulip/GlLayer.h>
-#include <tulip/Camera.h>
-#include <tulip/GlTools.h>
 
 using namespace std;
 
@@ -36,7 +30,7 @@ void GlBoundingBoxSceneVisitor::visit(GlSimpleEntity *entity) {
   if(entity->isVisible()) {
     BoundingBox bb=entity->getBoundingBox();
 
-    if(bb.isValid() && entity->isCheckByBoundingBoxVisitor()) {
+    if(bb.isValid()) {
       boundingBox.expand(bb[0]);
       boundingBox.expand(bb[1]);
     }
