@@ -19,9 +19,10 @@
 #include <GL/glew.h>
 
 #include <tulip/GlBox.h>
-
-#include <tulip/OpenGlConfigManager.h>
+#include <tulip/GlXMLTools.h>
 #include <tulip/GlTools.h>
+#include <tulip/GlTextureManager.h>
+#include <tulip/OpenGlConfigManager.h>
 
 using namespace std;
 
@@ -176,9 +177,9 @@ GlBox::~GlBox() {
 //===========================================================
 void GlBox::draw(float lod,Camera *) {
 
-  bool canUseGlew=OpenGlConfigManager::getInst().canUseGlew();
+  bool canUseVBO=OpenGlConfigManager::getInst().hasVertexBufferObject();
 
-  if(canUseGlew) {
+  if(canUseVBO) {
     if(!generated) {
       GLfloat newCubeCoordArrays[72];
 
@@ -220,7 +221,7 @@ void GlBox::draw(float lod,Camera *) {
 
   glEnableClientState(GL_VERTEX_ARRAY);
 
-  if(canUseGlew) {
+  if(canUseVBO) {
     glBindBuffer(GL_ARRAY_BUFFER, buffers[0]);
     glVertexPointer(3, GL_FLOAT, 3*sizeof(GLfloat), BUFFER_OFFSET(0));
   }
@@ -233,7 +234,7 @@ void GlBox::draw(float lod,Camera *) {
 
     glEnableClientState(GL_NORMAL_ARRAY);
 
-    if(canUseGlew) {
+    if(canUseVBO) {
       glBindBuffer(GL_ARRAY_BUFFER, buffers[1]);
       glNormalPointer(GL_FLOAT, 3*sizeof(GLfloat), BUFFER_OFFSET(0));
     }
@@ -245,7 +246,7 @@ void GlBox::draw(float lod,Camera *) {
       GlTextureManager::getInst().activateTexture(textureName);
       glEnableClientState(GL_TEXTURE_COORD_ARRAY);
 
-      if(canUseGlew) {
+      if(canUseVBO) {
         glBindBuffer(GL_ARRAY_BUFFER, buffers[2]);
         glTexCoordPointer(2,GL_FLOAT, 2*sizeof(GLfloat), BUFFER_OFFSET(0));
       }
@@ -256,7 +257,7 @@ void GlBox::draw(float lod,Camera *) {
 
     OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
 
-    if(canUseGlew) {
+    if(canUseVBO) {
       glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, buffers[3]);
       glDrawElements(GL_QUADS, 24, GL_UNSIGNED_BYTE, BUFFER_OFFSET(0));
     }
@@ -283,7 +284,7 @@ void GlBox::draw(float lod,Camera *) {
 
       OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
 
-      if(canUseGlew) {
+      if(canUseVBO) {
         glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, buffers[4]);
         glDrawElements(GL_LINES, 24, GL_UNSIGNED_BYTE, BUFFER_OFFSET(0));
       }
@@ -299,8 +300,10 @@ void GlBox::draw(float lod,Camera *) {
 
   glDisableClientState(GL_VERTEX_ARRAY);
 
-  glBindBuffer(GL_ARRAY_BUFFER, 0);
-  glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0);
+  if(canUseVBO) {
+    glBindBuffer(GL_ARRAY_BUFFER, 0);
+    glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0);
+  }
 }
 //===========================================================
 void GlBox::setSize(const Size& size) {
@@ -369,52 +372,43 @@ void GlBox::translate(const Coord &mouvement) {
   clearGenerated();
 }
 //===========================================================
-void GlBox::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
+void GlBox::getXML(string &outString) {
 
-  GlXMLTools::createProperty(rootNode, "type", "GlBox");
+  GlXMLTools::createProperty(outString,"type","GlBox","GlEntity");
 
-  GlXMLTools::getDataNode(rootNode,dataNode);
-
-  GlXMLTools::getXML(dataNode,"position",position);
-  GlXMLTools::getXML(dataNode,"size",size);
-  GlXMLTools::getXML(dataNode,"fillColors",fillColors);
-  GlXMLTools::getXML(dataNode,"outlineColors",outlineColors);
-  GlXMLTools::getXML(dataNode,"filled",filled);
-  GlXMLTools::getXML(dataNode,"outlined",outlined);
-  GlXMLTools::getXML(dataNode,"textureName",textureName);
-  GlXMLTools::getXML(dataNode,"outlineSize",outlineSize);
+  GlXMLTools::getXML(outString,"position",position);
+  GlXMLTools::getXML(outString,"size",size);
+  GlXMLTools::getXML(outString,"fillColors",fillColors);
+  GlXMLTools::getXML(outString,"outlineColors",outlineColors);
+  GlXMLTools::getXML(outString,"filled",filled);
+  GlXMLTools::getXML(outString,"outlined",outlined);
+  GlXMLTools::getXML(outString,"textureName",textureName);
+  GlXMLTools::getXML(outString,"outlineSize",outlineSize);
 }
 //============================================================
-void GlBox::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
+void GlBox::setWithXML(const string &inString, unsigned int &currentPosition) {
 
-  GlXMLTools::getDataNode(rootNode,dataNode);
+  GlXMLTools::setWithXML(inString, currentPosition,"position",position);
+  GlXMLTools::setWithXML(inString, currentPosition,"size",size);
+  fillColors.clear();
+  GlXMLTools::setWithXML(inString, currentPosition,"fillColors",fillColors);
+  outlineColors.clear();
+  GlXMLTools::setWithXML(inString, currentPosition,"outlineColors",outlineColors);
+  GlXMLTools::setWithXML(inString, currentPosition,"filled",filled);
+  GlXMLTools::setWithXML(inString, currentPosition,"outlined",outlined);
+  GlXMLTools::setWithXML(inString, currentPosition,"textureName",textureName);
+  GlXMLTools::setWithXML(inString, currentPosition,"outlineSize",outlineSize);
 
-  // Parse Data
-  if(dataNode) {
-    GlXMLTools::setWithXML(dataNode,"position",position);
-    GlXMLTools::setWithXML(dataNode,"size",size);
-    fillColors.clear();
-    GlXMLTools::setWithXML(dataNode,"fillColors",fillColors);
-    outlineColors.clear();
-    GlXMLTools::setWithXML(dataNode,"outlineColors",outlineColors);
-    GlXMLTools::setWithXML(dataNode,"filled",filled);
-    GlXMLTools::setWithXML(dataNode,"outlined",outlined);
-    GlXMLTools::setWithXML(dataNode,"textureName",textureName);
-    GlXMLTools::setWithXML(dataNode,"outlineSize",outlineSize);
-
-    boundingBox = BoundingBox();
-    boundingBox.expand(position-size/2.f);
-    boundingBox.expand(position+size/2.f);
-  }
+  boundingBox = BoundingBox();
+  boundingBox.expand(position-size/2.f);
+  boundingBox.expand(position+size/2.f);
 }
 //============================================================
 void GlBox::clearGenerated() {
   delete[] newCubeCoordArrays;
   newCubeCoordArrays=NULL;
 
-  if(OpenGlConfigManager::getInst().canUseGlew()) {
+  if(OpenGlConfigManager::getInst().hasVertexBufferObject()) {
     if(generated)
       glDeleteBuffers(5,buffers);
   }
