@@ -25,17 +25,14 @@
 #endif
 
 #include <tulip/Camera.h>
-#include <tulip/GlEntity.h>
 #include <tulip/GlTools.h>
-#include <tulip/GlScene.h>
-
-#include <iostream>
 
 using namespace std;
 
 namespace tlp {
 
-GlCPULODCalculator::GlCPULODCalculator():computeEdgesLOD(false),computeOutScreenLOD(false) {
+GlCPULODCalculator::GlCPULODCalculator():computeEdgesLOD(true) {
+
 }
 
 GlCPULODCalculator::~GlCPULODCalculator() {
@@ -122,7 +119,7 @@ void GlCPULODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
   size_t nb=layerLODUnit->simpleEntitiesLODVector.size();
 
 #ifdef _OPENMP
-  omp_set_num_threads(std::min(omp_get_num_procs(), 4));
+  omp_set_num_threads(omp_get_num_procs());
   omp_set_nested(true);
   omp_set_dynamic(false);
 #endif
@@ -131,8 +128,8 @@ void GlCPULODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
   #pragma omp parallel for
 #endif
 
-  for(int i=0; i<static_cast<int>(nb); ++i) {
-    layerLODUnit->simpleEntitiesLODVector[i].lod=calculateAABBSize(layerLODUnit->simpleEntitiesLODVector[i].boundingBox,eye,transformMatrix,globalViewport,currentViewport,computeOutScreenLOD);
+  for(int i = 0 ; i < static_cast<int>(nb) ; ++i) {
+    layerLODUnit->simpleEntitiesLODVector[i].lod=calculateAABBSize(layerLODUnit->simpleEntitiesLODVector[i].boundingBox,eye,transformMatrix,globalViewport,currentViewport);
   }
 
   nb=layerLODUnit->nodesLODVector.size();
@@ -140,8 +137,8 @@ void GlCPULODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
   #pragma omp parallel for
 #endif
 
-  for(int i=0; i<static_cast<int>(nb); ++i) {
-    layerLODUnit->nodesLODVector[i].lod=calculateAABBSize(layerLODUnit->nodesLODVector[i].boundingBox,eye,transformMatrix,globalViewport,currentViewport,computeOutScreenLOD);
+  for(int i = 0 ; i < static_cast<int>(nb) ; ++i) {
+    layerLODUnit->nodesLODVector[i].lod=calculateAABBSize(layerLODUnit->nodesLODVector[i].boundingBox,eye,transformMatrix,globalViewport,currentViewport);
   }
 
   nb=layerLODUnit->edgesLODVector.size();
@@ -151,8 +148,8 @@ void GlCPULODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
     #pragma omp parallel for
 #endif
 
-    for(int i=0; i<static_cast<int>(nb); ++i) {
-      layerLODUnit->edgesLODVector[i].lod=calculateAABBSize(layerLODUnit->edgesLODVector[i].boundingBox,eye,transformMatrix,globalViewport,currentViewport,computeOutScreenLOD);
+    for(int i = 0 ; i < static_cast<int>(nb) ; ++i) {
+      layerLODUnit->edgesLODVector[i].lod=calculateAABBSize(layerLODUnit->edgesLODVector[i].boundingBox,eye,transformMatrix,globalViewport,currentViewport);
     }
   }
   else {
@@ -160,7 +157,7 @@ void GlCPULODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
     #pragma omp parallel for
 #endif
 
-    for(int i=0; i<static_cast<int>(nb); ++i) {
+    for(int i = 0 ; i < static_cast<int>(nb) ; ++i) {
       layerLODUnit->edgesLODVector[i].lod=10;
     }
   }
