@@ -16,13 +16,12 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <typeinfo>
-#include <libxml/tree.h>
-#include <libxml/parser.h>
 #include <tulip/GlComposite.h>
 
 #include <tulip/GlLayer.h>
 #include <tulip/GlScene.h>
+#include <tulip/GlGraphComposite.h>
+#include <tulip/GlXMLTools.h>
 
 using namespace std;
 
@@ -39,8 +38,13 @@ GlComposite::~GlComposite() {
 void GlComposite::addLayerParent(GlLayer *layer) {
   layerParents.push_back(layer);
 
+  GlComposite *composite;
+
   for(list<GlSimpleEntity *>::iterator it = _sortedElements.begin(); it != _sortedElements.end(); ++it) {
-    (*it)->addLayerParent(layer);
+    composite=dynamic_cast<GlComposite*>(*it);
+
+    if(composite)
+      composite->addLayerParent(layer);
   }
 }
 //============================================================
@@ -52,8 +56,13 @@ void GlComposite::removeLayerParent(GlLayer *layer) {
     }
   }
 
+  GlComposite *composite;
+
   for(list<GlSimpleEntity *>::iterator it = _sortedElements.begin(); it != _sortedElements.end(); ++it) {
-    (*it)->removeLayerParent(layer);
+    composite=dynamic_cast<GlComposite*>(*it);
+
+    if(composite)
+      composite->removeLayerParent(layer);
   }
 }
 //============================================================
@@ -66,14 +75,24 @@ void GlComposite::reset(bool deleteElems) {
   }
 
   for(vector<GlSimpleEntity*>::iterator it = toTreat.begin() ; it != toTreat.end() ; ++it) {
+    for(vector<GlLayer*>::iterator it2=layerParents.begin(); it2!=layerParents.end(); ++it2) {
+      if((*it2)->getScene())
+        (*it2)->getScene()->notifyDeletedEntity(*it);
+    }
+
     if (deleteElems) {
       delete (*it);
     }
     else {
       (*it)->removeParent(this);
 
+      GlComposite *composite;
+
       for(vector<GlLayer*>::iterator itLayers=layerParents.begin(); itLayers!=layerParents.end(); ++itLayers) {
-        (*it)->removeLayerParent(*itLayers);
+        composite=dynamic_cast<GlComposite*>(*it);
+
+        if(composite)
+          composite->removeLayerParent(*itLayers);
       }
     }
   }
@@ -109,35 +128,65 @@ void GlComposite::addGlEntity(GlSimpleEntity *entity, const string &key) {
   if(doSceneTreatment) {
     entity->addParent(this);
 
+    GlComposite *composite;
+    composite=dynamic_cast<GlComposite*>(entity);
+
     for(vector<GlLayer*>::iterator it=layerParents.begin(); it!=layerParents.end(); ++it) {
-      entity->addLayerParent(*it);
+      if(composite)
+        composite->addLayerParent(*it);
 
       if((*it)->getScene())
         (*it)->getScene()->notifyModifyLayer((*it)->getName(),(*it));
     }
   }
+
+  GlGraphComposite *graphComposite=dynamic_cast<GlGraphComposite *>(entity);
+
+  if(graphComposite) {
+    for(std::vector<GlLayer *>::iterator it=layerParents.begin(); it!=layerParents.end(); ++it) {
+      (*it)->glGraphCompositeAdded(graphComposite);
+    }
+  }
+
 }
 //============================================================
 void GlComposite::deleteGlEntity(const string &key,bool informTheEntity) {
   if(elements.count(key)==0)
     return;
 
-  if(informTheEntity) {
-    GlSimpleEntity *entity=elements[key];
+  GlSimpleEntity *entity=elements[key];
 
-    if(informTheEntity)
+  if(informTheEntity)
+    entity->removeParent(this);
+
+  if(informTheEntity) {
+    GlComposite *composite=dynamic_cast<GlComposite *>(entity);
+
+    if(composite) {
       for(vector<GlLayer*>::iterator it=layerParents.begin(); it!=layerParents.end(); ++it) {
-        entity->removeLayerParent(*it);
+        composite->removeLayerParent(*it);
       }
+    }
+  }
+
+  GlGraphComposite *glGraphComposite=dynamic_cast<GlGraphComposite *>(entity);
+
+  if(glGraphComposite) {
+    for(vector<GlLayer*>::iterator it=layerParents.begin(); it!=layerParents.end(); ++it) {
+      (*it)->glGraphCompositeRemoved(glGraphComposite);
+    }
   }
 
   _sortedElements.remove(elements[key]);
   elements.erase(key);
 
   for(vector<GlLayer*>::iterator it=layerParents.begin(); it!=layerParents.end(); ++it) {
-    if((*it)->getScene())
+    if((*it)->getScene()) {
       (*it)->getScene()->notifyModifyLayer((*it)->getName(),(*it));
+      (*it)->getScene()->notifyDeletedEntity(entity);
+    }
   }
+
 }
 //============================================================
 void GlComposite::deleteGlEntity(GlSimpleEntity *entity,bool informTheEntity) {
@@ -147,8 +196,12 @@ void GlComposite::deleteGlEntity(GlSimpleEntity *entity,bool informTheEntity) {
       if(informTheEntity) {
         entity->removeParent(this);
 
-        for(vector<GlLayer*>::iterator it=layerParents.begin(); it!=layerParents.end(); ++it) {
-          entity->removeLayerParent(*it);
+        GlComposite *composite=dynamic_cast<GlComposite *>(entity);
+
+        if(composite) {
+          for(vector<GlLayer*>::iterator it=layerParents.begin(); it!=layerParents.end(); ++it) {
+            composite->removeLayerParent(*it);
+          }
         }
       }
 
@@ -156,8 +209,10 @@ void GlComposite::deleteGlEntity(GlSimpleEntity *entity,bool informTheEntity) {
       elements.erase(i->first);
 
       for(vector<GlLayer*>::iterator it=layerParents.begin(); it!=layerParents.end(); ++it) {
-        if((*it)->getScene())
+        if((*it)->getScene())  {
           (*it)->getScene()->notifyModifyLayer((*it)->getName(),(*it));
+          (*it)->getScene()->notifyDeletedEntity(entity);
+        }
       }
 
       return;
@@ -191,72 +246,68 @@ void GlComposite::translate(const Coord &mouvement) {
 }
 //============================================================
 void GlComposite::notifyModified(GlSimpleEntity *entity) {
-  if(layerParents.size()!=0)
+  if(!layerParents.empty())
     layerParents[0]->getScene()->notifyModifyEntity(entity);
 }
 //============================================================
-void GlComposite::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr node=NULL;
-  xmlNodePtr dataNode=NULL;
-  xmlNodePtr childrenNode=NULL;
-
+void GlComposite::getXML(string &outString) {
   string name;
 
-  GlXMLTools::createProperty(rootNode,"type","GlComposite");
+  GlXMLTools::createProperty(outString,"type","GlComposite","GlEntity");
 
-  GlXMLTools::createDataAndChildrenNodes(rootNode, dataNode, childrenNode);
+  GlXMLTools::beginChildNode(outString);
 
   for(list<GlSimpleEntity*>::iterator it=_sortedElements.begin(); it!=_sortedElements.end(); ++it) {
     name=findKey(*it);
-    GlXMLTools::createChild(childrenNode,"GlEntity",node);
-    GlXMLTools::createProperty(node,"name",name);
-    GlXMLTools::createDataNode(node,dataNode);
-    GlXMLTools::getXML(dataNode,"visible",(*it)->isVisible());
-    GlXMLTools::getXML(dataNode,"stencil",(*it)->getStencil());
-    (*it)->getXML(node);
+    GlXMLTools::beginChildNode(outString,"GlEntity");
+    GlXMLTools::createProperty(outString,"name",name);
+    GlXMLTools::beginDataNode(outString);
+    GlXMLTools::getXML(outString,"visible",(*it)->isVisible());
+    GlXMLTools::getXML(outString,"stencil",(*it)->getStencil());
+    (*it)->getXML(outString);
+    GlXMLTools::endDataNode(outString);
+    GlXMLTools::endChildNode(outString,"GlEntity");
   }
+
+  GlXMLTools::endChildNode(outString);
 }
 //============================================================
-void GlComposite::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr node=NULL;
-  xmlNodePtr dataNode=NULL;
-  xmlNodePtr childrenNode=NULL;
+void GlComposite::setWithXML(const string &inString, unsigned int &currentPosition) {
 
-  GlXMLTools::getDataAndChildrenNodes(rootNode,dataNode,childrenNode);
+  string childName=GlXMLTools::enterChildNode(inString,currentPosition);
+  assert(childName=="children");
 
-  // Parse Children
-  for (node = childrenNode->children; node; node = node->next) {
-    if(node->type == XML_ELEMENT_NODE) {
-      string type = GlXMLTools::getProperty("type",node);
-      string name;
+  childName=GlXMLTools::enterChildNode(inString,currentPosition);
 
-      if(string((char*)node->name)=="GlEntity") {
-        //New version
-        name = GlXMLTools::getProperty("name",node);
-      }
-      else {
-        //previous version compatibility
-        name=(char*)node->name;
-      }
+  while(childName!="") {
 
-      if(type!="") {
-        GlSimpleEntity *entity=GlXMLTools::createEntity(type);
+    map<string,string> properties=GlXMLTools::getProperties(inString,currentPosition);
 
-        if(entity) {
-          bool visible;
-          int stencil;
+    assert(properties.count("name")!=0);
+    assert(properties.count("type")!=0);
 
-          entity->setWithXML(node);
-          GlXMLTools::getDataNode(node,dataNode);
+    GlSimpleEntity *entity=GlXMLTools::createEntity(properties["type"]);
 
-          GlXMLTools::setWithXML(dataNode, "visible", visible);
-          GlXMLTools::setWithXML(dataNode, "stencil", stencil);
-          entity->setVisible(visible);
-          entity->setStencil(stencil );
-          addGlEntity(entity,name);
-        }
-      }
+    if(entity) {
+      bool visible;
+      int stencil;
+
+      GlXMLTools::enterDataNode(inString,currentPosition);
+
+      GlXMLTools::setWithXML(inString,currentPosition, "visible", visible);
+      GlXMLTools::setWithXML(inString,currentPosition, "stencil", stencil);
+      entity->setWithXML(inString,currentPosition);
+      entity->setVisible(visible);
+      entity->setStencil(stencil );
+      addGlEntity(entity,properties["name"]);
+
+      GlXMLTools::leaveDataNode(inString,currentPosition);
     }
+
+    GlXMLTools::leaveChildNode(inString,currentPosition,childName);
+    childName=GlXMLTools::enterChildNode(inString,currentPosition);
   }
+
+  GlXMLTools::leaveChildNode(inString,currentPosition,"children");
 }
 }
