@@ -24,6 +24,7 @@
 #include <tulip/GlTools.h>
 #include <tulip/GlConvexHull.h>
 #include <tulip/OpenGlConfigManager.h>
+#include <tulip/GlXMLTools.h>
 
 using namespace std;
 
@@ -52,11 +53,11 @@ GlConvexHull::GlConvexHull(const vector<Coord> &points,
     convexHull(_points, convexHullIdxs);
     // build new points
     vector<Coord> points;
-    vector<unsigned int>::const_iterator it = convexHullIdxs.begin();
 
-    for (; it != convexHullIdxs.end(); ++it) {
-      points.push_back(_points[*it]);
-      boundingBox.expand(_points[*it]);
+    for (vector<unsigned int>::const_iterator it = convexHullIdxs.begin(); it != convexHullIdxs.end(); ++it) {
+      unsigned i=*it;
+      points.push_back(_points[i]);
+      boundingBox.expand(_points[i]);
     }
 
     _points = points;
@@ -272,16 +273,16 @@ ConvexHullItem* GlConvexHull::buildConvexHullsFromHierarchy(Graph *graph,
         // convert in radian
         alpha = M_PI * alpha / 180.0;
         // get half height of bounding box
-        float hh = box.getH() / 2.0f;
+        float hh = box.getH() / 2.0;
         // get half width of bounding box
-        float hw = box.getW() / 2.0f;
+        float hw = box.getW() / 2.0;
         // add 10%
         float hl;
 
-        if (hh/10.f < hw/10.f)
-          hl = hh/10.f;
+        if (hh/10. < hw/10.)
+          hl = hh/10.;
         else
-          hl = hw/10.f;
+          hl = hw/10.;
 
         hh += hl;
         hw += hl;
@@ -290,9 +291,9 @@ ConvexHullItem* GlConvexHull::buildConvexHullsFromHierarchy(Graph *graph,
           bendsl = hl;
 
         // add points of rotated bounding box
-        float cosA = static_cast<float>(cos(alpha));
-        float sinA = static_cast<float>(sin(alpha));
-        Coord vect(0.0f, 0.0f, -0.01f);
+        float cosA = cos(alpha);
+        float sinA = sin(alpha);
+        Coord vect(0,0,-0.01f);
         vect.setX(-hw * cosA + hh * sinA);
         vect.setY(-hw * sinA - hh * cosA);
         gConvexHull.push_back(point + vect);
@@ -315,7 +316,7 @@ ConvexHullItem* GlConvexHull::buildConvexHullsFromHierarchy(Graph *graph,
 
         for (unsigned int i = 0; i < nbBends; i++) {
           Coord point(bends[i]);
-          float x = point.getX(), y = point.getY();
+          double x = point.getX(), y = point.getY();
           point.setX(x - bendsl);
           point.setY(y - bendsl);
           gConvexHull.push_back(point);
@@ -329,9 +330,8 @@ ConvexHullItem* GlConvexHull::buildConvexHullsFromHierarchy(Graph *graph,
       }
       // add a GlConvexHull for this graph in front of convexHulls
       string name;
-      graph->getAttribute<string>("name", name);
-      convexHullItem->hull = new GlConvexHull(gConvexHull, filledColors,
-                                              outColors, true, true, name);
+      graph->getAttribute("name", name);
+      convexHullItem->hull = new GlConvexHull(gConvexHull, filledColors, outColors, true, true, name);
       convexHullItem->hull->_graph = graph;
     }
 
@@ -349,32 +349,23 @@ void GlConvexHull::translate(const Coord& mouvement) {
   }
 }
 //====================================================
-void GlConvexHull::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode= NULL;
+void GlConvexHull::getXML(string &outString) {
 
-  GlXMLTools::createProperty(rootNode, "type", "GlConvexHull");
+  GlXMLTools::createProperty(outString,"type","GlConvexHull","GlEntity");
 
-  GlXMLTools::createDataNode(rootNode, dataNode);
-
-  GlXMLTools::getXML(dataNode, "points", _points);
-  GlXMLTools::getXML(dataNode, "fillColors", _fillColors);
-  GlXMLTools::getXML(dataNode, "outlineColor", _outlineColors);
-  GlXMLTools::getXML(dataNode, "filled", _filled);
-  GlXMLTools::getXML(dataNode, "outlined", _outlined);
+  GlXMLTools::getXML(outString, "points", _points);
+  GlXMLTools::getXML(outString, "fillColors", _fillColors);
+  GlXMLTools::getXML(outString, "outlineColor", _outlineColors);
+  GlXMLTools::getXML(outString, "filled", _filled);
+  GlXMLTools::getXML(outString, "outlined", _outlined);
 }
 //====================================================
-void GlConvexHull::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode= NULL;
-
-  GlXMLTools::getDataNode(rootNode, dataNode);
-
-  if(dataNode) {
-    GlXMLTools::setWithXML(dataNode, "points",_points);
-    GlXMLTools::setWithXML(dataNode, "fillColors", _fillColors);
-    GlXMLTools::setWithXML(dataNode, "outlineColor", _outlineColors);
-    GlXMLTools::setWithXML(dataNode, "filled", _filled);
-    GlXMLTools::setWithXML(dataNode, "outlined", _outlined);
-  }
+void GlConvexHull::setWithXML(const string &inString, unsigned int &currentPosition) {
+  GlXMLTools::setWithXML(inString,currentPosition, "points",_points);
+  GlXMLTools::setWithXML(inString,currentPosition, "fillColors", _fillColors);
+  GlXMLTools::setWithXML(inString,currentPosition, "outlineColor", _outlineColors);
+  GlXMLTools::setWithXML(inString,currentPosition, "filled", _filled);
+  GlXMLTools::setWithXML(inString,currentPosition, "outlined", _outlined);
 }
 
 }
