@@ -18,7 +18,7 @@
  */
 #include <tulip/GlDisplayListManager.h>
 
-#include <iostream>
+#include <cassert>
 
 //====================================================
 tlp::GlDisplayListManager* tlp::GlDisplayListManager::inst=0;
@@ -27,11 +27,11 @@ using namespace std;
 
 namespace tlp {
 //====================================================================
-void GlDisplayListManager::changeContext(unsigned long context) {
+void GlDisplayListManager::changeContext(uintptr_t context) {
   currentContext=context;
 }
 //====================================================================
-void GlDisplayListManager::removeContext(unsigned long context) {
+void GlDisplayListManager::removeContext(uintptr_t context) {
   displayListMap.erase(context);
 }
 //====================================================================
@@ -58,8 +58,8 @@ bool GlDisplayListManager::callDisplayList(const std::string& name) {
     assert(false);
   }
 
-  assert(glIsList((*it).second));
-  glCallList((*it).second);
+  assert(glIsList(it->second));
+  glCallList(it->second);
   return true;
 }
 }
