@@ -18,8 +18,6 @@
  */
 #include <tulip/GlEPSFeedBackBuilder.h>
 
-#include <iostream>
-
 using namespace std;
 
 namespace tlp {
@@ -82,8 +80,6 @@ void GlEPSFeedBackBuilder::begin(const Vector<int, 4> &viewport,GLfloat*,GLfloat
   stream_out << endl << lineWidth << " setlinewidth" << endl;
 
   /* Clear the background like OpenGL had it. */
-  //  fprintf(file, "%g %g %g setrgbcolor\n",
-  //    clearColor[0], clearColor[1], clearColor[2]);
   stream_out << "1.0 1.0 1.0 setrgbcolor" << endl;
   stream_out << viewport[0] << " " << viewport[1] << " " << viewport[2] << " " << viewport[3] << " rectfill" << endl << endl;
 }
@@ -167,11 +163,11 @@ void GlEPSFeedBackBuilder::lineToken(GLfloat *data) {
 
     /* Back up half a step; we want the end points to be
        exactly the their endpoint colors. */
-    xnext -= xstep / 2.0f;
-    ynext -= ystep / 2.0f;
-    rnext -= rstep / 2.0f;
-    gnext -= gstep / 2.0f;
-    bnext -= bstep / 2.0f;
+    xnext -= xstep / 2.0;
+    ynext -= ystep / 2.0;
+    rnext -= rstep / 2.0;
+    gnext -= gstep / 2.0;
+    bnext -= bstep / 2.0;
   }
   else {
     /* Single color line. */
@@ -202,24 +198,24 @@ void GlEPSFeedBackBuilder::lineResetToken(GLfloat *data) {
 void GlEPSFeedBackBuilder::polygonToken(GLfloat *data) {
   int nvertices =(int) *data;
   GLfloat red, green, blue;
-  int smooth;
   Feedback3Dcolor *vertex = (Feedback3Dcolor *)(data+1);
 
   if (nvertices > 0) {
     red = vertex[0].red;
     green = vertex[0].green;
     blue = vertex[0].blue;
-    smooth = 0;
+    bool smooth = false;
 
     for(int i = 1; i < nvertices; i++) {
       if (red != vertex[i].red || green != vertex[i].green || blue != vertex[i].blue) {
-        smooth = 1;
+        smooth = true;
         break;
       }
     }
 
     if (smooth) {
       /* Smooth shaded polygon; varying colors at vetices. */
+
       /* Break polygon into "nvertices-2" triangle fans. */
       for (int i = 0; i < nvertices - 2; i++) {
         stream_out << "[" << vertex[0].x << " " << vertex[i + 1].x << " " << vertex[i + 2].x << " " << vertex[0].y << " " <<  vertex[i + 1].y << " " << vertex[i + 2].y << "]";
