@@ -17,7 +17,7 @@
  *
  */
 #include <tulip/GlEdge.h>
-
+#include <tulip/EdgeExtremityGlyph.h>
 #include <tulip/Coord.h>
 #include <tulip/LayoutProperty.h>
 #include <tulip/DoubleProperty.h>
@@ -26,8 +26,7 @@
 #include <tulip/SizeProperty.h>
 #include <tulip/IntegerProperty.h>
 #include <tulip/ColorProperty.h>
-#include <tulip/PreferenceManager.h>
-
+#include <tulip/GlShaderProgram.h>
 #include <tulip/GlTools.h>
 #include <tulip/GlyphManager.h>
 #include <tulip/Curves.h>
@@ -46,12 +45,15 @@
 #include <tulip/GlVertexArrayManager.h>
 #include <tulip/GlLabel.h>
 #include <tulip/ParametricCurves.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/OpenGlConfigManager.h>
+#include <tulip/GlScene.h>
+#include <tulip/GlGlyphRenderer.h>
+#include <tulip/TulipViewSettings.h>
 
-#include <iostream>
 
 tlp::GlLabel* tlp::GlEdge::label=0;
 bool tlp::GlEdge::haveToComputeEdgeWidthBaseLod=true;
-bool tlp::GlEdge::orthoProjection=false;
 float tlp::GlEdge::edgeWidthBaseLod=0.;
 
 using namespace std;
@@ -63,7 +65,7 @@ GlEdge::GlEdge(unsigned int id):id(id) {
     label=new GlLabel();
 }
 
-BoundingBox GlEdge::getBoundingBox(GlGraphInputData* data) {
+BoundingBox GlEdge::getBoundingBox(const GlGraphInputData* data) {
   edge e = edge(id);
   BoundingBox bb;
 
@@ -73,32 +75,32 @@ BoundingBox GlEdge::getBoundingBox(GlGraphInputData* data) {
   const Coord& srcCoord = data->getElementLayout()->getNodeValue(source);
   const Coord& tgtCoord = data->getElementLayout()->getNodeValue(target);
 
+  const Size &srcSize = data->getElementSize()->getNodeValue(source);
+  const Size &tgtSize = data->getElementSize()->getNodeValue(target);
+  double srcRot = data->getElementRotation()->getNodeValue(source);
+  double tgtRot = data->getElementRotation()->getNodeValue(target);
+
   const LineType::RealType &bends = data->getElementLayout()->getEdgeValue(e);
 
-  if (bends.size() != 0) {
+  // set srcAnchor, tgtAnchor. tmpAnchor will be on the point just before tgtAnchor
+  Coord srcAnchor, tgtAnchor, tmpAnchor;
 
-    const Size &srcSize = data->getElementSize()->getNodeValue(source);
-    const Size &tgtSize = data->getElementSize()->getNodeValue(target);
-    double srcRot = data->getElementRotation()->getNodeValue(source);
-    double tgtRot = data->getElementRotation()->getNodeValue(target);
+  int srcGlyphId = data->getElementShape()->getNodeValue(source);
+  Glyph *sourceGlyph = data->glyphs.get(srcGlyphId);
+  tmpAnchor = (bends.size() > 0) ? bends.front() : tgtCoord;
+  srcAnchor = sourceGlyph->getAnchor(srcCoord, tmpAnchor, srcSize, srcRot);
 
-    // set srcAnchor, tgtAnchor. tmpAnchor will be on the point just before tgtAnchor
-    Coord srcAnchor, tgtAnchor, endLineAnchor, tmpAnchor;
+  int tgtGlyphId = 1; //cube outlined
 
-    int srcGlyphId = data->getElementShape()->getNodeValue(source);
-    Glyph *sourceGlyph = data->glyphs.get(srcGlyphId);
-    tmpAnchor = (bends.size() > 0) ? bends.front() : tgtCoord;
-    srcAnchor = sourceGlyph->getAnchor(srcCoord, tmpAnchor, srcSize, srcRot);
+  if (!data->getGraph()->isMetaNode(target))
+    tgtGlyphId = data->getElementShape()->getNodeValue(target);
 
-    int tgtGlyphId = 1; //cube outlined
+  Glyph *targetGlyph = data->glyphs.get(tgtGlyphId);
+  //this time we don't take srcCoord but srcAnchor to be oriented to where the line comes from
+  tmpAnchor = (bends.size() > 0) ? bends.back() : srcAnchor;
+  tgtAnchor = targetGlyph->getAnchor(tgtCoord, tmpAnchor, tgtSize, tgtRot);
 
-    if (!data->getGraph()->isMetaNode(target))
-      tgtGlyphId = data->getElementShape()->getNodeValue(target);
-
-    Glyph *targetGlyph = data->glyphs.get(tgtGlyphId);
-    //this time we don't take srcCoord but srcAnchor to be oriented to where the line comes from
-    tmpAnchor = (bends.size() > 0) ? bends.back() : srcAnchor;
-    tgtAnchor = targetGlyph->getAnchor(tgtCoord, tmpAnchor, tgtSize, tgtRot);
+  if (!bends.empty()) {
 
     vector<Coord> tmp;
     tlp::computeCleanVertices(bends, srcCoord, tgtCoord, srcAnchor,tgtAnchor, tmp);
@@ -107,8 +109,8 @@ BoundingBox GlEdge::getBoundingBox(GlGraphInputData* data) {
       bb.expand(*it);
   }
 
-  bb.expand(srcCoord);
-  bb.expand(tgtCoord);
+  bb.expand(srcAnchor);
+  bb.expand(tgtAnchor);
 
   return bb;
 }
@@ -117,7 +119,7 @@ void GlEdge::acceptVisitor(GlSceneVisitor *visitor) {
   visitor->visit(this);
 }
 
-void GlEdge::draw(float lod, GlGraphInputData* data, Camera* camera) {
+void GlEdge::draw(float lod, const GlGraphInputData* data, Camera* camera) {
   edge e = edge(id);
 
   const std::pair<node, node>& eEnds = data->graph->ends(e);
@@ -143,12 +145,7 @@ void GlEdge::draw(float lod, GlGraphInputData* data, Camera* camera) {
 
   getEdgeSize(data,e,srcSize,tgtSize,maxSrcSize,maxTgtSize,edgeSize);
 
-  float lodSize;
-
-  if(!orthoProjection)
-    lodSize = getEdgeWidthLod(Coord(0,0,0),edgeSize,camera);
-  else
-    lodSize = getEdgeWidthLod(data->getElementLayout()->getNodeValue(source),edgeSize,camera);
+  float lodSize = getEdgeWidthLod(data->getElementLayout()->getNodeValue(source),edgeSize,camera);
 
   bool selected = data->getElementSelected()->getEdgeValue(e);
 
@@ -178,17 +175,22 @@ void GlEdge::draw(float lod, GlGraphInputData* data, Camera* camera) {
 
   std::string edgeTexture = data->getElementTexture()->getEdgeValue(e);
 
-  if(lodSize>-5 && lodSize<5 && data->getGlVertexArrayManager()->renderingIsBegin() && (!data->parameters->getFeedbackRender())) {
-    data->getGlVertexArrayManager()->activateLineEdgeDisplay(this,selected);
-    return;
-  }
-  else if (data->getGlVertexArrayManager()->renderingIsBegin()
-           && !data->parameters->isEdge3D()
-           && !data->parameters->getFeedbackRender()
-           && !data->parameters->isViewArrow()
-           && edgeTexture == "") {
-    data->getGlVertexArrayManager()->activateQuadEdgeDisplay(this,selected);
-    return;
+  const LineType::RealType &bends = data->getElementLayout()->getEdgeValue(e);
+  unsigned nbBends = bends.size();
+
+  bool vertexArrayRendering = false;
+
+  if (data->getGlVertexArrayManager()->renderingIsBegin() &&
+      !data->parameters->getFeedbackRender()) {
+    if(lodSize>-5 && lodSize<5) {
+      vertexArrayRendering = true;
+      data->getGlVertexArrayManager()->activateLineEdgeDisplay(this,selected);
+      return;
+    }
+    else if (!data->parameters->isEdge3D() && edgeTexture == "") {
+      vertexArrayRendering = true;
+      data->getGlVertexArrayManager()->activateQuadEdgeDisplay(this,selected);
+    }
   }
 
   const Coord& srcCoord = data->getElementLayout()->getNodeValue(source);
@@ -196,11 +198,9 @@ void GlEdge::draw(float lod, GlGraphInputData* data, Camera* camera) {
   const Coord& tgtCoord = data->getElementLayout()->getNodeValue(target);
 
   if (selected) {
-    glDisable(GL_DEPTH_TEST);
     glStencilFunc(GL_LEQUAL, data->parameters->getSelectedEdgesStencil(), 0xFFFF);
   }
   else {
-    glEnable(GL_DEPTH_TEST);
     glStencilFunc(GL_LEQUAL, data->parameters->getEdgesStencil(), 0xFFFF);
   }
 
@@ -232,82 +232,74 @@ void GlEdge::draw(float lod, GlGraphInputData* data, Camera* camera) {
   Color srcCol, tgtCol;
   getEdgeColor(data,e,source,target,selected,srcCol,tgtCol);
 
-  const LineType::RealType &bends = data->getElementLayout()->getEdgeValue(e);
-  unsigned nbBends = bends.size();
-
   if (nbBends == 0 && (source == target)) { //a loop without bends
-    //draw a nice loop;
-    //TODO !!
+    //TODO : draw a nice loop!!
     return;
   }
 
   if (bends.size() == 0 && (srcCoord - tgtCoord).norm() < 1E-4)
     return; //two nodes very closed
 
-  //Get added transformations
-  vector<Coord> objectScale, objectTranslate, objectCoord;
-  camera->getObjectTransformation(objectTranslate, objectScale, objectCoord);
-
-  Matrix<float, 4> transformMatrix;
-  camera->getTransformMatrix(transformMatrix);
-
   // set srcAnchor, tgtAnchor. tmpAnchor will be on the point just before tgtAnchor
   Coord srcAnchor, tgtAnchor, beginLineAnchor, endLineAnchor;
 
   getEdgeAnchor(data,source,target,bends,srcCoord,tgtCoord,srcSize,tgtSize,srcAnchor,tgtAnchor);
 
-  float selectionOutlineSize= 0.f;
+  if (data->parameters->isViewArrow()) {
+    EdgeExtremityGlyph *startEdgeGlyph = data->extremityGlyphs.get(data->getElementSrcAnchorShape()->getEdgeValue(e));
+    EdgeExtremityGlyph *endEdgeGlyph = data->extremityGlyphs.get(data->getElementTgtAnchorShape()->getEdgeValue(e));
 
-  if (selected) {
-    glMatrixMode(GL_PROJECTION);
-    glPushMatrix();
-    glMatrixMode(GL_MODELVIEW);
-    glPushMatrix();
+    float selectionOutlineSize= 0.f;
 
-    Coord p1=camera->screenTo3DWorld(Coord(0,0,0));
-    Coord p2=camera->screenTo3DWorld(Coord(2,0,0));
-    selectionOutlineSize = (p2-p1).norm();
-    edgeSize[0] += selectionOutlineSize;
-    edgeSize[1] += selectionOutlineSize;
+    if (selected) {
+      glMatrixMode(GL_PROJECTION);
+      glPushMatrix();
+      glMatrixMode(GL_MODELVIEW);
+      glPushMatrix();
 
-    glMatrixMode(GL_PROJECTION);
-    glPopMatrix();
-    glMatrixMode(GL_MODELVIEW);
-    glPopMatrix();
-  }
+      Coord p1=camera->screenTo3DWorld(Coord(0,0,0));
+      Coord p2=camera->screenTo3DWorld(Coord(2,0,0));
+      selectionOutlineSize = (p2-p1).norm();
+      edgeSize[0] += selectionOutlineSize;
+      edgeSize[1] += selectionOutlineSize;
 
-  double lineWidth=data->getElementBorderWidth()->getEdgeValue(e);
+      glMatrixMode(GL_PROJECTION);
+      glPopMatrix();
+      glMatrixMode(GL_MODELVIEW);
+      glPopMatrix();
+    }
 
-  unsigned int startEdgeGlyph = data->getElementSrcAnchorShape()->getEdgeValue(e);
-  //Check if the plugin exists.
-  startEdgeGlyph = data->extremityGlyphs.get(startEdgeGlyph) != NULL?startEdgeGlyph:UINT_MAX;
-  unsigned int endEdgeGlyph = data->getElementTgtAnchorShape()->getEdgeValue(e);
-  //Check if the plugin exists.
-  endEdgeGlyph = data->extremityGlyphs.get(endEdgeGlyph)!=NULL ? endEdgeGlyph:UINT_MAX;
+    if (startEdgeGlyph != NULL) {
+      displayArrowAndAdjustAnchor(data,e,source,data->getElementSrcAnchorSize()->getEdgeValue(e),std::min(srcSize[0], srcSize[1]),srcCol,maxSrcSize,selected,selectionOutlineSize, endEdgeGlyph ? endEdgeGlyph->id() : UINT_MAX,
+                                  bends.size(),(nbBends > 0) ? bends.front() : tgtCoord,tgtCoord,srcAnchor,tgtAnchor,beginLineAnchor, startEdgeGlyph, camera);
+    }
+    else {
+      beginLineAnchor = srcAnchor;
+    }
 
-  if (startEdgeGlyph != UINT_MAX && data->parameters->isViewArrow()) {
-    displayArrow(data,e,source,data->getElementSrcAnchorSize()->getEdgeValue(e),std::min(srcSize[0], srcSize[1]),srcCol,maxSrcSize,selected,selectionOutlineSize,startEdgeGlyph,endEdgeGlyph,
-                 bends.size(),(nbBends > 0) ? bends.front() : tgtCoord,tgtCoord,srcAnchor,tgtAnchor,beginLineAnchor);
+    if (endEdgeGlyph != NULL) {
+      displayArrowAndAdjustAnchor(data,e,target,data->getElementTgtAnchorSize()->getEdgeValue(e),std::min(tgtSize[0], tgtSize[1]),tgtCol,maxTgtSize,selected,selectionOutlineSize,startEdgeGlyph ? startEdgeGlyph->id() : UINT_MAX,
+                                  bends.size(),(nbBends > 0) ? bends.back() : srcAnchor,srcCoord,tgtAnchor,srcAnchor,endLineAnchor, endEdgeGlyph, camera);
+    }
+    else {
+      endLineAnchor = tgtAnchor;
+    }
   }
   else {
     beginLineAnchor = srcAnchor;
-  }
-
-  if (endEdgeGlyph != UINT_MAX && data->parameters->isViewArrow()) {
-    displayArrow(data,e,target,data->getElementTgtAnchorSize()->getEdgeValue(e),std::min(tgtSize[0], tgtSize[1]),tgtCol,maxTgtSize,selected,selectionOutlineSize,endEdgeGlyph,startEdgeGlyph,
-                 bends.size(),(nbBends > 0) ? bends.back() : srcAnchor,srcCoord,tgtAnchor,srcAnchor,endLineAnchor);
-  }
-  else {
     endLineAnchor = tgtAnchor;
   }
 
-  //Reset in case of drawing extremity glyph that can alterate value
+  if (vertexArrayRendering)
+    return;
 
+  double lineWidth=data->getElementBorderWidth()->getEdgeValue(e);
+
+  //Reset in case of drawing extremity glyph that can alterate value
   GlTextureManager::getInst().setAnimationFrame(data->getElementAnimationFrame()->getEdgeValue(e));
   //draw Edge
   drawEdge(srcCoord, tgtCoord, beginLineAnchor, endLineAnchor, bends, srcCol, tgtCol,camera->getCenter()-camera->getEyes(),data->parameters->isEdgeColorInterpolate() ,strokeColor,edgeSize,
-           data->getElementShape()->getEdgeValue(e), data->parameters->isEdge3D(), lodSize, edgeTexture, static_cast<float>(lineWidth),
-           data->parameters->getPolylines3DAreBicolored());
+           data->getElementShape()->getEdgeValue(e), data->parameters->isEdge3D(), lodSize, edgeTexture, static_cast<float>(lineWidth));
   GlTextureManager::getInst().setAnimationFrame(0);
 
   if (data->parameters->getFeedbackRender()) {
@@ -322,11 +314,13 @@ void GlEdge::draw(float lod, GlGraphInputData* data, Camera* camera) {
 void GlEdge::drawEdge(const Coord &srcNodePos, const Coord &tgtNodePos, const Coord &startPoint,
                       const Coord &endPoint, const LineType::RealType &bends, const Color &startColor,
                       const Color &endColor, const Coord &lookDir, bool colorInterpolate, const Color &borderColor,
-                      const Size &size, int shape, bool edge3D, float lod,const string &textureName, const float outlineWidth, bool polylines3DAreBicolored) {
+                      const Size &size, int shape, bool edge3D, float lod,const string &textureName, const float outlineWidth) {
 
   glDisable(GL_CULL_FACE);
   glDepthFunc(GL_LEQUAL);
 
+  if(bends.empty())
+    shape=EdgeShape::Polyline;
 
   Coord srcDir(srcNodePos);
   Coord tgtDir(tgtNodePos);
@@ -345,9 +339,8 @@ void GlEdge::drawEdge(const Coord &srcNodePos, const Coord &tgtNodePos, const Co
     glDisable(GL_LIGHTING);
   }
 
-
   switch (shape) {
-  case POLYLINESHAPE:
+  case EdgeShape::Polyline:
 
     if (lod > 1000 || lod < -1000) {
       tlp::polyQuad(tmp, startColor, endColor, size[0] * .5f, size[1] * .5f, srcDir, tgtDir,colorInterpolate,borderColor,textureName, outlineWidth);
@@ -358,49 +351,33 @@ void GlEdge::drawEdge(const Coord &srcNodePos, const Coord &tgtNodePos, const Co
 
     break;
 
-  case L3D_BIT + POLYLINESHAPE: {
+  case L3D_BIT + EdgeShape::Polyline: {
     glDisable(GL_LIGHTING);
-
-    if (polylines3DAreBicolored) {
-      Coord mid=tmp[0]+(tmp[1]-tmp[0])/2.;
-      vector<Coord> tmp1,tmp2;
-      tmp1.push_back(tmp[0]);
-      tmp1.push_back(mid);
-      tmp2.push_back(mid);
-      tmp2.push_back(tmp[1]);
-
-      simpleQuad(tmp1, startColor, startColor, size[0] * .5, size[1] * .5, srcDir, tgtDir,lookDir,colorInterpolate,borderColor,textureName);
-      simpleQuad(tmp2, endColor, endColor, size[0] * .5, size[1] * .5, srcDir, tgtDir,lookDir,colorInterpolate,borderColor,textureName);
-    }
-    else
-      simpleQuad(tmp, startColor, endColor, size[0] * .5f, size[1] * .5f, srcDir, tgtDir,lookDir,colorInterpolate,borderColor,textureName);
-
+    simpleQuad(tmp, startColor, endColor, size[0] * .5f, size[1] * .5f, srcDir, tgtDir,lookDir,colorInterpolate,borderColor,textureName);
     glEnable(GL_LIGHTING);
     break;
   }
 
-  case BEZIERSHAPE :
-  case SPLINESHAPE :
-  case CUBICBSPLINE :
-  case BEZIERSHAPE + L3D_BIT:
-  case SPLINESHAPE + L3D_BIT:
-  case CUBICBSPLINE + L3D_BIT: {
+  case EdgeShape::BezierCurve :
+  case EdgeShape::CatmullRomCurve :
+  case EdgeShape::CubicBSplineCurve :
+  case EdgeShape::BezierCurve + L3D_BIT:
+  case EdgeShape::CatmullRomCurve + L3D_BIT:
+  case EdgeShape::CubicBSplineCurve + L3D_BIT: {
     static GlBezierCurve bezier;
     static GlCatmullRomCurve catmull;
     static GlOpenUniformCubicBSpline bspline;
     AbstractGlCurve *curve = NULL;
     unsigned int nbCurvePoints = 200;
 
-    if (shape == BEZIERSHAPE || shape == BEZIERSHAPE + L3D_BIT) {
+    if (shape == EdgeShape::BezierCurve || shape == EdgeShape::BezierCurve + L3D_BIT) {
       curve = &bezier;
     }
-    else if (shape == SPLINESHAPE || shape == SPLINESHAPE + L3D_BIT) {
+    else if (shape == EdgeShape::CatmullRomCurve || shape == EdgeShape::CatmullRomCurve + L3D_BIT) {
       curve = &catmull;
-      nbCurvePoints = 200;
     }
     else {
       curve = &bspline;
-      nbCurvePoints = 200;
     }
 
     bool fisheyeActivated = GlShaderProgram::getCurrentActiveShader() && GlShaderProgram::getCurrentActiveShader()->getName() == "fisheye";
@@ -430,7 +407,6 @@ void GlEdge::drawEdge(const Coord &srcNodePos, const Coord &tgtNodePos, const Co
     }
 
     curve->drawCurve(tmp, startColor, endColor, startSize, endSize, nbCurvePoints);
-
     break;
   }
 
@@ -449,7 +425,7 @@ void GlEdge::drawEdge(const Coord &srcNodePos, const Coord &tgtNodePos, const Co
   glDepthFunc(GL_LEQUAL);
 }
 
-void GlEdge::drawLabel(bool drawSelect,OcclusionTest* test, GlGraphInputData* data,float lod) {
+void GlEdge::drawLabel(bool drawSelect,OcclusionTest* test, const GlGraphInputData* data,float lod) {
   edge e = edge(id);
   bool select = data->getElementSelected()->getEdgeValue(e);
 
@@ -459,11 +435,11 @@ void GlEdge::drawLabel(bool drawSelect,OcclusionTest* test, GlGraphInputData* da
   drawLabel(test, data, lod);
 }
 
-void GlEdge::drawLabel(OcclusionTest* test, GlGraphInputData* data) {
+void GlEdge::drawLabel(OcclusionTest* test, const GlGraphInputData* data) {
   drawLabel(test,data,0.);
 }
 
-void GlEdge::drawLabel(OcclusionTest* test, GlGraphInputData* data, float lod, Camera *camera) {
+void GlEdge::drawLabel(OcclusionTest* test, const GlGraphInputData* data, float lod, Camera *camera) {
 
   edge e = edge(id);
 
@@ -475,15 +451,19 @@ void GlEdge::drawLabel(OcclusionTest* test, GlGraphInputData* data, float lod, C
 
   bool select = data->getElementSelected()->getEdgeValue(e);
 
-  Color fontColor;
+  Color fontColor, outlineColor;
 
-  if (data->getElementSelected()->getEdgeValue(e))
-    fontColor= data->parameters->getSelectionColor();
+  if (data->getElementSelected()->getEdgeValue(e)) {
+    fontColor = outlineColor = data->parameters->getSelectionColor();
+  }
   else {
     fontColor = data->getElementLabelColor()->getEdgeValue(e);
+    outlineColor = data->getElementLabelBorderColor()->getEdgeValue(e);
   }
 
-  if(fontColor.getA()==0)
+  float outlineWidth = data->getElementLabelBorderWidth()->getEdgeValue(e);
+
+  if(fontColor.getA()==0 && (outlineColor.getA()==0 || outlineWidth==0))
     return;
 
   int fontSize=data->getElementFontSize()->getEdgeValue(e);
@@ -496,9 +476,10 @@ void GlEdge::drawLabel(OcclusionTest* test, GlGraphInputData* data, float lod, C
   else
     label->setStencil(data->parameters->getEdgesLabelStencil());
 
-  label->setText(tmp);
   label->setFontNameSizeAndColor(data->getElementFont()->getEdgeValue(e),fontSize,fontColor);
-  label->setOutlineColor(Color(0,0,0,fontColor[3]));
+  label->setText(tmp);
+  label->setOutlineColor(outlineColor);
+  label->setOutlineSize(outlineWidth);
 
   const std::pair<node, node>& eEnds = data->graph->ends(e);
   const node source = eEnds.first;
@@ -521,10 +502,7 @@ void GlEdge::drawLabel(OcclusionTest* test, GlGraphInputData* data, float lod, C
 
   getEdgeSize(data,e,srcSize,tgtSize,maxSrcSize,maxTgtSize,edgeSize);
 
-  if(edgeSize[0]>edgeSize[1])
-    label->setTranslationAfterRotation(Coord(0,edgeSize[0]*2,0));
-  else
-    label->setTranslationAfterRotation(Coord(0,edgeSize[1]*2,0));
+  label->setTranslationAfterRotation(Coord());
 
   const Coord & srcCoord = data->getElementLayout()->getNodeValue(source);
   const Coord & tgtCoord = data->getElementLayout()->getNodeValue(target);
@@ -575,22 +553,30 @@ void GlEdge::drawLabel(OcclusionTest* test, GlGraphInputData* data, float lod, C
   }
 
   BoundingBox bb=getBoundingBox(data);
+  int labelPos = data->getElementLabelPosition()->getEdgeValue(e);
 
-  label->setSize(Size(0.001f,0.001f,0.0f));
+  label->setSize(Size());
   label->rotate(0,0,angle);
-  label->setAlignment(ON_TOP);
+  label->setAlignment(labelPos);
   label->setScaleToSize(false);
-  label->setLabelsDensity(data->parameters->getLabelsBorder());
+  label->setLabelsDensity(data->parameters->getLabelsDensity());
 
-  if(!data->parameters->isLabelOverlaped())
+  if(!(data->parameters->getLabelsDensity()==100)) //labels overlap
     label->setOcclusionTester(test);
   else
     label->setOcclusionTester(NULL);
 
   label->setPosition(position);
 
+  if (edgeSize[0] > edgeSize[1]) {
+    label->setTranslationAfterRotation(Coord(0, -edgeSize[0]/2));
+  }
+  else {
+    label->setTranslationAfterRotation(Coord(0, -edgeSize[1]/2));
+  }
+
   label->setUseLODOptimisation(true,bb);
-  label->setUseMinMaxSize(true);
+  label->setUseMinMaxSize(!data->parameters->isLabelFixedFontSize());
   label->setMinSize(data->parameters->getMinSizeOfLabel());
   label->setMaxSize(data->parameters->getMaxSizeOfLabel());
   label->setBillboarded(data->parameters->getLabelsAreBillboarded());
@@ -598,7 +584,7 @@ void GlEdge::drawLabel(OcclusionTest* test, GlGraphInputData* data, float lod, C
   label->drawWithStencil(lod,camera);
 }
 
-void GlEdge::getVertices(GlGraphInputData *data,
+void GlEdge::getVertices(const GlGraphInputData *data,
                          std::vector<Coord> &linesCoordsArray) {
   edge e = edge(id);
 
@@ -607,6 +593,7 @@ void GlEdge::getVertices(GlGraphInputData *data,
   const node target = eEnds.second;
   const Coord& srcCoord = data->getElementLayout()->getNodeValue(source);
   const Coord& tgtCoord = data->getElementLayout()->getNodeValue(target);
+  bool selected = data->getElementSelected()->getEdgeValue(e);
 
   const LineType::RealType &bends = data->getElementLayout()->getEdgeValue(e);
   unsigned nbBends = bends.size();
@@ -621,35 +608,73 @@ void GlEdge::getVertices(GlGraphInputData *data,
   const Size &srcSize = data->getElementSize()->getNodeValue(source);
   const Size &tgtSize = data->getElementSize()->getNodeValue(target);
 
+  float maxSrcSize, maxTgtSize;
+
+  if(srcSize[0]>=srcSize[1])
+    maxSrcSize=srcSize[0];
+  else
+    maxSrcSize=srcSize[1];
+
+  if(tgtSize[0]>=tgtSize[1])
+    maxTgtSize=tgtSize[0];
+  else
+    maxTgtSize=tgtSize[1];
+
   Coord srcAnchor, tgtAnchor;
   getEdgeAnchor(data,source,target,bends,srcCoord,tgtCoord,srcSize,tgtSize,srcAnchor,tgtAnchor);
 
   vector<Coord> vertices;
   Coord srcCoordTmp=srcCoord;
   Coord tgtCoordTmp=tgtCoord;
-  computeCleanVertices(bends, srcAnchor, tgtAnchor, srcCoordTmp, tgtCoordTmp, vertices);
+
+  EdgeExtremityGlyph *startEdgeGlyph = data->extremityGlyphs.get(data->getElementSrcAnchorShape()->getEdgeValue(e));
+  EdgeExtremityGlyph *endEdgeGlyph = data->extremityGlyphs.get(data->getElementTgtAnchorShape()->getEdgeValue(e));
+
+
+  Coord beginLineAnchor;
+
+  if (data->parameters->isViewArrow() && startEdgeGlyph != NULL) {
+    displayArrowAndAdjustAnchor(data,e,source,data->getElementSrcAnchorSize()->getEdgeValue(e),std::min(srcSize[0], srcSize[1]),Color(),maxSrcSize,selected,0, endEdgeGlyph ? endEdgeGlyph->id() : UINT_MAX,
+                                bends.size(),(nbBends > 0) ? bends.front() : tgtCoord,tgtCoord,srcAnchor,tgtAnchor,beginLineAnchor);
+  }
+  else {
+    beginLineAnchor = srcAnchor;
+  }
+
+  Coord endLineAnchor;
+
+  if (data->parameters->isViewArrow() && endEdgeGlyph != NULL) {
+    displayArrowAndAdjustAnchor(data,e,target,data->getElementTgtAnchorSize()->getEdgeValue(e),std::min(tgtSize[0], tgtSize[1]),Color(),maxTgtSize,selected,0,startEdgeGlyph ? startEdgeGlyph->id() : UINT_MAX,
+                                bends.size(),(nbBends > 0) ? bends.back() : srcAnchor,srcCoord,tgtAnchor,srcAnchor,endLineAnchor);
+  }
+  else {
+    endLineAnchor = tgtAnchor;
+  }
+
+  computeCleanVertices(bends, beginLineAnchor, endLineAnchor, srcCoordTmp, tgtCoordTmp, vertices);
 
   if(vertices.empty())
     return ;
 
-  if ((vertices.size() > 2 && data->getElementShape()->getEdgeValue(e) == BEZIERSHAPE) ||
-      (vertices.size() == 3 && data->getElementShape()->getEdgeValue(e) == CUBICBSPLINE)) {
+  if ((vertices.size() > 2 && data->getElementShape()->getEdgeValue(e) == EdgeShape::BezierCurve) ||
+      (vertices.size() == 3 && data->getElementShape()->getEdgeValue(e) == EdgeShape::CubicBSplineCurve)) {
     vector<Coord> curvePoints;
     computeBezierPoints(vertices, curvePoints, 200);
     vertices = curvePoints;
   }
-  else if (vertices.size() > 2 && data->getElementShape()->getEdgeValue(e) == SPLINESHAPE) {
+  else if (vertices.size() > 2 && data->getElementShape()->getEdgeValue(e) == EdgeShape::CatmullRomCurve) {
     vector<Coord> curvePoints;
     computeCatmullRomPoints(vertices, curvePoints, false, 200);
     vertices = curvePoints;
   }
 
-  if (vertices.size() > 2 && data->getElementShape()->getEdgeValue(e) == CUBICBSPLINE) {
+  if (vertices.size() > 2 && data->getElementShape()->getEdgeValue(e) == EdgeShape::CubicBSplineCurve) {
     vector<Coord> curvePoints;
     computeOpenUniformBsplinePoints(vertices, curvePoints, 3, 200);
     vertices = curvePoints;
   }
 
+
   size_t numberOfVertices=vertices.size();
 
   for(size_t i=0; i<numberOfVertices; ++i) {
@@ -657,7 +682,7 @@ void GlEdge::getVertices(GlGraphInputData *data,
   }
 }
 
-void GlEdge::getColors(GlGraphInputData *data,
+void GlEdge::getColors(const GlGraphInputData *data,
                        const Coord *vertices,unsigned int numberOfVertices,
                        std::vector<Color> &linesColorsArray) {
 
@@ -687,7 +712,7 @@ void GlEdge::getColors(GlGraphInputData *data,
   }
 }
 
-void GlEdge::getColors(GlGraphInputData *data,
+void GlEdge::getColors(const GlGraphInputData *data,
                        const vector<Coord> &vertices,
                        std::vector<Color> &linesColorsArray) {
 
@@ -695,7 +720,7 @@ void GlEdge::getColors(GlGraphInputData *data,
 }
 
 
-void GlEdge::getEdgeColor(GlGraphInputData *data,const edge &e,const node &source,const node &target, bool selected,Color &srcCol, Color &tgtCol) {
+void GlEdge::getEdgeColor(const GlGraphInputData *data,const edge &e,const node &source,const node &target, bool selected,Color &srcCol, Color &tgtCol) {
   Color selectionColor=data->parameters->getSelectionColor();
 
   if (selected) {
@@ -713,7 +738,7 @@ void GlEdge::getEdgeColor(GlGraphInputData *data,const edge &e,const node &sourc
   }
 }
 
-void GlEdge::getEdgeSize(GlGraphInputData *data,edge e,const Size &srcSize, const Size &tgtSize,const float maxSrcSize,const float maxTgtSize,Size &edgeSize) {
+void GlEdge::getEdgeSize(const GlGraphInputData *data,edge e,const Size &srcSize, const Size &tgtSize,const float maxSrcSize,const float maxTgtSize,Size &edgeSize) {
 
   if (data->parameters->isEdgeSizeInterpolate()) {
     if(srcSize[0]<srcSize[1])
@@ -741,7 +766,7 @@ void GlEdge::getEdgeSize(GlGraphInputData *data,edge e,const Size &srcSize, cons
   }
 }
 
-void GlEdge::getEdgeAnchor(GlGraphInputData *data,const node &source,const node &target,const LineType::RealType &bends,const Coord &srcCoord,const Coord &tgtCoord,const Size &srcSize,const Size &tgtSize, Coord &srcAnchor, Coord &tgtAnchor) {
+void GlEdge::getEdgeAnchor(const GlGraphInputData *data,const node &source,const node &target,const LineType::RealType &bends,const Coord &srcCoord,const Coord &tgtCoord,const Size &srcSize,const Size &tgtSize, Coord &srcAnchor, Coord &tgtAnchor) {
   double srcRot = data->getElementRotation()->getNodeValue(source);
   double tgtRot = data->getElementRotation()->getNodeValue(target);
 
@@ -760,26 +785,16 @@ void GlEdge::getEdgeAnchor(GlGraphInputData *data,const node &source,const node
 
 float GlEdge::getEdgeWidthLod(const Coord &edgeCoord,
                               const Size &edgeSize,Camera *camera) {
-  if(!orthoProjection) {
+  if(!camera->getScene()->isViewOrtho()) {
     if(haveToComputeEdgeWidthBaseLod) {
-      // This code is here because screenTo3DWorld function modify current projection
-      // ==>
-      Matrix<float, 4> transformMatrix;
       Vector<int, 4> viewport = camera->getViewport();
-      camera->getTransformMatrix(transformMatrix);
-      Coord pScr = projectPoint(Coord(0,0,0), transformMatrix, viewport);
-      pScr[0] = static_cast<float>(viewport[2]);
-      pScr[1] = static_cast<float>(viewport[3]) - 1.0f;
-      MatrixGL tmp(transformMatrix);
-      tmp.inverse();
-      Coord worldPosition=unprojectPoint(pScr, tmp, viewport);
-      // <==
+      Matrix<float, 4> transformMatrix;
+
+      camera->getTransformMatrix(viewport,transformMatrix);
+
+      edgeWidthBaseLod=((projectPoint(Coord(1,0,0), transformMatrix, viewport) - Coord(viewport[0], viewport[1]))
+                        -(projectPoint(Coord(0,0,0), transformMatrix, viewport) - Coord(viewport[0], viewport[1]))).norm();
 
-      Matrix<float, 4u> projectionMatrix;
-      Matrix<float, 4u> modelviewMatrix;
-      camera->getProjectionMatrix(projectionMatrix);
-      camera->getModelviewMatrix(modelviewMatrix);
-      edgeWidthBaseLod=projectSize(worldPosition, Size(1, 1, 1), projectionMatrix, modelviewMatrix,camera->getViewport());
       haveToComputeEdgeWidthBaseLod=false;
     }
 
@@ -795,27 +810,35 @@ float GlEdge::getEdgeWidthLod(const Coord &edgeCoord,
     Matrix<float, 4u> modelviewMatrix;
     camera->getProjectionMatrix(projectionMatrix);
     camera->getModelviewMatrix(modelviewMatrix);
-    return projectSize(edgeCoord, Size(edgeSize[0], edgeSize[0], edgeSize[0]), projectionMatrix, modelviewMatrix,camera->getViewport());
+
+    if (edgeSize[0] != edgeSize[1]) {
+      return std::max(std::abs(projectSize(edgeCoord, Size(edgeSize[0], edgeSize[0], edgeSize[0]), projectionMatrix, modelviewMatrix,camera->getViewport())),
+                      std::abs(projectSize(edgeCoord, Size(edgeSize[1], edgeSize[1], edgeSize[1]), projectionMatrix, modelviewMatrix,camera->getViewport())));
+    }
+    else {
+      return std::abs(projectSize(edgeCoord, Size(edgeSize[0], edgeSize[0], edgeSize[0]), projectionMatrix, modelviewMatrix,camera->getViewport()));
+    }
   }
 }
 
-void GlEdge::displayArrow(GlGraphInputData *data,
-                          const edge &e,
-                          const node &source,
-                          const Size& sizeRatio,
-                          float edgeSize,
-                          const Color &color,
-                          float maxSize,
-                          bool selected,
-                          float selectionOutlineSize,
-                          int srcEdgeGlyph,
-                          int tgtEdgeGlyph,
-                          size_t numberOfBends,
-                          const Coord &anchor,
-                          const Coord &tgtCoord,
-                          const Coord &srcAnchor,
-                          const Coord &tgtAnchor,
-                          Coord &lineAnchor) {
+void GlEdge::displayArrowAndAdjustAnchor(const GlGraphInputData *data,
+    const edge &e,
+    const node &source,
+    const Size& sizeRatio,
+    float edgeSize,
+    const Color &color,
+    float maxSize,
+    bool selected,
+    float selectionOutlineSize,
+    int tgtEdgeGlyph,
+    size_t numberOfBends,
+    const Coord &anchor,
+    const Coord &tgtCoord,
+    const Coord &srcAnchor,
+    const Coord &tgtAnchor,
+    Coord &lineAnchor,
+    EdgeExtremityGlyph* extremityGlyph,
+    Camera *camera) {
 
   //Correct begin tmp Anchor
   Coord beginTmpAnchor = anchor;
@@ -860,23 +883,40 @@ void GlEdge::displayArrow(GlGraphInputData *data,
 
   size[0] = std::min(maxGlyphSize, size[0]);
 
-  EdgeExtremityGlyph *extremityGlyph = data->extremityGlyphs.get(srcEdgeGlyph);
-  assert(extremityGlyph);
+  if (extremityGlyph) {
 
-  MatrixGL srcTransformationMatrix;
-  MatrixGL srcScalingMatrix;
+    MatrixGL projectionMatrix;
+    MatrixGL modelviewMatrix;
+    camera->getProjectionMatrix(projectionMatrix);
+    camera->getModelviewMatrix(modelviewMatrix);
 
-  extremityGlyph->getTransformationMatrix(beginTmpAnchor, srcAnchor, size,
-                                          srcTransformationMatrix, srcScalingMatrix);
+    float lod = projectSize(srcAnchor, size, projectionMatrix, modelviewMatrix,camera->getViewport());
 
+    // edge extremity glyph is in the viewport
+    if (lod > 0) {
 
-  glPushMatrix();
-  glMultMatrixf((GLfloat *) &srcTransformationMatrix);
-  glMultMatrixf((GLfloat *) &srcScalingMatrix);
-  glDisable(GL_CULL_FACE);
-  extremityGlyph->draw(e, source, color,(data->parameters->isEdgeColorInterpolate() ? color : data->getElementBorderColor()->getEdgeValue(e)), 100.);
-  glEnable(GL_CULL_FACE);
-  glPopMatrix();
+      Color borderColor = data->parameters->isEdgeColorInterpolate() ? color : data->getElementBorderColor()->getEdgeValue(e);
+
+      if (data->getGlGlyphRenderer()->renderingHasStarted()) {
+        data->getGlGlyphRenderer()->addEdgeExtremityGlyphRendering(extremityGlyph, e, source, color, borderColor, 100., beginTmpAnchor, srcAnchor, size, selected);
+      }
+      else {
+        MatrixGL srcTransformationMatrix;
+        MatrixGL srcScalingMatrix;
+
+        extremityGlyph->get2DTransformationMatrix(beginTmpAnchor, srcAnchor, size,
+            srcTransformationMatrix, srcScalingMatrix);
+
+        glPushMatrix();
+        glMultMatrixf((GLfloat *) &srcTransformationMatrix);
+        glMultMatrixf((GLfloat *) &srcScalingMatrix);
+        glDisable(GL_CULL_FACE);
+        extremityGlyph->draw(e, source, color, borderColor, 100.);
+        glEnable(GL_CULL_FACE);
+        glPopMatrix();
+      }
+    }
+  }
 
   //Compute new Anchor
 
