@@ -17,9 +17,9 @@
  *
  */
 #include <tulip/GlFeedBackRecorder.h>
+#include <tulip/GlFeedBackBuilder.h>
 
-#include <stdio.h>
-#include <iostream>
+#include <cstdlib>
 
 using namespace std;
 
@@ -41,6 +41,8 @@ static int compare(const void *a, const void *b) {
   }
 }
 
+GlFeedBackRecorder::GlFeedBackRecorder(GlFeedBackBuilder *builder,unsigned int pointSize):feedBackBuilder(builder), pointSize(pointSize) {}
+
 void GlFeedBackRecorder::record(bool doSort,GLint size, GLfloat *feedBackBuffer,const Vector<int,4>& viewport) {
   feedBackBuilder->begin(viewport);
 
@@ -96,7 +98,8 @@ void GlFeedBackRecorder::sortAndRecord(GLint size, GLfloat *feedBackBuffer) {
 
     default:
       /* XXX Left as an excersie to the reader. */
-      printf("Incomplete implementation.  Unexpected token (%d).\n",token);
+      //printf("Incomplete implementation.  Unexpected token (%d).\n",token);
+      assert(false);
     }
   }
 
@@ -120,7 +123,7 @@ void GlFeedBackRecorder::sortAndRecord(GLint size, GLfloat *feedBackBuffer) {
     case GL_LINE_RESET_TOKEN:
       vertex = (Feedback3Dcolor *) loc;
       depthSum = vertex[0].z + vertex[1].z;
-      prims[item].depth = depthSum / 2.0f;
+      prims[item].depth = depthSum / 2.0;
       loc += pointSize*2;
       item++;
       break;
@@ -230,8 +233,9 @@ GLfloat* GlFeedBackRecorder::recordPrimitive(GLfloat *loc) {
 
   default:
     /* XXX Left as an excersie to the reader. */
-    printf("Incomplete implementation.  Unexpected token (%d).\n", token);
+    //printf("Incomplete implementation.  Unexpected token (%d).\n", token);
     //exit(1);
+    assert(false);
   }
 
   return loc;
