@@ -16,18 +16,15 @@
  * See the GNU General Public License for more details.
  *
  */
-
 #include <tulip/LayoutProperty.h>
 #include <tulip/Vector.h>
 #include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/TlpTools.h>
-#include <tulip/PreferenceManager.h>
 
 using namespace tlp;
 
 GlGraphRenderingParameters::GlGraphRenderingParameters() :
   //_graph(0),
-  _pointModeLOD(10.0f),
   _antialiased(true),
   _viewArrow(false),
   _viewNodeLabel(true),
@@ -52,16 +49,16 @@ GlGraphRenderingParameters::GlGraphRenderingParameters() :
   _metaNodesLabelStencil(0xFFFF),
   _edgesLabelStencil(0xFFFF),
   _labelScaled(false),
+  _labelFixedFontSize(false),
   _labelMinSize(10),
   _labelMaxSize(30),
-  _labelsDensity(100),
+  _labelsDensity(0),
   _labelsAreBillboarded(false),
-  _polylines3DAreBicolored(false),
   _fontsPath(tlp::TulipBitmapDir),
   _texturePath(""),
   _edgesMaxSizeToNodesSize(true),
   _feedbackRender(false),
-  _selectionColor(PreferenceManager::getInst().getSelectionColor()),
+  _selectionColor(GlDefaultSelectionColorManager::getDefaultSelectionColor()),
   _displayFilteringProperty(NULL),
   _elementOrderingProperty(NULL) {
 }
@@ -100,7 +97,6 @@ DataSet GlGraphRenderingParameters::getParameters() const {
   data.set("selectionColor",_selectionColor);
   data.set("labelsDensity", _labelsDensity);
   data.set("labelsAreBillboarded", _labelsAreBillboarded);
-  data.set("polylines3DAreBicolored", _polylines3DAreBicolored);
   //data.set("SupergraphId", _graph->getId());
   return data;
 }
@@ -159,14 +155,11 @@ void GlGraphRenderingParameters::setParameters(const DataSet &data) {
     setLabelScaled(b);
 
   if (data.get<bool>("labelOverlaped", b))
-    setLabelOverlaped(b);
+    setLabelsDensity(b ? 100 : 0);
 
   if (data.get<bool>("labelsAreBillboarded", b))
     setLabelsAreBillboarded(b);
 
-  if (data.get<bool>("polylines3DAreBicolored", b))
-    setPolylines3DAreBicolored(b);
-
   unsigned int ui = 0;
 
   if (data.get<unsigned int>("fontType", ui))
@@ -250,7 +243,7 @@ void GlGraphRenderingParameters::setFontsType(unsigned int i) {
 void GlGraphRenderingParameters::setFontsPath(const std::string &path) {
   _fontsPath = path;
 }
-std::string GlGraphRenderingParameters::getFontsPath() {
+std::string GlGraphRenderingParameters::getFontsPath() const {
   return _fontsPath;
 }
 //====================================================
@@ -341,63 +334,63 @@ bool GlGraphRenderingParameters::isViewOutScreenLabel() const {
 void GlGraphRenderingParameters::setSelectedNodesStencil(const int stencil) {
   _selectedNodesStencil=stencil;
 }
-int GlGraphRenderingParameters::getSelectedNodesStencil() {
+int GlGraphRenderingParameters::getSelectedNodesStencil() const {
   return _selectedNodesStencil;
 }
 //====================================================
 void GlGraphRenderingParameters::setSelectedMetaNodesStencil(const int stencil) {
   _selectedMetaNodesStencil=stencil;
 }
-int GlGraphRenderingParameters::getSelectedMetaNodesStencil() {
+int GlGraphRenderingParameters::getSelectedMetaNodesStencil() const {
   return _selectedMetaNodesStencil;
 }
 //====================================================
 void GlGraphRenderingParameters::setSelectedEdgesStencil(const int stencil) {
   _selectedEdgesStencil=stencil;
 }
-int GlGraphRenderingParameters::getSelectedEdgesStencil() {
+int GlGraphRenderingParameters::getSelectedEdgesStencil() const {
   return _selectedEdgesStencil;
 }
 //====================================================
 void GlGraphRenderingParameters::setNodesStencil(const int stencil) {
   _nodesStencil=stencil;
 }
-int GlGraphRenderingParameters::getNodesStencil() {
+int GlGraphRenderingParameters::getNodesStencil() const {
   return _nodesStencil;
 }
 //====================================================
 void GlGraphRenderingParameters::setMetaNodesStencil(const int stencil) {
   _metaNodesStencil=stencil;
 }
-int GlGraphRenderingParameters::getMetaNodesStencil() {
+int GlGraphRenderingParameters::getMetaNodesStencil() const {
   return _metaNodesStencil;
 }
 //====================================================
 void GlGraphRenderingParameters::setEdgesStencil(const int stencil) {
   _edgesStencil=stencil;
 }
-int GlGraphRenderingParameters::getEdgesStencil() {
+int GlGraphRenderingParameters::getEdgesStencil() const {
   return _edgesStencil;
 }
 //====================================================
 void GlGraphRenderingParameters::setNodesLabelStencil(const int stencil) {
   _nodesLabelStencil=stencil;
 }
-int GlGraphRenderingParameters::getNodesLabelStencil() {
+int GlGraphRenderingParameters::getNodesLabelStencil() const {
   return _nodesLabelStencil;
 }
 //====================================================
 void GlGraphRenderingParameters::setMetaNodesLabelStencil(const int stencil) {
   _metaNodesLabelStencil=stencil;
 }
-int GlGraphRenderingParameters::getMetaNodesLabelStencil() {
+int GlGraphRenderingParameters::getMetaNodesLabelStencil() const {
   return _metaNodesLabelStencil;
 }
 //====================================================
 void GlGraphRenderingParameters::setEdgesLabelStencil(const int stencil) {
   _edgesLabelStencil=stencil;
 }
-int GlGraphRenderingParameters::getEdgesLabelStencil() {
+int GlGraphRenderingParameters::getEdgesLabelStencil() const {
   return _edgesLabelStencil;
 }
 //====================================================
@@ -408,14 +401,14 @@ void GlGraphRenderingParameters::setEdgeColorInterpolate(const bool b) {
   _edgeColorInterpolate=b;
 }
 //====================================================
-bool GlGraphRenderingParameters::isEdgeSizeInterpolate()const {
+bool GlGraphRenderingParameters::isEdgeSizeInterpolate() const {
   return (_edgeSizeInterpolate);
 }
 void GlGraphRenderingParameters::setEdgeSizeInterpolate(const bool b) {
   _edgeSizeInterpolate=b;
 }
 //====================================================
-bool GlGraphRenderingParameters::getEdgesMaxSizeToNodesSize()const {
+bool GlGraphRenderingParameters::getEdgesMaxSizeToNodesSize() const {
   return (_edgesMaxSizeToNodesSize);
 }
 void GlGraphRenderingParameters::setEdgesMaxSizeToNodesSize(const bool b) {
@@ -425,74 +418,66 @@ void GlGraphRenderingParameters::setEdgesMaxSizeToNodesSize(const bool b) {
 void GlGraphRenderingParameters::setFeedbackRender(bool feedback) {
   _feedbackRender=feedback;
 }
-//====================================================
-bool GlGraphRenderingParameters::getFeedbackRender() {
+bool GlGraphRenderingParameters::getFeedbackRender() const {
   return _feedbackRender;
 }
 //====================================================
 void GlGraphRenderingParameters::setSelectionColor(const Color &color) {
   _selectionColor=color;
 }
-//====================================================
-Color GlGraphRenderingParameters::getSelectionColor() {
+Color GlGraphRenderingParameters::getSelectionColor() const {
   return _selectionColor;
 }
 //====================================================
-bool GlGraphRenderingParameters::isLabelScaled() {
+bool GlGraphRenderingParameters::isLabelScaled() const {
   return _labelScaled;
 }
-//====================================================
 void GlGraphRenderingParameters::setLabelScaled(bool state) {
   _labelScaled=state;
 }
 //====================================================
-bool GlGraphRenderingParameters::isLabelOverlaped() {
-  return _labelsDensity==100;
+bool GlGraphRenderingParameters::isLabelFixedFontSize() const {
+  return _labelFixedFontSize;
+}
+void GlGraphRenderingParameters::setLabelFixedFontSize(bool state) {
+  _labelFixedFontSize=state;
 }
 //====================================================
-void GlGraphRenderingParameters::setLabelOverlaped(bool state) {
-  if(state)
-    _labelsDensity=100;
-  else
-    _labelsDensity=0;
-}
-//====================================================
-int GlGraphRenderingParameters::getLabelsDensity() {
+int GlGraphRenderingParameters::getLabelsDensity() const {
   return _labelsDensity;
 }
-//====================================================
 void GlGraphRenderingParameters::setLabelsDensity(int density) {
   _labelsDensity=density;
 }
 //====================================================
-int GlGraphRenderingParameters::getMinSizeOfLabel() {
+int GlGraphRenderingParameters::getMinSizeOfLabel() const {
   return _labelMinSize;
 }
-//====================================================
 void GlGraphRenderingParameters::setMinSizeOfLabel(int size) {
   _labelMinSize=size;
 }
 //====================================================
-int GlGraphRenderingParameters::getMaxSizeOfLabel() {
+int GlGraphRenderingParameters::getMaxSizeOfLabel() const {
   return _labelMaxSize;
 }
-//====================================================
 void GlGraphRenderingParameters::setMaxSizeOfLabel(int size) {
   _labelMaxSize=size;
 }
-
+//====================================================
 void GlGraphRenderingParameters::setElementOrderingProperty(tlp::DoubleProperty* property) {
   _elementOrderingProperty = property;
 }
-
 tlp::DoubleProperty* GlGraphRenderingParameters::getElementOrderingProperty() const {
   return _elementOrderingProperty;
 }
+//====================================================
+GlDefaultSelectionColorManager* GlDefaultSelectionColorManager::manager = NULL;
 
-float GlGraphRenderingParameters::getPointModeLOD() const {
-  return _pointModeLOD;
+void GlDefaultSelectionColorManager::setManager(GlDefaultSelectionColorManager* mgr) {
+  manager = mgr;
 }
 
-void GlGraphRenderingParameters::setPointModeLOD(const float pointModeLOD) {
-  _pointModeLOD = pointModeLOD;
+tlp::Color GlDefaultSelectionColorManager::getDefaultSelectionColor() {
+  static Color selectionColor(23, 81, 228);
+  return manager ? manager->defaultSelectionColor() : selectionColor;
 }
