@@ -17,6 +17,7 @@
  *
  */
 #include <tulip/GlGraphStaticData.h>
+#include <tulip/TulipViewSettings.h>
 
 #include <iostream>
 
@@ -25,45 +26,45 @@ using namespace std;
 namespace tlp {
 
 const int GlGraphStaticData::edgeShapesCount = 4;
-int GlGraphStaticData::edgeShapeIds[edgeShapesCount] = {BEZIERSHAPE, POLYLINESHAPE, SPLINESHAPE, CUBICBSPLINE};
+int GlGraphStaticData::edgeShapeIds[edgeShapesCount] = {EdgeShape::Polyline, EdgeShape::BezierCurve, EdgeShape::CatmullRomCurve, EdgeShape::CubicBSplineCurve};
 string GlGraphStaticData::labelPositionNames[] = { string("Center"), string("Top"), string("Bottom"),string("Left"), string("Right") };
 
 string GlGraphStaticData::edgeShapeName(int id) {
   switch(id) {
-  case POLYLINESHAPE:
+  case EdgeShape::Polyline:
     return string("Polyline");
 
-  case BEZIERSHAPE:
+  case EdgeShape::BezierCurve:
     return string("Bezier Curve");
 
-  case SPLINESHAPE:
+  case EdgeShape::CatmullRomCurve:
     return string("Catmull-Rom Spline");
 
-  case CUBICBSPLINE:
+  case EdgeShape::CubicBSplineCurve:
     return string("Cubic B-Spline");
 
   default:
-    cerr << __PRETTY_FUNCTION__ << endl;
-    cerr << "Invalid edge shape id" << endl;
+    tlp::warning() << __PRETTY_FUNCTION__ << endl;
+    tlp::warning() << "Invalid edge shape id" << endl;
     return string("invalid shape id");
   }
 }
 
 int GlGraphStaticData::edgeShapeId(string name) {
-  if (name == edgeShapeName(POLYLINESHAPE))
-    return POLYLINESHAPE;
+  if (name == edgeShapeName(EdgeShape::Polyline))
+    return EdgeShape::Polyline;
 
-  if (name == edgeShapeName(BEZIERSHAPE))
-    return BEZIERSHAPE;
+  if (name == edgeShapeName(EdgeShape::BezierCurve))
+    return EdgeShape::BezierCurve;
 
-  if (name == edgeShapeName(SPLINESHAPE))
-    return SPLINESHAPE;
+  if (name == edgeShapeName(EdgeShape::CatmullRomCurve))
+    return EdgeShape::CatmullRomCurve;
 
-  if (name == edgeShapeName(CUBICBSPLINE))
-    return CUBICBSPLINE;
+  if (name == edgeShapeName(EdgeShape::CubicBSplineCurve))
+    return EdgeShape::CubicBSplineCurve;
 
-  cerr << __PRETTY_FUNCTION__ << endl;
-  cerr << "Invalid edge shape name" << endl;
+  tlp::warning() << __PRETTY_FUNCTION__ << endl;
+  tlp::warning() << "Invalid edge shape name" << endl;
   return -1;
 }
 
@@ -81,8 +82,8 @@ int GlGraphStaticData::labelPositionId(string name) {
       return i;
   }
 
-  cerr << __PRETTY_FUNCTION__ << endl;
-  cerr << "Invalid label position name" << endl;
+  tlp::warning() << __PRETTY_FUNCTION__ << endl;
+  tlp::warning() << "Invalid label position name" << endl;
   return -1;
 }
 
