@@ -16,9 +16,6 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <libxml/parser.h>
-#include <iostream>
-
 #include <FTGL/ftgl.h>
 
 #include <tulip/GlLabel.h>
@@ -30,7 +27,7 @@
 #include <tulip/SizeProperty.h>
 #include <tulip/IntegerProperty.h>
 #include <tulip/ColorProperty.h>
-
+#include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlTools.h>
 #include <tulip/GlyphManager.h>
 #include <tulip/GlDisplayListManager.h>
@@ -38,7 +35,8 @@
 #include <tulip/GlTLPFeedBackBuilder.h>
 #include <tulip/OcclusionTest.h>
 #include <tulip/GlTextureManager.h>
-
+#include <tulip/GlXMLTools.h>
+#include <tulip/TlpTools.h>
 
 using namespace std;
 
@@ -46,44 +44,37 @@ namespace tlp {
 
 static const int SpaceBetweenLine=5;
 
-std::map<std::string, FTGLPolygonFont*> GlLabel::fontMap;
-std::map<std::string, FTOutlineFont*> GlLabel::borderFontMap;
-
-GlLabel::GlLabel() {
+GlLabel::GlLabel():oldCamera(NULL) {
   init();
 }
-GlLabel::GlLabel(Coord centerPosition,Coord labelSize,Color fontColor,bool leftAlign):centerPosition(centerPosition),size(Size(labelSize[0],labelSize[1],labelSize[2])),color(fontColor),leftAlign(leftAlign) {
+GlLabel::GlLabel(Coord centerPosition,Size size,Color fontColor,bool leftAlign):centerPosition(centerPosition),size(size),color(fontColor),leftAlign(leftAlign),oldCamera(NULL) {
   init();
 }
 
-GlLabel::GlLabel(Coord centerPosition,Size size,Color fontColor,bool leftAlign):centerPosition(centerPosition),size(size),color(fontColor),leftAlign(leftAlign) {
-  init();
+GlLabel::~GlLabel() {
+  delete font;
+  delete borderFont;
 }
-
-
-GlLabel::GlLabel(const string &,Coord centerPosition,Coord labelSize,Color fontColor,bool leftAlign):centerPosition(centerPosition),size(Size(labelSize[0],labelSize[1],labelSize[2])),color(fontColor),leftAlign(leftAlign) {
-  init();
-}
-
-GlLabel::~GlLabel() {}
 //============================================================
 void GlLabel::init() {
   fontName=TulipBitmapDir + "font.ttf";
+  font=new FTPolygonFont(fontName.c_str());
 
-  if (fontMap.find(fontName) == fontMap.end()) {
-    fontMap[fontName]=new FTPolygonFont(fontName.c_str());
-    borderFontMap[fontName]=new FTGLOutlineFont(fontName.c_str());
+  if(font->Error()==0) { //no error
+    borderFont=new FTGLOutlineFont(fontName.c_str());
+    fontSize=20;
+    font->FaceSize(fontSize);
+    borderFont->FaceSize(fontSize);
+  }
+  else {
+    tlp::warning() << "Error when loading font file (" << fontName << ") for rendering labels" << endl;
   }
-
-  font = fontMap[fontName];
-  borderFont = borderFontMap[fontName];
-  fontSize=20;
 
   outlineColor=Color(0,0,0,255);
   outlineSize=1.;
   renderingMode=0;
   translationAfterRotation=Coord(0,0,0);
-  alignment=ON_CENTER;
+  alignment=LabelPosition::Center;
   scaleToSize=true;
   useMinMaxSize=false;
   minSize=10;
@@ -96,19 +87,16 @@ void GlLabel::init() {
   useLOD=false;
   labelsDensity=100;
   billboarded=false;
-
   sizeForOutAlign = size;
+  oldLod=-1;
 }
 //============================================================
 void GlLabel::setText(const string& text) {
   this->text=text;
-}
-//============================================================
-std::string GlLabel::getText() const {
-  return this->text;
-}
-//============================================================
-void GlLabel::setTextBeforeRendering(const std::string& text) {
+
+  if (font->Error())
+    return;
+
   if(font->FaceSize()!=(unsigned int)fontSize) {
     font->FaceSize(fontSize);
     borderFont->FaceSize(fontSize);
@@ -145,7 +133,6 @@ void GlLabel::setTextBeforeRendering(const std::string& text) {
   // After we compute width of text
   for(vector<string>::iterator it=textVector.begin(); it!=textVector.end(); ++it) {
     font->BBox((*it).c_str(),x1,w1,z1,x2,w2,z2);
-
     textWidthVector.push_back(x2-x1);
 
     if(it==textVector.begin()) {
@@ -163,6 +150,10 @@ void GlLabel::setTextBeforeRendering(const std::string& text) {
   }
 }
 //============================================================
+const std::string& GlLabel::getText() const {
+  return text;
+}
+//============================================================
 void GlLabel::setPosition(const Coord &position) {
   centerPosition=position;
 }
@@ -179,43 +170,23 @@ BoundingBox GlLabel::getBoundingBox() {
 }
 //============================================================
 BoundingBox GlLabel::getTextBoundingBox() {
-  setTextBeforeRendering(text);
-
   return textBoundingBox;
 }
 //============================================================
-void GlLabel::setSize(const Coord& size) {
-  setSize(Size(size[0],size[1],size[2]));
-}
-//============================================================
 void GlLabel::setSize(const Size &size) {
   this->size=size;
   this->sizeForOutAlign=size;
 }
 //============================================================
-Coord GlLabel::getSize() {
-  Size s = getLabelSize();
-  return Coord(s[0],s[1],s[2]);
-}
-//============================================================
-Size GlLabel::getLabelSize() const {
+Size GlLabel::getSize() {
   return size;
 }
 //============================================================
-void GlLabel::setSizeForOutAlign(const Coord &size) {
-  setSizeForOutAlign(Size(size[0],size[1],size[2]));
-}
-//============================================================
 void GlLabel::setSizeForOutAlign(const Size &size) {
   this->sizeForOutAlign=size;
 }
 //============================================================
-Coord GlLabel::getSizeForOutAlign() {
-  Size s = getLabelSizeForOutAlign();
-  return Coord(s[0],s[1],s[2]);
-}
-//============================================================
-Size GlLabel::getLabelSizeForOutAlign() const {
+Size GlLabel::getSizeForOutAlign() {
   return sizeForOutAlign;
 }
 //============================================================
@@ -230,32 +201,28 @@ void GlLabel::setPlainFont() {
 }
 //============================================================
 void GlLabel::setFontName(const std::string &name) {
-  if(fontName==name)
+  if(fontName==name || name=="")
     return;
 
   fontName=name;
 
-  if (fontMap.find(fontName) == fontMap.end()) {
-    fontMap[fontName] = new FTGLPolygonFont(fontName.c_str());
-    borderFontMap[fontName]=new FTOutlineFont(fontName.c_str());
+  delete font;
+  delete borderFont;
+  font=new FTGLPolygonFont(fontName.c_str());
+  borderFont=new FTOutlineFont(fontName.c_str());
 
-    if(fontMap[fontName]->Error() || borderFontMap[fontName]->Error()) {
-      if(fontName=="")
-        cerr << "Error in font loading: no font name" << endl;
-      else
-        cerr << "Error in font loading: " << fontName << " cannot be loaded" << endl;
+  if(font->Error() || borderFont->Error()) {
+    if(fontName=="")
+      tlp::warning() << "Error in font loading: no font name" << endl;
+    else
+      tlp::warning() << "Error in font loading: " << fontName << " cannot be loaded" << endl;
 
-      delete fontMap[fontName];
-      delete borderFontMap[fontName];
-      fontMap.erase(fontName);
-      borderFontMap.erase(fontName);
+    delete font;
+    delete borderFont;
 
-      fontName=TulipBitmapDir + "font.ttf";
-    }
+    font=new FTPolygonFont((TulipBitmapDir + "font.ttf").c_str());
+    borderFont=new FTGLOutlineFont((TulipBitmapDir + "font.ttf").c_str());
   }
-
-  font = fontMap[fontName];
-  borderFont = borderFontMap[fontName];
 }
 //============================================================
 void GlLabel::setFontNameSizeAndColor(const std::string &name, const int &size, const Color &color) {
@@ -273,12 +240,57 @@ void GlLabel::drawWithStencil(float lod, Camera *camera) {
   draw(lod,camera);
 }
 //============================================================
-void GlLabel::draw(float lod, Camera *camera) {
+float GlLabel::getHeightAfterScale() {
+  float w=textBoundingBox[1][0]-textBoundingBox[0][0];
+  float h=textBoundingBox[1][1]-textBoundingBox[0][1];
+  float div_w, div_h;
 
-  if(fontSize<=0)
+  div_w = size[0]/w;
+  div_h = size[1]/h;
+
+  if(div_h * w > size[0]) {
+    if(div_w<4)
+      return size[1]*(div_w/4.);
+  }
+
+  return size[1];
+}
+//============================================================
+void GlLabel::draw(float, Camera *camera) {
+
+  if(fontSize<=0 || font->Error())
     return;
 
-  setTextBeforeRendering(text);
+  bool computeLOD=false;
+
+  if(oldLod==-1) {
+    computeLOD=true;
+  }
+  else {
+    computeLOD=camera->getEyes()!=oldCamera.getEyes() ||
+               camera->getCenter()!=oldCamera.getCenter() ||
+               camera->getZoomFactor()!=oldCamera.getZoomFactor() ||
+               camera->getViewport() != oldViewport;
+  }
+
+  float lod=oldLod;
+
+  if(computeLOD) {
+    glMatrixMode(GL_MODELVIEW);
+    glPushMatrix();
+    glMatrixMode(GL_PROJECTION);
+    glPushMatrix();
+    Coord test=camera->screenTo3DWorld(Coord(1,1,1))-camera->screenTo3DWorld(Coord(0,0,0));
+    test/=test.norm();
+    lod=(camera->worldTo2DScreen(test)-camera->worldTo2DScreen(Coord(0,0,0))).norm();
+    oldLod=lod;
+    oldCamera=*camera;
+    oldViewport = camera->getViewport();
+    glMatrixMode(GL_PROJECTION);
+    glPopMatrix();
+    glMatrixMode(GL_MODELVIEW);
+    glPopMatrix();
+  }
 
   glPushAttrib(GL_ALL_ATTRIB_BITS);
 
@@ -303,24 +315,12 @@ void GlLabel::draw(float lod, Camera *camera) {
   float screenH;
   float multiLineH=h;
 
-  //Here the 4.5 number is the size of space between two lines
+  //Here the 4.5 magic number is the size of space between two lines
   if(textVector.size()>1)
     multiLineH=(h-(textVector.size()-1)*4.5)/textVector.size();
 
-  if(camera) {
-    //Here we compute the deformation of the bounding box when we have a rotation on the camera
-    float a=acos(camera->getUp()[1]/sqrt(camera->getUp()[0]*camera->getUp()[0]+camera->getUp()[1]*camera->getUp()[1]));
-    a=M_PI/4-a;
-
-    if(a<-M_PI/4)
-      a=-M_PI/2-a;
-
-    //We compute the size of the text on the screen
-    screenH=static_cast<float>(multiLineH*(lod/(cos(a)*sqrt((lodBoundingBox[1][0]-lodBoundingBox[0][0])*(lodBoundingBox[1][0]-lodBoundingBox[0][0])+(lodBoundingBox[1][1]-lodBoundingBox[0][1])*(lodBoundingBox[1][1]-lodBoundingBox[0][1])+(lodBoundingBox[1][2]-lodBoundingBox[0][2])*(lodBoundingBox[1][2]-lodBoundingBox[0][2])))))/2.f;
-  }
-  else {
-    screenH=static_cast<float>(multiLineH)/2.f;
-  }
+  //We compute the size of the text on the screen
+  screenH=(multiLineH*lod)/2.f;
 
   //Scale of the text
   float scaleToApply=1.;
@@ -335,9 +335,10 @@ void GlLabel::draw(float lod, Camera *camera) {
   }
   else {
     scaleToApply=0.05f;
-    float tmpScreenH=screenH*0.05f;
 
     if(useMinMaxSize) {
+      float tmpScreenH=screenH*0.05f;
+
       if(tmpScreenH<minSize) {
         scaleToApply*=minSize/tmpScreenH;
       }
@@ -361,37 +362,37 @@ void GlLabel::draw(float lod, Camera *camera) {
       hModified-=labelsDensity;
     }
     else {
-      wModified=w-w*(((float)labelsDensity)/(100.f));
-      hModified=h-h*(((float)labelsDensity)/(100.f));
+      wModified=w-w*(((float)labelsDensity)/(100.));
+      hModified=h-h*(((float)labelsDensity)/(100.));
     }
 
     switch(alignment) {
-    case ON_CENTER:
+    case LabelPosition::Center:
       break;
 
-    case ON_LEFT:
-      baseCoord[0]-=sizeForOutAlign[0]/2+wModified*scaleToApply/2.f;
+    case LabelPosition::Left:
+      baseCoord[0]-=sizeForOutAlign[0]/2+wModified*scaleToApply/2.;
       break;
 
-    case ON_RIGHT:
-      baseCoord[0]+=sizeForOutAlign[0]/2+wModified*scaleToApply/2.f;
+    case LabelPosition::Right:
+      baseCoord[0]+=sizeForOutAlign[0]/2+wModified*scaleToApply/2.;
       break;
 
-    case ON_TOP:
-      baseCoord[1]+=sizeForOutAlign[1]/2+hModified*scaleToApply/2.f;
+    case LabelPosition::Top:
+      baseCoord[1]+=sizeForOutAlign[1]/2+hModified*scaleToApply/2.;
       break;
 
-    case ON_BOTTOM:
-      baseCoord[1]-=sizeForOutAlign[1]/2+hModified*scaleToApply/2.f;
+    case LabelPosition::Bottom:
+      baseCoord[1]-=sizeForOutAlign[1]/2+hModified*scaleToApply/2.;
       break;
 
     default:
       break;
     }
 
-    Size occlusionSize(wModified*scaleToApply/2.f,hModified*scaleToApply/2.f,0);
+    Size occlusionSize(wModified*scaleToApply/2.,hModified*scaleToApply/2.,0);
 
-    float angle=static_cast<float>(M_PI*zRot/180);
+    float angle=M_PI*zRot/180;
 
     if(zRot!=0) {
       BoundingBox tmpBB;
@@ -435,12 +436,10 @@ void GlLabel::draw(float lod, Camera *camera) {
     labelBoundingBox.expand(projectPoint(Coord(baseCoord[0]-occlusionSize[0],baseCoord[1]-occlusionSize[1],baseCoord[2]),transformMatrix,camera->getViewport()));
     labelBoundingBox.expand(projectPoint(Coord(baseCoord[0]-occlusionSize[0],baseCoord[1]+occlusionSize[1],baseCoord[2]),transformMatrix,camera->getViewport()));
 
-    if(occlusionTester->testRectangle(RectangleInt2D(static_cast<int>(labelBoundingBox[0][0]),static_cast<int>(labelBoundingBox[0][1]),static_cast<int>(labelBoundingBox[1][0]),static_cast<int>(labelBoundingBox[1][1])))) {
+    if(!occlusionTester->addRectangle(RectangleInt2D(labelBoundingBox[0][0],labelBoundingBox[0][1],labelBoundingBox[1][0],labelBoundingBox[1][1]))) {
       glPopAttrib();
       return;
     }
-
-    occlusionTester->addRectangle(RectangleInt2D(static_cast<int>(labelBoundingBox[0][0]),static_cast<int>(labelBoundingBox[0][1]),static_cast<int>(labelBoundingBox[1][0]),static_cast<int>(labelBoundingBox[1][1])));
   }
 
   glPushMatrix();
@@ -457,34 +456,93 @@ void GlLabel::draw(float lod, Camera *camera) {
   if(zRot!=0.)
     glRotatef(zRot,0.,0.,1.);
 
-  //Alignement translation
-  switch(alignment) {
-  case ON_CENTER:
-    glTranslatef(translationAfterRotation[0],translationAfterRotation[1],translationAfterRotation[2]);
-    break;
+  glTranslatef(translationAfterRotation[0],translationAfterRotation[1],translationAfterRotation[2]);
 
-  case ON_LEFT:
-    glTranslatef(-sizeForOutAlign[0]/2,0,0);
-    break;
+  if(!billboarded) {
+    //Alignement translation
+    switch(alignment) {
+    case LabelPosition::Center:
 
-  case ON_RIGHT:
-    glTranslatef(sizeForOutAlign[0]/2,0,0);
-    break;
+      break;
 
-  case ON_TOP:
-    glTranslatef(0,sizeForOutAlign[1]/2,0);
-    break;
+    case LabelPosition::Left:
+      glTranslatef(-sizeForOutAlign[0]/2,0,0);
+      break;
 
-  case ON_BOTTOM:
-    glTranslatef(0,-sizeForOutAlign[1]/2,0);
-    break;
+    case LabelPosition::Right:
+      glTranslatef(sizeForOutAlign[0]/2,0,0);
+      break;
 
-  default:
-    break;
+    case LabelPosition::Top:
+      glTranslatef(0,sizeForOutAlign[1]/2,0);
+      break;
+
+    case LabelPosition::Bottom:
+      glTranslatef(0,-sizeForOutAlign[1]/2,0);
+      break;
+
+    default:
+      break;
+    }
   }
+  else {
 
-  //Billboard computation
-  if(billboarded) {
+    Matrix<float, 4> modelviewMatrix, projectionMatrix, transformMatrix;
+
+    glGetFloatv (GL_MODELVIEW_MATRIX, (GLfloat*)&modelviewMatrix);
+    glGetFloatv (GL_PROJECTION_MATRIX, (GLfloat*)&projectionMatrix);
+
+    glMatrixMode(GL_MODELVIEW);
+    glPushMatrix();
+    glLoadIdentity();
+    glMultMatrixf((GLfloat*)&projectionMatrix);
+    glMultMatrixf((GLfloat*)&modelviewMatrix);
+    glGetFloatv(GL_MODELVIEW_MATRIX, (GLfloat*)&transformMatrix);
+    glPopMatrix();
+
+    MatrixGL invTransformMatrix(transformMatrix);
+    invTransformMatrix.inverse();
+
+    Coord baseCenter=projectPoint(centerPosition,transformMatrix,camera->getViewport());
+    baseCenter=unprojectPoint(baseCenter,invTransformMatrix,camera->getViewport());
+
+    BoundingBox billboardedBB;
+    billboardedBB.expand(projectPoint(centerPosition+Coord(sizeForOutAlign[0]/2.,sizeForOutAlign[1]/2.,sizeForOutAlign[2]/2.),transformMatrix,camera->getViewport()));
+    billboardedBB.expand(projectPoint(centerPosition+Coord(-sizeForOutAlign[0]/2.,sizeForOutAlign[1]/2.,sizeForOutAlign[2]/2.),transformMatrix,camera->getViewport()));
+    billboardedBB.expand(projectPoint(centerPosition+Coord(sizeForOutAlign[0]/2.,-sizeForOutAlign[1]/2.,sizeForOutAlign[2]/2.),transformMatrix,camera->getViewport()));
+    billboardedBB.expand(projectPoint(centerPosition+Coord(-sizeForOutAlign[0]/2.,-sizeForOutAlign[1]/2.,sizeForOutAlign[2]/2.),transformMatrix,camera->getViewport()));
+    billboardedBB.expand(projectPoint(centerPosition+Coord(sizeForOutAlign[0]/2.,sizeForOutAlign[1]/2.,-sizeForOutAlign[2]/2.),transformMatrix,camera->getViewport()));
+    billboardedBB.expand(projectPoint(centerPosition+Coord(-sizeForOutAlign[0]/2.,sizeForOutAlign[1]/2.,-sizeForOutAlign[2]/2.),transformMatrix,camera->getViewport()));
+    billboardedBB.expand(projectPoint(centerPosition+Coord(sizeForOutAlign[0]/2.,-sizeForOutAlign[1]/2.,-sizeForOutAlign[2]/2.),transformMatrix,camera->getViewport()));
+    billboardedBB.expand(projectPoint(centerPosition+Coord(-sizeForOutAlign[0]/2.,-sizeForOutAlign[1]/2.,-sizeForOutAlign[2]/2.),transformMatrix,camera->getViewport()));
+
+    Coord billboardedTranlation(0,0,0);
+
+    switch(alignment) {
+
+    case LabelPosition::Left:
+      billboardedTranlation=unprojectPoint(((Coord)billboardedBB.center())+Coord(-billboardedBB.width()/2.,0,0),invTransformMatrix,camera->getViewport())-baseCenter;
+      break;
+
+    case LabelPosition::Right:
+      billboardedTranlation=unprojectPoint(((Coord)billboardedBB.center())+Coord(billboardedBB.width()/2.,0,0),invTransformMatrix,camera->getViewport())-baseCenter;
+      break;
+
+    case LabelPosition::Top:
+      billboardedTranlation=unprojectPoint(((Coord)billboardedBB.center())+Coord(0,billboardedBB.height()/2.,0),invTransformMatrix,camera->getViewport())-baseCenter;
+      break;
+
+    case LabelPosition::Bottom:
+      billboardedTranlation=unprojectPoint(((Coord)billboardedBB.center())+Coord(0,-billboardedBB.height()/2.,0),invTransformMatrix,camera->getViewport())-baseCenter;
+      break;
+
+    default:
+      break;
+    }
+
+    glTranslatef(billboardedTranlation[0],billboardedTranlation[1],billboardedTranlation[2]);
+
+    //Billboard computation
     float mdlM[16];
     glGetFloatv( GL_MODELVIEW_MATRIX, mdlM );
     glMatrixMode( GL_MODELVIEW );
@@ -508,25 +566,25 @@ void GlLabel::draw(float lod, Camera *camera) {
   glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
   //The label is too small to be readed, draw a line
-  if(screenH < 4 && useLOD) {
+  if(screenH < 2 && useLOD) {
     float wAlign=0;
     float hAlign=0;
 
     switch (alignment) {
-    case ON_TOP:
-      hAlign=h/2.f;
+    case LabelPosition::Top:
+      hAlign=h/2.;
       break;
 
-    case ON_BOTTOM:
-      hAlign=-(h/2.f);
+    case LabelPosition::Bottom:
+      hAlign=-(h/2.);
       break;
 
-    case ON_LEFT:
-      wAlign = -(w/2.f);
+    case LabelPosition::Left:
+      wAlign = -(w/2.);
       break;
 
-    case ON_RIGHT:
-      wAlign = w/2.f;
+    case LabelPosition::Right:
+      wAlign = w/2.;
       break;
 
     default:
@@ -534,28 +592,34 @@ void GlLabel::draw(float lod, Camera *camera) {
     }
 
     glLineWidth(screenH);
-    setMaterial(Color(color[0],color[1],color[2],128));
+
+    if (outlineColor.getA()==0 || outlineSize == 0)
+      setMaterial(Color(color[0],color[1],color[2],color[3]));
+    else
+      setMaterial(Color(outlineColor[0],outlineColor[1],outlineColor[2],outlineColor[3]));
+
     OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
     glBegin(GL_LINES);
-    glVertex3f(-w/2.f+wAlign,hAlign,0);
-    glVertex3f(w/2.f+wAlign,hAlign,0);
+    glVertex3f(-w/2.+wAlign,hAlign,0);
+    glVertex3f(w/2.+wAlign,hAlign,0);
     glEnd();
     OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
     glLineWidth(1);
   }
   else {
     //Draw labels
+
     glDisable(GL_DEPTH_TEST);
 
     // For left and right alignment
     float xAlignFactor=.5;
 
     switch (alignment) {
-    case ON_LEFT:
+    case LabelPosition::Left:
       xAlignFactor = 1.;
       break;
 
-    case ON_RIGHT:
+    case LabelPosition::Right:
       xAlignFactor = .0;
       break;
 
@@ -568,19 +632,19 @@ void GlLabel::draw(float lod, Camera *camera) {
     float yShiftFactor=0.;
 
     switch (alignment) {
-    case ON_LEFT:
+    case LabelPosition::Left:
       xShiftFactor = -0.5;
       break;
 
-    case ON_RIGHT:
+    case LabelPosition::Right:
       xShiftFactor = 0.5;
       break;
 
-    case ON_TOP:
+    case LabelPosition::Top:
       yShiftFactor = 0.5;
       break;
 
-    case ON_BOTTOM:
+    case LabelPosition::Bottom:
       yShiftFactor = -0.5;
       break;
 
@@ -593,7 +657,6 @@ void GlLabel::draw(float lod, Camera *camera) {
 
     float x1,y1,z1,x2,y2,z2,w1,w2;
     font->BBox("|",x1,y1,z1,x2,y2,z2);
-
     vector<float>::iterator itW=textWidthVector.begin();
 
     for(vector<string>::iterator it=textVector.begin(); it!=textVector.end(); ++it) {
@@ -607,19 +670,32 @@ void GlLabel::draw(float lod, Camera *camera) {
 
       setMaterial(color);
 
-      font->Render((*it).c_str(),-1,shift);
+      if (screenH > 6 || outlineColor.getA()==0 || outlineSize==0) {
+        OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
+        font->Render((*it).c_str(),-1,shift);
+        OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
+      }
 
       if(textureName!="")
         GlTextureManager::getInst().desactivateTexture();
 
-      if(screenH > 25 && useLOD) {
-        glLineWidth(outlineSize);
+      if (outlineSize > 0) {
+        if (screenH > 25) {
+          glLineWidth(outlineSize);
+        }
+        else {
+          glLineWidth(1);
+        }
+
         setMaterial(outlineColor);
+
+        OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
+        borderFont->Render((*it).c_str(),-1,shift);
+        OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
       }
 
-      borderFont->Render((*it).c_str(),-1,shift);
       yShift-=fontSize+5;
-      itW++;
+      ++itW;
     }
   }
 
@@ -638,63 +714,54 @@ void GlLabel::rotate(float xRot, float yRot, float zRot) {
   this->zRot=zRot;
 }
 //===========================================================
-void GlLabel::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
+void GlLabel::getXML(string &outString) {
 
-  xmlNewProp(rootNode,BAD_CAST "type",BAD_CAST "GlLabel");
+  GlXMLTools::createProperty(outString,"type","GlLabel","GlEntity");
 
-  GlXMLTools::getDataNode(rootNode,dataNode);
-
-  GlXMLTools::getXML(dataNode,"text",text);
-  GlXMLTools::getXML(dataNode,"renderingMode",renderingMode);
-  GlXMLTools::getXML(dataNode,"fontName",fontName);
-  GlXMLTools::getXML(dataNode,"centerPosition",centerPosition);
-  GlXMLTools::getXML(dataNode,"translationAfterRotation",translationAfterRotation);
-  GlXMLTools::getXML(dataNode,"size",size);
-  GlXMLTools::getXML(dataNode,"color",color);
-  GlXMLTools::getXML(dataNode,"alignment",alignment);
-  GlXMLTools::getXML(dataNode,"scaleToSize",scaleToSize);
-  GlXMLTools::getXML(dataNode,"useMinMaxSize",useMinMaxSize);
-  GlXMLTools::getXML(dataNode,"minSize",minSize);
-  GlXMLTools::getXML(dataNode,"maxSize",maxSize);
-  GlXMLTools::getXML(dataNode,"depthTestEnabled",depthTestEnabled);
-  GlXMLTools::getXML(dataNode,"leftAlign",leftAlign);
-  GlXMLTools::getXML(dataNode,"xRot",xRot);
-  GlXMLTools::getXML(dataNode,"yRot",yRot);
-  GlXMLTools::getXML(dataNode,"zRot",zRot);
-  GlXMLTools::getXML(dataNode,"outlineColor",outlineColor);
-  GlXMLTools::getXML(dataNode,"outlineSize",outlineSize);
-  GlXMLTools::getXML(dataNode,"textureName",textureName);
+  GlXMLTools::getXML(outString,"text",text);
+  GlXMLTools::getXML(outString,"renderingMode",renderingMode);
+  GlXMLTools::getXML(outString,"fontName",fontName);
+  GlXMLTools::getXML(outString,"centerPosition",centerPosition);
+  GlXMLTools::getXML(outString,"translationAfterRotation",translationAfterRotation);
+  GlXMLTools::getXML(outString,"size",size);
+  GlXMLTools::getXML(outString,"color",color);
+  GlXMLTools::getXML(outString,"alignment",alignment);
+  GlXMLTools::getXML(outString,"scaleToSize",scaleToSize);
+  GlXMLTools::getXML(outString,"useMinMaxSize",useMinMaxSize);
+  GlXMLTools::getXML(outString,"minSize",minSize);
+  GlXMLTools::getXML(outString,"maxSize",maxSize);
+  GlXMLTools::getXML(outString,"depthTestEnabled",depthTestEnabled);
+  GlXMLTools::getXML(outString,"leftAlign",leftAlign);
+  GlXMLTools::getXML(outString,"xRot",xRot);
+  GlXMLTools::getXML(outString,"yRot",yRot);
+  GlXMLTools::getXML(outString,"zRot",zRot);
+  GlXMLTools::getXML(outString,"outlineColor",outlineColor);
+  GlXMLTools::getXML(outString,"outlineSize",outlineSize);
+  GlXMLTools::getXML(outString,"textureName",textureName);
 }
 //============================================================
-void GlLabel::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
+void GlLabel::setWithXML(const string &inString, unsigned int &currentPosition) {
 
-  GlXMLTools::getDataNode(rootNode,dataNode);
-
-  // Parse Data
-  if(dataNode) {
-    GlXMLTools::setWithXML(dataNode,"text",text);
-    GlXMLTools::setWithXML(dataNode,"renderingMode",renderingMode);
-    GlXMLTools::setWithXML(dataNode,"fontName",fontName);
-    GlXMLTools::setWithXML(dataNode,"centerPosition",centerPosition);
-    GlXMLTools::setWithXML(dataNode,"translationAfterRotation",translationAfterRotation);
-    GlXMLTools::setWithXML(dataNode, "size", size);
-    GlXMLTools::setWithXML(dataNode,"color",color);
-    GlXMLTools::setWithXML(dataNode,"alignment",alignment);
-    GlXMLTools::setWithXML(dataNode,"scaleToSize",scaleToSize);
-    GlXMLTools::setWithXML(dataNode,"useMinMaxSize",useMinMaxSize);
-    GlXMLTools::setWithXML(dataNode,"minSize",minSize);
-    GlXMLTools::setWithXML(dataNode,"maxSize",maxSize);
-    GlXMLTools::setWithXML(dataNode,"depthTestEnabled",depthTestEnabled);
-    GlXMLTools::setWithXML(dataNode,"leftAlign",leftAlign);
-    GlXMLTools::setWithXML(dataNode,"xRot",xRot);
-    GlXMLTools::setWithXML(dataNode,"yRot",yRot);
-    GlXMLTools::setWithXML(dataNode,"zRot",zRot);
-    GlXMLTools::setWithXML(dataNode,"outlineColor",outlineColor);
-    GlXMLTools::setWithXML(dataNode,"outlineSize",outlineSize);
-    GlXMLTools::setWithXML(dataNode,"textureName",textureName);
-  }
+  GlXMLTools::setWithXML(inString, currentPosition,"text",text);
+  GlXMLTools::setWithXML(inString, currentPosition,"renderingMode",renderingMode);
+  GlXMLTools::setWithXML(inString, currentPosition,"fontName",fontName);
+  GlXMLTools::setWithXML(inString, currentPosition,"centerPosition",centerPosition);
+  GlXMLTools::setWithXML(inString, currentPosition,"translationAfterRotation",translationAfterRotation);
+  GlXMLTools::setWithXML(inString, currentPosition, "size", size);
+  GlXMLTools::setWithXML(inString, currentPosition,"color",color);
+  GlXMLTools::setWithXML(inString, currentPosition,"alignment",alignment);
+  GlXMLTools::setWithXML(inString, currentPosition,"scaleToSize",scaleToSize);
+  GlXMLTools::setWithXML(inString, currentPosition,"useMinMaxSize",useMinMaxSize);
+  GlXMLTools::setWithXML(inString, currentPosition,"minSize",minSize);
+  GlXMLTools::setWithXML(inString, currentPosition,"maxSize",maxSize);
+  GlXMLTools::setWithXML(inString, currentPosition,"depthTestEnabled",depthTestEnabled);
+  GlXMLTools::setWithXML(inString, currentPosition,"leftAlign",leftAlign);
+  GlXMLTools::setWithXML(inString, currentPosition,"xRot",xRot);
+  GlXMLTools::setWithXML(inString, currentPosition,"yRot",yRot);
+  GlXMLTools::setWithXML(inString, currentPosition,"zRot",zRot);
+  GlXMLTools::setWithXML(inString, currentPosition,"outlineColor",outlineColor);
+  GlXMLTools::setWithXML(inString, currentPosition,"outlineSize",outlineSize);
+  GlXMLTools::setWithXML(inString, currentPosition,"textureName",textureName);
 }
 
 }
