@@ -17,13 +17,12 @@
  *
  */
 #include <tulip/GlLayer.h>
-
-#include <iostream>
-
+#include <tulip/GlXMLTools.h>
 #include <tulip/Camera.h>
-#include <tulip/GlEntity.h>
 #include <tulip/GlSceneVisitor.h>
 #include <tulip/GlScene.h>
+#include <tulip/GlGraphComposite.h>
+
 
 using namespace std;
 
@@ -42,11 +41,18 @@ GlLayer::GlLayer(const std::string& name,Camera *camera,bool workingLayer)
 GlLayer::~GlLayer() {
   if(!sharedCamera)
     delete camera;
+
+  composite.removeLayerParent(this);
 }
 
-void GlLayer::setCamera(const Camera& camera) {
+void GlLayer::setScene(GlScene *scene) {
+  this->scene=scene;
+  camera->setScene(scene);
+}
+
+void GlLayer::setCamera(Camera* camera) {
   Camera *oldCamera=this->camera;
-  this->camera = new Camera(camera);
+  this->camera = camera;
 
   if (!sharedCamera)
     delete oldCamera;
@@ -98,6 +104,11 @@ void GlLayer::addGlEntity(GlSimpleEntity *entity,const std::string& name) {
     scene->notifyModifyLayer(this->name,this);
 }
 
+void GlLayer::addGraph(tlp::Graph *graph, const string &name) {
+  GlGraphComposite* graphComposite=new GlGraphComposite(graph,scene);
+  addGlEntity(graphComposite,name);
+}
+
 void GlLayer::deleteGlEntity(const std::string &key) {
   composite.deleteGlEntity(key);
 
@@ -116,52 +127,78 @@ GlSimpleEntity* GlLayer::findGlEntity(const std::string &key) {
   return composite.findGlEntity(key);
 }
 
-std::map<std::string, GlSimpleEntity*> *GlLayer::getDisplays() {
-  return composite.getDisplays();
+const std::map<std::string, GlSimpleEntity*> &GlLayer::getGlEntities() const {
+  return composite.getGlEntities();
 }
 
-void GlLayer::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode= NULL;
-  xmlNodePtr childrenNode= NULL;
-  xmlNodePtr node=NULL;
+void GlLayer::getXML(string &outString) {
+  GlXMLTools::beginDataNode(outString);
 
-  GlXMLTools::createDataAndChildrenNodes(rootNode, dataNode, childrenNode);
+  GlXMLTools::beginChildNode(outString,"camera");
+  camera->getXML(outString);
+  GlXMLTools::endChildNode(outString,"camera");
 
-  GlXMLTools::createChild(dataNode,"camera",node);
-  camera->getXML(node);
   bool visible=composite.isVisible();
-  GlXMLTools::getXML(dataNode,"visible",visible);
+  GlXMLTools::getXML(outString,"visible",visible);
 
-  composite.getXML(childrenNode);
+  GlXMLTools::endDataNode(outString);
+
+  GlXMLTools::beginChildNode(outString,"GlEntity");
+  composite.getXML(outString);
+  GlXMLTools::endChildNode(outString);
 
 }
 
-void GlLayer::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode= NULL;
-  xmlNodePtr childrenNode= NULL;
-  xmlNodePtr node= NULL;
+void GlLayer::getXMLOnlyForCameras(string &outString) {
+  GlXMLTools::beginDataNode(outString);
 
-  GlXMLTools::getDataAndChildrenNodes(rootNode, dataNode, childrenNode);
+  GlXMLTools::beginChildNode(outString,"camera");
+  camera->getXML(outString);
+  GlXMLTools::endChildNode(outString,"camera");
 
-  // Parse data
-  if(dataNode) {
-    GlXMLTools::getData("camera", dataNode, node);
+  bool visible=composite.isVisible();
+  GlXMLTools::getXML(outString,"visible",visible);
 
-    if(node) {
-      camera->setWithXML(node);
-    }
+  GlXMLTools::endDataNode(outString);
+}
 
-    bool visible;
-    GlXMLTools::setWithXML(dataNode,"visible",visible);
-    composite.setVisible(visible);
-  }
+void GlLayer::setWithXML(const string &inString, unsigned int &currentPosition) {
 
-  // Parse children
-  if(childrenNode) {
-    composite.setWithXML(childrenNode);
+  GlXMLTools::enterDataNode(inString,currentPosition);
+  string childName=GlXMLTools::enterChildNode(inString,currentPosition);
+  assert(childName=="camera");
+  camera->setWithXML(inString,currentPosition);
+  GlXMLTools::leaveChildNode(inString,currentPosition,"camera");
+
+  bool visible;
+  GlXMLTools::setWithXML(inString,currentPosition,"visible",visible);
+  composite.setVisible(visible);
+
+  GlXMLTools::leaveDataNode(inString,currentPosition);
+
+  childName=GlXMLTools::enterChildNode(inString,currentPosition);
+
+  if(childName!="") {
+
+    map<string,string> childMap=GlXMLTools::getProperties(inString,currentPosition);
+    assert(childMap["type"]=="GlComposite");
+    composite.setWithXML(inString,currentPosition);
+
+    GlXMLTools::leaveChildNode(inString,currentPosition,"children");
   }
 
 }
 
+void GlLayer::glGraphCompositeAdded(GlGraphComposite *composite) {
+  assert(scene);
+  scene->glGraphCompositeAdded(this,composite);
+}
+
+void GlLayer::glGraphCompositeRemoved(GlGraphComposite *composite) {
+  assert(scene);
+  scene->glGraphCompositeRemoved(this,composite);
+}
+
+
 
 }
