@@ -28,24 +28,22 @@
 #include <tulip/SizeProperty.h>
 #include <tulip/IntegerProperty.h>
 #include <tulip/ColorProperty.h>
-#include <tulip/PreferenceManager.h>
-
+#include <tulip/GlMetaNodeRenderer.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/Glyph.h>
 #include <tulip/GlTools.h>
-#include <tulip/GlyphManager.h>
-#include <tulip/GlDisplayListManager.h>
-#include <tulip/OcclusionTest.h>
 #include <tulip/GlTLPFeedBackBuilder.h>
 #include <tulip/GlSceneVisitor.h>
 #include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/GlVertexArrayManager.h>
 #include <tulip/GlLabel.h>
-
-#include <iostream>
+#include <tulip/GlBox.h>
+#include <tulip/GlGlyphRenderer.h>
 
 //====================================================
-tlp::GlLabel* tlp::GlNode::label=0;
-tlp::GlBox* tlp::GlNode::selectionBox=0;
+tlp::GlLabel* tlp::GlNode::label=NULL;
+tlp::GlBox* tlp::GlNode::selectionBox=NULL;
 
 using namespace std;
 
@@ -61,20 +59,23 @@ GlNode::GlNode(unsigned int id):id(id) {
   }
 }
 
-BoundingBox GlNode::getBoundingBox(GlGraphInputData* data) {
-  node n=node(id);
+BoundingBox GlNode::getBoundingBox(const GlGraphInputData* data) {
+  node n(id);
+  int nodeRot = data->getElementRotation()->getNodeValue(n);
+  const Size& nodeSize = data->getElementSize()->getNodeValue(n);
+  const Coord& nodeCoord = data->getElementLayout()->getNodeValue(n);
 
-  if(data->getElementRotation()->getNodeValue(n)==0) {
+  if(nodeRot==0) {
     BoundingBox box;
-    box.expand(data->getElementLayout()->getNodeValue(n)-data->getElementSize()->getNodeValue(n)/2.f);
-    box.expand(data->getElementLayout()->getNodeValue(n)+data->getElementSize()->getNodeValue(n)/2.f);
+    box.expand(nodeCoord-nodeSize/2.f);
+    box.expand(nodeCoord+nodeSize/2.f);
     assert(box.isValid());
     return box;
   }
   else {
-    float cosAngle=static_cast<float>(cos(data->getElementRotation()->getNodeValue(n)/180.*M_PI));
-    float sinAngle=static_cast<float>(sin(data->getElementRotation()->getNodeValue(n)/180.*M_PI));
-    Coord tmp1(data->getElementSize()->getNodeValue(n)/2.f);
+    float cosAngle=cos((float)nodeRot/180.*M_PI);
+    float sinAngle=sin((float)nodeRot/180.*M_PI);
+    Coord tmp1(nodeSize/2.f);
     Coord tmp2(tmp1[0] ,-tmp1[1], tmp1[2]);
     Coord tmp3(-tmp1[0],-tmp1[1],-tmp1[2]);
     Coord tmp4(-tmp1[0], tmp1[1],-tmp1[2]);
@@ -83,10 +84,10 @@ BoundingBox GlNode::getBoundingBox(GlGraphInputData* data) {
     tmp3=Coord(tmp3[0]*cosAngle-tmp3[1]*sinAngle,tmp3[0]*sinAngle+tmp3[1]*cosAngle,tmp3[2]);
     tmp4=Coord(tmp4[0]*cosAngle-tmp4[1]*sinAngle,tmp4[0]*sinAngle+tmp4[1]*cosAngle,tmp4[2]);
     BoundingBox bb;
-    bb.expand(data->getElementLayout()->getNodeValue(n)+tmp1);
-    bb.expand(data->getElementLayout()->getNodeValue(n)+tmp2);
-    bb.expand(data->getElementLayout()->getNodeValue(n)+tmp3);
-    bb.expand(data->getElementLayout()->getNodeValue(n)+tmp4);
+    bb.expand(nodeCoord+tmp1);
+    bb.expand(nodeCoord+tmp2);
+    bb.expand(nodeCoord+tmp3);
+    bb.expand(nodeCoord+tmp4);
     return bb;
   }
 }
@@ -95,7 +96,7 @@ void GlNode::acceptVisitor(GlSceneVisitor *visitor) {
   visitor->visit(this);
 }
 
-void GlNode::draw(float lod,GlGraphInputData* data,Camera*) {
+void GlNode::draw(float lod,const GlGraphInputData* data,Camera* camera) {
   const Color& colorSelect2=data->parameters->getSelectionColor();
 
   glEnable(GL_CULL_FACE);
@@ -103,31 +104,24 @@ void GlNode::draw(float lod,GlGraphInputData* data,Camera*) {
   node n=node(id);
 
   if (data->getElementSelected()->getNodeValue(n)) {
-    glDisable(GL_DEPTH_TEST);
-
-    if(data->getGraph()->isMetaNode(n)) {
-      glStencilFunc(GL_LEQUAL,data->parameters->getSelectedMetaNodesStencil(),0xFFFF);
-    }
-    else {
-      glStencilFunc(GL_LEQUAL,data->parameters->getSelectedNodesStencil(),0xFFFF);
-    }
+    glStencilFunc(GL_LEQUAL,data->parameters->getSelectedNodesStencil(),0xFFFF);
   }
   else {
-    glEnable(GL_DEPTH_TEST);
+    glStencilFunc(GL_LEQUAL,data->parameters->getNodesStencil(),0xFFFF);
+  }
 
-    if(data->getGraph()->isMetaNode(n)) {
-      glStencilFunc(GL_LEQUAL,data->parameters->getMetaNodesStencil(),0xFFFF);
-    }
-    else {
-      glStencilFunc(GL_LEQUAL,data->parameters->getNodesStencil(),0xFFFF);
-    }
+  ColorProperty *colP=data->getElementColor();
+
+  if(data->getGraph()->isMetaNode(n)) {
+    if(!(((colP->getNodeValue(n))[3]==255) && (data->parameters->getNodesStencil()==0xFFFF)))
+      data->getMetaNodeRenderer()->render(n,lod,camera);
   }
 
   const Coord &nodeCoord = data->getElementLayout()->getNodeValue(n);
 
-  const Size &nodeSize = data->getElementSize()->getNodeValue(n);
+  Size nodeSize = data->getElementSize()->getNodeValue(n);
 
-  const Color& fillColor = data->getElementColor()->getNodeValue(n);
+  const Color& fillColor = colP->getNodeValue(n);
 
   const Color& strokeColor = data->getElementBorderColor()->getNodeValue(n);
 
@@ -151,34 +145,31 @@ void GlNode::draw(float lod,GlGraphInputData* data,Camera*) {
     glPassThrough(textColor[3]);
 
     glPassThrough(TLP_FB_BEGIN_NODE);
-    glPassThrough(static_cast<float>(id)); //id of the node for the feed back mode
+    glPassThrough(id); //id of the node for the feed back mode
   }
 
   bool selected = data->getElementSelected()->getNodeValue(n);
 
-  if (lod < data->parameters->getPointModeLOD()) { //less than four pixel on screen, we use points instead of glyphs
+  if (lod < 10.0) { //less than four pixel on screen, we use points instead of glyphs
     if (lod < 1) lod = 1;
 
-    int size= static_cast<int>(sqrt(lod));
-
     if(data->getGlVertexArrayManager()->renderingIsBegin()) {
-      if(size<2)
-        data->getGlVertexArrayManager()->activatePointNodeDisplay(this,true,selected);
-      else
-        data->getGlVertexArrayManager()->activatePointNodeDisplay(this,false,selected);
+      data->getGlVertexArrayManager()->activatePointNodeDisplay(this, selected);
     }
     else {
-      if(size>2)
-        size=2;
 
-      const Color& color = selected ? colorSelect2 : fillColor;
+      Color pointColor = data->getElementColor()->getNodeValue(n);
+
+      if (data->getElementBorderWidth()->getNodeValue(n) > 0) {
+        pointColor = data->getElementBorderColor()->getNodeValue(n);
+      }
 
       OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
       glDisable(GL_LIGHTING);
-      setColor(color);
-      glPointSize(static_cast<float>(size));
+      setColor(selected ? colorSelect2 : pointColor);
+      glPointSize(4);
       glBegin(GL_POINTS);
-      glVertex3f(nodeCoord[0], nodeCoord[1], nodeCoord[2]+nodeSize[2]/2.f);
+      glVertex3f(nodeCoord[0], nodeCoord[1], nodeCoord[2]+nodeSize[2]/2.);
       glEnd();
       glEnable(GL_LIGHTING);
       OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
@@ -188,29 +179,58 @@ void GlNode::draw(float lod,GlGraphInputData* data,Camera*) {
 
   }
 
-  //draw a glyph or make recursive call for meta nodes
-  glPushMatrix();
-  glTranslatef(nodeCoord[0], nodeCoord[1], nodeCoord[2]);
-  glRotatef(static_cast<float>(data->getElementRotation()->getNodeValue(n)), 0.f, 0.f, 1.f);
+  if (!data->parameters->isDisplayNodes())
+    return;
+
+  float rot = data->getElementRotation()->getNodeValue(n);
 
   // If node size in z is equal to 0 we have to scale with FLT_EPSILON to preserve normal
   // (because if we do a scale of (x,y,0) and if we have a normal like (0,0,1) the new normal after scale will be (0,0,0) and we will have light problem)
   if(nodeSize[2]==0)
-    glScalef(nodeSize[0], nodeSize[1],FLT_EPSILON);
-  else
-    glScalef(nodeSize[0], nodeSize[1],nodeSize[2]);
+    nodeSize[2] = FLT_EPSILON;
 
-  data->glyphs.get(data->getElementShape()->getNodeValue(n))->draw(n,lod);
+  // Some glyphs can not benefit from the shader rendering optimization
+  // due to the use of quadrics or modelview matrix modification or lighting effect
+  static set<int> noShaderGlyphs;
 
-  if (selected) {
-    OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-    selectionBox->setStencil(data->parameters->getSelectedNodesStencil()-1);
-    selectionBox->setOutlineColor(colorSelect2);
-    selectionBox->draw(10,NULL);
-    OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
+  if (noShaderGlyphs.empty()) {
+    noShaderGlyphs.insert(NodeShape::Billboard);
+    noShaderGlyphs.insert(NodeShape::ChristmasTree);
+    noShaderGlyphs.insert(NodeShape::Cone);
+    noShaderGlyphs.insert(NodeShape::Cylinder);
+    noShaderGlyphs.insert(NodeShape::GlowSphere);
+    noShaderGlyphs.insert(NodeShape::HalfCylinder);
+    noShaderGlyphs.insert(NodeShape::Sphere);
   }
 
-  glPopMatrix();
+  int glyph = data->getElementShape()->getNodeValue(n);
+
+  if (data->getGlGlyphRenderer()->renderingHasStarted() && noShaderGlyphs.find(glyph) == noShaderGlyphs.end()) {
+    data->getGlGlyphRenderer()->addNodeGlyphRendering(data->glyphs.get(glyph),
+        n, lod, nodeCoord, nodeSize, rot, selected);
+  }
+  else {
+
+    //draw a glyph or make recursive call for meta nodes
+    glPushMatrix();
+    glTranslatef(nodeCoord[0], nodeCoord[1], nodeCoord[2]);
+    glRotatef(rot, 0., 0., 1.);
+
+    glScalef(nodeSize[0], nodeSize[1],nodeSize[2]);
+
+    if (selected) {
+      OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
+      selectionBox->setStencil(data->parameters->getSelectedNodesStencil()-1);
+      selectionBox->setOutlineColor(colorSelect2);
+      selectionBox->draw(10,NULL);
+      OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
+    }
+
+    data->glyphs.get(data->getElementShape()->getNodeValue(n))->draw(n,lod);
+
+    glPopMatrix();
+
+  }
 
   if (selected) {
     glStencilFunc(GL_LEQUAL,data->parameters->getNodesStencil(),0xFFFF);
@@ -223,7 +243,7 @@ void GlNode::draw(float lod,GlGraphInputData* data,Camera*) {
   }
 }
 
-void GlNode::drawLabel(bool drawSelect,OcclusionTest* test,GlGraphInputData* data,float lod) {
+void GlNode::drawLabel(bool drawSelect,OcclusionTest* test,const GlGraphInputData* data,float lod) {
   node n=node(id);
   bool selected=data->getElementSelected()->getNodeValue(n);
 
@@ -233,11 +253,11 @@ void GlNode::drawLabel(bool drawSelect,OcclusionTest* test,GlGraphInputData* dat
   drawLabel(test,data,lod);
 }
 
-void GlNode::drawLabel(OcclusionTest* test,GlGraphInputData* data) {
+void GlNode::drawLabel(OcclusionTest* test,const GlGraphInputData* data) {
   GlNode::drawLabel(test,data,1000.);
 }
 
-void GlNode::drawLabel(OcclusionTest* test,GlGraphInputData* data,float lod, Camera *camera) {
+void GlNode::drawLabel(OcclusionTest* test,const GlGraphInputData* data,float lod,Camera *camera) {
 
   node n=node(id);
 
@@ -249,9 +269,11 @@ void GlNode::drawLabel(OcclusionTest* test,GlGraphInputData* data,float lod, Cam
   bool selected=data->getElementSelected()->getNodeValue(n);
   // Color of the label : selected or not
   const Color& fontColor = selected ? data->parameters->getSelectionColor() :data->getElementLabelColor()->getNodeValue(n);
+  const Color& fontBorderColor = selected ? data->parameters->getSelectionColor() : data->getElementLabelBorderColor()->getNodeValue(n);
+  float fontBorderWidth = data->getElementLabelBorderWidth()->getNodeValue(n);
 
   // If we have transparent label : return
-  if(fontColor.getA()==0)
+  if(fontColor.getA()==0 && (fontBorderColor.getA()==0 || fontBorderWidth==0))
     return;
 
   // Node text
@@ -260,14 +282,9 @@ void GlNode::drawLabel(OcclusionTest* test,GlGraphInputData* data,float lod, Cam
   if (tmp.length() < 1)
     return;
 
-  if(!data->getGraph()->isMetaNode(n)) {
-    if(selected) label->setStencil(data->parameters->getSelectedNodesStencil());
-    else label->setStencil(data->parameters->getNodesLabelStencil());
-  }
-  else {
-    if(selected) label->setStencil(data->parameters->getSelectedMetaNodesStencil());
-    else label->setStencil(data->parameters->getMetaNodesLabelStencil());
-  }
+
+  if(selected) label->setStencil(data->parameters->getSelectedNodesStencil());
+  else label->setStencil(data->parameters->getNodesLabelStencil());
 
   int fontSize=data->getElementFontSize()->getNodeValue(n);
 
@@ -281,31 +298,31 @@ void GlNode::drawLabel(OcclusionTest* test,GlGraphInputData* data,float lod, Cam
   const Size  &nodeSize  = data->getElementSize()->getNodeValue(n);
   int labelPos = data->getElementLabelPosition()->getNodeValue(n);
 
-
   BoundingBox includeBB;
   data->glyphs.get(data->getElementShape()->getNodeValue(n))->getTextBoundingBox(includeBB,n);
   Coord centerBB(includeBB.center());
   Vec3f sizeBB = includeBB[1]-includeBB[0];
 
   label->setFontNameSizeAndColor(data->getElementFont()->getNodeValue(n),fontSize,fontColor);
-  label->setOutlineColor(Color(0,0,0,fontColor[3]));
+  label->setOutlineColor(fontBorderColor);
+  label->setOutlineSize(fontBorderWidth);
   label->setText(tmp);
   label->setTranslationAfterRotation(centerBB*nodeSize);
   label->setSize(Size(nodeSize[0]*sizeBB[0],nodeSize[1]*sizeBB[1],0));
   label->setSizeForOutAlign(Size(nodeSize[0],nodeSize[1],0));
-  label->rotate(0,0,static_cast<float>(data->getElementRotation()->getNodeValue(n)));
+  label->rotate(0,0,data->getElementRotation()->getNodeValue(n));
   label->setAlignment(labelPos);
   label->setScaleToSize(data->parameters->isLabelScaled());
   label->setUseLODOptimisation(true,this->getBoundingBox(data));
   label->setLabelsDensity(data->parameters->getLabelsDensity());
-  label->setUseMinMaxSize(true);
+  label->setUseMinMaxSize(!data->parameters->isLabelFixedFontSize());
   label->setMinSize(data->parameters->getMinSizeOfLabel());
   label->setMaxSize(data->parameters->getMaxSizeOfLabel());
   label->setOcclusionTester(test);
   label->setBillboarded(data->parameters->getLabelsAreBillboarded());
 
   if(includeBB[1][2]!=0 && !data->parameters->getLabelsAreBillboarded())
-    label->setPosition(Coord(nodeCoord[0],nodeCoord[1],nodeCoord[2]+nodeSize[2]/2.f));
+    label->setPosition(Coord(nodeCoord[0],nodeCoord[1],nodeCoord[2]+nodeSize[2]/2.));
   else
     label->setPosition(Coord(nodeCoord[0],nodeCoord[1],nodeCoord[2]));
 
@@ -316,13 +333,27 @@ void GlNode::getPointAndColor(GlGraphInputData *inputData,std::vector<Coord> &po
   node n=node(id);
   const Coord &nodeCoord = inputData->getElementLayout()->getNodeValue(n);
   const Color& fillColor = inputData->getElementColor()->getNodeValue(n);
+  const Color& borderColor = inputData->getElementBorderColor()->getNodeValue(n);
   pointsCoordsArray.push_back(nodeCoord);
-  pointsColorsArray.push_back(fillColor);
+
+  if (inputData->getElementBorderWidth()->getNodeValue(n) > 0) {
+    pointsColorsArray.push_back(borderColor);
+  }
+  else {
+    pointsColorsArray.push_back(fillColor);
+  }
 }
 
 void GlNode::getColor(GlGraphInputData *inputData,std::vector<Color> &pointsColorsArray) {
   node n=node(id);
   const Color& fillColor = inputData->getElementColor()->getNodeValue(n);
-  pointsColorsArray.push_back(fillColor);
+  const Color& borderColor = inputData->getElementBorderColor()->getNodeValue(n);
+
+  if (inputData->getElementBorderWidth()->getNodeValue(n) > 0) {
+    pointsColorsArray.push_back(borderColor);
+  }
+  else {
+    pointsColorsArray.push_back(fillColor);
+  }
 }
 }
