@@ -18,7 +18,7 @@
  */
 #include <tulip/GlTextureManager.h>
 #include <tulip/GlTools.h>
-
+#include <tulip/GlXMLTools.h>
 #include <tulip/GlPolyQuad.h>
 #include <tulip/Vector.h>
 #include <tulip/OpenGlConfigManager.h>
@@ -86,7 +86,7 @@ void GlPolyQuad::draw(float, Camera *) {
   texCoordsArray.reserve(nbVertices * 2);
   colorsArray.reserve(nbVertices);
   quadIndices.reserve(nbVertices);
-  outlineIndices.resize(nbVertices);
+  outlineIndices.reserve(nbVertices);
 
   for (size_t i = 0 ; i < (polyQuadEdges.size() / 2) - 1 ; ++i) {
     Vector<float, 4> startColor;
@@ -202,7 +202,7 @@ void GlPolyQuad::draw(float, Camera *) {
 
   if (outlined) {
     OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-    glLineWidth(static_cast<float>(outlineWidth));
+    glLineWidth(outlineWidth);
     setMaterial(outlineColor);
 
     if (nbSubdivisionsPerSegment > 1) {
@@ -240,25 +240,20 @@ void GlPolyQuad::setColor(const Color &color) {
   }
 }
 
-void GlPolyQuad::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
-  GlXMLTools::createProperty(rootNode, "type", "GlPolyQuad");
-  GlXMLTools::getDataNode(rootNode,dataNode);
-  GlXMLTools::getXML(dataNode,"polyQuadEdges", polyQuadEdges);
-  GlXMLTools::getXML(dataNode,"polyQuadEdgesColors", polyQuadEdgesColors);
-  GlXMLTools::getXML(dataNode,"textureName", textureName);
+void GlPolyQuad::getXML(string &outString) {
+
+  GlXMLTools::createProperty(outString,"type","GlPolyQuad","GlEntity");
+
+  GlXMLTools::getXML(outString,"polyQuadEdges", polyQuadEdges);
+  GlXMLTools::getXML(outString,"polyQuadEdgesColors", polyQuadEdgesColors);
+  GlXMLTools::getXML(outString,"textureName", textureName);
 }
 
-void GlPolyQuad::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
-  GlXMLTools::getDataNode(rootNode,dataNode);
+void GlPolyQuad::setWithXML(const string &inString, unsigned int &currentPosition) {
 
-  // Parse Data
-  if(dataNode) {
-    GlXMLTools::setWithXML(dataNode,"polyQuadEdges", polyQuadEdges);
-    GlXMLTools::setWithXML(dataNode,"polyQuadEdgesColors", polyQuadEdgesColors);
-    GlXMLTools::setWithXML(dataNode,"textureName", textureName);
-  }
+  GlXMLTools::setWithXML(inString, currentPosition,"polyQuadEdges", polyQuadEdges);
+  GlXMLTools::setWithXML(inString, currentPosition,"polyQuadEdgesColors", polyQuadEdgesColors);
+  GlXMLTools::setWithXML(inString, currentPosition,"textureName", textureName);
 
   vector<Coord>::iterator it;
 
