@@ -18,10 +18,6 @@
  */
 
 #include <tulip/GlPolygon.h>
-#include <tulip/GlTools.h>
-#include <tulip/GlLayer.h>
-
-
 
 using namespace std;
 
