@@ -19,10 +19,7 @@
 
 #include <tulip/GlQuad.h>
 
-#include <tulip/GlTextureManager.h>
 #include <tulip/GlXMLTools.h>
-#include <tulip/GlTools.h>
-#include <tulip/OpenGlConfigManager.h>
 
 using namespace std;
 
@@ -54,24 +51,6 @@ GlQuad::GlQuad(const Coord &p1, const Coord &p2, const Coord &p3, const Coord &p
   recomputeBoundingBox();
 }
 
-GlQuad::GlQuad(const Coord positions[4], const Color &color):GlPolygon(4,4,4,true,false) {
-  for(int i=0; i < 4; ++i) {
-    points[i] = positions[i];
-  }
-
-  setFillColor(color);
-  recomputeBoundingBox();
-}
-
-GlQuad::GlQuad(const Coord positions[4], const Color colors[4]) {
-  for(int i=0; i < 4; ++i) {
-    points[i] = positions[i];
-    fillColors[i]    = colors[i];
-  }
-
-  recomputeBoundingBox();
-}
-
 GlQuad::~GlQuad() {
 }
 
@@ -95,22 +74,17 @@ const Color& GlQuad::getColor(const int idColor) const {
   return (*(const_cast< vector<Color> * > (&fillColors)))[idColor];
 }
 //===========================================================
-void GlQuad::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode = NULL;
+void GlQuad::getXML(string &outString) {
 
-  GlXMLTools::createProperty(rootNode, "type", "GlQuad");
+  GlXMLTools::createProperty(outString,"type","GlQuad","GlEntity");
 
-  GlPolygon::getXMLOnlyData(rootNode);
+  GlPolygon::getXMLOnlyData(outString);
 
-  GlXMLTools::getDataNode(rootNode, dataNode);
 }
 //============================================================
-void GlQuad::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode = NULL;
+void GlQuad::setWithXML(const string &inString, unsigned int &currentPosition) {
 
-  GlPolygon::setWithXML(rootNode);
-
-  GlXMLTools::getDataNode(rootNode, dataNode);
+  GlPolygon::setWithXML(inString,currentPosition);
 }
 
 }
