@@ -24,12 +24,14 @@
 
 #include <tulip/Matrix.h>
 #include <tulip/QuadTree.h>
-
+#include <tulip/GlGraphInputData.h>
 #include <tulip/Camera.h>
 #include <tulip/GlEntity.h>
 #include <tulip/GlTools.h>
 #include <tulip/GlScene.h>
-#include <iostream>
+#include <tulip/GlNode.h>
+#include <tulip/GlEdge.h>
+#include <tulip/GlSceneObserver.h>
 
 using namespace std;
 
@@ -41,13 +43,13 @@ BoundingBox computeNewBoundingBox(const BoundingBox &box,const Coord &centerScen
   Coord center(box[0] + size);
   //size = Coord(size.norm(),size.norm(),size.norm());
   size.fill(size.norm());
-  center[0]=centerScene[0]+(static_cast<float>(cos(aY))*(center[0]-centerScene[0]));
-  center[1]=centerScene[1]+(static_cast<float>(cos(aX))*(center[1]-centerScene[1]));
+  center[0]=centerScene[0]+(cos(aY)*(center[0]-centerScene[0]));
+  center[1]=centerScene[1]+(cos(aX)*(center[1]-centerScene[1]));
 
   return BoundingBox(center-size,center+size);
 }
 
-GlQuadTreeLODCalculator::GlQuadTreeLODCalculator() : haveToCompute(true),currentGraph(NULL),layoutProperty(NULL),sizeProperty(NULL),selectionProperty(NULL) {
+GlQuadTreeLODCalculator::GlQuadTreeLODCalculator() : haveToCompute(true),haveToInitObservers(true),currentGraph(NULL),layoutProperty(NULL),sizeProperty(NULL),selectionProperty(NULL) {
 }
 
 GlQuadTreeLODCalculator::~GlQuadTreeLODCalculator() {
@@ -71,7 +73,7 @@ void GlQuadTreeLODCalculator::setScene(GlScene &scene) {
   GlLODCalculator::setScene(scene);
 }
 
-void GlQuadTreeLODCalculator::setInputData(GlGraphInputData *newInputData) {
+void GlQuadTreeLODCalculator::setInputData(const GlGraphInputData *newInputData) {
   setHaveToCompute();
 
   if (newInputData == NULL) {
@@ -86,16 +88,32 @@ void GlQuadTreeLODCalculator::setInputData(GlGraphInputData *newInputData) {
 }
 
 bool GlQuadTreeLODCalculator::needEntities() {
+  if(inputData != NULL) {
+    //Checks if the properties in the GlGraphInputData have changed
+    if(layoutProperty != inputData->getElementLayout() || sizeProperty != inputData->getElementSize() || selectionProperty != inputData->getElementSelected()) {
+      //Remove observers on old properties
+      removeObservers();
+      //Reinit properties and listen them
+      addObservers();
+      //Need to recompute
+      haveToCompute = true;
+      haveToInitObservers=false;
+    }
+  }
+
   // Check if quadtree need entities
-  if(haveToCompute)
+  if(haveToCompute) {
+    if(inputData)
+      oldParameters=*inputData->parameters;
+
     return true;
+  }
 
   // Check if a camera have changed (diff between old backup camera and current camera)
-  // If the camera have changed : we need to recompute LOD
-  for(map<GlLayer *,pair<Camera*, Camera> >::iterator it=layerToCamera.begin(); it!=layerToCamera.end(); ++it) {
+  for(map<GlLayer *, Camera>::iterator it=layerToCamera.begin(); it!=layerToCamera.end(); ++it) {
     if(((*it).first->getCamera()).is3D()) {
       Camera camera      = (*it).first->getCamera();
-      Camera oldCamera   = (*it).second.second;
+      Camera oldCamera   = (*it).second;
       Coord unitCamera    = camera.getEyes() - camera.getCenter();
       unitCamera          = unitCamera/unitCamera.norm();
       Coord unitOldCamera = oldCamera.getEyes()-oldCamera.getCenter();
@@ -103,11 +121,31 @@ bool GlQuadTreeLODCalculator::needEntities() {
 
       if(unitCamera != unitOldCamera) {
         haveToCompute = true;
+
+        if(inputData)
+          oldParameters=*inputData->parameters;
+
         return true;
       }
     }
   }
 
+  if(inputData) {
+    // Check visibility flags
+    GlGraphRenderingParameters *newParameters=inputData->parameters;
+
+    if(oldParameters.isDisplayEdges()!=newParameters->isDisplayEdges() ||
+        oldParameters.isDisplayMetaNodes()!=newParameters->isDisplayMetaNodes() ||
+        oldParameters.isDisplayNodes()!=newParameters->isDisplayNodes() ||
+        oldParameters.isViewNodeLabel() != newParameters->isViewNodeLabel() ||
+        oldParameters.isViewEdgeLabel() != newParameters->isViewEdgeLabel() ||
+        oldParameters.isViewMetaLabel() != newParameters->isViewMetaLabel()) {
+      oldParameters=*inputData->parameters;
+      haveToCompute = true;
+      return true;
+    }
+  }
+
   return false;
 }
 
@@ -136,7 +174,10 @@ void GlQuadTreeLODCalculator::compute(const Vector<int,4>& globalViewport,const
   if(haveToCompute) {
     // if have to compute : rebuild quadtree
 
-    addObservers();
+    if(haveToInitObservers) {
+      addObservers();
+      haveToInitObservers=false;
+    }
 
     clearCamerasObservers();
 
@@ -161,14 +202,14 @@ void GlQuadTreeLODCalculator::compute(const Vector<int,4>& globalViewport,const
     entitiesQuadTree.clear();
 
     quadTreesVectorPosition=0;
-    vector<pair<std::string, GlLayer*> > *layersVector=glScene->getLayersList();
+    const vector<pair<std::string, GlLayer*> > &layersVector=glScene->getLayersList();
 
     for(vector<LayerLODUnit>::iterator it=layersLODVector.begin(); it!=layersLODVector.end(); ++it) {
       Camera *camera= ((*it).camera);
 
       GlLayer *currentLayer=NULL;
 
-      for(vector<pair<std::string, GlLayer*> >::iterator itL=layersVector->begin(); itL!=layersVector->end(); ++itL) {
+      for(vector<pair<std::string, GlLayer*> >::const_iterator itL=layersVector.begin(); itL!=layersVector.end(); ++itL) {
         if(&(*itL).second->getCamera()==camera) {
           currentLayer=(*itL).second;
           break;
@@ -178,7 +219,7 @@ void GlQuadTreeLODCalculator::compute(const Vector<int,4>& globalViewport,const
       cameras.push_back(camera);
 
       if(currentLayer!=NULL) {
-        layerToCamera.insert(pair<GlLayer*,pair<Camera*,Camera> >(currentLayer,pair<Camera *,Camera>(camera,*camera)));
+        layerToCamera.insert(pair<GlLayer*, Camera>(currentLayer, *camera));
       }
 
       Matrix<float,4> transformMatrix;
@@ -285,30 +326,35 @@ void GlQuadTreeLODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
       #pragma omp sections nowait
 #endif
       {
-        for(size_t i=0; i<nbSimples; ++i) {
-          entitiesQuadTree[quadTreesVectorPosition]->insert(layerLODUnit->simpleEntitiesLODVector[i].boundingBox,layerLODUnit->simpleEntitiesLODVector[i].entity);
-        }
-      }
 #ifdef _OPENMP
-      #pragma omp sections nowait
+        #pragma omp section
 #endif
-      {
-        for(size_t i=0; i<nbNodes; ++i) {
-          nodesQuadTree[quadTreesVectorPosition]->insert(layerLODUnit->nodesLODVector[i].boundingBox,layerLODUnit->nodesLODVector[i].id);
-        }
-      }
-#ifdef _OPENMP
-      #pragma omp sections nowait
-#endif
-      {
-        for(size_t i=0; i<nbEdges; ++i) {
-          // This code is here to expand edge bonding box when we have an edge with direction (0,0,x)
-          if(layerLODUnit->edgesLODVector[i].boundingBox[0][0] == layerLODUnit->edgesLODVector[i].boundingBox[1][0] &&
-          layerLODUnit->edgesLODVector[i].boundingBox[0][1] == layerLODUnit->edgesLODVector[i].boundingBox[1][1]) {
-            layerLODUnit->edgesLODVector[i].boundingBox.expand(layerLODUnit->edgesLODVector[i].boundingBox[1]+Coord(0.01,0.01,0));
+        {
+          for(size_t i=0; i<nbSimples; ++i) {
+            entitiesQuadTree[quadTreesVectorPosition]->insert(layerLODUnit->simpleEntitiesLODVector[i].boundingBox,layerLODUnit->simpleEntitiesLODVector[i].entity);
           }
+        }
+#ifdef _OPENMP
+        #pragma omp section
+#endif
+        {
+          for(size_t i=0; i<nbNodes; ++i) {
+            nodesQuadTree[quadTreesVectorPosition]->insert(layerLODUnit->nodesLODVector[i].boundingBox,layerLODUnit->nodesLODVector[i].id);
+          }
+        }
+#ifdef _OPENMP
+        #pragma omp section
+#endif
+        {
+          for(size_t i=0; i<nbEdges; ++i) {
+            // This code is here to expand edge bonding box when we have an edge with direction (0,0,x)
+            if(layerLODUnit->edgesLODVector[i].boundingBox[0][0] == layerLODUnit->edgesLODVector[i].boundingBox[1][0] &&
+            layerLODUnit->edgesLODVector[i].boundingBox[0][1] == layerLODUnit->edgesLODVector[i].boundingBox[1][1]) {
+              layerLODUnit->edgesLODVector[i].boundingBox.expand(layerLODUnit->edgesLODVector[i].boundingBox[1]+Coord(0.01,0.01,0));
+            }
 
-          edgesQuadTree[quadTreesVectorPosition]->insert(layerLODUnit->edgesLODVector[i].boundingBox,layerLODUnit->edgesLODVector[i].id);
+            edgesQuadTree[quadTreesVectorPosition]->insert(layerLODUnit->edgesLODVector[i].boundingBox,layerLODUnit->edgesLODVector[i].id);
+          }
         }
       }
     }
@@ -328,14 +374,14 @@ void GlQuadTreeLODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
   BoundingBox cameraBoundingBox;
 
   // Project camera bondinx box to know visible part of the quadtree
-  pSrc[0] = static_cast<float>(transformedViewport[0]);
-  pSrc[1] = static_cast<float>((globalViewport[1] + globalViewport[3]) - (transformedViewport[1] + transformedViewport[3]));
+  pSrc[0] = transformedViewport[0];
+  pSrc[1] = (globalViewport[1] + globalViewport[3]) - (transformedViewport[1] + transformedViewport[3]);
   cameraBoundingBox.expand(unprojectPoint(pSrc, invTransformMatrix, globalViewport));
-  pSrc[1] = static_cast<float>(transformedViewport[1]+transformedViewport[3]);
+  pSrc[1] = transformedViewport[1]+transformedViewport[3];
   cameraBoundingBox.expand(unprojectPoint(pSrc, invTransformMatrix, globalViewport));
-  pSrc[0] = static_cast<float>(transformedViewport[0]+transformedViewport[2]);
+  pSrc[0] = transformedViewport[0]+transformedViewport[2];
   cameraBoundingBox.expand(unprojectPoint(pSrc, invTransformMatrix, globalViewport));
-  pSrc[1] = static_cast<float>(transformedViewport[1]);
+  pSrc[1] = transformedViewport[1];
   cameraBoundingBox.expand(unprojectPoint(pSrc, invTransformMatrix, globalViewport));
 
   int ratio;
@@ -366,7 +412,7 @@ void GlQuadTreeLODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
           if(aX==0 && aY==0) {
             if((renderingEntitiesFlag & RenderingWithoutRemove)==0) {
               if(nodesQuadTree[quadTreesVectorPosition])
-                nodesQuadTree[quadTreesVectorPosition]->getElementsWithRatio(cameraBoundingBox,resNodes,static_cast<float>(ratio));
+                nodesQuadTree[quadTreesVectorPosition]->getElementsWithRatio(cameraBoundingBox,resNodes,ratio);
             }
             else {
               if(nodesQuadTree[quadTreesVectorPosition])
@@ -395,7 +441,7 @@ void GlQuadTreeLODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
           if(aX==0 && aY==0) {
             if((renderingEntitiesFlag & RenderingWithoutRemove)==0) {
               if(edgesQuadTree[quadTreesVectorPosition])
-                edgesQuadTree[quadTreesVectorPosition]->getElementsWithRatio(cameraBoundingBox,resEdges,static_cast<float>(ratio));
+                edgesQuadTree[quadTreesVectorPosition]->getElementsWithRatio(cameraBoundingBox,resEdges,ratio);
             }
             else {
               if(edgesQuadTree[quadTreesVectorPosition])
@@ -424,7 +470,7 @@ void GlQuadTreeLODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
       if((renderingEntitiesFlag & RenderingSimpleEntities)!=0 && entitiesQuadTree[quadTreesVectorPosition]!=NULL) {
         if(aX==0 && aY==0) {
           if((renderingEntitiesFlag & RenderingWithoutRemove)==0)
-            entitiesQuadTree[quadTreesVectorPosition]->getElementsWithRatio(cameraBoundingBox, resEntities, static_cast<float>(ratio));
+            entitiesQuadTree[quadTreesVectorPosition]->getElementsWithRatio(cameraBoundingBox, resEntities, ratio);
           else
             entitiesQuadTree[quadTreesVectorPosition]->getElements(cameraBoundingBox,resEntities);
         }
@@ -439,32 +485,28 @@ void GlQuadTreeLODCalculator::computeFor3DCamera(LayerLODUnit *layerLODUnit,
     }
   }
 
-
-
-  // If edge labels are rendered we have to compute the edges LOD because label rendering use LOD
-  computeEdgesLOD=false;
-
-  if(inputData)
-    setComputeEdgesLOD(inputData->parameters->isViewEdgeLabel());
-
-
   GlCPULODCalculator::computeFor3DCamera(layerLODUnit,eye,transformMatrix,globalViewport,currentViewport);
-
 }
 
 void GlQuadTreeLODCalculator::removeObservers() {
   if(inputData) {
     if(currentGraph)
-      currentGraph->removeGraphObserver(this);
+      currentGraph->removeListener(this);
 
-    if(layoutProperty)
-      layoutProperty->removePropertyObserver(this);
+    if(layoutProperty) {
+      layoutProperty->removeListener(this);
+      layoutProperty = NULL;
+    }
 
-    if(sizeProperty)
-      sizeProperty->removePropertyObserver(this);
+    if(sizeProperty) {
+      sizeProperty->removeListener(this);
+      sizeProperty = NULL;
+    }
 
-    if(selectionProperty)
-      selectionProperty->removePropertyObserver(this);
+    if(selectionProperty) {
+      selectionProperty->removeListener(this);
+      selectionProperty = NULL;
+    }
   }
 
   if(glScene)
@@ -474,30 +516,24 @@ void GlQuadTreeLODCalculator::removeObservers() {
 void GlQuadTreeLODCalculator::addObservers() {
   if(inputData) {
     currentGraph=inputData->getGraph();
-    currentGraph->addGraphObserver(this);
+    currentGraph->addListener(this);
 
-    if(currentGraph->existProperty(inputData->getElementLayoutPropName())) {
-      layoutProperty=currentGraph->getProperty(inputData->getElementLayoutPropName());
-      layoutProperty->addPropertyObserver(this);
-    }
-    else {
-      layoutProperty =NULL;
+    layoutProperty = inputData->getElementLayout();
+
+    if(layoutProperty != NULL) {
+      layoutProperty->addListener(this);
     }
 
-    if(currentGraph->existProperty(inputData->getElementSizePropName())) {
-      sizeProperty=currentGraph->getProperty(inputData->getElementSizePropName());
-      sizeProperty->addPropertyObserver(this);
-    }
-    else {
-      sizeProperty = NULL;
+    sizeProperty = inputData->getElementSize();
+
+    if(sizeProperty != NULL) {
+      sizeProperty->addListener(this);
     }
 
-    if(currentGraph->existProperty(inputData->getElementSelectedPropName())) {
-      selectionProperty=currentGraph->getProperty(inputData->getElementSelectedPropName());
-      selectionProperty->addPropertyObserver(this);
-    }
-    else {
-      selectionProperty = NULL;
+    selectionProperty=inputData->getElementSelected();
+
+    if(selectionProperty != NULL) {
+      selectionProperty->addListener(this);
     }
   }
 
@@ -506,14 +542,9 @@ void GlQuadTreeLODCalculator::addObservers() {
 }
 
 void GlQuadTreeLODCalculator::update(PropertyInterface *property) {
-  bool needCompute=false;
-
-  if(property==inputData->getElementLayout() || property==inputData->getElementSize() || property==inputData->getElementSelected()) {
-    needCompute=true;
-
-  }
-
-  if(needCompute)
+  if(property==inputData->getElementLayout() ||
+      property==inputData->getElementSize() ||
+      property==inputData->getElementSelected())
     setHaveToCompute();
 }
 
@@ -523,89 +554,104 @@ void GlQuadTreeLODCalculator::treatEvent(const Event &ev) {
   if(sceneEv) {
     setHaveToCompute();
   }
-  else {
-    const Camera *camera=dynamic_cast<Camera *>(ev.sender());
+  else if (typeid(ev) == typeid(GraphEvent)) {
+    const GraphEvent* graphEvent = dynamic_cast<const GraphEvent*>(&ev);
 
-    if (camera) {
-      if (ev.type()==Event::TLP_DELETE) {
-        destroy(camera);
+    switch(graphEvent->getType()) {
+    case GraphEvent::TLP_ADD_NODE:
+    case GraphEvent::TLP_ADD_EDGE:
+    case GraphEvent::TLP_DEL_NODE:
+    case GraphEvent::TLP_DEL_EDGE:
+      setHaveToCompute();
+      break;
+
+    case GraphEvent::TLP_ADD_LOCAL_PROPERTY:
+    case GraphEvent::TLP_BEFORE_DEL_LOCAL_PROPERTY: {
+      const PropertyInterface *property = inputData->getGraph()->getProperty(graphEvent->getPropertyName());
+
+      if(property==inputData->getElementLayout() || property==inputData->getElementSize()) {
+        setHaveToCompute();
+        removeObservers();
+        addObservers();
+      }
+
+      break;
+    }
+
+    default:
+      break;
+    }
+  }
+  else if(typeid(ev) == typeid(PropertyEvent)) {
+    const PropertyEvent* propertyEvent = dynamic_cast<const PropertyEvent*>(&ev);
+    PropertyInterface* property = propertyEvent->getProperty();
+
+    switch(propertyEvent->getType()) {
+    case PropertyEvent::TLP_BEFORE_SET_ALL_NODE_VALUE:
+    case PropertyEvent::TLP_BEFORE_SET_NODE_VALUE:
+    case PropertyEvent::TLP_BEFORE_SET_ALL_EDGE_VALUE:
+    case PropertyEvent::TLP_BEFORE_SET_EDGE_VALUE:
+      update(property);
+      break;
+
+    default:
+      break;
+    }
+  }
+  else if (ev.type()==Event::TLP_DELETE) {
+    if (dynamic_cast<Camera*>(ev.sender())) {
+
+      for(vector<Camera *>::iterator it=cameras.begin(); it!=cameras.end(); ++it) {
+        if(*it == dynamic_cast<Camera*>(ev.sender())) {
+          (*it)->removeListener(this);
+          cameras.erase(it);
+          break;
+        }
+      }
+
+      haveToCompute=true;
+    }
+
+    if (dynamic_cast<tlp::Graph*>(ev.sender())) {
+      clear();
+      setInputData(NULL);
+    }
+
+    PropertyInterface* property;
+
+    if ((property = dynamic_cast<PropertyInterface*>(ev.sender()))) {
+      if(property == layoutProperty) {
+        layoutProperty=NULL;
+      }
+      else if(property == sizeProperty) {
+        sizeProperty = NULL;
+      }
+      else if(property == selectionProperty) {
+        selectionProperty = NULL;
       }
     }
   }
 }
 
-void GlQuadTreeLODCalculator::afterSetNodeValue(PropertyInterface *property,const node) {
-  update(property);
-}
-void GlQuadTreeLODCalculator::afterSetEdgeValue(PropertyInterface *property,const edge) {
-  update(property);
-}
-void GlQuadTreeLODCalculator::afterSetAllNodeValue(PropertyInterface *property) {
-  update(property);
-}
-void GlQuadTreeLODCalculator::afterSetAllEdgeValue(PropertyInterface *property) {
-  update(property);
-}
-
-void GlQuadTreeLODCalculator::addLocalProperty(Graph*, const std::string &name) {
-  if(name==inputData->getElementLayoutPropName() || name==inputData->getElementSizePropName() || name == inputData->getElementSelectedPropName()) {
-    setHaveToCompute();
-    addObservers();
-  }
-}
-void GlQuadTreeLODCalculator::delLocalProperty(Graph*, const std::string &name) {
-  if(name==inputData->getElementLayoutPropName() || name==inputData->getElementSizePropName() || name == inputData->getElementSelectedPropName()) {
-    setHaveToCompute();
-    addObservers();
-  }
-}
-
-void GlQuadTreeLODCalculator::addInheritedProperty(Graph *, const string &name) {
-  if(name==inputData->getElementLayoutPropName() || name==inputData->getElementSizePropName() || name == inputData->getElementSelectedPropName()) {
-    setHaveToCompute();
-    addObservers();
-  }
-}
-
-void GlQuadTreeLODCalculator::afterDelInheritedProperty(Graph *, const string &name) {
-  if(name==inputData->getElementLayoutPropName() || name==inputData->getElementSizePropName() || name == inputData->getElementSelectedPropName()) {
-    setHaveToCompute();
-    addObservers();
-  }
-}
-
-void GlQuadTreeLODCalculator::destroy(Graph *) {
-  clear();
-  setInputData(NULL);
-}
-
-void GlQuadTreeLODCalculator::destroy(const Camera *) {
-  std::vector<std::pair<std::string, GlLayer*> > *layerList=glScene->getLayersList();
-
-  clearCamerasObservers();
-
-  cameras.clear();
-
-  for(std::vector<std::pair<std::string, GlLayer*> >::iterator it=layerList->begin(); it!=layerList->end(); ++it) {
-    if(layerToCamera.find((*it).second)==layerToCamera.end())
-      continue;
-
-    (*layerToCamera.find((*it).second)).second.first=&(*it).second->getCamera();
-    cameras.push_back(&(*it).second->getCamera());
-  }
-
-  initCamerasObservers();
-}
-
 void GlQuadTreeLODCalculator::initCamerasObservers() {
+  set<Camera*> treatedCameras;
+
   for(vector<Camera *>::iterator it=cameras.begin(); it!=cameras.end(); ++it) {
-    (*it)->addListener(this);
+    if(treatedCameras.find(*it)==treatedCameras.end()) {
+      treatedCameras.insert(*it);
+      (*it)->addListener(this);
+    }
   }
 }
 
 void GlQuadTreeLODCalculator::clearCamerasObservers() {
+  set<Camera*> treatedCameras;
+
   for(vector<Camera *>::iterator it=cameras.begin(); it!=cameras.end(); ++it) {
-    (*it)->removeListener(this);
+    if(treatedCameras.find(*it)==treatedCameras.end()) {
+      treatedCameras.insert(*it);
+      (*it)->removeListener(this);
+    }
   }
 }
 
@@ -613,8 +659,13 @@ void GlQuadTreeLODCalculator::setHaveToCompute() {
   if(haveToCompute)
     return;
 
-  haveToCompute=true;
+  GlQuadTreeLODCalculator *attachedQuadTreeLODCalculator=dynamic_cast<GlQuadTreeLODCalculator*>(attachedLODCalculator);
 
+  if(attachedQuadTreeLODCalculator)
+    attachedQuadTreeLODCalculator->setHaveToCompute();
+
+  haveToCompute=true;
+  haveToInitObservers=true;
   removeObservers();
 }
 }
