@@ -17,8 +17,7 @@
  *
  */
 
-#include <tulip/GlQuad.h>
-#include <tulip/GlTriangle.h>
+#include <tulip/GlLine.h>
 
 #include <sstream>
 #include <algorithm>
@@ -38,9 +37,9 @@ using namespace std;
 namespace tlp {
 
 GlQuantitativeAxis::GlQuantitativeAxis(const std::string &axisName, const Coord &axisBaseCoord, const float axisLength,
-                                       const AxisOrientation &axisOrientation, const Color &axisColor, const float axisWidth,
+                                       const AxisOrientation &axisOrientation, const Color &axisColor,
                                        const bool addArrow, const bool ascendingOrder)
-  : GlAxis(axisName, axisBaseCoord, axisLength, axisOrientation, axisColor, axisWidth) ,
+  : GlAxis(axisName, axisBaseCoord, axisLength, axisOrientation, axisColor) ,
     ascendingOrder(ascendingOrder), addArrow(addArrow), logScale(false), logBase(10),
     integerScale(false), incrementStep(0), minMaxSet(false) {
   if (addArrow) {
@@ -71,16 +70,11 @@ void GlQuantitativeAxis::setAxisParameters(const int minV, const int maxV, const
   min = minV;
   int maxVCp = maxV;
 
-  if (incrementStepV) {
+  if (incrementStepV)
     while (((maxVCp - minV)%incrementStepV) != 0) ++maxVCp;
 
-    incrementStep = incrementStepV;
-  }
-  else {
-    incrementStep = 1;
-  }
-
   max = maxVCp;
+  incrementStep = incrementStepV;
 
   if (min == max) {
     max += incrementStep;
@@ -206,10 +200,10 @@ Coord GlQuantitativeAxis::getAxisPointCoordForValue(double value) const {
   }
 
   if (ascendingOrder) {
-    offset = static_cast<float>((val - minV) * scale);
+    offset = (val - minV) * scale;
   }
   else {
-    offset = static_cast<float>((maxV - val) * scale);
+    offset = (maxV - val) * scale;
   }
 
   if (axisOrientation == HORIZONTAL_AXIS) {
@@ -269,79 +263,70 @@ double GlQuantitativeAxis::getValueForAxisPoint(const Coord &axisPointCoord) {
 }
 
 void GlQuantitativeAxis::addArrowDrawing() {
-  GlQuad *arrowLine = new GlQuad();
-  arrowLine->setStencil(2);
-
-
-
+  GlLine *arrowLine1 = new GlLine();
+  GlLine *arrowLine2 = new GlLine();
+  GlLine *arrowLine3 = new GlLine();
+  arrowLine1->setStencil(1);
+  arrowLine1->setLineWidth(2.0);
+  arrowLine2->setStencil(1);
+  arrowLine2->setLineWidth(2.0);
+  arrowLine3->setStencil(1);
+  arrowLine3->setLineWidth(2.0);
   float axisExtensionLength = captionOffset;
   float arrowWidth = axisGradsWidth;
-  float arrowLength = 0.5f * axisExtensionLength;
-  Coord arrowStartCoord, arrowEndCoord;
-  vector<Coord> trianglePoints;
+  float arrowLength = (1./2.) * axisExtensionLength;
+  Coord arrowEndCoord;
 
   if (axisOrientation == HORIZONTAL_AXIS) {
     if (ascendingOrder) {
-      arrowStartCoord = Coord(axisBaseCoord.getX() + axisLength + (axisExtensionLength - arrowLength), axisBaseCoord.getY());
       arrowEndCoord = Coord(axisBaseCoord.getX() + axisLength + axisExtensionLength, axisBaseCoord.getY());
-      arrowLine->setPosition(0, Coord(axisBaseCoord.getX() + axisLength, axisBaseCoord.getY()) - Coord(0, axisWidth/2));
-      arrowLine->setPosition(1, Coord(axisBaseCoord.getX() + axisLength, axisBaseCoord.getY()) + Coord(0, axisWidth/2));
-      arrowLine->setPosition(2, Coord(arrowStartCoord.getX(), arrowStartCoord.getY()) + Coord(0, axisWidth/2));
-      arrowLine->setPosition(3, Coord(arrowStartCoord.getX(), arrowStartCoord.getY()) - Coord(0, axisWidth/2));
-      trianglePoints.push_back(arrowStartCoord - Coord(0, arrowWidth/2));
-      trianglePoints.push_back(arrowStartCoord + Coord(0, arrowWidth/2));
-      trianglePoints.push_back(arrowEndCoord);
+      arrowLine1->addPoint(Coord(axisBaseCoord.getX() + axisLength, axisBaseCoord.getY()), axisColor);
+      arrowLine1->addPoint(arrowEndCoord, axisColor);
+      arrowLine2->addPoint(arrowEndCoord, axisColor);
+      arrowLine2->addPoint(Coord(axisBaseCoord.getX() + axisLength + (axisExtensionLength - arrowLength), axisBaseCoord.getY() + arrowWidth / 2), axisColor);
+      arrowLine3->addPoint(arrowEndCoord, axisColor);
+      arrowLine3->addPoint(Coord(axisBaseCoord.getX() + axisLength + (axisExtensionLength - arrowLength) , axisBaseCoord.getY() - arrowWidth / 2), axisColor);
     }
     else {
-      arrowStartCoord = Coord(axisBaseCoord.getX() - (axisExtensionLength - arrowLength) , axisBaseCoord.getY());
       arrowEndCoord = Coord(axisBaseCoord.getX() - axisExtensionLength, axisBaseCoord.getY());
-      arrowLine->setPosition(0, Coord(axisBaseCoord.getX(), axisBaseCoord.getY()) - Coord(0, axisWidth/2));
-      arrowLine->setPosition(1, Coord(axisBaseCoord.getX(), axisBaseCoord.getY()) + Coord(0, axisWidth/2));
-      arrowLine->setPosition(2, Coord(arrowStartCoord.getX(), arrowStartCoord.getY()) + Coord(0, axisWidth/2));
-      arrowLine->setPosition(3, Coord(arrowStartCoord.getX(), arrowStartCoord.getY()) - Coord(0, axisWidth/2));
-      trianglePoints.push_back(arrowStartCoord - Coord(0, arrowWidth/2));
-      trianglePoints.push_back(arrowStartCoord + Coord(0, arrowWidth/2));
-      trianglePoints.push_back(arrowEndCoord);
+      arrowLine1->addPoint(axisBaseCoord, axisColor);
+      arrowLine1->addPoint(arrowEndCoord, axisColor);
+      arrowLine2->addPoint(arrowEndCoord, axisColor);
+      arrowLine2->addPoint(Coord(axisBaseCoord.getX() - (axisExtensionLength - arrowLength), axisBaseCoord.getY() + arrowWidth / 2), axisColor);
+      arrowLine3->addPoint(arrowEndCoord, axisColor);
+      arrowLine3->addPoint(Coord(axisBaseCoord.getX() - (axisExtensionLength - arrowLength), axisBaseCoord.getY() - arrowWidth / 2), axisColor);
     }
   }
   else if (axisOrientation == VERTICAL_AXIS) {
     if (ascendingOrder) {
-      arrowStartCoord = Coord(axisBaseCoord.getX(), axisBaseCoord.getY() + axisLength + (axisExtensionLength - arrowLength));
       arrowEndCoord = Coord(axisBaseCoord.getX(), axisBaseCoord.getY() + axisLength + axisExtensionLength);
-      arrowLine->setPosition(0, Coord(axisBaseCoord.getX(), axisBaseCoord.getY() + axisLength) - Coord(axisWidth/2, 0));
-      arrowLine->setPosition(1, Coord(axisBaseCoord.getX(), axisBaseCoord.getY() + axisLength) + Coord(axisWidth/2, 0));
-      arrowLine->setPosition(2, Coord(arrowStartCoord.getX(), arrowStartCoord.getY()) + Coord(axisWidth/2, 0));
-      arrowLine->setPosition(3, Coord(arrowStartCoord.getX(), arrowStartCoord.getY()) - Coord(axisWidth/2, 0));
-      trianglePoints.push_back(arrowStartCoord - Coord(arrowWidth/2, 0));
-      trianglePoints.push_back(arrowStartCoord + Coord(arrowWidth/2, 0));
-      trianglePoints.push_back(arrowEndCoord);
+      arrowLine1->addPoint(Coord(axisBaseCoord.getX(), axisBaseCoord.getY() + axisLength), axisColor);
+      arrowLine1->addPoint(arrowEndCoord, axisColor);
+      arrowLine2->addPoint(arrowEndCoord, axisColor);
+      arrowLine2->addPoint(Coord(axisBaseCoord.getX() + arrowWidth / 2, axisBaseCoord.getY() + axisLength + (axisExtensionLength - arrowLength)), axisColor);
+      arrowLine3->addPoint(arrowEndCoord, axisColor);
+      arrowLine3->addPoint(Coord(axisBaseCoord.getX() - arrowWidth / 2, axisBaseCoord.getY() + axisLength + (axisExtensionLength - arrowLength)), axisColor);
     }
     else {
-      arrowStartCoord = Coord(axisBaseCoord.getX(), axisBaseCoord.getY() - (axisExtensionLength - arrowLength));
       arrowEndCoord = Coord(axisBaseCoord.getX(), axisBaseCoord.getY() - axisExtensionLength);
-      arrowLine->setPosition(0, Coord(axisBaseCoord.getX(), axisBaseCoord.getY()) - Coord(axisWidth/2, 0));
-      arrowLine->setPosition(1, Coord(axisBaseCoord.getX(), axisBaseCoord.getY()) + Coord(axisWidth/2, 0));
-      arrowLine->setPosition(2, Coord(arrowStartCoord.getX(), arrowStartCoord.getY()) + Coord(axisWidth/2, 0));
-      arrowLine->setPosition(3, Coord(arrowStartCoord.getX(), arrowStartCoord.getY()) - Coord(axisWidth/2, 0));
-      trianglePoints.push_back(arrowStartCoord - Coord(arrowWidth/2, 0));
-      trianglePoints.push_back(arrowStartCoord + Coord(arrowWidth/2, 0));
-      trianglePoints.push_back(arrowEndCoord);
+      arrowLine1->addPoint(axisBaseCoord, axisColor);
+      arrowLine1->addPoint(arrowEndCoord, axisColor);
+      arrowLine2->addPoint(arrowEndCoord, axisColor);
+      arrowLine2->addPoint(Coord(axisBaseCoord.getX() + arrowWidth / 2, axisBaseCoord.getY() - (axisExtensionLength - arrowLength)), axisColor);
+      arrowLine3->addPoint(arrowEndCoord, axisColor);
+      arrowLine3->addPoint(Coord(axisBaseCoord.getX() - arrowWidth / 2, axisBaseCoord.getY() - (axisExtensionLength - arrowLength)), axisColor);
     }
   }
 
-
-  vector<Color> colors;
-  colors.resize(3, Color(0,0,0));
-  GlPolygon *arrowTriangle = new GlPolygon(trianglePoints, colors, colors, true, true);
-  arrowTriangle->setStencil(2);
-
-
   ostringstream oss;
-  oss << axisName << " axis arrow line";
-  axisLinesComposite->addGlEntity(arrowLine, oss.str());
+  oss << axisName << " axis arrow line 1";
+  axisLinesComposite->addGlEntity(arrowLine1, oss.str());
   oss.str("");
-  oss << axisName << " axis arrow triangle";
-  axisLinesComposite->addGlEntity(arrowTriangle, oss.str());
+  oss << axisName << " axis arrow line 2";
+  axisLinesComposite->addGlEntity(arrowLine2, oss.str());
+  oss.str("");
+  oss << axisName << " axis arrow line 3";
+  axisLinesComposite->addGlEntity(arrowLine3, oss.str());
   computeBoundingBox();
 }
 
