@@ -43,24 +43,43 @@ GlRect::GlRect(const Coord &topLeftPos, const Coord &bottomRightPos, const Color
   setFillColor(2, bottomRightCol);
   setFillColor(3, bottomRightCol);
 }
+
+GlRect::GlRect(const Coord &center, const float width, const float height,
+               const Color &fillColor, const Color &outlineColor) :
+  GlPolygon(4u, 4u, 4u, true, true) {
+
+  invertYTexture=false;
+
+  vector<Coord> coords;
+  coords.push_back(center+Coord(width/2.,height/2.,0));
+  coords.push_back(center+Coord(width/2.,-height/2.,0));
+  coords.push_back(center+Coord(-width/2.,-height/2.,0));
+  coords.push_back(center+Coord(-width/2.,height/2.0));
+  setPoints(coords);
+
+  setFillColor(fillColor);
+  setOutlineColor(outlineColor);
+}
+
 //=====================================================
+/*
 GlRect::GlRect(const Coord &center, const Size &size, const Color &fillColor, const Color &outlineColor):
   GlPolygon(4u, 4u, 4u, true, true) {
 
   invertYTexture=false;
 
   vector<Coord> coords;
-  coords.push_back(center+Coord(size[0]/2.f,size[1]/2.f,0));
-  coords.push_back(center+Coord(size[0]/2.f,-size[1]/2.f,0));
-  coords.push_back(center+Coord(-size[0]/2.f,-size[1]/2.f,0));
-  coords.push_back(center+Coord(-size[0]/2.f,size[1]/2.f));
+  coords.push_back(center+Coord(size[0]/2.,size[1]/2.,0));
+  coords.push_back(center+Coord(size[0]/2.,-size[1]/2.,0));
+  coords.push_back(center+Coord(-size[0]/2.,-size[1]/2.,0));
+  coords.push_back(center+Coord(-size[0]/2.,size[1]/2.0));
   setPoints(coords);
 
   setFillColor(fillColor);
 
   setOutlineColor(outlineColor);
 }
-
+*/
 //=====================================================
 GlRect::GlRect(bool filled, bool outlined) :
   GlPolygon(4u, 4u, 4u, filled, outlined) {
@@ -74,10 +93,10 @@ Coord GlRect::getCenter() {
 }
 //=====================================================
 void GlRect::setCenterAndSize(const Coord &center, const Size &size) {
-  points[0]=center+Coord(size[0]/2.f,size[1]/2.f,0);
-  points[1]=center+Coord(size[0]/2.f,-size[1]/2.f,0);
-  points[2]=center+Coord(-size[0]/2.f,-size[1]/2.f,0);
-  points[3]=center+Coord(-size[0]/2.f,size[1]/2.f,0);
+  points[0]=center+Coord(size[0]/2.,size[1]/2.,0);
+  points[1]=center+Coord(size[0]/2.,-size[1]/2.,0);
+  points[2]=center+Coord(-size[0]/2.,-size[1]/2.,0);
+  points[3]=center+Coord(-size[0]/2.,size[1]/2.,0);
 }
 //=====================================================
 Coord GlRect::getTopLeftPos() {
@@ -137,23 +156,5 @@ bool GlRect::inRect(double x, double y) {
 void GlRect::draw(float lod, Camera *camera) {
   GlPolygon::draw(lod, camera);
 }
-//===========================================================
-void GlRect::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode = NULL;
-
-  GlXMLTools::createProperty(rootNode, "type", "GlRect");
-
-  GlPolygon::getXMLOnlyData(rootNode);
-
-  GlXMLTools::getDataNode(rootNode, dataNode);
-}
-//============================================================
-void GlRect::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode = NULL;
-
-  GlPolygon::setWithXML(rootNode);
-
-  GlXMLTools::getDataNode(rootNode, dataNode);
-}
 }
 
