@@ -36,7 +36,7 @@ GlRegularPolygon::GlRegularPolygon(const Coord &position,
   position(position),
   size(size),
   numberOfSides(numberOfSides),
-  startAngle(static_cast<float>(M_PI/2.)) {
+  startAngle(float(M_PI)/2.0f) {
   computePolygon();
 
   invertYTexture=false;
@@ -75,18 +75,18 @@ void GlRegularPolygon::computePolygon() {
 
   BoundingBox box;
   vector<Coord> points;
-  float delta = static_cast<float>((2.0 * M_PI) / numberOfSides);
+  float delta = (2.0f * M_PI) / (float)numberOfSides;
 
   for (unsigned int i=0; i < numberOfSides; ++i) {
     float deltaX = cos(i * delta + startAngle);
     float deltaY = sin(i * delta + startAngle);
-    points.push_back(Coord(deltaX,deltaY,0));
+    points.push_back(Coord(deltaX,deltaY,position[2]));
     box.expand(points.back());
   }
 
   for(vector<Coord>::iterator it=points.begin(); it!=points.end(); ++it) {
-    (*it)[0]=position[0]+(((*it)[0]-((box[1][0]+box[0][0])/2.f))/((box[1][0]-box[0][0])/2.f))*size[0];
-    (*it)[1]=position[1]+(((*it)[1]-((box[1][1]+box[0][1])/2.f))/((box[1][1]-box[0][1])/2.f))*size[1];
+    (*it)[0]=position[0]+(((*it)[0]-((box[1][0]+box[0][0])/2.))/((box[1][0]-box[0][0])/2.))*size[0];
+    (*it)[1]=position[1]+(((*it)[1]-((box[1][1]+box[0][1])/2.))/((box[1][1]-box[0][1])/2.))*size[1];
   }
 
   boundingBox.expand(position+size/2.f);
