@@ -18,6 +18,9 @@
  */
 
 #include <tulip/GlSceneZoomAndPan.h>
+#include <tulip/GlScene.h>
+#include <tulip/Camera.h>
+
 #include <algorithm>
 
 using namespace std;
@@ -25,17 +28,13 @@ using namespace std;
 namespace tlp {
 
 GlSceneZoomAndPan::GlSceneZoomAndPan(GlScene *glScene, const BoundingBox &boundingBox, const std::string &layerName, const int nbAnimationSteps, const bool optimalPath, const double p) :
-  camera(glScene->getLayer(layerName)->getCamera()),nbAnimationSteps(nbAnimationSteps), optimalPath(optimalPath), p(p), additionalAnimation(NULL) {
-
-  viewport = glScene->getViewport();
-
-  camCenterStart = camera.getCenter();
-  camCenterEnd = Coord(boundingBox.center());
+  camera(glScene->getLayer(layerName)->getCamera()),viewport(glScene->getViewport()),nbAnimationSteps(nbAnimationSteps), optimalPath(optimalPath), p(p),
+  camCenterStart(camera.getCenter()),camCenterEnd(Coord(boundingBox.center())),additionalAnimation(NULL) {
 
   camCenterEnd[2] = camCenterStart[2];
 
   Coord blScene(camera.screenTo3DWorld(Coord(0, 0, 0)));
-  Coord trScene(camera.screenTo3DWorld(Coord(static_cast<float>(viewport[2]), static_cast<float>(viewport[3]), 0)));
+  Coord trScene(camera.screenTo3DWorld(Coord(viewport[2], viewport[3], 0)));
 
   BoundingBox sceneBB;
   sceneBB.expand(blScene);
@@ -64,19 +63,10 @@ GlSceneZoomAndPan::GlSceneZoomAndPan(GlScene *glScene, const BoundingBox &boundi
     if (u0 != u1) {
       b0 = (w1 * w1 - w0 * w0 + p * p * p * p * u1 * u1) / (2 * w0 * p * p * u1);
       b1 = (w1 * w1 - w0 * w0 - p * p * p * p * u1 * u1) / (2 * w1 * p * p * u1);
-
       r0 = log(-b0 + sqrt(b0 * b0 + 1));
       r1 = log(-b1 + sqrt(b1 * b1 + 1));
 
-      //Checks if r0 is not equal to infinity it is the case when u1 is too close to u0.
-      //Avoid projections errors
-      if(fabs(r0) == std::numeric_limits<double>::infinity()) {
-        u1=0;
-        S = abs(log(w1 / w0)) / p;
-      }
-      else {
-        S = (r1 - r0) / p;
-      }
+      S = (r1 - r0) / p;
     }
     else {
       S = abs(log(w1 / w0)) / p;
@@ -107,7 +97,7 @@ void GlSceneZoomAndPan::setAdditionalGlSceneAnimation(AdditionalGlSceneAnimation
 
 void GlSceneZoomAndPan::zoomAndPanAnimationStep(int animationStep) {
   if (doZoomAndPan) {
-    double t = static_cast<double>(animationStep) / nbAnimationSteps;
+    double t = (double) animationStep / (double) nbAnimationSteps;
     double s = t * S;
     double u = 0, w = 0, f = 0;
 
@@ -146,12 +136,12 @@ void GlSceneZoomAndPan::zoomAndPanAnimationStep(int animationStep) {
     }
 
     camera.setCenter(camCenterStart + (camCenterEnd - camCenterStart) * static_cast<float>(f));
-    camera.setEyes(Coord(0, 0, static_cast<float>(camera.getSceneRadius())));
+    camera.setEyes(Coord(0, 0, camera.getSceneRadius()));
     camera.setEyes(camera.getEyes() + camera.getCenter());
-    camera.setUp(Coord(0, 1, 0));
+    camera.setUp(Coord(0, 1., 0));
 
-    Coord bbScreenFirst = camera.worldTo2DScreen(camera.getCenter() - Coord(static_cast<float>(w/2), static_cast<float>(w/2), 0));
-    Coord bbScreenSecond = camera.worldTo2DScreen(camera.getCenter() + Coord(static_cast<float>(w/2), static_cast<float>(w/2), 0));
+    Coord bbScreenFirst = camera.worldTo2DScreen(camera.getCenter() - Coord(w/2, w/2, 0));
+    Coord bbScreenSecond = camera.worldTo2DScreen(camera.getCenter() + Coord(w/2, w/2, 0));
     float bbWidthScreen = abs(bbScreenSecond.getX() - bbScreenFirst.getX());
     float bbHeightScreen = abs(bbScreenSecond.getY() - bbScreenFirst.getY());
     double newZoomFactor = 0.0;
