@@ -63,7 +63,7 @@ static void readShaderSourceFile(const string &vertexShaderSourceFilePath, char
   ifs.open(vertexShaderSourceFilePath.c_str());
 
   if (!ifs.is_open()) {
-    cerr << "Error opening file : " << vertexShaderSourceFilePath << endl;
+    tlp::warning() << "Error opening file : " << vertexShaderSourceFilePath << endl;
     return;
   }
 
@@ -252,12 +252,12 @@ void GlShaderProgram::printInfoLog() {
     string shaderCompilationlog = attachedShaders[i]->getCompilationLog();
 
     if (shaderCompilationlog != "") {
-      cout << shaderCompilationlog << endl;
+      tlp::debug() << shaderCompilationlog << endl;
     }
   }
 
   if (programLinkLog != "") {
-    cout << programLinkLog << endl;
+    tlp::debug() << programLinkLog << endl;
   }
 }
 
@@ -278,25 +278,14 @@ void GlShaderProgram::desactivate() {
 }
 
 bool GlShaderProgram::shaderProgramsSupported() {
-  OpenGlConfigManager::getInst().initGlew();
 
-  if (!OpenGlConfigManager::getInst().canUseGlew()) {
-    return false;
-  }
-
-  static bool vertexShaderExtOk = glewIsSupported("GL_ARB_vertex_shader") == GL_TRUE;
-  static bool fragmentShaderExtOk = glewIsSupported("GL_ARB_fragment_shader") == GL_TRUE;
+  static bool vertexShaderExtOk = OpenGlConfigManager::getInst().isExtensionSupported("GL_ARB_vertex_shader");
+  static bool fragmentShaderExtOk = OpenGlConfigManager::getInst().isExtensionSupported("GL_ARB_fragment_shader");
   return (vertexShaderExtOk && fragmentShaderExtOk);
 }
 
 bool GlShaderProgram::geometryShaderSupported() {
-  OpenGlConfigManager::getInst().initGlew();
-
-  if (!OpenGlConfigManager::getInst().canUseGlew()) {
-    return false;
-  }
-
-  static bool geometryShaderExtOk = glewIsSupported("GL_EXT_geometry_shader4") == GL_TRUE;
+  static bool geometryShaderExtOk = OpenGlConfigManager::getInst().isExtensionSupported("GL_EXT_geometry_shader4");
   return geometryShaderExtOk;
 }
 
