@@ -18,6 +18,9 @@
  */
 #include <tulip/GlSimpleEntity.h>
 
+#include <QStringList>
+#include <QVariantList>
+
 #include <tulip/GlComposite.h>
 
 using namespace std;
@@ -29,6 +32,17 @@ GlSimpleEntity::~GlSimpleEntity() {
   }
 }
 
+QStringList GlSimpleEntity::propertiesNames() const {
+  return QStringList();
+}
+
+QVariantList GlSimpleEntity::propertiesQVariant() const {
+  return QVariantList();
+}
+
+void GlSimpleEntity::setProperty(const QString &, const QVariant &) {
+}
+
 void GlSimpleEntity::addParent(GlComposite *composite) {
   parents.push_back(composite);
 }
