@@ -18,13 +18,23 @@
  */
 #include <tulip/GlSphere.h>
 
-#include <tulip/Color.h>
-
-#include <tulip/GlDisplayListManager.h>
+#include <tulip/GlXMLTools.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/GlTools.h>
 #include <tulip/OpenGlConfigManager.h>
 
+#if defined(_MSC_VER)
+#include <Windows.h>
+#endif
+
+#if defined(__APPLE__)
+#include <OpenGL/gl.h>
+#include <OpenGL/glu.h>
+#else
+#include <GL/gl.h>
+#include <GL/glu.h>
+#endif
+
 using namespace std;
 
 namespace tlp {
@@ -76,38 +86,28 @@ void GlSphere::translate(const Coord& vec) {
   position += vec;
 }
 //===========================================================
-void GlSphere::getXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
+void GlSphere::getXML(string &outString) {
+  GlXMLTools::createProperty(outString,"type","GlSphere","GlEntity");
 
-  GlXMLTools::createProperty(rootNode, "type", "GlSphere");
-
-  GlXMLTools::getDataNode(rootNode,dataNode);
-
-  GlXMLTools::getXML(dataNode,"position",position);
-  GlXMLTools::getXML(dataNode,"radius",radius);
-  GlXMLTools::getXML(dataNode,"color",color);
-  GlXMLTools::getXML(dataNode,"textureFile",textureFile);
-  GlXMLTools::getXML(dataNode,"rotation",rot);
+  GlXMLTools::getXML(outString,"position",position);
+  GlXMLTools::getXML(outString,"radius",radius);
+  GlXMLTools::getXML(outString,"color",color);
+  GlXMLTools::getXML(outString,"textureFile",textureFile);
+  GlXMLTools::getXML(outString,"rotation",rot);
 
 }
 //============================================================
-void GlSphere::setWithXML(xmlNodePtr rootNode) {
-  xmlNodePtr dataNode=NULL;
+void GlSphere::setWithXML(const string &inString, unsigned int &currentPosition) {
 
-  GlXMLTools::getDataNode(rootNode,dataNode);
+  GlXMLTools::setWithXML(inString, currentPosition,"position",position);
+  GlXMLTools::setWithXML(inString, currentPosition,"radius",radius);
+  GlXMLTools::setWithXML(inString, currentPosition,"color",color);
+  GlXMLTools::setWithXML(inString, currentPosition,"textureFile",textureFile);
+  GlXMLTools::setWithXML(inString, currentPosition,"rotation",rot);
 
-  // Parse Data
-  if(dataNode) {
+  boundingBox[0] = Coord(position[0]-radius,position[1]-radius,position[2]-radius);
+  boundingBox[1] = Coord(position[0]+radius,position[1]+radius,position[2]+radius);
 
-    GlXMLTools::setWithXML(dataNode,"position",position);
-    GlXMLTools::setWithXML(dataNode,"radius",radius);
-    GlXMLTools::setWithXML(dataNode,"color",color);
-    GlXMLTools::setWithXML(dataNode,"textureFile",textureFile);
-    GlXMLTools::setWithXML(dataNode,"rotation",rot);
-
-    boundingBox[0] = Coord(position[0]-radius,position[1]-radius,position[2]-radius);
-    boundingBox[1] = Coord(position[0]+radius,position[1]+radius,position[2]+radius);
-  }
 }
 
 }
