@@ -17,14 +17,28 @@
  *
  */
 
-#include <tulip/OpenGlConfigManager.h>
+#ifndef NDEBUG
+
+#ifdef WIN32
+#include <windows.h>
+#endif
+
+#ifdef __APPLE__
+#include <OpenGL/glu.h>
+#else
+#include <GL/glu.h>
+#endif
+
+#endif
 
 #include <tulip/Rectangle.h>
 #include <tulip/GlTools.h>
 #include <tulip/Matrix.h>
 #include <tulip/BoundingBox.h>
+#include <tulip/TulipException.h>
 #include <iostream>
 #include <string>
+#include <sstream>
 
 using namespace std;
 namespace tlp {
@@ -76,18 +90,32 @@ static char hullVertexTable[][7] = {
 };
 
 //====================================================
-void glTest(string message) {
+void glTest(const string &message) {
+#ifndef NDEBUG
   unsigned int i = 1;
   GLenum error = glGetError();
 
-  while (error != GL_NO_ERROR) {
-    if (i==1) cerr << "[OpenGL ERROR] : " << message << endl;
+  stringstream errorStream;
+  bool haveError=false;
 
-    cerr << "[" << i << "] ========> : " << gluErrorString(error) <<  endl;
-    assert (error == GL_NO_ERROR);
+  while (error != GL_NO_ERROR) {
+    haveError=true;
+
+    if (i==1)
+      errorStream << "[OpenGL ERROR] : " << message << endl;
+
+    errorStream << "[" << i << "] ========> : " << gluErrorString(error) <<  endl;
     error = glGetError();
     ++i;
   }
+
+  if(haveError)
+    throw tlp::TulipException(errorStream.str());
+
+#else
+  //fixes unused parameter warning in release mode
+  (void)message;
+#endif
 }
 //====================================================
 void setColor(const Color &c) {
@@ -100,16 +128,16 @@ void setColor(GLfloat *c) {
 //====================================================
 void setMaterial(const Color &c) {
   float colorMat[4];
-  colorMat[0] = ((float)c[0])/255.0f;
-  colorMat[1] = ((float)c[1])/255.0f;
-  colorMat[2] = ((float)c[2])/255.0f;
-  colorMat[3] = ((float)c[3])/255.0f;
+  colorMat[0] = ((float)c[0])/255.0;
+  colorMat[1] = ((float)c[1])/255.0;
+  colorMat[2] = ((float)c[2])/255.0;
+  colorMat[3] = ((float)c[3])/255.0;
   setColor(c);
   glMaterialfv(GL_FRONT, GL_AMBIENT_AND_DIFFUSE, colorMat);
 }
 //====================================================
 bool cameraIs3D() {
-  return glIsEnabled(GL_LIGHT0) == GL_TRUE;
+  return glIsEnabled(GL_LIGHT0);
 }
 //====================================================
 Coord projectPoint(const Coord &obj,
@@ -124,7 +152,9 @@ Coord projectPoint(const Coord &obj,
 #ifndef NDEBUG
 
   if(fabs(point[3]) < 1E-6) {
-    std::cerr << "Error in projectPoint with coord : " << obj << " and transform matrix : " << transform << std::endl;
+    std::cerr << "Error in projectPoint with coord : "
+              << obj
+              << " and transform matrix : " << transform;
   }
 
 #endif
@@ -152,7 +182,7 @@ Coord unprojectPoint(const Coord &obj,
 #ifndef NDEBUG
 
   if(fabs(point[3]) < 1E-6) {
-    std::cerr << "Error in unprojectPoint with coord : " << obj << " and transform matrix : " << invtransform << std::endl;
+    std::cerr << "Error in unprojectPoint with coord : " << obj << " and transform matrix : " << invtransform;
   }
 
 #endif
@@ -164,35 +194,6 @@ Coord unprojectPoint(const Coord &obj,
   return result;
 }
 //====================================================
-double segmentSize(const Coord &u, const Coord &v,
-                   const tlp::MatrixGL &transform,
-                   const Vector<int, 4> &viewport) {
-  Coord p1 = projectPoint(u, transform, viewport);
-  Coord p2 = projectPoint(v, transform, viewport);
-  return sqr(p1[0]-p2[0]) + sqr(p1[1]-p2[1]);
-}
-//====================================================
-double segmentVisible(const Coord &u, const Coord &v,
-                      const tlp::MatrixGL &transform,
-                      const Vector<int, 4> &viewport) {
-  Coord p1 = projectPoint(u, transform, viewport);
-  Coord p2 = projectPoint(v, transform, viewport);
-  GLfloat minx = static_cast<GLfloat>(viewport[0]);
-  GLfloat miny = static_cast<GLfloat>(viewport[1]);
-  GLfloat maxx = minx + viewport[2];
-  GLfloat maxy = miny + viewport[3];
-  double size = sqr(p1[0]-p2[0]) + sqr(p1[1]-p2[1]);
-
-  if (( (p1[0]<minx && p2[0]<minx) ||
-        (p1[1]<miny && p2[1]<miny) ||
-        (p1[0]>maxx && p2[0]>maxx) ||
-        (p1[1]>maxy && p2[1]>maxy) ) ) {
-    return -size;
-  }
-  else
-    return size;
-}
-//====================================================
 GLfloat projectSize(const Coord &position,const Size& size,
                     const MatrixGL &projectionMatrix, const MatrixGL &modelviewMatrix,
                     const Vector<int, 4> &viewport) {
@@ -244,15 +245,15 @@ GLfloat projectSize(const BoundingBox &bb,
   Vector<float, 4> proj2 =  vect2 * tmp;
 
 
-  float x1 = (proj1[0]/proj1[3] * 0.5f + 0.5f ) * viewport[2];
-  float x2 = (proj2[0]/proj2[3] * 0.5f + 0.5f ) * viewport[2];
+  float x1 = (proj1[0]/proj1[3] * 0.5 + 0.5 ) * viewport[2];
+  float x2 = (proj2[0]/proj2[3] * 0.5 + 0.5 ) * viewport[2];
 
   float width = fabs(x1 - x2);
-  float size = sqr(2.f * width);
+  float size = pow(2. * width, 2);
 
   // Test of visibily
   x2 += viewport[0];
-  float y2 = (proj2[1]/proj2[3] * 0.5f + 0.5f) * viewport[3] + viewport[1];
+  float y2 = (proj2[1]/proj2[3] * 0.5 + 0.5) * viewport[3] + viewport[1];
   Vector<float, 2> upleft;
   upleft[0] = x2 - width;
   upleft[1] = y2 - width;
@@ -264,12 +265,12 @@ GLfloat projectSize(const BoundingBox &bb,
   r1[1] = downright;
 
   Vector<float, 2> upleftV;
-  upleftV[0] = static_cast<float>(viewport[0]);
-  upleftV[1] = static_cast<float>(viewport[1]);
+  upleftV[0] = viewport[0];
+  upleftV[1] = viewport[1];
 
   Vector<float, 2> downrightV;
-  downrightV[0] = static_cast<float>(viewport[0] + viewport[2]);
-  downrightV[1] = static_cast<float>(viewport[1] + viewport[3]);
+  downrightV[0] = viewport[0] + viewport[2];
+  downrightV[1] = viewport[1] + viewport[3];
 
   Rectangle<float> r2;
   r2[0] = upleftV;
@@ -282,7 +283,7 @@ GLfloat projectSize(const BoundingBox &bb,
   return size;
 }
 //====================================================
-float calculateAABBSize(const BoundingBox& bb,const Coord& eye,const Matrix<float, 4>& transformMatrix,const Vector<int, 4>& globalViewport,const Vector<int, 4>& currentViewport,bool computeOutScreenLOD) {
+float calculateAABBSize(const BoundingBox& bb,const Coord& eye,const Matrix<float, 4>& transformMatrix,const Vector<int, 4>& globalViewport,const Vector<int, 4>& currentViewport) {
   BoundingBox bbTmp(bb);
   Coord src[8];
   Coord dst[8];
@@ -305,6 +306,11 @@ float calculateAABBSize(const BoundingBox& bb,const Coord& eye,const Matrix<floa
         + ((eye[2] < src[0][2]) << 4)
         + ((eye[2] > src[6][2]) << 5);
   assert(pos<=42);
+
+  //If pos==0 : camera are inside the entity so we return a arbitrary lod
+  if(pos==0)
+    return 10.;
+
   num=hullVertexTable[pos][0];
 
   if(num==0)
@@ -349,10 +355,7 @@ float calculateAABBSize(const BoundingBox& bb,const Coord& eye,const Matrix<floa
   }
 
   if(!inScreen) {
-    if(computeOutScreenLOD)
-      return -sqrt((bbBox[2]-bbBox[0])*(bbBox[2]-bbBox[0])+(bbBox[3]-bbBox[1])*(bbBox[3]-bbBox[1])) * 2;
-    else
-      return -1;
+    return -1;
   }
   else {
     return sqrt((bbBox[2]-bbBox[0])*(bbBox[2]-bbBox[0])+(bbBox[3]-bbBox[1])*(bbBox[3]-bbBox[1])) * 2;
@@ -363,7 +366,3 @@ float calculate2DLod(const BoundingBox& bb,const Vector<int, 4>&,const Vector<in
   return (bb[1][0] - bb[0][0]) * (bb[1][1] - bb[0][1]);
 }
 }
-
-GLfloat tlp::sqr(const GLfloat f) {
-  return f*f;
-}
