@@ -24,19 +24,18 @@
 using namespace tlp;
 using namespace std;
 
-TemplateFactory<GlyphFactory,Glyph, GlyphContext *> *GlyphFactory::factory;
-
-Glyph::Glyph(GlyphContext *gc) {
-  if (gc != 0) {
-    glGraphInputData=gc->glGraphInputData;
-  }
-  else {
-    glGraphInputData = 0;
+Glyph::Glyph(const tlp::PluginContext* context) : glGraphInputData(NULL) {
+  if(context != NULL) {
+    const GlyphContext* glyphContext = dynamic_cast<const GlyphContext*>(context);
+    assert(glyphContext != NULL);
+    glGraphInputData = glyphContext->glGraphInputData;
   }
 }
 //=============================================
 Glyph::~Glyph() {
 }
+
+
 //=============================================
 Coord Glyph::getAnchor(const Coord &nodeCenter, const Coord &from, const Size &scale, const double zRotation) const {
   Coord anchor = from - nodeCenter;
@@ -51,8 +50,8 @@ Coord Glyph::getAnchor(const Coord &nodeCenter, const Coord &from, const Size &s
     //unrotate
     Coord saveAnchor(anchor);
     double zRot =  - 2.0*M_PI * zRotation / 360.0;
-    anchor[0] = saveAnchor[0]*static_cast<float>(cos(zRot)) - saveAnchor[1]*static_cast<float>(sin(zRot));
-    anchor[1] = saveAnchor[0]*static_cast<float>(sin(zRot)) + saveAnchor[1]*static_cast<float>(cos(zRot));
+    anchor[0] = saveAnchor[0]*cos(zRot) - saveAnchor[1]*sin(zRot);
+    anchor[1] = saveAnchor[0]*sin(zRot) + saveAnchor[1]*cos(zRot);
   }
 
   // unscale
@@ -71,15 +70,12 @@ Coord Glyph::getAnchor(const Coord &nodeCenter, const Coord &from, const Size &s
   anchor.setY( anchor.getY() * scale.getH() );
   anchor.setZ( anchor.getZ() * scale.getD() );
 
-  if(scale.getD() == 0.0f)
-    anchor[2]=0.;
-
   if(zRotation!=0) {
     //rerotate
-    Coord saveAnchor = anchor;
+    Coord saveAnchor(anchor);
     double zRot = 2.0*M_PI * zRotation / 360.0;
-    anchor[0] = saveAnchor[0]*static_cast<float>(cos(zRot)) - saveAnchor[1]*static_cast<float>(sin(zRot));
-    anchor[1] = saveAnchor[0]*static_cast<float>(sin(zRot)) + saveAnchor[1]*static_cast<float>(cos(zRot));
+    anchor[0] = saveAnchor[0]*cos(zRot) - saveAnchor[1]*sin(zRot);
+    anchor[1] = saveAnchor[0]*sin(zRot) + saveAnchor[1]*cos(zRot);
   }
 
   return nodeCenter + anchor;
