@@ -16,69 +16,61 @@
  * See the GNU General Public License for more details.
  *
  */
+
 #include <GL/glew.h>
 
 #include <tulip/OpenGlConfigManager.h>
 
-#include <tulip/OpenGlErrorViewer.h>
-
 #include <iostream>
+#include <cstdlib>
 
 //====================================================
-tlp::OpenGlConfigManager* tlp::OpenGlConfigManager::inst=0;
+tlp::OpenGlConfigManager* tlp::OpenGlConfigManager::inst=NULL;
 
 using namespace std;
 
 namespace tlp {
-OpenGlConfigManager::OpenGlConfigManager():errorViewer(new OpenGlErrorViewer()),glewIsChecked(false),driversAreChecked(false),glewIsOk(false),antialiased(true) {
+
+OpenGlConfigManager& OpenGlConfigManager::getInst() {
+  if(!inst)
+    inst=new OpenGlConfigManager();
+
+  return *inst;
 }
 
-OpenGlErrorViewer *OpenGlConfigManager::setErrorViewer(OpenGlErrorViewer *errorViewer) {
-  OpenGlErrorViewer *oldErrorViewer=this->errorViewer;
-  this->errorViewer=errorViewer;
-  return oldErrorViewer;
+OpenGlConfigManager::OpenGlConfigManager():
+  glewIsInit(false),
+  driversAreChecked(false), antialiased(true) {
 }
 
-void OpenGlConfigManager::checkDrivers() {
-  if(driversAreChecked)
-    return;
-
-  driversAreChecked=true;
-
-  bool nvidia=false;
-  bool ati=false;
-  string vendor(((const char*)glGetString(GL_VENDOR)));
-
-  if(vendor.find("NVIDIA")!=string::npos)
-    nvidia=true;
-
-  if(vendor.find("ATI")!=string::npos)
-    ati=true;
-
-  if(!nvidia && !ati) {
-    errorViewer->displayErrorWithAskAgain("Graphics card warning","Warning :\n\nYour graphics card is not powerful enough\nor it is not configured with the correct driver\nto suit the Tulip graphics rendering needs.\n\nIf you have an ATI or NVIDIA graphics card,\nwe recommend to install the official driver\nto benefit from an optimal graphics rendering.");
+void OpenGlConfigManager::initExtensions() {
+  if (!glewIsInit) {
+    glewExperimental=true;
+    glewIsInit = (glewInit() == GLEW_OK);
   }
 }
 
-void OpenGlConfigManager::initGlew() {
-  if(glewIsChecked)
-    return;
+double OpenGlConfigManager::getOpenGLVersion() {
+  return atof(reinterpret_cast<const char *>(glGetString(GL_VERSION)));
+}
 
-  GLenum err = glewInit();
+string OpenGlConfigManager::getOpenGLVendor() {
+  return string(reinterpret_cast<const char*>(glGetString(GL_VENDOR)));
+}
 
-  if (GLEW_OK != err) {
-    glewIsOk=false;
-  }
-  else {
-    if(((void*)(glGenBuffers))!=NULL) {
-      glewIsOk=true;
-    }
-    else {
-      glewIsOk=false;
-    }
+bool OpenGlConfigManager::isExtensionSupported(const string &extensionName) {
+  if (!glewIsInit)
+    return false;
+
+  if (checkedExtensions.find(extensionName) == checkedExtensions.end()) {
+    checkedExtensions[extensionName] = (glewIsSupported(extensionName.c_str()) == GL_TRUE);
   }
 
-  glewIsChecked=true;
+  return checkedExtensions[extensionName];
+}
+
+bool OpenGlConfigManager::hasVertexBufferObject() {
+  return isExtensionSupported("GL_ARB_vertex_buffer_object");
 }
 
 void OpenGlConfigManager::activateLineAndPointAntiAliasing() {
