@@ -20,28 +20,27 @@
 #include <tulip/EdgeExtremityGlyph.h>
 #include <tulip/GlGraphInputData.h>
 #include <tulip/GlTriangle.h>
+#include <tulip/Glyph.h>
+#include <tulip/TulipViewSettings.h>
 
-#include <string>
 using namespace tlp;
 using namespace std;
-class GlArrow2DEdgeExtremity: public EdgeExtremityGlyphFrom2DGlyph {
+class GlArrow2DEdgeExtremity: public EdgeExtremityGlyph {
 public:
-  GlArrow2DEdgeExtremity(EdgeExtremityGlyphContext *gc);
+  GLYPHINFORMATION("2D - Arrow","Jonathan Dubois","09/04/09","Edge Extremity with 2D arrow","1.0",EdgeExtremityShape::Arrow)
+  GlArrow2DEdgeExtremity(tlp::PluginContext *gc);
   virtual ~GlArrow2DEdgeExtremity();
-
   void draw(edge e, node n, const Color& glyphColor, const Color &borderColor, float lod);
-
 protected :
-
   static GlTriangle *triangle;
 };
 
-EEGLYPHPLUGIN(GlArrow2DEdgeExtremity,"2D - Arrow","Jonathan Dubois","09/04/09","Edge Extremity with 2D arrow","1.0",50);
+PLUGIN(GlArrow2DEdgeExtremity)
 
 GlTriangle* GlArrow2DEdgeExtremity::triangle=0;
 
-GlArrow2DEdgeExtremity::GlArrow2DEdgeExtremity(EdgeExtremityGlyphContext *gc) :
-  EdgeExtremityGlyphFrom2DGlyph(gc) {
+GlArrow2DEdgeExtremity::GlArrow2DEdgeExtremity(tlp::PluginContext *gc) :
+  EdgeExtremityGlyph(gc) {
   if(!triangle) {
     triangle=new GlTriangle(Coord(0,0,0),Size(0.5,0.5,0.5));
     triangle->setLightingMode(false);
@@ -57,11 +56,8 @@ void GlArrow2DEdgeExtremity::draw(edge e, node, const Color& glyphColor, const C
 
   double width = edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e);
 
-  if (width < 1e-6)
-    width=1e-6;
-
   triangle->setFillColor(glyphColor);
-  triangle->setOutlineSize(static_cast<float>(width));
+  triangle->setOutlineSize(width);
   triangle->setOutlineColor(borderColor);
   triangle->draw(lod,NULL);
 }
