@@ -19,11 +19,12 @@
 #ifndef _EqualValueClustering_H
 #define _EqualValueClustering_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 class EqualValueClustering:public tlp::Algorithm {
 public:
-  EqualValueClustering(tlp::AlgorithmContext);
+  PLUGININFORMATION("Equal Value","David Auber","20/05/2008","Beta","1.1", "Clustering")
+  EqualValueClustering(tlp::PluginContext* context);
   bool run();
 };
 
