@@ -22,21 +22,20 @@
 #include <list>
 #include <string>
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup clustering */
-/*@{*/
+
 class HierarchicalClustering:public tlp::Algorithm {
 public:
-  HierarchicalClustering(tlp::AlgorithmContext);
+  PLUGININFORMATION("Hierarchical","David Auber","27/01/2000","Alpha","1.0", "Clustering")
+  HierarchicalClustering(tlp::PluginContext* context);
   ~HierarchicalClustering();
   bool run();
-  bool check(std::string &);
-  void reset();
 private :
   bool split (tlp::DoubleProperty*, std::list<tlp::node> &);
 };
-/*@}*/
+
 
 #endif
 
