@@ -19,19 +19,18 @@
 #ifndef _QuotientClustering_H
 #define _QuotientClustering_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup clustering */
-/*@{*/
+
 class QuotientClustering:public tlp::Algorithm {
 public:
-  QuotientClustering(tlp::AlgorithmContext);
+  PLUGININFORMATION("Quotient Clustering","David Auber","13/06/2001","OK","1.3", "Clustering")
+  QuotientClustering(tlp::PluginContext* context);
   ~QuotientClustering();
   bool run();
-  bool check(std::string &);
-  void reset();
 };
-/*@}*/
+
 #endif
 
 
