@@ -22,7 +22,7 @@
 using namespace std;
 using namespace tlp;
 
-DOUBLEPLUGINOFGROUP(StrengthClustering, "Strength Clustering", "David Auber", "27/01/2003", "Alpha", "2.0","Clustering");
+PLUGIN(StrengthClustering)
 
 //================================================================================
 StrengthClustering::~StrengthClustering() {}
@@ -95,7 +95,7 @@ double StrengthClustering::computeMQValue(const vector<set<node> > & partition,
     pair<unsigned int, unsigned int> pp = itMap->first;
     unsigned int val = itMap->second;
 
-    if ( (partition[pp.first].size()!=0) && (partition[pp.second].size()!=0))
+    if ( !partition[pp.first].empty() && !partition[pp.second].empty())
       negative += double(val) / double(partition[pp.first].size() * partition[pp.second].size());
   }
 
@@ -108,10 +108,10 @@ double StrengthClustering::computeMQValue(const vector<set<node> > & partition,
 
 
 //==============================================================================
-vector< set<node> > StrengthClustering::computeNodePartition(double threshold) {
-  //cerr << __PRETTY_FUNCTION__ << endl;
-  string errMsg;
-  Graph *tmpGraph= graph->addCloneSubGraph();
+void StrengthClustering::computeNodePartition(double threshold,
+    vector<set<node> >& result ) {
+  //tlp::warning() << __PRETTY_FUNCTION__ << endl;
+  Graph *tmpGraph = graph->addCloneSubGraph();
   StableIterator<edge> itE(graph->getEdges());
 
   while (itE.hasNext()) {
@@ -149,18 +149,18 @@ vector< set<node> > StrengthClustering::computeNodePartition(double threshold) {
   }
 
   //Extract connected component
-  DoubleProperty *connected= new DoubleProperty(tmpGraph);
-  tmpGraph->computeProperty("Connected Component", connected, errMsg);
+  DoubleProperty connected(tmpGraph);
+  string errMsg;
+  tmpGraph->applyPropertyAlgorithm("Connected Component", &connected, errMsg);
 
   //Compute the node partition
   int index=0;
-  vector< set<node > > result;
   map<double,int> resultIndex;
   Iterator<node> *itN2=tmpGraph->getNodes();
 
   while (itN2->hasNext()) {
     node itn=itN2->next();
-    const double& val=connected->getNodeValue(itn);
+    const double& val=connected.getNodeValue(itn);
 
     if (resultIndex.find(val)!=resultIndex.end())
       result[resultIndex[val]].insert(itn);
@@ -175,13 +175,11 @@ vector< set<node> > StrengthClustering::computeNodePartition(double threshold) {
 
   delete itN2;
 
-  delete connected;
   graph->delAllSubGraphs(tmpGraph);
-  return result;
 }
 //==============================================================================
 //void drawGraph(Graph *tmpg) {
-//  //  cerr << __PRETTY_FUNCTION__ << endl;
+//  //  tlp::warning() << __PRETTY_FUNCTION__ << endl;
 //  string errMsg;
 //  string layoutName;
 //  if (tmpg->numberOfNodes() > 300)
@@ -202,7 +200,7 @@ double StrengthClustering::findBestThreshold(int numberOfSteps, bool& stopped) {
 
   for (double i=values->getEdgeMin(graph); i<values->getEdgeMax(graph); i+=deltaThreshold) {
     vector< set<node > > tmp;
-    tmp = computeNodePartition(i);
+    computeNodePartition(i, tmp);
 
     if (pluginProgress && ((++steps % (numberOfSteps / 10)) == 0)) {
       pluginProgress->progress(steps, numberOfSteps);
@@ -220,10 +218,10 @@ double StrengthClustering::findBestThreshold(int numberOfSteps, bool& stopped) {
     }
   }
 
-  // cout << __PRETTY_FUNCTION__ << endl;
-  // cout << "\t" <<" Nb try : " << numberOfSteps << endl;
-  // cout << "\t" <<" Max MQ : " << maxMQ << endl << flush;
-  // cout << "\t" <<" Best threshold : " << threshold << endl << flush;
+  // tlp::debug() << __PRETTY_FUNCTION__ << endl;
+  // tlp::debug() << "\t" <<" Nb try : " << numberOfSteps << endl;
+  // tlp::debug() << "\t" <<" Max MQ : " << maxMQ << endl << flush;
+  // tlp::debug() << "\t" <<" Best threshold : " << threshold << endl << flush;
   return threshold;
 }
 //==============================================================================
@@ -269,10 +267,10 @@ double StrengthClustering::findBestThreshold(int numberOfSteps, bool& stopped) {
 //      if (!tlp::averageCluster(sg, avCluster, pluginProgress))
 //  return false;
 //      /*
-//  cout << "Average Path Length :" << avPath << endl;
-//  cout << "Average clustering  :" <<  avCluster << endl;
-//  cout << "Number of nodes     :" <<  tmpg->numberOfNodes() << endl;
-//  cout << "Number of edges     :" <<  tmpg->numberOfEdges() << endl;
+//  tlp::debug() << "Average Path Length :" << avPath << endl;
+//  tlp::debug() << "Average clustering  :" <<  avCluster << endl;
+//  tlp::debug() << "Number of nodes     :" <<  tmpg->numberOfNodes() << endl;
+//  tlp::debug() << "Number of edges     :" <<  tmpg->numberOfEdges() << endl;
 //      */
 //      if ( avPath > 1 && avPath < 4 && avCluster > 0.25) {
 //  DataSet tmpData;
@@ -321,16 +319,17 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "DoubleProperty" )       \
   HTML_HELP_DEF( "value", "An existing metric property" )   \
   HTML_HELP_BODY()              \
-  "This parameter defines the metric used in order to multiply strength metric computed values."\
-  "If one is given the complexity will be in o(nlog(n)), o(n) neither." \
+  "Metric used in order to multiply strength metric computed values."\
+  "If one is given, the complexity is O(n log(n)), O(n) neither." \
   HTML_HELP_CLOSE(),
+// do you mean "else it will be O(n)" instead of "O(n) neither"?
   /*// layout subgraphs
   HTML_HELP_OPEN() \
   HTML_HELP_DEF( "type", "bool" ) \
   HTML_HELP_DEF( "values", "[true, false]" ) \
   HTML_HELP_DEF( "default", "true" ) \
   HTML_HELP_BODY() \
-  "This parameter indicates whether the layout of the newly created subgraphs has to be computed or not." \
+  "If true the layout of the newly created subgraphs is computed." \
   HTML_HELP_CLOSE(),
   // layout quotient graph
   HTML_HELP_OPEN() \
@@ -338,22 +337,22 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "values", "[true, false]" ) \
   HTML_HELP_DEF( "default", "true" ) \
   HTML_HELP_BODY() \
-  "This parameter indicates whether the layout of the quotient graph has to be computed or not." \
+  "If true the layout of the quotient graph is computed." \
   HTML_HELP_CLOSE(),*/
 };
 }
 
 //================================================================================
-StrengthClustering::StrengthClustering(PropertyContext context):DoubleAlgorithm(context) {
-  addParameter<DoubleProperty>("metric", paramHelp[0], 0, false);
-//  addParameter<bool>("layout subgraphs", paramHelp[1], "true");
-//  addParameter<bool>("layout quotient graph", paramHelp[2], "true");
-//  addDependency<Algorithm>("Quotient Clustering", "1.3");
-//  addDependency<DoubleAlgorithm>("Connected Component", "1.0");
-  addDependency<DoubleAlgorithm>("Strength", "1.0");
-//  addDependency<LayoutAlgorithm>("Circular", "1.1");
-//  addDependency<LayoutAlgorithm>("GEM (Frick)", "1.1");
-//  addDependency<SizeAlgorithm>("Auto Sizing", "1.0");
+StrengthClustering::StrengthClustering(PluginContext* context):DoubleAlgorithm(context) {
+  addInParameter<NumericProperty*>("metric", paramHelp[0], "", false);
+//  addInParameter<bool>("layout subgraphs", paramHelp[1], "true");
+//  addInParameter<bool>("layout quotient graph", paramHelp[2], "true");
+//  addDependency("Quotient Clustering", "1.3");
+//  addDependency("Connected Component", "1.0");
+  addDependency("Strength", "1.0");
+//  addDependency("Circular", "1.1");
+//  addDependency("GEM (Frick)", "1.1");
+//  addDependency("Auto Sizing", "1.0");
 }
 
 //==============================================================================
@@ -361,28 +360,26 @@ bool StrengthClustering::run() {
   string errMsg;
   values = new DoubleProperty(graph);
 
-  if (!graph->computeProperty("Strength", values, errMsg, pluginProgress))
+  if (!graph->applyPropertyAlgorithm("Strength", values, errMsg, pluginProgress))
     return false;
 
-  DoubleProperty *metric = NULL;
-  bool multi = false;
+  NumericProperty *metric = NULL;
 
 //  subgraphsLayout = true;
 //  quotientLayout = true;
   if (dataSet) {
-    multi = dataSet->get("metric", metric);
+    dataSet->get("metric", metric);
 //    dataSet->get("layout subgraphs", subgraphsLayout);
 //    dataSet->get("layout quotient graph", quotientLayout);
   }
 
-  if (multi) {
-    DoubleProperty mult(graph);
+  if (metric) {
+    NumericProperty* mult = metric->copyProperty(graph);
 
     if (pluginProgress)
       pluginProgress->setComment("Computing Strength metric X specified metric on edges ...");
 
-    mult = *metric;
-    mult.uniformQuantification(100);
+    mult->uniformQuantification(100);
     edge e;
     unsigned int steps = 0, maxSteps = graph->numberOfEdges();
 
@@ -390,7 +387,7 @@ bool StrengthClustering::run() {
       maxSteps = 10;
 
     forEach (e, graph->getEdges()) {
-      values->setEdgeValue(e, values->getEdgeValue(e)*(mult.getEdgeValue(e) + 1));
+      values->setEdgeValue(e, values->getEdgeValue(e)*(mult->getEdgeDoubleValue(e) + 1));
 
       if (pluginProgress && ((++steps % (maxSteps / 10) == 0))) {
         pluginProgress->progress(++steps, maxSteps);
@@ -399,6 +396,7 @@ bool StrengthClustering::run() {
           return pluginProgress->state()!= TLP_CANCEL;
       }
     }
+    delete mult;
   }
 
   bool stopped = false;
@@ -415,13 +413,13 @@ bool StrengthClustering::run() {
     return pluginProgress->state()!= TLP_CANCEL;
 
   vector< set<node > > tmp;
-  tmp = computeNodePartition(threshold);
+  computeNodePartition(threshold, tmp);
 
   for(unsigned int i=0; i<tmp.size(); ++i) {
     set<node>::const_iterator it;
 
     for(it=tmp[i].begin(); it!=tmp[i].end(); ++it) {
-      doubleResult->setNodeValue(*it,i);
+      result->setNodeValue(*it,i);
     }
   }
 
