@@ -18,19 +18,21 @@
  */
 #include <cmath>
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 #include <tulip/Color.h>
 #include <tulip/Vector.h>
 #include <tulip/ColorScale.h>
-#include "DoubleStringsListRelationDialog.h"
-
+#include <tulip/StringCollection.h>
 #include <tulip/GlComposite.h>
 #include <tulip/GlRect.h>
 #include <tulip/GlLabel.h>
 
+#include "DoubleStringsListRelationDialog.h"
+
 using namespace std;
 using namespace tlp;
 
+namespace {
 void RGBtoHSV( float r, float g, float b, float *h, float *s, float *v ) {
   float theMin, theMax, delta;
   theMin = std::min(std::min(r, g), b); //MIN( MIN( r, g) , b );
@@ -115,41 +117,38 @@ void HSVtoRGB( float *r, float *g, float *b, float h, float s, float v ) {
   }
 }
 
-namespace {
 const char * paramHelp[] = {
-  // property
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "DoubleProperty" ) \
-  HTML_HELP_BODY() \
-  "This metric is used to affect scalar values to graph items." \
-  "The meaning of theses values depends of the choosen color model." \
-  HTML_HELP_CLOSE(),
-  // property
-  HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "PropertyInterface*" ) \
-  HTML_HELP_BODY() \
-  "This metric is used to affect scalar values to graph items." \
-  "The meaning of theses values depends of the choosen color model." \
-  HTML_HELP_CLOSE(),
+  // type
   HTML_HELP_OPEN()         \
   HTML_HELP_DEF( "type", "String Collection" ) \
   HTML_HELP_DEF("values", "linear <BR> uniform <BR> enumerated") \
   HTML_HELP_DEF( "default", "linear" )   \
   HTML_HELP_BODY() \
-  "This parameter enables to choose the type of color mapping"  \
+  "If linear, the input property must be a Double or Integer property. The minimum value is mapped to one end of the color scale," \
+  "the maximum value is mapped to the other end, and a linear interpolation is used between both.<BR>"          \
+  "If uniform, this is the same except for the interpolation: the value are sorted, numbered, and a linear interpolation is used on those numbers" \
+  "(in other words, only the order is taken into account, not the actual values).<BR>" \
+  "Finally, if enumerated, the input property can be of any type. Each possible value is mapped to a distinct color in no specific order." \
   HTML_HELP_CLOSE(),
+  // property
+  HTML_HELP_OPEN() \
+  HTML_HELP_DEF( "type", "PropertyInterface" ) \
+  HTML_HELP_BODY() \
+  "This property is used to get the values affected to graph items." \
+  HTML_HELP_CLOSE(),
+  // target
   HTML_HELP_OPEN()         \
   HTML_HELP_DEF( "type", "String Collection" ) \
   HTML_HELP_DEF("values", "nodes <BR> edges") \
   HTML_HELP_DEF( "default", "nodes" )  \
   HTML_HELP_BODY() \
-  "This parameter enables to choose the target of the color mapping"  \
+  "Whether colors are computed for nodes or for edges."  \
   HTML_HELP_CLOSE(),
-  // color1
+  // color
   HTML_HELP_OPEN() \
   HTML_HELP_DEF( "type", "ColorScale" ) \
   HTML_HELP_BODY() \
-  "This is the color scale used." \
+  "Color scale used to transform a scalar into a color." \
   HTML_HELP_CLOSE(),
 
 };
@@ -168,7 +167,7 @@ const char * paramHelp[] = {
 
 class ColorMapping: public ColorAlgorithm {
 private:
-  DoubleProperty *entryMetric;
+  NumericProperty *entryMetric;
   StringCollection eltTypes;
   StringCollection targetType;
   ColorScale colorScale;
@@ -178,12 +177,17 @@ private:
 
 
 public:
-  ColorMapping(const PropertyContext &context):ColorAlgorithm(context),eltTypes(ELT_TYPES) {
-    addParameter<DoubleProperty>("linear/uniform\nproperty",paramHelp[0],"viewMetric");
-    addParameter<PropertyInterface*>("enumerated\nproperty",paramHelp[1],"viewMetric");
-    addParameter<StringCollection>(ELT_TYPE, paramHelp[2], ELT_TYPES);
-    addParameter<StringCollection>(TARGET_TYPE, paramHelp[3], TARGET_TYPES);
-    addParameter<ColorScale>("colorScale",paramHelp[4],"((229, 40, 0, 200), (255, 170, 0, 200), (255, 255, 127, 200), (156, 161, 255, 200), (75, 75, 255, 200))");
+  PLUGININFORMATION("Color Mapping","Mathiaut","16/09/2010","Color mapping plugin","2.1", "Color")
+  ColorMapping(const tlp::PluginContext* context):ColorAlgorithm(context), entryMetric(NULL), eltTypes(ELT_TYPES) {
+    addInParameter<StringCollection>(ELT_TYPE, paramHelp[0], ELT_TYPES);
+    addInParameter<PropertyInterface*>("input property",paramHelp[1],"viewMetric");
+    addInParameter<StringCollection>(TARGET_TYPE, paramHelp[2], TARGET_TYPES);
+    addInParameter<ColorScale>("colorScale",paramHelp[3],"((75, 75, 255, 200), (156, 161, 255, 200), (255, 255, 127, 200), (255, 170, 0, 200), (229, 40, 0, 200))");
+    // result needs to be an inout parameter
+    // in order to preserve the original values of non targetted elements
+    // i.e if "target" = "nodes", the values of edges must be preserved
+    // and if "target" = "edges", the values of nodes must be preserved
+    parameters.setDirection("result", INOUT_PARAM);
   }
 
   //=========================================================
@@ -195,77 +199,98 @@ public:
     return colorScale.getColorAtPos(value/range);
   }
   //=========================================================
-  void computeEdgeColor() {
-    double minE,maxE;
-    minE = entryMetric->getEdgeMin(graph);
-    maxE = entryMetric->getEdgeMax(graph);
-    Iterator<edge> *itE=graph->getEdges();
-
-    while(itE->hasNext()) {
-      edge ite=itE->next();
-      double dd=entryMetric->getEdgeValue(ite)-minE;
-      colorResult->setEdgeValue(ite, getColor(dd,maxE-minE));
-    }
-
-    delete itE;
-  }
-  //=========================================================
-  void computeNodeColor() {
-    double minN,maxN;
-    minN=entryMetric->getNodeMin(graph);
-    maxN=entryMetric->getNodeMax(graph);
-    Iterator<node> *itN=graph->getNodes();
-
-    while(itN->hasNext()) {
-      node itn=itN->next();
-      double dd=entryMetric->getNodeValue(itn)-minN;
-      colorResult->setNodeValue(itn, getColor(dd,maxN-minN));
-    }
-
-    delete itN;
-  }
-  //=========================================================
   bool run() {
-    //    cerr << __PRETTY_FUNCTION__ << endl;
+    //    qWarning() << __PRETTY_FUNCTION__ << endl;
     eltTypes.setCurrent(LINEAR_ELT);
     targetType.setCurrent(NODES_TARGET);
-    DoubleProperty* metricS = NULL;
+    NumericProperty* metricS = NULL;
+    PropertyInterface* metric = NULL;
 
-    PropertyInterface *metric = NULL;
-
-    if ( dataSet!=0 ) {
-      dataSet->get("linear/uniform\nproperty", metricS);
-      dataSet->get("enumerated\nproperty", metric);
+    if ( dataSet!=NULL ) {
+      dataSet->get("input property", metric);
       dataSet->get(ELT_TYPE, eltTypes);
       dataSet->get(TARGET_TYPE, targetType);
       dataSet->get("colorScale", colorScale);
     }
 
-    if (metricS == NULL)
-      metricS = graph->getProperty<DoubleProperty>("viewMetric");
-
     if (metric == NULL)
-      metric = graph->getProperty<DoubleProperty>("viewMetric");
+      metricS = graph->getProperty<DoubleProperty>("viewMetric");
+    else
+      metricS = dynamic_cast<NumericProperty*>(metric);
 
-    if (eltTypes.getCurrent()==LINEAR_ELT || eltTypes.getCurrent()==UNIFORM_ELT) {
+    if (eltTypes.getCurrent()!=ENUMERATED_ELT) {
       if (eltTypes.getCurrent()==LINEAR_ELT) {
         entryMetric = metricS;
       }
       else {
-        DoubleProperty *tmp= new DoubleProperty(graph);
-        *tmp = *metricS;
+        NumericProperty *tmp= metricS->copyProperty(graph);
         tmp->uniformQuantification(300);
         entryMetric = tmp;
       }
 
-      if(targetType.getCurrent()==NODES_TARGET && graph->numberOfNodes()!=0)
-        computeNodeColor();
+      // loop on nodes
+      if(targetType.getCurrent()==NODES_TARGET && graph->numberOfNodes()!=0) {
+        unsigned int maxIter = graph->numberOfNodes();
+        unsigned int iter = 0;
+        double minN,maxN;
+        minN=entryMetric->getNodeDoubleMin(graph);
+        maxN=entryMetric->getNodeDoubleMax(graph);
+        Iterator<node> *itN=graph->getNodes();
 
-      if(targetType.getCurrent()==EDGES_TARGET && graph->numberOfEdges()!=0)
-        computeEdgeColor();
+        while(itN->hasNext()) {
+          node itn=itN->next();
+          double dd=entryMetric->getNodeDoubleValue(itn)-minN;
+          result->setNodeValue(itn, getColor(dd,maxN-minN));
 
+          if ((iter % 100 == 0) &&
+              (pluginProgress->progress(iter, maxIter)!=TLP_CONTINUE)) {
+            if (eltTypes.getCurrent()==UNIFORM_ELT) delete entryMetric;
+
+            delete itN;
+            return pluginProgress->state()!=TLP_CANCEL;
+          }
+
+          ++iter;
+        }
+
+        delete itN;
+      }
+
+      // loop on edges
+      if(targetType.getCurrent()==EDGES_TARGET && graph->numberOfEdges()!=0) {
+        unsigned int maxIter = graph->numberOfEdges();
+        unsigned int iter = 0;
+        double minE,maxE;
+        minE = entryMetric->getEdgeDoubleMin(graph);
+        maxE = entryMetric->getEdgeDoubleMax(graph);
+        Iterator<edge> *itE=graph->getEdges();
+
+        while(itE->hasNext()) {
+          edge ite=itE->next();
+          double dd=entryMetric->getEdgeDoubleValue(ite)-minE;
+          result->setEdgeValue(ite, getColor(dd,maxE-minE));
+
+          if ((iter % 100 == 0) &&
+              (pluginProgress->progress(iter, maxIter)!=TLP_CONTINUE)) {
+            if (eltTypes.getCurrent()==UNIFORM_ELT) delete entryMetric;
+
+            delete itE;
+            return pluginProgress->state()!=TLP_CANCEL;
+          }
+
+          ++iter;
+        }
+
+        delete itE;
+      }
+
+      if (eltTypes.getCurrent()==UNIFORM_ELT) delete entryMetric;
     }
     else {
+      unsigned int maxIter = (targetType.getCurrent()==NODES_TARGET) ?
+                             graph->numberOfNodes() : graph->numberOfEdges();
+      unsigned int iter = 0;
+
       for(vector<pair<string,Color> >::iterator it =
             enumeratedMappingResultVector.begin();
           it!=enumeratedMappingResultVector.end(); ++it) {
@@ -273,15 +298,20 @@ public:
 
         for(vector<unsigned>::iterator itE=elements->begin(); itE!=elements->end(); ++itE) {
           if(targetType.getCurrent()==NODES_TARGET)
-            colorResult->setNodeValue(node(*itE),(*it).second);
+            result->setNodeValue(node(*itE),(*it).second);
           else
-            colorResult->setEdgeValue(edge(*itE),(*it).second);
+            result->setEdgeValue(edge(*itE),(*it).second);
+
+          if ((iter % 100 == 0) &&
+              (pluginProgress->progress(iter, maxIter)!=TLP_CONTINUE)) {
+            return pluginProgress->state()!=TLP_CANCEL;
+          }
+
+          ++iter;
         }
       }
     }
 
-    if (eltTypes.getCurrent()==UNIFORM_ELT) delete entryMetric;
-
     return true;
   }
   //=========================================================
@@ -289,8 +319,8 @@ public:
     //    cerr << __PRETTY_FUNCTION__ << endl;
     PropertyInterface *metric = NULL;
 
-    if (dataSet!=0) {
-      dataSet->get("enumerated\nproperty", metric);
+    if (dataSet!=NULL) {
+      dataSet->get("input property", metric);
       dataSet->get(ELT_TYPE, eltTypes);
       dataSet->get(TARGET_TYPE, targetType);
       dataSet->get("colorScale", colorScale);
@@ -348,9 +378,16 @@ public:
 
       dialog.getResult(enumeratedMappingResultVector);
     }
+    else {
+      // check if input property is a NumericProperty
+      if (! dynamic_cast<NumericProperty*>(metric)) {
+        errorMsg += "For a linear or uniform color mapping,\nthe input property must be a Double or Integer property";
+        return false;
+      }
+    }
 
     return true;
   }
 };
 
-COLORPLUGIN(ColorMapping,"Color Mapping","Mathiaut","16/09/2010","Color mapping plugin","1.0");
+PLUGIN(ColorMapping)
