@@ -20,7 +20,9 @@
 #include <iostream>
 #include <iomanip>
 
-#include <tulip/TulipPlugin.h>
+
+#include <tulip/ExportModule.h>
+#include <tulip/TulipPluginHeaders.h>
 #include <tulip/AbstractProperty.h>
 
 using namespace std;
@@ -49,17 +51,19 @@ void printSize(ostream &os,const Size &v) {
   printFloat(os,"d ",v.getD());
 }
 
-/** \addtogroup export */
-/*@{*/
-/// Export plugin for GML format.
 /**
  * This plugin records a Tulip graph structure using the GML File format.
  * This format is the file format used by Graphlet.
  * See www.infosun.fmi.uni-passau.de/Graphlet/GML/ for details.
  */
-class GMLExport:public ExportModule {
+class GMLExport:public tlp::ExportModule {
 public:
-  GMLExport(AlgorithmContext context):ExportModule(context)
+  PLUGININFORMATION("GML Export","Auber David","31/07/2001","Exports a Tulip graph in a file using the GML format (used by Graphlet)","1.0", "File")
+  std::string fileExtension() const {
+    return "gml";
+  }
+
+  GMLExport(tlp::PluginContext* context) : tlp::ExportModule(context)
   {}
 
   ~GMLExport() {}
@@ -162,5 +166,5 @@ public:
     return true;
   }
 };
-/*@}*/
-EXPORTPLUGIN(GMLExport,"GML","Auber David","31/07/2001","GML Export plugin","1.0")
+
+PLUGIN(GMLExport)
