@@ -28,12 +28,15 @@
 #include <tulip/Glyph.h>
 #include <tulip/Graph.h>
 #include <tulip/GlRect.h>
+#include <tulip/GlGraphRenderingParameters.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
 /** \addtogroup glyph */
-/*@{*/
+
 /// A 2D glyph.
 /**
  * This glyph draws a textured square using the "viewTexture"
@@ -44,7 +47,8 @@ using namespace tlp;
  */
 class Billboard : public Glyph {
 public:
-  Billboard(GlyphContext *gc=NULL);
+  GLYPHINFORMATION("2D - Billboard", "Gerald Gainant", "08/03/2004", "Textured billboard", "1.0", NodeShape::Billboard)
+  Billboard(const tlp::PluginContext* context = NULL);
   virtual ~Billboard();
   virtual void draw(node n,float lod);
   virtual Coord getAnchor(const Coord &vector) const;
@@ -54,14 +58,14 @@ protected:
   static GlRect *rect;
 };
 
-GlRect* Billboard::rect=0;
+GlRect* Billboard::rect=NULL;
 
-GLYPHPLUGIN(Billboard, "2D - Billboard", "Gerald Gainant", "08/03/2004", "Textured billboard", "1.0", 7);
+PLUGIN(Billboard)
 
 //===================================================================================
-Billboard::Billboard(GlyphContext *gc): Glyph(gc) {
+Billboard::Billboard(const tlp::PluginContext* context): Glyph(context) {
   if(!rect)
-    rect = new GlRect(Coord(0,0,0),Size(1,1,0),Color(0,0,0,255),Color(0,0,0,255));
+    rect = new GlRect(Coord(0,0,0), 1., 1., Color(0,0,0,255),Color(0,0,0,255));
 }
 //========================================================
 Billboard::~Billboard() {
@@ -70,7 +74,6 @@ Billboard::~Billboard() {
 void Billboard::draw(node n,float lod) {
 
   rect->setFillColor(glGraphInputData->getElementColor()->getNodeValue(n));
-  rect->setOutlineColor(glGraphInputData->getElementBorderColor()->getNodeValue(n));
 
   string texFile = glGraphInputData->getElementTexture()->getNodeValue(n);
 
@@ -84,10 +87,14 @@ void Billboard::draw(node n,float lod) {
 
   double borderWidth=glGraphInputData->getElementBorderWidth()->getNodeValue(n);
 
-  if (borderWidth < 1e-6)
-    borderWidth=1e-6;
-
-  rect->setOutlineSize(static_cast<float>(borderWidth));
+  if (borderWidth > 0) {
+    rect->setOutlineMode(true);
+    rect->setOutlineColor(glGraphInputData->getElementBorderColor()->getNodeValue(n));
+    rect->setOutlineSize(borderWidth);
+  }
+  else {
+    rect->setOutlineMode(false);
+  }
 
   // setup orientation
   float mdlM[16];
@@ -126,4 +133,4 @@ Coord Billboard::getAnchor(const Coord & vector ) const {
     return v;
 }
 //========================================================
-/*@}*/
+
