@@ -29,66 +29,15 @@
 #include <tulip/GlDisplayListManager.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/OpenGlConfigManager.h>
-
+#include <tulip/GlGraphInputData.h>
 #include <tulip/Graph.h>
 #include <tulip/GlTools.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
-/** \addtogroup glyph */
-/*@{*/
-/// A 3D glyph.
-/** This glyph draws a christmas tree special for christmas release of 2008
- */
-class ChristmasTree: public Glyph, public EdgeExtremityGlyphFrom3DGlyph {
-public:
-  ChristmasTree(GlyphContext *gc = NULL);
-  ChristmasTree(EdgeExtremityGlyphContext *gc);
-  virtual void draw(node n, float lod);
-  virtual void draw(edge e, node n, const Color& glyphColor,const Color &borderColor, float lod);
-
-protected:
-  void drawTree();
-
-};
-
-GLYPHPLUGIN(ChristmasTree, "3D - ChristmasTree", "Morgan Mathiaut", "16/12/2008", "Christmas tree", "1.0" , 28)
-EEGLYPHPLUGIN(ChristmasTree,"3D - ChristmasTree", "Morgan Mathiaut", "16/12/2008", "Christmas tree", "1.0" , 28)
-
-//===================================================================================
-ChristmasTree::ChristmasTree(GlyphContext *gc) :
-  Glyph(gc), EdgeExtremityGlyphFrom3DGlyph(NULL) {
-}
-ChristmasTree::ChristmasTree(EdgeExtremityGlyphContext *gc) :
-  Glyph(NULL), EdgeExtremityGlyphFrom3DGlyph(gc) {
-}
-//=======================================================
-void ChristmasTree::draw(node n, float) {
-  drawTree();
-  glRotatef(-90., 1., 0., 0.);
-  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
-  GlDisplayListManager::getInst().callDisplayList("ChristmasTree_tree");
-  setMaterial(glGraphInputData->getElementColor()->getNodeValue(n));
-  GlDisplayListManager::getInst().callDisplayList("ChristmasTree_sphere");
-  setMaterial(Color(255, 255, 255, 50));
-  GlDisplayListManager::getInst().callDisplayList("ChristmasTree_outsphere");
-  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
-}
-
-void ChristmasTree::draw(edge, node, const Color& glyphColor,const Color&, float) {
-  glEnable(GL_LIGHTING);
-  drawTree();
-  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
-  GlDisplayListManager::getInst().callDisplayList("ChristmasTree_tree");
-  setMaterial(glyphColor);
-  GlDisplayListManager::getInst().callDisplayList("ChristmasTree_sphere");
-  setMaterial(Color(255, 255, 255, 50));
-  GlDisplayListManager::getInst().callDisplayList("ChristmasTree_outsphere");
-  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
-}
-
-void ChristmasTree::drawTree() {
+void drawTree() {
   if (GlDisplayListManager::getInst().beginNewDisplayList(
         "ChristmasTree_tree")) {
     GLUquadricObj *quadratic1;
@@ -167,4 +116,34 @@ void ChristmasTree::drawTree() {
   }
 }
 
-/*@}*/
+/** \addtogroup glyph */
+
+/// A 3D glyph.
+/** This glyph draws a christmas tree special for christmas release of 2008
+ */
+class ChristmasTree: public Glyph {
+public:
+  GLYPHINFORMATION("3D - ChristmasTree", "Morgan Mathiaut", "16/12/2008", "Christmas tree", "1.0" , NodeShape::ChristmasTree)
+  ChristmasTree(const tlp::PluginContext* context = NULL);
+  virtual void draw(node n, float lod);
+};
+PLUGIN(ChristmasTree)
+
+ChristmasTree::ChristmasTree(const tlp::PluginContext* context) :
+  Glyph(context) {
+}
+void ChristmasTree::draw(node n, float) {
+  drawTree();
+  glRotatef(-90., 1., 0., 0.);
+  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
+  GlDisplayListManager::getInst().callDisplayList("ChristmasTree_tree");
+  setMaterial(glGraphInputData->getElementColor()->getNodeValue(n));
+  GlDisplayListManager::getInst().callDisplayList("ChristmasTree_sphere");
+  setMaterial(Color(255, 255, 255, 50));
+  GlDisplayListManager::getInst().callDisplayList("ChristmasTree_outsphere");
+  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
+}
+
+
+
+
