@@ -23,56 +23,58 @@
 #include <tulip/GlDisplayListManager.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/OpenGlConfigManager.h>
-
+#include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/Graph.h>
 #include <tulip/Glyph.h>
 #include <tulip/EdgeExtremityGlyph.h>
 #include <tulip/GlTools.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
+void drawCone() {
+  GLUquadricObj *quadratic;
+  quadratic = gluNewQuadric();
+  gluQuadricNormals(quadratic, GLU_SMOOTH);
+  gluQuadricTexture(quadratic, GL_TRUE);
+  glTranslatef(0.0f, 0.0f, -0.5f);
+  gluQuadricOrientation(quadratic, GLU_OUTSIDE);
+  gluCylinder(quadratic, 0.5f, 0.0f, 1.0f, 10, 10);
+  gluQuadricOrientation(quadratic, GLU_INSIDE);
+  gluDisk(quadratic, 0.0f, 0.5f, 10, 10);
+  gluDeleteQuadric(quadratic);
+}
+
 /** \addtogroup glyph */
-/*@{*/
+
 /// A 3D glyph.
 /**
  * This glyph draws a textured cone using the "viewTexture" node
  * property value. If this property has no value, the cone is then colored
  * using the "viewColor" node property value.
  */
-//===========================================================
-class Cone: public Glyph, public EdgeExtremityGlyphFrom3DGlyph {
+class Cone: public Glyph {
 public:
-  Cone(GlyphContext *gc = NULL);
-  Cone(EdgeExtremityGlyphContext *gc);
+  GLYPHINFORMATION("3D - Cone", "Bertrand Mathieu", "09/07/2002", "Textured cone", "1.0", NodeShape::Cone)
+  Cone(const tlp::PluginContext* context = NULL);
   virtual ~Cone();
   virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
   virtual void draw(node n, float lod);
   virtual Coord getAnchor(const Coord &vector) const;
-  virtual void draw(edge e, node n, const Color& glyphColor, const Color &borderColor, float lod);
-
-private:
-  void drawCone();
 };
-//===========================================================
-GLYPHPLUGIN(Cone, "3D - Cone", "Bertrand Mathieu", "09/07/2002", "Textured cone", "1.0", 3)
-EEGLYPHPLUGIN(Cone, "3D - Cone", "Bertrand Mathieu", "09/07/2002", "Cone", "1.0", 3)
-//===================================================================================
-Cone::Cone(GlyphContext *gc) :
-  Glyph(gc), EdgeExtremityGlyphFrom3DGlyph(NULL) {
+PLUGIN(Cone)
+
+Cone::Cone(const tlp::PluginContext* context) :
+  Glyph(context) {
 }
-Cone::Cone(EdgeExtremityGlyphContext *gc) :
-  Glyph(NULL), EdgeExtremityGlyphFrom3DGlyph(gc) {
-}
-//===========================================================
 Cone::~Cone() {
 }
-//===========================================================
 void Cone::getIncludeBoundingBox(BoundingBox& boundingBox,node) {
   boundingBox[0] = Coord(-0.25, -0.25, 0);
   boundingBox[1] = Coord(0.25, 0.25, 0.5);
 }
-//===========================================================
 void Cone::draw(node n, float) {
   if (GlDisplayListManager::getInst().beginNewDisplayList("Cone_cone")) {
     drawCone();
@@ -93,7 +95,6 @@ void Cone::draw(node n, float) {
 
   GlTextureManager::getInst().desactivateTexture();
 }
-//===========================================================
 Coord Cone::getAnchor(const Coord &vector) const {
   Coord anchor = vector;
 
@@ -109,13 +110,13 @@ Coord Cone::getAnchor(const Coord &vector) const {
   y1 = 0;
   vx1 = sqrt(x * x + y * y);
   vy1 = z;
-  py = -1.0f * (vy1 * (vx0 / vy0 * y0 + x0 - x1) - vx1 * y1) / (vx1 - vy1
+  py = -1.0 * (vy1 * (vx0 / vy0 * y0 + x0 - x1) - vx1 * y1) / (vx1 - vy1
        / vy0 * vx0);
   px = vx0 * (py - y0) / vy0 + x0;
 
-  if (fabsf(py) > 0.5f) {
+  if (fabsf(py) > 0.5) {
     n = anchor.norm();
-    py = n * 0.5f / fabsf(z);
+    py = n * 0.5 / fabsf(z);
     anchor.setX(x * py / n);
     anchor.setY(y * py / n);
     anchor.setZ(z * py / n);
@@ -129,40 +130,36 @@ Coord Cone::getAnchor(const Coord &vector) const {
   return anchor;
 }
 
-void Cone::draw(edge e, node, const Color& glyphColor,const Color&, float) {
-  glEnable(GL_LIGHTING);
+class EECone: public EdgeExtremityGlyph {
+public:
+  GLYPHINFORMATION("3D - Cone extremity", "Bertrand Mathieu", "09/07/2002", "Textured cone for edge extremities", "1.0", EdgeExtremityShape::Cone)
 
-  if (GlDisplayListManager::getInst().beginNewDisplayList("Cone_cone")) {
-    drawCone();
-    GlDisplayListManager::getInst().endNewDisplayList();
+  EECone(const tlp::PluginContext *context): EdgeExtremityGlyph(context) {
   }
+  virtual ~EECone() {}
 
-  setMaterial(glyphColor);
-  string texFile = edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e);
+  virtual void draw(edge e, node /*n*/, const Color& glyphColor,const Color &/*borderColor*/, float /*lod*/) {
+    glEnable(GL_LIGHTING);
 
-  if (texFile != "") {
-    string texturePath =
-      edgeExtGlGraphInputData->parameters->getTexturePath();
-    GlTextureManager::getInst().activateTexture(texturePath + texFile);
+    if (GlDisplayListManager::getInst().beginNewDisplayList("Cone_cone")) {
+      drawCone();
+      GlDisplayListManager::getInst().endNewDisplayList();
+    }
+
+    setMaterial(glyphColor);
+    string texFile = edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e);
+
+    if (texFile != "") {
+      string texturePath =
+        edgeExtGlGraphInputData->parameters->getTexturePath();
+      GlTextureManager::getInst().activateTexture(texturePath + texFile);
+    }
+
+    OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
+    GlDisplayListManager::getInst().callDisplayList("Cone_cone");
+    OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
+    GlTextureManager::getInst().desactivateTexture();
   }
+};
 
-  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
-  GlDisplayListManager::getInst().callDisplayList("Cone_cone");
-  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
-  GlTextureManager::getInst().desactivateTexture();
-}
-
-void Cone::drawCone() {
-  GLUquadricObj *quadratic;
-  quadratic = gluNewQuadric();
-  gluQuadricNormals(quadratic, GLU_SMOOTH);
-  gluQuadricTexture(quadratic, GL_TRUE);
-  glTranslatef(0.0f, 0.0f, -0.5f);
-  gluQuadricOrientation(quadratic, GLU_OUTSIDE);
-  gluCylinder(quadratic, 0.5f, 0.0f, 1.0f, 10, 10);
-  gluQuadricOrientation(quadratic, GLU_INSIDE);
-  gluDisk(quadratic, 0.0f, 0.5f, 10, 10);
-  gluDeleteQuadric(quadratic);
-}
-//===========================================================
-/*@}*/
+PLUGIN(EECone)
