@@ -26,70 +26,17 @@
 #include <tulip/Coord.h>
 #include <tulip/Glyph.h>
 #include <tulip/EdgeExtremityGlyph.h>
-
+#include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/Graph.h>
 #include <tulip/GlBox.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
-/** \addtogroup glyph */
-/*@{*/
-/// A 3D glyph.
-/** This glyph draws a textured cube using the "viewTexture" node
- * property value. If this property has no value, the cube is then colored
- * using the "viewColor" node property value.
- */
-class Cube: public Glyph, public EdgeExtremityGlyphFrom3DGlyph {
-public:
-  Cube(GlyphContext *gc = NULL);
-  Cube(EdgeExtremityGlyphContext *gc);
-  virtual ~Cube();
-  virtual void draw(node n, float lod);
-  virtual Coord getAnchor(const Coord & vector) const;
-  virtual void draw(edge e, node n, const Color& glyphColor,const Color &borderColor, float lod);
-  virtual void draw(const Color &fillColor,const std::string &textureName, float lod);
-
-protected:
-
-  static GlBox* box;
-
-};
-
-GlBox* Cube::box=0;
-
-GLYPHPLUGIN(Cube, "3D - Cube", "Bertrand Mathieu", "09/07/2002", "Textured cube", "1.0" , 0)
-EEGLYPHPLUGIN(Cube,"3D - Cube","Bertrand Mathieu", "09/07/2002", "Textured cube", "1.0" , 0)
-//===================================================================================
-Cube::Cube(GlyphContext *gc) :
-  Glyph(gc), EdgeExtremityGlyphFrom3DGlyph(NULL) {
-  if(!box)
-    box = new GlBox(Coord(0,0,0),Size(1,1,1),Color(0,0,0,255),Color(0,0,0,255));
-}
-
-Cube::Cube(EdgeExtremityGlyphContext *gc) :
-  Glyph(NULL), EdgeExtremityGlyphFrom3DGlyph(gc) {
-  if(!box)
-    box = new GlBox(Coord(0,0,0),Size(1,1,1),Color(0,0,0,255),Color(0,0,0,255));
-}
-//=======================================================
-Cube::~Cube() {
-}
-//=======================================================
-void Cube::draw(node n, float lod) {
-  draw(glGraphInputData->getElementColor()->getNodeValue(n),
-       glGraphInputData->getElementTexture()->getNodeValue(n),
-       lod);
-}
-
-void Cube::draw(edge, node n, const Color& glyphColor,const Color&, float lod) {
-  glEnable(GL_LIGHTING);
-  draw(glyphColor,
-       edgeExtGlGraphInputData->getElementTexture()->getNodeValue(n),
-       lod);
-}
-
-void Cube::draw(const Color &fillColor,const std::string &textureName, float lod) {
+static GlBox* box = NULL;
+void drawBox(const Color &fillColor, const Color &outlineColor, const float outlineSize, const std::string &textureName, float lod, GlGraphInputData *glGraphInputData) {
   if (textureName.size() != 0) {
     const string& texturePath=glGraphInputData->parameters->getTexturePath();
     box->setTextureName(texturePath+textureName);
@@ -98,13 +45,43 @@ void Cube::draw(const Color &fillColor,const std::string &textureName, float lod
     box->setTextureName("");
 
   box->setFillColor(fillColor);
-  box->setOutlineColor(Color(0,0,0,0));
+  box->setOutlineSize(outlineSize);
+  box->setOutlineColor(outlineColor);
 
   box->draw(lod,NULL);
 }
 
+/** \addtogroup glyph */
 
-//=======================================================
+/// A 3D glyph.
+/** This glyph draws a textured cube using the "viewTexture" node
+ * property value. If this property has no value, the cube is then colored
+ * using the "viewColor" node property value.
+ */
+class Cube: public Glyph {
+public:
+  GLYPHINFORMATION("3D - Cube", "Bertrand Mathieu", "09/07/2002", "Textured cube", "1.0" , NodeShape::Cube)
+  Cube(const tlp::PluginContext* context = NULL);
+  virtual ~Cube();
+  virtual void draw(node n, float lod);
+  virtual Coord getAnchor(const Coord & vector) const;
+protected:
+};
+PLUGIN(Cube)
+Cube::Cube(const tlp::PluginContext* context) :
+  Glyph(context) {
+  if(!box)
+    box = new GlBox(Coord(0,0,0),Size(1,1,1),Color(0,0,0,255),Color(0,0,0,255));
+}
+Cube::~Cube() {
+}
+void Cube::draw(node n, float lod) {
+  drawBox(glGraphInputData->getElementColor()->getNodeValue(n),
+          glGraphInputData->getElementBorderColor()->getNodeValue(n),
+          glGraphInputData->getElementBorderWidth()->getNodeValue(n),
+          glGraphInputData->getElementTexture()->getNodeValue(n),
+          lod, glGraphInputData);
+}
 Coord Cube::getAnchor(const Coord & vector) const {
   float x, y, z, fmax;
   vector.get(x, y, z);
@@ -115,4 +92,25 @@ Coord Cube::getAnchor(const Coord & vector) const {
   else
     return vector;
 }
-/*@}*/
+
+
+class EECube: public EdgeExtremityGlyph {
+public:
+  GLYPHINFORMATION("3D - Cube extremity", "Bertrand Mathieu", "09/07/2002", "Textured cube for edge extremities", "1.0" , EdgeExtremityShape::Cube)
+
+  EECube(const tlp::PluginContext* context): EdgeExtremityGlyph(context) {
+    if(!box)
+      box = new GlBox(Coord(0,0,0),Size(1,1,1),Color(0,0,0,255),Color(0,0,0,255));
+  }
+
+  void draw(edge e, node n, const Color& glyphColor,const Color& borderColor, float lod) {
+    glEnable(GL_LIGHTING);
+    drawBox(glyphColor,
+            borderColor,
+            edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e),
+            edgeExtGlGraphInputData->getElementTexture()->getNodeValue(n),
+            lod, edgeExtGlGraphInputData);
+  }
+};
+
+PLUGIN(EECube)
