@@ -21,86 +21,20 @@
 #include <tulip/StringProperty.h>
 #include <tulip/ColorProperty.h>
 #include <tulip/DoubleProperty.h>
-
+#include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/Glyph.h>
 #include <tulip/EdgeExtremityGlyph.h>
 #include <tulip/Graph.h>
 #include <tulip/GlBox.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
-/** \addtogroup glyph */
-/*@{*/
-/// A 3D glyph.
-/** This glyph draws a transparent cube using the "viewBorderColor" node
- * property value to draw its edges.
- */
-class CubeOutLinedTransparent: public Glyph,
-  public EdgeExtremityGlyphFrom3DGlyph {
-public:
-  CubeOutLinedTransparent(GlyphContext *gc = NULL);
-  CubeOutLinedTransparent(EdgeExtremityGlyphContext *gc);
-  virtual ~CubeOutLinedTransparent();
-  virtual void draw(node n, float lod);
-  virtual void draw(edge e, node n, const Color& glyphColor, const Color &borderColor, float lod);
-  virtual void draw(const Color &borderColor,float borderWidth,const std::string &textureName, float lod);
-  virtual Coord getAnchor(const Coord & vector) const;
 
-protected:
-
-  static GlBox* box;
-
-};
-
-GlBox* CubeOutLinedTransparent::box=0;
-
-GLYPHPLUGIN(CubeOutLinedTransparent, "3D - Cube OutLined Transparent", "David Auber", "09/07/2002", "Textured cubeOutLined", "1.0", 9)
-EEGLYPHPLUGIN(CubeOutLinedTransparent, "3D - Cube OutLined Transparent", "David Auber", "09/07/2002", "Textured cubeOutLined", "1.0", 9)
-
-//===================================================================================
-CubeOutLinedTransparent::CubeOutLinedTransparent(GlyphContext *gc) :
-  Glyph(gc), EdgeExtremityGlyphFrom3DGlyph(NULL) {
-  if(!box)
-    box = new GlBox(Coord(0,0,0),Size(1,1,1),Color(0,0,0,255),Color(0,0,0,255));
-}
-CubeOutLinedTransparent::CubeOutLinedTransparent(EdgeExtremityGlyphContext *gc) :
-  Glyph(NULL), EdgeExtremityGlyphFrom3DGlyph(gc) {
-  if(!box)
-    box = new GlBox(Coord(0,0,0),Size(1,1,1),Color(0,0,0,255),Color(0,0,0,255));
-}
-
-CubeOutLinedTransparent::~CubeOutLinedTransparent() {
-}
-
-void CubeOutLinedTransparent::draw(node n, float lod) {
-  string textureName=glGraphInputData->getElementTexture()->getNodeValue(n);
-
-  if(textureName!="")
-    textureName=glGraphInputData->parameters->getTexturePath()+textureName;
-
-  draw(glGraphInputData->getElementBorderColor()->getNodeValue(n),
-       static_cast<float>(glGraphInputData->getElementBorderWidth()->getNodeValue(n)),
-       textureName,
-       lod);
-}
-
-void CubeOutLinedTransparent::draw(edge e, node, const Color &borderColor, const Color&,
-                                   float lod) {
-  glEnable(GL_LIGHTING);
-  string textureName=edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e);
-
-  if(textureName!="")
-    textureName=edgeExtGlGraphInputData->parameters->getTexturePath()+textureName;
-
-  draw(borderColor,
-       static_cast<float>(edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e)),
-       textureName,
-       lod);
-  glDisable(GL_LIGHTING);
-}
-
-void CubeOutLinedTransparent::draw(const Color &borderColor,float borderWidth,const std::string &textureName, float lod) {
+static GlBox* box = NULL;
+void drawBox(const Color &borderColor,float borderWidth,const std::string &textureName, float lod, GlGraphInputData* glGraphInputData) {
   if (textureName.size() != 0) {
     const string& texturePath=glGraphInputData->parameters->getTexturePath();
     box->setTextureName(texturePath+textureName);
@@ -115,11 +49,49 @@ void CubeOutLinedTransparent::draw(const Color &borderColor,float borderWidth,co
   if(lineWidth < 1e-6)
     lineWidth=1e-6;
 
-  box->setOutlineSize(static_cast<float>(lineWidth));
+  box->setOutlineSize(lineWidth);
 
   box->draw(lod,NULL);
 }
 
+
+/** \addtogroup glyph */
+
+/// A 3D glyph.
+/** This glyph draws a transparent cube using the "viewBorderColor" node
+ * property value to draw its edges.
+ */
+class CubeOutLinedTransparent: public Glyph {
+public:
+  GLYPHINFORMATION("3D - Cube OutLined Transparent", "David Auber", "09/07/2002", "Textured cubeOutLined", "1.0", NodeShape::CubeOutlinedTransparent)
+  CubeOutLinedTransparent(const tlp::PluginContext *context = NULL);
+  virtual ~CubeOutLinedTransparent();
+  virtual void draw(node n, float lod);
+  virtual Coord getAnchor(const Coord & vector) const;
+};
+PLUGIN(CubeOutLinedTransparent)
+
+CubeOutLinedTransparent::CubeOutLinedTransparent(const tlp::PluginContext* context) :
+  Glyph(context) {
+  if(!box)
+    box = new GlBox(Coord(0,0,0),Size(1,1,1),Color(0,0,0,255),Color(0,0,0,255));
+}
+
+CubeOutLinedTransparent::~CubeOutLinedTransparent() {
+}
+
+void CubeOutLinedTransparent::draw(node n, float lod) {
+  string textureName=glGraphInputData->getElementTexture()->getNodeValue(n);
+
+  if(textureName!="")
+    textureName=glGraphInputData->parameters->getTexturePath()+textureName;
+
+  drawBox(glGraphInputData->getElementBorderColor()->getNodeValue(n),
+          glGraphInputData->getElementBorderWidth()->getNodeValue(n),
+          textureName,
+          lod,glGraphInputData);
+}
+
 Coord CubeOutLinedTransparent::getAnchor(const Coord & vector) const {
   float x, y, z, fmax;
   vector.get(x, y, z);
@@ -131,4 +103,32 @@ Coord CubeOutLinedTransparent::getAnchor(const Coord & vector) const {
     return vector;
 }
 
-/*@}*/
+
+class EECubeOutlinedTransparent: public EdgeExtremityGlyph {
+public:
+  GLYPHINFORMATION("3D - Cube OutLined Transparent extremity", "David Auber", "09/07/2002", "Textured cubeOutLined for edge extremities", "1.0", EdgeExtremityShape::CubeOutlinedTransparent)
+
+  EECubeOutlinedTransparent(const tlp::PluginContext* context): EdgeExtremityGlyph(context) {
+    if (!box)
+      box = new GlBox(Coord(0,0,0),Size(1,1,1),Color(0,0,0,255),Color(0,0,0,255));
+  }
+
+  void draw(edge e, node, const Color &borderColor, const Color&,
+            float lod) {
+    glEnable(GL_LIGHTING);
+    string textureName=edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e);
+
+    if(textureName!="")
+      textureName=edgeExtGlGraphInputData->parameters->getTexturePath()+textureName;
+
+    drawBox(borderColor,
+            edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e),
+            textureName,
+            lod,edgeExtGlGraphInputData);
+    glDisable(GL_LIGHTING);
+  }
+};
+PLUGIN(EECubeOutlinedTransparent)
+
+
+
