@@ -27,10 +27,29 @@
 #include <tulip/Glyph.h>
 #include <tulip/EdgeExtremityGlyph.h>
 #include <tulip/GlTools.h>
+#include <tulip/GlGraphRenderingParameters.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
+void drawCylinder() {
+  GLUquadricObj *quadratic;
+  quadratic = gluNewQuadric();
+  gluQuadricNormals(quadratic, GLU_SMOOTH);
+  gluQuadricTexture(quadratic, GL_TRUE);
+  glTranslatef(0.0f, 0.0f, -0.5f);
+  gluQuadricOrientation(quadratic, GLU_INSIDE);
+  gluDisk(quadratic, 0.0f, 0.5f, 10, 10);
+  gluQuadricOrientation(quadratic, GLU_OUTSIDE);
+  gluCylinder(quadratic, 0.5f, 0.5f, 1.0f, 10, 10);
+  glTranslatef(0.0f, 0.0f, 1.0f);
+  gluDisk(quadratic, 0.0f, 0.5f, 10, 10);
+  gluDeleteQuadric(quadratic);
+
+}
+
 /** \addtogroup glyph */
 /// A 3D glyph.
 /**
@@ -38,37 +57,26 @@ using namespace tlp;
  * property value. If this property has no value, the cylinder is then colored
  * using the "viewColor" node property value.
  */
-class Cylinder: public Glyph, public EdgeExtremityGlyphFrom3DGlyph {
+class Cylinder: public Glyph {
 public:
-  Cylinder(GlyphContext *gc = NULL);
-  Cylinder(EdgeExtremityGlyphContext *gc);
+  GLYPHINFORMATION("3D - Cylinder", "Bertrand Mathieu", "31/07/2002", "Textured Cylinder", "1.0", NodeShape::Cylinder)
+  Cylinder(const tlp::PluginContext* context = NULL);
   virtual ~Cylinder();
   virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
   virtual void draw(node n, float lod);
-  virtual void draw(edge e, node n, const Color& glyphColor, const Color &borderColor, float lod);
   virtual Coord getAnchor(const Coord &vector) const;
-
-private:
-  inline void drawCylinder();
 };
-GLYPHPLUGIN(Cylinder, "3D - Cylinder", "Bertrand Mathieu", "31/07/2002", "Textured Cylinder", "1.0", 6)
-EEGLYPHPLUGIN(Cylinder,"3D - Cylinder","Bertrand Mathieu", "31/07/2002", "Textured Cylinder", "1.0", 6)
-//=================================================================================================
-Cylinder::Cylinder(GlyphContext *gc) :
-  Glyph(gc), EdgeExtremityGlyphFrom3DGlyph(NULL) {
+PLUGIN(Cylinder)
+
+Cylinder::Cylinder(const tlp::PluginContext* context) :
+  Glyph(context) {
 }
-Cylinder::Cylinder(EdgeExtremityGlyphContext *gc) :
-  Glyph(NULL), EdgeExtremityGlyphFrom3DGlyph(gc) {
-}
-//=================================================================================================
 Cylinder::~Cylinder() {
 }
-//=====================================================
 void Cylinder::getIncludeBoundingBox(BoundingBox &boundingBox,node) {
   boundingBox[0] = Coord(-0.35f, -0.35f, 0);
   boundingBox[1] = Coord(0.35f, 0.35f, 1);
 }
-//=================================================================================================
 void Cylinder::draw(node n, float) {
   if (GlDisplayListManager::getInst().beginNewDisplayList("Cylinder_cylinder")) {
     drawCylinder();
@@ -88,7 +96,6 @@ void Cylinder::draw(node n, float) {
   OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
   GlTextureManager::getInst().desactivateTexture();
 }
-//=================================================================================================
 Coord Cylinder::getAnchor(const Coord &vector) const {
   Coord anchor = vector;
   float x, y, z, n;
@@ -111,44 +118,37 @@ Coord Cylinder::getAnchor(const Coord &vector) const {
 
   return Coord(x, y, z);
 }
-//=================================================================================================
 
-void Cylinder::draw(edge, node n, const Color& glyphColor, const Color&, float) {
-  glEnable(GL_LIGHTING);
+class EECylinder: public EdgeExtremityGlyph {
+public:
+  GLYPHINFORMATION("3D - Cylinder extremity", "Bertrand Mathieu", "31/07/2002", "Textured Cylinder for edge extremities", "1.0", EdgeExtremityShape::Cylinder)
 
-  if (GlDisplayListManager::getInst().beginNewDisplayList("Cylinder_cylinder")) {
-    drawCylinder();
-    GlDisplayListManager::getInst().endNewDisplayList();
+  EECylinder(const tlp::PluginContext* context): EdgeExtremityGlyph(context) {
   }
 
-  setMaterial(glyphColor);
-  string texFile = edgeExtGlGraphInputData->getElementTexture()->getNodeValue(n);
+  void draw(edge, node n, const Color& glyphColor, const Color&, float) {
+    glEnable(GL_LIGHTING);
 
-  if (texFile != "") {
-    string texturePath =
-      edgeExtGlGraphInputData->parameters->getTexturePath();
-    GlTextureManager::getInst().activateTexture(texturePath + texFile);
+    if (GlDisplayListManager::getInst().beginNewDisplayList("Cylinder_cylinder")) {
+      drawCylinder();
+      GlDisplayListManager::getInst().endNewDisplayList();
+    }
+
+    setMaterial(glyphColor);
+    string texFile = edgeExtGlGraphInputData->getElementTexture()->getNodeValue(n);
+
+    if (texFile != "") {
+      string texturePath =
+        edgeExtGlGraphInputData->parameters->getTexturePath();
+      GlTextureManager::getInst().activateTexture(texturePath + texFile);
+    }
+
+    OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
+    GlDisplayListManager::getInst().callDisplayList("Cylinder_cylinder");
+    OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
+    GlTextureManager::getInst().desactivateTexture();
   }
+};
 
-  OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
-  GlDisplayListManager::getInst().callDisplayList("Cylinder_cylinder");
-  OpenGlConfigManager::getInst().desactivatePolygonAntiAliasing();
-  GlTextureManager::getInst().desactivateTexture();
-}
+PLUGIN(EECylinder)
 
-void Cylinder::drawCylinder() {
-  GLUquadricObj *quadratic;
-  quadratic = gluNewQuadric();
-  gluQuadricNormals(quadratic, GLU_SMOOTH);
-  gluQuadricTexture(quadratic, GL_TRUE);
-  glTranslatef(0.0f, 0.0f, -0.5f);
-  gluQuadricOrientation(quadratic, GLU_INSIDE);
-  gluDisk(quadratic, 0.0f, 0.5f, 10, 10);
-  gluQuadricOrientation(quadratic, GLU_OUTSIDE);
-  gluCylinder(quadratic, 0.5f, 0.5f, 1.0f, 10, 10);
-  glTranslatef(0.0f, 0.0f, 1.0f);
-  gluDisk(quadratic, 0.0f, 0.5f, 10, 10);
-  GlDisplayListManager::getInst().endNewDisplayList();
-  gluDeleteQuadric(quadratic);
-
-}
