@@ -28,61 +28,65 @@
 #include <tulip/Glyph.h>
 #include <tulip/EdgeExtremityGlyph.h>
 #include <tulip/GlRegularPolygon.h>
-
+#include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/Graph.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
+static GlRegularPolygon *diamond = NULL;
+void drawDiamond(const Color &fillColor,
+                 const Color &borderColor,
+                 float borderWidth,
+                 const std::string &textureName,
+                 float lod) {
+
+  diamond->setFillColor(fillColor);
+
+  if (borderWidth > 0) {
+    diamond->setOutlineMode(true);
+    diamond->setOutlineColor(borderColor);
+    diamond->setOutlineSize(borderWidth);
+  }
+  else {
+    diamond->setOutlineMode(false);
+  }
+
+  diamond->setTextureName(textureName);
+  diamond->draw(lod,NULL);
+}
+
 /** \addtogroup glyph */
-/*@{*/
+
 /// A 2D glyph
 /**
  * This glyph draws a textured diamond using the "viewTexture"
  * node property value. If this property has no value, the diamond
  * is then colored using the "viewColor" node property value.
  */
-class Diamond: public Glyph, public EdgeExtremityGlyphFrom2DGlyph {
+class Diamond: public Glyph {
 public:
-  Diamond(GlyphContext *gc = NULL);
-  Diamond(EdgeExtremityGlyphContext *gc);
+  GLYPHINFORMATION("2D - Diamond", "Patrick Mary", "23/06/2011", "Textured Diamond", "1.0", NodeShape::Diamond)
+  Diamond(const tlp::PluginContext *context = NULL);
   virtual ~Diamond();
   virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
   virtual void draw(node n, float lod);
-  virtual void draw(edge e, node n, const Color& glyphColor, const Color &borderColor, float lod);
-  virtual void draw(const Color &fillColor,const Color &borderColor,float borderWidth,const std::string &textureName, float lod);
   virtual Coord getAnchor(const Coord &vector) const;
-
-protected :
-
-  static GlRegularPolygon *diamond;
 };
-
-GlRegularPolygon* Diamond::diamond=0;
-
-//=====================================================
-GLYPHPLUGIN(Diamond, "2D - Diamond", "Patrick Mary", "23/06/2011", "Textured Diamond", "1.0", 5)
-EEGLYPHPLUGIN(Diamond,"2D - Diamond", "David Auber", "23/06/2011", "Textured Diamond", "1.0", 5)
-//===================================================================================
-Diamond::Diamond(GlyphContext *gc) :
-  Glyph(gc), EdgeExtremityGlyphFrom2DGlyph(NULL) {
+PLUGIN(Diamond)
+Diamond::Diamond(const tlp::PluginContext* context) :
+  Glyph(context) {
   if(!diamond)
     diamond=new GlRegularPolygon(Coord(0,0,0),Size(.5,.5,0), 4);
 }
-Diamond::Diamond(EdgeExtremityGlyphContext *gc) :
-  Glyph(NULL), EdgeExtremityGlyphFrom2DGlyph(gc) {
-  if(!diamond)
-    diamond=new GlRegularPolygon(Coord(0,0,0), Size(.5,.5,0), 4);
-}
-//=====================================================
 Diamond::~Diamond() {
 }
-//=====================================================
 void Diamond::getIncludeBoundingBox(BoundingBox &boundingBox,node) {
-  boundingBox[0] = Coord(-0.35, -0.35, 0);
-  boundingBox[1] = Coord(0.35, 0.35, 0);
+  boundingBox[0] = Coord(-0.35f, -0.35f, 0);
+  boundingBox[1] = Coord(0.35f, 0.35f, 0);
 }
-//=====================================================
 void Diamond::draw(node n, float lod) {
   diamond->setLightingMode(true);
   string textureName=glGraphInputData->getElementTexture()->getNodeValue(n);
@@ -90,46 +94,12 @@ void Diamond::draw(node n, float lod) {
   if(textureName!="")
     textureName=glGraphInputData->parameters->getTexturePath()+textureName;
 
-  draw(glGraphInputData->getElementColor()->getNodeValue(n),
-       glGraphInputData->getElementBorderColor()->getNodeValue(n),
-       glGraphInputData->getElementBorderWidth()->getNodeValue(n),
-       textureName,
-       lod);
+  drawDiamond(glGraphInputData->getElementColor()->getNodeValue(n),
+              glGraphInputData->getElementBorderColor()->getNodeValue(n),
+              glGraphInputData->getElementBorderWidth()->getNodeValue(n),
+              textureName,
+              lod);
 }
-
-void Diamond::draw(edge e,
-                   node,
-                   const Color & glyphColor,
-                   const Color &borderColor,
-                   float lod) {
-  diamond->setLightingMode(false);
-  string textureName=edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e);
-
-  if(textureName!="")
-    textureName=edgeExtGlGraphInputData->parameters->getTexturePath()+textureName;
-
-  draw(glyphColor,
-       borderColor,
-       edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e),
-       textureName,
-       lod);
-}
-//=====================================================
-void Diamond::draw(const Color &fillColor,
-                   const Color &borderColor,
-                   float borderWidth,
-                   const std::string &textureName,
-                   float lod) {
-  if(borderWidth<1e-6)
-    borderWidth=1e-6;
-
-  diamond->setFillColor(fillColor);
-  diamond->setOutlineColor(borderColor);
-  diamond->setOutlineSize(borderWidth);
-  diamond->setTextureName(textureName);
-  diamond->draw(lod,NULL);
-}
-//=====================================================
 Coord Diamond::getAnchor(const Coord &vector) const {
   Coord v(vector);
   float x, y, z;
@@ -159,4 +129,33 @@ Coord Diamond::getAnchor(const Coord &vector) const {
 
   return anchor;
 }
-/*@}*/
+
+class EEDiamond: public EdgeExtremityGlyph {
+public:
+  GLYPHINFORMATION("2D - Diamond extremity", "Patrick Mary", "23/06/2011", "Textured Diamond for edge extremities", "1.0", EdgeExtremityShape::Diamond)
+
+  EEDiamond(const tlp::PluginContext* context): EdgeExtremityGlyph(context) {
+    if(!diamond)
+      diamond=new GlRegularPolygon(Coord(0,0,0),Size(.5,.5,0), 4);
+  }
+
+  void draw(edge e,
+            node,
+            const Color & glyphColor,
+            const Color &borderColor,
+            float lod) {
+    diamond->setLightingMode(false);
+    string textureName=edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e);
+
+    if(textureName!="")
+      textureName=edgeExtGlGraphInputData->parameters->getTexturePath()+textureName;
+
+    drawDiamond(glyphColor,
+                borderColor,
+                edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e),
+                textureName,
+                lod);
+  }
+};
+
+PLUGIN(EEDiamond)
