@@ -26,6 +26,9 @@
 #include <tulip/Graph.h>
 #include <tulip/Glyph.h>
 #include <tulip/GlTools.h>
+#include <tulip/GlGraphRenderingParameters.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
@@ -38,12 +41,13 @@ using namespace tlp;
  * node property value. If this property has no value, the half cylinder
  * is then colored using the "viewColor" node property value.
  */
-/*@{*/
+
 
 //=================================================================================================
 class HalfCylinder : public Glyph {
 public:
-  HalfCylinder(GlyphContext *gc=NULL);
+  GLYPHINFORMATION("3D - Half Cylinder", "Auber David", "31/07/2002", "Textured HalfCylinder", "1.0", NodeShape::HalfCylinder)
+  HalfCylinder(const tlp::PluginContext *context = NULL);
   virtual ~HalfCylinder();
   virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
   virtual void draw(node n,float lod);
@@ -52,9 +56,9 @@ public:
 private:
 };
 
-GLYPHPLUGIN(HalfCylinder, "3D - Half Cylinder", "Auber David", "31/07/2002", "Textured HalfCylinder", "1.0", 10);
+PLUGIN(HalfCylinder)
 //=================================================================================================
-HalfCylinder::HalfCylinder(GlyphContext *gc): Glyph(gc) {
+HalfCylinder::HalfCylinder(const tlp::PluginContext* context): Glyph(context) {
 }
 //=================================================================================================
 HalfCylinder::~HalfCylinder() {
@@ -117,4 +121,4 @@ Coord HalfCylinder::getAnchor(const Coord &vector) const {
   return Coord(x,y,z);
 }
 //=================================================================================================
-/*@}*/
+
