@@ -30,79 +30,16 @@
 #include <tulip/GlDisplayListManager.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/OpenGlConfigManager.h>
-
+#include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/Graph.h>
 #include <tulip/GlTools.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
-/** \addtogroup glyph */
-/*@{*/
-/// A 2D glyph
-/**
- * This glyph draws a textured disc with a circular hole using the
- * "viewTexture" node property value.
- * If this property has no value, the ring
- * is then colored using the "viewColor" node property value.
- */
-class Ring: public Glyph, public EdgeExtremityGlyphFrom2DGlyph {
-public:
-  Ring(GlyphContext *gc = NULL);
-  Ring(EdgeExtremityGlyphContext *gc);
-  virtual ~Ring();
-  virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
-  virtual string getName() {
-    return string("Ring");
-  }
-  virtual void draw(node n, float lod);
-  virtual void draw(edge e, node n, const Color& glyphColor, const Color &borderColor, float lod);
-
-protected:
-  inline void drawGlyph(const Color& glyohColor, const string& texture,
-                        const string& texturePath, double borderWidth,
-                        const Color& borderColor, float lod);
-  void drawRing();
-  void drawRingBorder();
-};
-//=====================================================
-GLYPHPLUGIN(Ring, "2D - Ring", "David Auber", "09/07/2002", "Textured Ring", "1.0", 15)
-EEGLYPHPLUGIN(Ring, "2D - Ring", "David Auber", "09/07/2002", "Textured Ring", "1.0", 15)
-//===================================================================================
-Ring::Ring(GlyphContext *gc) :
-  Glyph(gc), EdgeExtremityGlyphFrom2DGlyph(NULL) {
-}
-Ring::Ring(EdgeExtremityGlyphContext *gc) :
-  Glyph(NULL), EdgeExtremityGlyphFrom2DGlyph(gc) {
-}
-//=====================================================
-Ring::~Ring() {
-}
-//=====================================================
-void Ring::getIncludeBoundingBox(BoundingBox &boundingBox,node) {
-  boundingBox[0] = Coord(-0.35f, -0.35f, 0);
-  boundingBox[1] = Coord(0.35f, 0.35f, 0);
-}
-//=====================================================
-void Ring::draw(node n, float lod) {
-  drawGlyph(glGraphInputData->getElementColor()->getNodeValue(n),
-            glGraphInputData->getElementTexture()->getNodeValue(n),
-            glGraphInputData->parameters->getTexturePath(),
-            glGraphInputData->getElementBorderWidth()->getNodeValue(n),
-            glGraphInputData->getElementBorderColor()->getNodeValue(n), lod);
-
-}
-void Ring::draw(edge e, node, const Color& glyphColor, const Color &borderColor, float lod) {
-  glDisable(GL_LIGHTING);
-  drawGlyph(glyphColor,
-            edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e),
-            edgeExtGlGraphInputData->parameters->getTexturePath(),
-            edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e),
-            borderColor, lod);
-}
-
-//=====================================================
-void Ring::drawRing() {
+void drawRing() {
   GLUquadricObj *quadratic;
   quadratic = gluNewQuadric();
   gluQuadricNormals(quadratic, GLU_SMOOTH);
@@ -113,14 +50,13 @@ void Ring::drawRing() {
   gluDisk(quadratic, 0.2f, 0.5f, 30, 1);
   gluDeleteQuadric(quadratic);
 }
-//=====================================================
-void Ring::drawRingBorder() {
+void drawRingBorder() {
   glBegin(GL_LINE_LOOP);
   double alpha = M_PI / 2.;
   double delta = 2. * M_PI / 30.0;
 
   for (unsigned int i = 0; i < 30; ++i) {
-    glVertex3f(0.5f * static_cast<float>(cos(alpha)), 0.5f * static_cast<float>(sin(alpha)), 0.0f);
+    glVertex3f(0.5 * cos(alpha), 0.5 * sin(alpha), 0.0);
     alpha += delta;
   }
 
@@ -129,18 +65,15 @@ void Ring::drawRingBorder() {
   alpha = M_PI / 2.;
 
   for (unsigned int i = 0; i < 30; ++i) {
-    glVertex3f(0.2f * static_cast<float>(cos(alpha)), 0.2f * static_cast<float>(sin(alpha)), 0.0f);
+    glVertex3f(0.2 * cos(alpha), 0.2 * sin(alpha), 0.0);
     alpha += delta;
   }
 
   glEnd();
 }
-//=====================================================
-/*@}*/
-
-void Ring::drawGlyph(const Color& glyohColor, const string& texture,
-                     const string& texturePath, double borderWidth,
-                     const Color& borderColor, float lod) {
+void drawGlyph(const Color& glyohColor, const string& texture,
+               const string& texturePath, double borderWidth,
+               const Color& borderColor, float lod) {
 
   if (GlDisplayListManager::getInst().beginNewDisplayList("Ring_ring")) {
     drawRing();
@@ -164,17 +97,74 @@ void Ring::drawGlyph(const Color& glyohColor, const string& texture,
 
   GlTextureManager::getInst().desactivateTexture();
 
-  if (lod > 20) {
-    if (borderWidth < 1e-6)
-      glLineWidth(1e-6f); //no negative borders
-    else
-      glLineWidth(static_cast<float>(borderWidth));
+  if (lod > 20 && borderWidth > 0) {
+
+    glLineWidth(borderWidth);
+
+    glDisable(GL_LIGHTING);
+    setColor(borderColor);
+    OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
+    GlDisplayListManager::getInst().callDisplayList("Ring_ringborder");
+    OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
+    glEnable(GL_LIGHTING);
+  }
+}
+
+/** \addtogroup glyph */
+
+/// A 2D glyph
+/**
+ * This glyph draws a textured disc with a circular hole using the
+ * "viewTexture" node property value.
+ * If this property has no value, the ring
+ * is then colored using the "viewColor" node property value.
+ */
+class Ring: public Glyph {
+public:
+  GLYPHINFORMATION("2D - Ring", "David Auber", "09/07/2002", "Textured Ring", "1.0", NodeShape::Ring)
+  Ring(const tlp::PluginContext *context = NULL);
+  virtual ~Ring();
+  virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
+  virtual string getName() {
+    return string("Ring");
+  }
+  virtual void draw(node n, float lod);
+};
+PLUGIN(Ring)
+Ring::Ring(const tlp::PluginContext* context) :
+  Glyph(context) {
+}
+Ring::~Ring() {
+}
+void Ring::getIncludeBoundingBox(BoundingBox &boundingBox,node) {
+  boundingBox[0] = Coord(-0.35f, -0.35f, 0);
+  boundingBox[1] = Coord(0.35f, 0.35f, 0);
+}
+void Ring::draw(node n, float lod) {
+  drawGlyph(glGraphInputData->getElementColor()->getNodeValue(n),
+            glGraphInputData->getElementTexture()->getNodeValue(n),
+            glGraphInputData->parameters->getTexturePath(),
+            glGraphInputData->getElementBorderWidth()->getNodeValue(n),
+            glGraphInputData->getElementBorderColor()->getNodeValue(n), lod);
+
+}
+
+
+class EERing: public EdgeExtremityGlyph {
+public:
+  GLYPHINFORMATION("2D - Ring extremity", "David Auber", "09/07/2002", "Textured Ring for edge extremities", "1.0", EdgeExtremityShape::Ring)
+
+  EERing(const tlp::PluginContext* context): EdgeExtremityGlyph(context) {
   }
 
-  glDisable(GL_LIGHTING);
-  setColor(borderColor);
-  OpenGlConfigManager::getInst().activateLineAndPointAntiAliasing();
-  GlDisplayListManager::getInst().callDisplayList("Ring_ringborder");
-  OpenGlConfigManager::getInst().desactivateLineAndPointAntiAliasing();
-  glEnable(GL_LIGHTING);
-}
+  void draw(edge e, node, const Color& glyphColor, const Color &borderColor, float lod) {
+    glDisable(GL_LIGHTING);
+    drawGlyph(glyphColor,
+              edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e),
+              edgeExtGlGraphInputData->parameters->getTexturePath(),
+              edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e),
+              borderColor, lod);
+  }
+};
+PLUGIN(EERing)
+
