@@ -22,6 +22,10 @@
 #include <tulip/GlPolygon.h>
 #include <tulip/GlShaderProgram.h>
 #include <tulip/GlTextureManager.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/OpenGlConfigManager.h>
+#include <tulip/GlTools.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace tlp;
 using namespace std;
@@ -148,8 +152,8 @@ const string roundedBoxOutlineGeometryShaderSrc =
   "}"
   ;
 
-/** \addtogroup glyph */
-/*@{*/
+/** @addtogroup glyph */
+
 /// A 2D glyph.
 /**
  * This glyph draws a rounded box, meaning a rectangle with rounded corners.
@@ -161,7 +165,8 @@ const string roundedBoxOutlineGeometryShaderSrc =
 
 class RoundedBox : public Glyph {
 public:
-  RoundedBox(GlyphContext *gc = NULL);
+  GLYPHINFORMATION("2D - Rounded Box", "Antoine LAMBERT", "02/11/2010", "Rounded Box", "1.0", NodeShape::RoundedBox)
+  RoundedBox(const tlp::PluginContext *context = NULL);
   ~RoundedBox() {}
   void draw(node n, float lod);
   Coord getAnchor(const Coord &vector) const;
@@ -173,19 +178,42 @@ private:
   GlPolygon *createRoundedRect(const Size &size);
 
   static GlPolygon *roundedSquare;
+  static Coord minIncludeBBSquare;
+  static Coord maxIncludeBBSquare;
 };
 
-GlPolygon* RoundedBox::roundedSquare=0;
+static Coord computeCircleArcMidPoint(const Coord &start, const Coord &end, const Coord &center) {
+  float radius = start.dist(center);
+  float c=atan2(start[1]+end[1], start[0]+end[0]);
+  return Coord(center.x() + radius*cos(c), center.y() + radius*sin(c));
+}
 
-RoundedBox::RoundedBox(GlyphContext *gc) : Glyph(gc) {}
+GlPolygon* RoundedBox::roundedSquare=NULL;
+Coord RoundedBox::minIncludeBBSquare;
+Coord RoundedBox::maxIncludeBBSquare;
+
+RoundedBox::RoundedBox(const tlp::PluginContext* context) : Glyph(context) {
+  minIncludeBBSquare = computeCircleArcMidPoint(Coord(-0.25, -0.5), Coord(-0.5, -0.25), Coord(-0.25, -0.25));
+  maxIncludeBBSquare = -minIncludeBBSquare;
+}
 
 void RoundedBox::initRoundedSquare() {
   roundedSquare = createRoundedRect(Size(1,1,1));
 }
 
-void RoundedBox::getIncludeBoundingBox(BoundingBox &boundingBox,node ) {
-  boundingBox[0] = Coord(-0.35f, -0.35f, 0);
-  boundingBox[1] = Coord(0.35f, 0.35f, 0);
+void RoundedBox::getIncludeBoundingBox(BoundingBox &boundingBox,node n) {
+  const Size &size = glGraphInputData->getElementSize()->getNodeValue(n);
+
+  if (size[0] == size[1]) {
+    boundingBox[0] = minIncludeBBSquare;
+    boundingBox[1] = maxIncludeBBSquare;
+  }
+  else {
+    float radius = min(size[0] / 4, size[1] / 4);
+    radius = min(radius/size[0], radius/size[1]);
+    boundingBox[0] = computeCircleArcMidPoint(Coord(-0.5+radius, -0.5), Coord(-0.5, -0.5+radius), Coord(-0.5+radius, -0.5+radius));
+    boundingBox[1] = -boundingBox[0];
+  }
 }
 
 GlPolygon *RoundedBox::createRoundedRect(const Size &size) {
@@ -193,16 +221,16 @@ GlPolygon *RoundedBox::createRoundedRect(const Size &size) {
   float radiusL = radius / size[0];
   float radiusH = radius / size[1];
 
-  float wi = 1.0f - 2*radiusL;
-  float hi = 1.0f - 2*radiusH;
+  float wi = 1.0 - 2*radiusL;
+  float hi = 1.0 - 2*radiusH;
 
-  Coord P1 = Coord(-0.5f, 0.5f) + Coord(radiusL, -radiusH);
+  Coord P1 = Coord(-0.5, 0.5) + Coord(radiusL, -radiusH);
   Coord P2 = P1 + Coord(wi, 0);
   Coord P3 = P2 + Coord(0, -hi);
   Coord P4 = P1 + Coord(0, -hi);
 
   int steps = 20;
-  float delta = static_cast<float>((M_PI/2) / steps);
+  float delta = (M_PI/2) / steps;
 
   vector<Coord> boxPoints;
   boxPoints.resize(steps * 4);
@@ -243,7 +271,10 @@ GlPolygon *RoundedBox::createRoundedRect(const Size &size) {
   fillColors.push_back(Color(255,255,255));
   outlineColors.push_back(Color(0,0,0));
 
-  return new GlPolygon(boxPoints, fillColors, outlineColors, true, true);
+  GlPolygon *ret = new GlPolygon(boxPoints, fillColors, outlineColors, true, true);
+  ret->setInvertYTexture(false);
+
+  return ret;
 }
 
 const float squareVerticesData[56] = {
@@ -288,14 +319,13 @@ void RoundedBox::draw(node n, float lod) {
     roundedBoxOutlineShader->printInfoLog();
   }
 
-
   const Size &size = glGraphInputData->getElementSize()->getNodeValue(n);
 
-  float outlineWidth = static_cast<float>(glGraphInputData->getElementBorderWidth()->getNodeValue(n));
+  float outlineWidth = glGraphInputData->getElementBorderWidth()->getNodeValue(n);
 
   const string &texture = glGraphInputData->getElementTexture()->getNodeValue(n);
 
-  if (roundedBoxShader == NULL || !roundedBoxShader->isLinked() || !roundedBoxOutlineShader->isLinked() || (GlShaderProgram::getCurrentActiveShader() && GlShaderProgram::getCurrentActiveShader()->getName() == "fisheye")) {
+  if (roundedBoxShader == NULL || !roundedBoxShader->isLinked() || !roundedBoxOutlineShader->isLinked() || GlShaderProgram::getCurrentActiveShader()) {
     if (roundedSquare == NULL)
       initRoundedSquare();
 
@@ -310,6 +340,10 @@ void RoundedBox::draw(node n, float lod) {
     polygon->setOutlineSize(outlineWidth);
     polygon->setTextureName(texture);
     polygon->draw(lod,NULL);
+
+    if (polygon != roundedSquare)
+      // because createRoundedRect() creates a new GlPolygon
+      delete polygon;
   }
   else {
 
@@ -324,19 +358,21 @@ void RoundedBox::draw(node n, float lod) {
 
     setMaterial(glGraphInputData->getElementColor()->getNodeValue(n));
 
+    bool textureOK = false;
+
     if (texture != "") {
-      GlTextureManager::getInst().activateTexture(texture);
+      textureOK = GlTextureManager::getInst().activateTexture(texture);
     }
 
     roundedBoxShader->activate();
     roundedBoxShader->setUniformFloat("boxWidth", size[0]);
     roundedBoxShader->setUniformFloat("boxHeight", size[1]);
-    roundedBoxShader->setUniformBool("textureActivated", texture != "");
+    roundedBoxShader->setUniformBool("textureActivated", textureOK);
     roundedBoxShader->setUniformTextureSampler("texture", 0);
     glDrawArrays(GL_QUADS, 0, 8);
     roundedBoxShader->desactivate();
 
-    if (texture != "") {
+    if (textureOK) {
       GlTextureManager::getInst().desactivateTexture();
     }
 
@@ -379,4 +415,6 @@ Coord RoundedBox::getAnchor(const Coord &vector) const {
     return v;
 }
 
-GLYPHPLUGIN(RoundedBox, "2D - Rounded Box", "Antoine LAMBERT", "02/11/2010", "Rounded Box", "1.0", 18)
+PLUGIN(RoundedBox)
+
+
