@@ -26,78 +26,24 @@
 #include <tulip/ColorProperty.h>
 #include <tulip/GlDisplayListManager.h>
 #include <tulip/GlTextureManager.h>
-
+#include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/Graph.h>
 #include <tulip/Glyph.h>
 #include <tulip/EdgeExtremityGlyph.h>
 #include <tulip/GlTools.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
-/** \addtogroup glyph */
-/*@{*/
-/// A 3D glyph.
-/**
- * This glyph draws a textured sphere using the "viewTexture" node
- * property value. If this property has no value, the sphere
- * is then colored using the "viewColor" node property value.
- */
-class Sphere: public Glyph, public EdgeExtremityGlyphFrom3DGlyph {
-public:
-  Sphere(GlyphContext *gc = NULL);
-  Sphere(EdgeExtremityGlyphContext *gc);
-  virtual ~Sphere();
-  virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
-  virtual void draw(node n, float lod);
-  virtual void draw(edge e, node n, const Color& glyphColor, const Color &borderColor, float lod);
-
-private:
-  void generateBuffers(int space);
-  inline void drawGlyph(const Color& glyphColor, const string& texture,
-                        const string& texturePath, float lod);
-};
-
-GLYPHPLUGIN(Sphere, "3D - Sphere", "Bertrand Mathieu", "09/07/2002", "Textured sphere", "1.0", 2)
-EEGLYPHPLUGIN(Sphere, "3D - Sphere", "Bertrand Mathieu", "09/07/2002", "Textured sphere", "1.0", 2)
-
-//=========================================================================================
-Sphere::Sphere(GlyphContext *gc) :
-  Glyph(gc), EdgeExtremityGlyphFrom3DGlyph(NULL) {
-}
-Sphere::Sphere(EdgeExtremityGlyphContext *gc) :
-  Glyph(NULL), EdgeExtremityGlyphFrom3DGlyph(gc) {
-}
-
-Sphere::~Sphere() {
-}
-//=====================================================
-void Sphere::getIncludeBoundingBox(BoundingBox &boundingBox,node) {
-  boundingBox[0] = Coord(-0.35f, -0.35f, -0.35f);
-  boundingBox[1] = Coord(0.35f, 0.35f, 0.35f);
-}
-
 static GLuint buffers[] = { 0, 0, 0 };
 
 static GLfloat *vertex;
 static GLfloat *texturesCoord;
 static GLushort *indices;
-//=====================================================
-void Sphere::draw(node n, float lod) {
-  drawGlyph(glGraphInputData->getElementColor()->getNodeValue(n),
-            glGraphInputData->getElementTexture()->getNodeValue(n),
-            glGraphInputData->parameters->getTexturePath(), lod);
-}
 
-void Sphere::draw(edge e, node, const Color& glyphColor, const Color&, float lod) {
-  glEnable(GL_LIGHTING);
-  drawGlyph(glyphColor,
-            edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e),
-            edgeExtGlGraphInputData->parameters->getTexturePath(), lod);
-}
-
-//=====================================================
-void Sphere::generateBuffers(int space) {
+void generateBuffers(int space) {
   int vertexCount = (90 / space) * (360 / space) * 4;
 
   glGenBuffers(3, buffers);
@@ -122,9 +68,9 @@ void Sphere::generateBuffers(int space) {
       indices[vertexCount*2-n-2]=n+vertexCount+2;
       indices[vertexCount*2-n-3]=n+vertexCount+3;
 
-      vertex[n*3] = static_cast<float>(sin((i) / 180 * PI) * sin((j) / 180 * PI) /2.);
-      vertex[n*3+1] = static_cast<float>(cos((i) / 180 * PI) * sin((j) / 180 * PI) /2.);
-      vertex[n*3+2] = static_cast<float>(-cos((j) / 180 * PI) /2.);
+      vertex[n*3] = sin((i) / 180 * PI) * sin((j) / 180 * PI) /2.;
+      vertex[n*3+1] = cos((i) / 180 * PI) * sin((j) / 180 * PI) /2.;
+      vertex[n*3+2] = -cos((j) / 180 * PI) /2.;
       vertex[(vertexCount+n)*3]=vertex[n*3];
       vertex[(vertexCount+n)*3+1]=vertex[n*3+1];
       vertex[(vertexCount+n)*3+2]=-vertex[n*3+2];
@@ -134,9 +80,9 @@ void Sphere::generateBuffers(int space) {
       texturesCoord[(vertexCount+n)*2+1] = -texturesCoord[n*2+1];
       n++;
 
-      vertex[n*3] = static_cast<float>(sin((i) / 180 * PI) * sin((j + space) / 180 * PI) /2.);
-      vertex[n*3+1] = static_cast<float>(cos((i) / 180 * PI) * sin((j + space) / 180 * PI) /2.);
-      vertex[n*3+2] = static_cast<float>(-cos((j + space) / 180 * PI) /2.);
+      vertex[n*3] = sin((i) / 180 * PI) * sin((j + space) / 180 * PI) /2.;
+      vertex[n*3+1] = cos((i) / 180 * PI) * sin((j + space) / 180 * PI) /2.;
+      vertex[n*3+2] = -cos((j + space) / 180 * PI) /2.;
       vertex[(vertexCount+n)*3]=vertex[n*3];
       vertex[(vertexCount+n)*3+1]=vertex[n*3+1];
       vertex[(vertexCount+n)*3+2]=-vertex[n*3+2];
@@ -146,9 +92,9 @@ void Sphere::generateBuffers(int space) {
       texturesCoord[(vertexCount+n)*2+1] = -texturesCoord[n*2+1];
       n++;
 
-      vertex[n*3] = static_cast<float>(sin((i + space) / 180 * PI) * sin((j) / 180 * PI) /2.);
-      vertex[n*3+1] = static_cast<float>(cos((i + space) / 180 * PI) * sin((j) / 180 * PI) /2.);
-      vertex[n*3+2] = static_cast<float>(-cos((j) / 180 * PI) /2.);
+      vertex[n*3] = sin((i + space) / 180 * PI) * sin((j) / 180 * PI) /2.;
+      vertex[n*3+1] = cos((i + space) / 180 * PI) * sin((j) / 180 * PI) /2.;
+      vertex[n*3+2] = -cos((j) / 180 * PI) /2.;
       vertex[(vertexCount+n)*3]=vertex[n*3];
       vertex[(vertexCount+n)*3+1]=vertex[n*3+1];
       vertex[(vertexCount+n)*3+2]=-vertex[n*3+2];
@@ -158,9 +104,9 @@ void Sphere::generateBuffers(int space) {
       texturesCoord[(vertexCount+n)*2+1] = -texturesCoord[n*2+1];
       n++;
 
-      vertex[n*3] = static_cast<float>(sin((i + space) / 180 * PI) * sin((j + space) / 180 * PI) /2.);
-      vertex[n*3+1] = static_cast<float>(cos((i + space) / 180 * PI) * sin((j + space) / 180 * PI) /2.);
-      vertex[n*3+2] = static_cast<float>(-cos((j + space) / 180 * PI) /2.);
+      vertex[n*3] = sin((i + space) / 180 * PI) * sin((j + space) / 180 * PI) /2.;
+      vertex[n*3+1] = cos((i + space) / 180 * PI) * sin((j + space) / 180 * PI) /2.;
+      vertex[n*3+2] = -cos((j + space) / 180 * PI) /2.;
       vertex[(vertexCount+n)*3]=vertex[n*3];
       vertex[(vertexCount+n)*3+1]=vertex[n*3+1];
       vertex[(vertexCount+n)*3+2]=-vertex[n*3+2];
@@ -181,15 +127,14 @@ void Sphere::generateBuffers(int space) {
   glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, buffers[2]);
   glBufferData(GL_ELEMENT_ARRAY_BUFFER, vertexCount*2*sizeof(GLushort), indices, GL_STATIC_DRAW);
 }
-/*@}*/
-void Sphere::drawGlyph(const Color& glyphColor, const string& texture,
-                       const string& texturePath, float) {
-  bool canUseGlew = OpenGlConfigManager::getInst().canUseGlew();
+void drawGlyph(const Color& glyphColor, const string& texture,
+               const string& texturePath, float) {
+  bool canUseVBO = OpenGlConfigManager::getInst().hasVertexBufferObject();
 
   int space = 9;
   int vertexCount = (90 / space) * (360 / space) * 4;
 
-  if (canUseGlew) {
+  if (canUseVBO) {
     if (buffers[0] == 0) {
       generateBuffers(space);
     }
@@ -214,7 +159,7 @@ void Sphere::drawGlyph(const Color& glyphColor, const string& texture,
 
   OpenGlConfigManager::getInst().activatePolygonAntiAliasing();
 
-  if (canUseGlew) {
+  if (canUseVBO) {
     glEnableClientState(GL_VERTEX_ARRAY);
     glEnableClientState(GL_NORMAL_ARRAY);
 
@@ -249,3 +194,59 @@ void Sphere::drawGlyph(const Color& glyphColor, const string& texture,
 
   GlTextureManager::getInst().desactivateTexture();
 }
+
+/** \addtogroup glyph */
+
+/// A 3D glyph.
+/**
+ * This glyph draws a textured sphere using the "viewTexture" node
+ * property value. If this property has no value, the sphere
+ * is then colored using the "viewColor" node property value.
+ */
+class Sphere: public Glyph {
+public:
+  GLYPHINFORMATION("3D - Sphere", "Bertrand Mathieu", "09/07/2002", "Textured sphere", "1.0", NodeShape::Sphere)
+  Sphere(const tlp::PluginContext *context = NULL);
+  virtual ~Sphere();
+  virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
+  virtual void draw(node n, float lod);
+};
+
+PLUGIN(Sphere)
+
+//=========================================================================================
+Sphere::Sphere(const tlp::PluginContext* context) :
+  Glyph(context) {
+}
+
+Sphere::~Sphere() {
+}
+
+void Sphere::getIncludeBoundingBox(BoundingBox &boundingBox,node) {
+  boundingBox[0] = Coord(-0.35f, -0.35f, -0.35f);
+  boundingBox[1] = Coord(0.35f, 0.35f, 0.35f);
+}
+
+void Sphere::draw(node n, float lod) {
+  drawGlyph(glGraphInputData->getElementColor()->getNodeValue(n),
+            glGraphInputData->getElementTexture()->getNodeValue(n),
+            glGraphInputData->parameters->getTexturePath(), lod);
+}
+
+class EESphere: public EdgeExtremityGlyph {
+  GLYPHINFORMATION("3D - Sphere extremity", "Bertrand Mathieu", "09/07/2002", "Textured sphere for edge extremities", "1.0", EdgeExtremityShape::Sphere)
+public:
+  EESphere(const tlp::PluginContext *context): EdgeExtremityGlyph(context) {
+
+  }
+  virtual ~EESphere() {
+
+  }
+  virtual void draw(edge e, node, const Color& glyphColor,const Color&, float lod) {
+    glEnable(GL_LIGHTING);
+    drawGlyph(glyphColor,
+              edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e),
+              edgeExtGlGraphInputData->parameters->getTexturePath(), lod);
+  }
+};
+PLUGIN(EESphere)
