@@ -29,55 +29,60 @@
 #include <tulip/EdgeExtremityGlyph.h>
 #include <tulip/Graph.h>
 #include <tulip/GlRect.h>
+#include <tulip/GlGraphRenderingParameters.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
+
+static GlRect *rect = NULL;
+
+void drawGlyph(const Color& glyphColor, const string& texture,
+               const string& texturePath, double borderWidth,
+               const Color& borderColor, float lod) {
+  rect->setFillColor(glyphColor);
+  rect->setTextureName(texturePath+texture);
+
+  if (borderWidth > 0) {
+    rect->setOutlineMode(true);
+    rect->setOutlineColor(borderColor);
+    rect->setOutlineSize(borderWidth);
+  }
+  else {
+    rect->setOutlineMode(false);
+  }
+
+  rect->draw(lod,NULL);
+
+}
+
+
 /** \addtogroup glyph */
-/*@{*/
+
 /// A 2D glyph.
 /**
  * This glyph draws a textured square using the "viewTexture" node
  * property value. If this property has no value, the square
  * is then colored using the "viewColor" node property value.
  */
-class Square: public Glyph, public EdgeExtremityGlyphFrom2DGlyph {
+class Square: public Glyph {
 public:
-  Square(GlyphContext *gc = NULL);
-  Square(EdgeExtremityGlyphContext*gc);
+  GLYPHINFORMATION("2D - Square", "David Auber", "09/07/2002", "Textured square", "1.0", NodeShape::Square)
+  Square(const tlp::PluginContext *context = NULL);
   virtual ~Square();
   virtual void draw(node n, float lod);
   virtual Coord getAnchor(const Coord &vector) const;
-  virtual void draw(edge e, node n, const Color& glyphColor, const Color &borderColor, float lod);
-
-protected:
-  inline void drawGlyph(const Color& glyphColor, const string& texture,
-                        const string& texturePath, double borderWidth,
-                        const Color& borderColor, float lod);
-
-  static GlRect *rect;
 };
-
-GlRect* Square::rect=0;
-
-//=====================================================
-GLYPHPLUGIN(Square, "2D - Square", "David Auber", "09/07/2002", "Textured square", "1.0", 4)
-EEGLYPHPLUGIN(Square,"2D - Square", "David Auber", "09/07/2002", "Textured square", "1.0", 4)
-//===================================================================================
-Square::Square(GlyphContext *gc) :
-  Glyph(gc), EdgeExtremityGlyphFrom2DGlyph(NULL) {
+PLUGIN(Square)
+Square::Square(const tlp::PluginContext* context) :
+  Glyph(context) {
   if(!rect)
-    rect = new GlRect(Coord(0,0,0),Size(1,1,0),Color(0,0,0,255),Color(0,0,0,255));
+    rect = new GlRect(Coord(0,0,0), 1., 1., Color(0,0,0,255),Color(0,0,0,255));
 }
-Square::Square(EdgeExtremityGlyphContext *gc) :
-  Glyph(NULL), EdgeExtremityGlyphFrom2DGlyph(gc) {
-  if(!rect)
-    rect = new GlRect(Coord(0,0,0),Size(1,1,0),Color(0,0,0,255),Color(0,0,0,255));
-}
-//=====================================================
 Square::~Square() {
 }
-//=====================================================
 void Square::draw(node n, float lod) {
   drawGlyph(glGraphInputData->getElementColor()->getNodeValue(n),
             glGraphInputData->getElementTexture()->getNodeValue(n),
@@ -86,17 +91,6 @@ void Square::draw(node n, float lod) {
             glGraphInputData->getElementBorderColor()->getNodeValue(n), lod);
 
 }
-
-void Square::draw(edge e, node, const Color& glyphColor, const Color &borderColor, float lod) {
-  glDisable(GL_LIGHTING);
-  drawGlyph(glyphColor,
-            edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e),
-            edgeExtGlGraphInputData->parameters->getTexturePath(),
-            edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e),
-            borderColor, lod);
-}
-
-//=====================================================
 Coord Square::getAnchor(const Coord &vector) const {
   Coord v(vector);
   float x, y, z, fmax;
@@ -110,17 +104,21 @@ Coord Square::getAnchor(const Coord &vector) const {
     return v;
 }
 
-void Square::drawGlyph(const Color& glyphColor, const string& texture,
-                       const string& texturePath, double borderWidth,
-                       const Color& borderColor, float lod) {
-  rect->setFillColor(glyphColor);
-  rect->setOutlineColor(borderColor);
-  rect->setTextureName(texturePath+texture);
+class EESquare: public EdgeExtremityGlyph {
+public:
+  GLYPHINFORMATION("2D - Square extremity", "David Auber", "09/07/2002", "Textured square for edge extremities", "1.0", EdgeExtremityShape::Square)
+  EESquare(const tlp::PluginContext* context): EdgeExtremityGlyph(context) {
+    if(!rect)
+      rect = new GlRect(Coord(0,0,0), 1., 1.,Color(0,0,0,255),Color(0,0,0,255));
+  }
 
-  if (borderWidth < 1e-6)
-    borderWidth=1e-6;
-
-  rect->setOutlineSize(static_cast<float>(borderWidth));
-  rect->draw(lod,NULL);
-}
-/*@}*/
+  void draw(edge e, node, const Color& glyphColor, const Color &borderColor, float lod) {
+    glDisable(GL_LIGHTING);
+    drawGlyph(glyphColor,
+              edgeExtGlGraphInputData->getElementTexture()->getEdgeValue(e),
+              edgeExtGlGraphInputData->parameters->getTexturePath(),
+              edgeExtGlGraphInputData->getElementBorderWidth()->getEdgeValue(e),
+              borderColor, lod);
+  }
+};
+PLUGIN(EESquare)
