@@ -27,16 +27,19 @@
 #include <tulip/Coord.h>
 #include <tulip/Glyph.h>
 #include <tulip/GlTriangle.h>
-
+#include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/Graph.h>
 #include <tulip/GlTools.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace std;
 using namespace tlp;
 
 class Triangle : public Glyph {
 public:
-  Triangle(GlyphContext *gc=NULL);
+  GLYPHINFORMATION("2D - Triangle", "David Auber", "09/07/2002", "Textured Triangle", "1.0", NodeShape::Triangle)
+  Triangle(const tlp::PluginContext *context =NULL);
   virtual ~Triangle();
   virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
   virtual void draw(node n,float lod);
@@ -47,12 +50,12 @@ protected:
 
 };
 
-GlTriangle* Triangle::triangle=0;
+GlTriangle* Triangle::triangle=NULL;
 
 //=====================================================
-GLYPHPLUGIN(Triangle, "2D - Triangle", "David Auber", "09/07/2002", "Textured Triangle", "1.0", 11);
+PLUGIN(Triangle)
 //===================================================================================
-Triangle::Triangle(GlyphContext *gc): Glyph(gc) {
+Triangle::Triangle(const tlp::PluginContext* context): Glyph(context) {
   if(!triangle)
     triangle = new GlTriangle(Coord(0,0,0),Size(0.5,0.5,0));
 }
@@ -79,18 +82,15 @@ void Triangle::draw(node n,float lod) {
     triangle->setTextureName("");
   }
 
-  triangle->setOutlineColor(glGraphInputData->getGraph()->getProperty<ColorProperty>("viewBorderColor")->getNodeValue(n));
+  double lineWidth=glGraphInputData->getElementBorderWidth()->getNodeValue(n);
 
-  if (glGraphInputData->getGraph()->existProperty ("viewBorderWidth")) {
-    double lineWidth=glGraphInputData->getGraph()->getProperty<DoubleProperty>("viewBorderWidth")->getNodeValue(n);
-
-    if (lineWidth < 1e-6)
-      lineWidth=1e-6;
-
-    triangle->setOutlineSize(static_cast<float>(lineWidth));
+  if (lineWidth > 0) {
+    triangle->setOutlineMode(true);
+    triangle->setOutlineColor(glGraphInputData->getElementBorderColor()->getNodeValue(n));
+    triangle->setOutlineSize(lineWidth);
   }
   else {
-    triangle->setOutlineSize(2.f);
+    triangle->setOutlineMode(false);
   }
 
   triangle->draw(lod,NULL);
