@@ -25,18 +25,22 @@
 #include <tulip/GlPolyQuad.h>
 #include <tulip/GlQuad.h>
 #include <tulip/GlTextureManager.h>
+#include <tulip/GlGraphRenderingParameters.h>
+#include <tulip/ColorProperty.h>
+#include <tulip/GlGraphInputData.h>
+#include <tulip/TlpTools.h>
+#include <tulip/TulipViewSettings.h>
 
 using namespace tlp;
 using namespace std;
 
-
-
 const string texture(TulipBitmapDir + "halfCylinderTexture.png");
 const string gradient(TulipBitmapDir + "titlebarGradient.png");
 
 class Window : public Glyph {
 public:
-  Window(GlyphContext* context);
+  GLYPHINFORMATION("2D - Window", "David Auber", "28/05/2010", "Window with a title bar", "1.0", NodeShape::Window)
+  Window(const tlp::PluginContext *context);
   virtual void getIncludeBoundingBox(BoundingBox &boundingBox,node);
   virtual void getTextBoundingBox(BoundingBox &boundingBox,node);
   virtual void draw(node n, float lod);
@@ -67,9 +71,9 @@ private:
 3------------2  -0.5,-0.5        0.5, -0.5
 */
 
-GLYPHPLUGIN(Window, "2D - Window", "David Auber", "28/05/2010", "Window with a title bar", "1.0", 17);
+PLUGIN(Window)
 
-Window::Window(GlyphContext* context):
+Window::Window(const tlp::PluginContext* context):
   Glyph(context),
   _rectColor(205, 205, 205, 255),
   _textColor(205, 205, 205, 255),
@@ -80,16 +84,16 @@ Window::Window(GlyphContext* context):
   const float textheight = 0.05f;
 
   Coord v[10];
-  v[0].set(-0.5f, 0.5f, 0);
-  v[1].set( 0.5f, 0.5f, 0);
-  v[2].set( 0.5f,-0.5f, 0);
-  v[3].set(-0.5f,-0.5f, 0);
-  v[4].set(-0.5f + _borderWidth, 0.5f - _borderWidth, 0);
-  v[5].set( 0.5f - _borderWidth, 0.5f - _borderWidth, 0);
-  v[6].set( 0.5f - _borderWidth,-0.5f + _borderWidth, 0);
-  v[7].set(-0.5f + _borderWidth,-0.5f + _borderWidth, 0);
-  v[8].set( 0.5f - _borderWidth, 0.5f - _borderWidth - textheight *2.f, 0);
-  v[9].set(-0.5f + _borderWidth, 0.5f - _borderWidth - textheight *2.f, 0);
+  v[0].set(-0.5, 0.5, 0);
+  v[1].set( 0.5, 0.5, 0);
+  v[2].set( 0.5,-0.5, 0);
+  v[3].set(-0.5,-0.5, 0);
+  v[4].set(-0.5 + _borderWidth, 0.5 - _borderWidth, 0);
+  v[5].set( 0.5 - _borderWidth, 0.5 - _borderWidth, 0);
+  v[6].set( 0.5 - _borderWidth,-0.5 + _borderWidth, 0);
+  v[7].set(-0.5 + _borderWidth,-0.5 + _borderWidth, 0);
+  v[8].set( 0.5 - _borderWidth, 0.5 - _borderWidth - textheight *2.f, 0);
+  v[9].set(-0.5 + _borderWidth, 0.5 - _borderWidth - textheight *2.f, 0);
 
   _bb.expand(v[6]);
   _bb.expand(v[9]);
