@@ -18,19 +18,17 @@
  */
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <errno.h>
+#include <cerrno>
 #include <fstream>
 #include <sstream>
 #include <cmath>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 #include <vector>
-#include <string.h>
+#include <cstring>
 
 using namespace std;
 using namespace tlp;
 
-const unsigned int MAX_SIZE = 10000;
-
 enum ValType { TLP_DOUBLE = 0, TLP_STRING = 1, TLP_NOVAL = 2, TLP_NOTHING = 3, TLP_AND = 4 };
 namespace {
 const char * paramHelp[] = {
@@ -44,7 +42,7 @@ const char * paramHelp[] = {
 }
 
 /** \addtogroup import */
-/*@{*/
+
 /** This plugin enables to import a graph coded with a matrix
  *
  *  File format:
@@ -65,45 +63,52 @@ const char * paramHelp[] = {
  *  If M(i,j) == @ an edge will be created without value <br>
  *  If M(i,j) == # no edge will be created between node[i] and node[j]
  *
- *  EXEMPLE 1 :
+ *  EXAMPLE 1 :
  *  <br>A
  *  <br># B
  *  <br># # C
- *  <br>Define  a graph with 3 nodes (with labels A B C) and without edge.
+ *  <br>Defines a graph with 3 nodes (with labels A B C) and without edge.
  *
- *  EXEMPLE 2 :
+ *  EXAMPLE 2 :
  *  <br>A
  *  <br>@ B
  *  <br>@ @ C
- *  <br>Define a simple complete graph with 3 nodes (with labels A B C) and no label (or value) on its edges
+ *  <br>Defines a simple complete graph with 3 nodes (with labels A B C) and no label (or value) on its edges
  *
- *  EXEMPLE 3 :
+ *  EXAMPLE 3 :
  *  <br>A # E & 5
  *  <br>@ B
  *  <br># @ C
- *  <br>Define a graph with 3 nodes and 3 edges, the edge between A and C is named E and has the value 5
+ *  <br>Defines a graph with 3 nodes and 3 edges, the edge between A and C is named E and has the value 5
  *
  */
 class AdjacencyMatrixImport:public ImportModule {
 public:
-  AdjacencyMatrixImport(AlgorithmContext context):ImportModule(context) {
-    addParameter<string>("file::name",paramHelp[0]);
+  PLUGININFORMATION("Adjacency Matrix", "Auber David", "05/09/2008","Imports a graph from a file coding an adjacency matrix.","1.2","File")
+  AdjacencyMatrixImport(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<string>("file::filename",paramHelp[0],"");
   }
   ~AdjacencyMatrixImport() {}
   vector<node> nodes;
 
+  std::string icon() const {
+    return ":/tulip/graphperspective/icons/32/import_adj_mat.png";
+  }
+
   bool formatError(const char* s, int curLine) {
     std::stringstream ess;
-    ess <<  "Error parsing '" << s << "' at line :" << curLine;
+    ess <<  "Error parsing '" << s << "' at line :" << curLine + 1;
     pluginProgress->setError(ess.str());
-    std::cerr << pluginProgress->getError() << std::endl;
+    tlp::warning() << pluginProgress->getError() << std::endl;
     return false;
   }
 
   bool importGraph() {
     string name2;
 
-    if (!dataSet->get("file::name", name2))
+    if (!(dataSet->get("file::filename", name2) ||
+          // ensure compatibility with old version
+          dataSet->get("file::name", name2)))
       return false;
 
     struct stat infoEntry;
@@ -124,9 +129,9 @@ public:
     DoubleProperty *metric = graph->getProperty<DoubleProperty>("viewMetric");
     StringProperty *stringP = graph->getProperty<StringProperty>("viewLabel");
 
-    while (!in.eof()) {
-      char line[MAX_SIZE];
-      in.getline(line,MAX_SIZE);
+    std::string line;
+
+    while (!in.eof() && std::getline(in, line)) {
       stringstream lines(line);
       unsigned int curNode = 0;
       edge e;
@@ -135,12 +140,12 @@ public:
 
       while (lines.good()) {
         string valString;
-        ValType type;
 
         if ( lines >> valString) {
           const char *start= valString.c_str();
           char *res;
           double valDouble = strtod(start, &res);
+          ValType type;
 
           if (res!=start) {
             type = TLP_DOUBLE;
@@ -151,7 +156,7 @@ public:
               return formatError(valString.c_str(), curLine);
 
             type = TLP_AND;
-            curNode--;
+            --curNode;
             andFound = true;
             itemFound = false;
             continue;
@@ -223,7 +228,7 @@ public:
             }
           }
 
-          curNode++;
+          ++curNode;
         }
 
         andFound = false;
@@ -232,11 +237,18 @@ public:
       if (andFound)
         return formatError("&", curLine);
 
-      curLine++;
+      ++curLine;
     }
 
-    return true;
+    // final check:
+    // number of lines must be equal to number of nodes
+    if (curLine == nodes.size())
+      return true;
+
+    pluginProgress->setError(std::string("The number of lines in file ") + name2 + "\n is different from the number of found nodes.");
+    tlp::warning() << pluginProgress->getError() << std::endl;
+    return false;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(AdjacencyMatrixImport, "Adjacency Matrix", "Auber David", "05/09/2008","","1.2","File")
+
+PLUGIN(AdjacencyMatrixImport)
