@@ -17,7 +17,7 @@
  *
  */
 #include <list>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 using namespace std;
 using namespace tlp;
@@ -32,7 +32,7 @@ static const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" )   \
   HTML_HELP_DEF( "default", "5" )     \
   HTML_HELP_BODY()                \
-  "This parameter defines the tree's depth to build."     \
+  "Depth of the tree."     \
   HTML_HELP_CLOSE(),
 
   // degree
@@ -40,14 +40,14 @@ static const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "2" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the tree's degree to build." \
+  "The tree's degree." \
   HTML_HELP_CLOSE(),
   // tree layout
   HTML_HELP_OPEN() \
   HTML_HELP_DEF( "type", "bool" ) \
   HTML_HELP_DEF( "default", "false" ) \
   HTML_HELP_BODY() \
-  "This parameter indicates if the generated tree has to be drawn with a tree layout algorithm." \
+  "If true, the generated tree is drawn with a tree layout algorithm." \
   HTML_HELP_CLOSE(),
 };
 
@@ -56,7 +56,7 @@ static const char * paramHelp[] = {
 
 
 /** \addtogroup import */
-/*@{*/
+
 /// Complete Tree - Import of a complete tree
 /** This plugin enables to create a complete tree
  *
@@ -64,11 +64,12 @@ static const char * paramHelp[] = {
  */
 class CompleteTree:public ImportModule {
 public:
-  CompleteTree(AlgorithmContext context):ImportModule(context) {
-    addParameter<unsigned int>("depth",paramHelp[0],"5");
-    addParameter<unsigned int>("degree",paramHelp[1],"2");
-    addParameter<bool>("tree layout",paramHelp[2],"false");
-    addDependency<LayoutAlgorithm>("Tree Leaf", "1.0");
+  PLUGININFORMATION("Complete Tree","Auber","08/09/2002","Imports a new complete tree.","1.1","Graph")
+  CompleteTree(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<unsigned int>("depth",paramHelp[0],"5");
+    addInParameter<unsigned int>("degree",paramHelp[1],"2");
+    addInParameter<bool>("tree layout",paramHelp[2],"false");
+    addDependency("Tree Leaf", "1.0");
   }
   ~CompleteTree() {
   }
@@ -78,7 +79,7 @@ public:
     unsigned int depth   = 5;
     bool needLayout = false;
 
-    if (dataSet!=0) {
+    if (dataSet!=NULL) {
       dataSet->get("depth", depth);
       dataSet->get("degree", degree);
       dataSet->get("tree layout", needLayout);
@@ -113,12 +114,12 @@ public:
       DataSet dSet;
       string errMsg;
       LayoutProperty *layout = graph->getProperty<LayoutProperty>("viewLayout");
-      return graph->computeProperty("Tree Leaf", layout, errMsg,
-                                    pluginProgress, &dSet);
+      return graph->applyPropertyAlgorithm("Tree Leaf", layout, errMsg,
+                                           pluginProgress, &dSet);
     }
 
     return true;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(CompleteTree,"Complete Tree","Auber","08/09/2002","","1.1","Graphs")
+
+PLUGIN(CompleteTree)
