@@ -18,9 +18,9 @@
  */
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <errno.h>
+#include <cerrno>
 #include <fstream>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 #include <tulip/AbstractProperty.h>
 #include "GMLParser.h"
 
@@ -40,10 +40,10 @@ using namespace std;
 using namespace tlp;
 
 void nodeAttributeError() {
-  cerr << "Error reading node attribute: The attributes of nodes must be defined after the node id (data ignored)" << endl;
+  tlp::warning() << "Error reading node attribute: The attributes of nodes must be defined after the node id (data ignored)" << endl;
 }
 void edgeAttributeError() {
-  cerr << "Error reading edge attribute: The attributes of edges must be defined after source and target (data ignored)" << endl;
+  tlp::warning() << "Error reading edge attribute: The attributes of edges must be defined after source and target (data ignored)" << endl;
 }
 
 //=================================================================================
@@ -68,7 +68,7 @@ struct GMLGraphBuilder:public GMLTrue {
 
     return edge();
   }
-  bool setNodeValue(int nodeId, const string propertyName, string value) {
+  bool setNodeValue(int nodeId, const string& propertyName, const string& value) {
     if (_graph->isElement(nodeIndex[nodeId])) {
       _graph->getLocalProperty<StringProperty>(propertyName)->setNodeValue(nodeIndex[nodeId],value);
       return true;
@@ -76,7 +76,7 @@ struct GMLGraphBuilder:public GMLTrue {
 
     return false;
   }
-  bool setNodeValue(int nodeId, const string propertyName, double value) {
+  bool setNodeValue(int nodeId, const string& propertyName, const double& value) {
     if (_graph->isElement(nodeIndex[nodeId])) {
       _graph->getLocalProperty<DoubleProperty>(propertyName)->setNodeValue(nodeIndex[nodeId],value);
       return true;
@@ -84,7 +84,7 @@ struct GMLGraphBuilder:public GMLTrue {
 
     return false;
   }
-  bool setNodeValue(int nodeId, const string propertyName, int value) {
+  bool setNodeValue(int nodeId, const string& propertyName, int value) {
     if (_graph->isElement(nodeIndex[nodeId])) {
       _graph->getLocalProperty<IntegerProperty>(propertyName)->setNodeValue(nodeIndex[nodeId],value);
       return true;
@@ -92,7 +92,7 @@ struct GMLGraphBuilder:public GMLTrue {
 
     return false;
   }
-  bool setNodeValue(int nodeId, const string propertyName, bool value) {
+  bool setNodeValue(int nodeId, const string& propertyName, bool value) {
     if (_graph->isElement(nodeIndex[nodeId])) {
       _graph->getLocalProperty<BooleanProperty>(propertyName)->setNodeValue(nodeIndex[nodeId],value);
       return true;
@@ -100,7 +100,7 @@ struct GMLGraphBuilder:public GMLTrue {
 
     return false;
   }
-  bool setNodeValue(int nodeId, const string propertyName, Coord value) {
+  bool setNodeCoordValue(int nodeId, const string& propertyName, const Coord& value) {
     if (_graph->isElement(nodeIndex[nodeId])) {
       _graph->getLocalProperty<LayoutProperty>(propertyName)->setNodeValue(nodeIndex[nodeId],value);
       return true;
@@ -108,7 +108,7 @@ struct GMLGraphBuilder:public GMLTrue {
 
     return false;
   }
-  bool setNodeValue(int nodeId, const string propertyName, Size value) {
+  bool setNodeSizeValue(int nodeId, const string& propertyName, const Size& value) {
     if (_graph->isElement(nodeIndex[nodeId])) {
       _graph->getLocalProperty<SizeProperty>(propertyName)->setNodeValue(nodeIndex[nodeId],value);
       return true;
@@ -116,7 +116,7 @@ struct GMLGraphBuilder:public GMLTrue {
 
     return false;
   }
-  bool setNodeValue(int nodeId, const string propertyName, Color value) {
+  bool setNodeValue(int nodeId, const string& propertyName, const Color& value) {
     if (_graph->isElement(nodeIndex[nodeId])) {
       _graph->getLocalProperty<ColorProperty>(propertyName)->setNodeValue(nodeIndex[nodeId],value);
       return true;
@@ -221,10 +221,10 @@ struct GMLNodeBuilder:public GMLBuilder {
     graphBuilder->setNodeValue(idSet,"viewColor",color);
   }
   void setSize(const Size &size) {
-    graphBuilder->setNodeValue(idSet,"viewSize",size);
+    graphBuilder->setNodeSizeValue(idSet,"viewSize",size);
   }
   void setCoord(const Coord &coord) {
-    graphBuilder->setNodeValue(idSet,"viewLayout",coord);
+    graphBuilder->setNodeCoordValue(idSet,"viewLayout",coord);
   }
   bool addStruct(const string& structName,GMLBuilder*&newBuilder);
   bool close() {
@@ -247,32 +247,32 @@ struct GMLNodeGraphicsBuilder:public GMLTrue {
   {}
 
   bool addInt(const string &st,const int integer) {
-    if (st=="x") coord.setX(static_cast<float>(integer));
+    if (st=="x") coord.setX(integer);
 
-    if (st=="y") coord.setY(static_cast<float>(integer));
+    if (st=="y") coord.setY(integer);
 
-    if (st=="z") coord.setZ(static_cast<float>(integer));
+    if (st=="z") coord.setZ(integer);
 
-    if (st=="w") size.setW(static_cast<float>(integer));
+    if (st=="w") size.setW(integer);
 
-    if (st=="h") size.setH(static_cast<float>(integer));
+    if (st=="h") size.setH(integer);
 
-    if (st=="d") size.setD(static_cast<float>(integer));
+    if (st=="d") size.setD(integer);
 
     return true;
   }
   bool addDouble(const string &st,const double real) {
-    if (st=="x") coord.setX(static_cast<float>(real));
+    if (st=="x") coord.setX(real);
 
-    if (st=="y") coord.setY(static_cast<float>(real));
+    if (st=="y") coord.setY(real);
 
-    if (st=="z") coord.setZ(static_cast<float>(real));
+    if (st=="z") coord.setZ(real);
 
-    if (st=="w") size.setW(static_cast<float>(real));
+    if (st=="w") size.setW(real);
 
-    if (st=="h") size.setH(static_cast<float>(real));
+    if (st=="h") size.setH(real);
 
-    if (st=="d") size.setD(static_cast<float>(real));
+    if (st=="d") size.setD(real);
 
     return true;
   }
@@ -449,20 +449,20 @@ struct GMLEdgeGraphicsLinePointBuilder:public GMLTrue {
     coord(0,0,0)
   {}
   bool addInt(const string &st,const int integer) {
-    if (st=="x") coord.setX(static_cast<float>(integer));
+    if (st=="x") coord.setX(integer);
 
-    if (st=="y") coord.setY(static_cast<float>(integer));
+    if (st=="y") coord.setY(integer);
 
-    if (st=="z") coord.setZ(static_cast<float>(integer));
+    if (st=="z") coord.setZ(integer);
 
     return true;
   }
   bool addDouble(const string &st,const double real) {
-    if (st=="x") coord.setX(static_cast<float>(real));
+    if (st=="x") coord.setX(real);
 
-    if (st=="y") coord.setY(static_cast<float>(real));
+    if (st=="y") coord.setY(real);
 
-    if (st=="z") coord.setZ(static_cast<float>(real));
+    if (st=="z") coord.setZ(real);
 
     return true;
   }
@@ -529,14 +529,14 @@ const char * paramHelp[] = {
   HTML_HELP_OPEN()            \
   HTML_HELP_DEF( "type", "pathname" )       \
   HTML_HELP_BODY()                  \
-  "This parameter defines the file pathname to import."       \
+  "File to import."       \
   HTML_HELP_CLOSE(),
 };
 }
 
 
 /** \addtogroup import */
-/*@{*/
+
 /// Import plugin for GML format.
 /**
  * This plugin imports a graph structure recorded using the GML File format.
@@ -545,8 +545,14 @@ const char * paramHelp[] = {
  */
 class GMLImport:public ImportModule {
 public:
-  GMLImport(AlgorithmContext context):ImportModule(context) {
-    addParameter<string>("file::filename",paramHelp[0]);
+  PLUGININFORMATION("GML","Auber","04/07/2001","Imports a new graph from a file (.gml) in the GML input format (used by Graphlet).","1.1","File")
+  std::list<std::string> fileExtensions() const {
+    std::list<std::string> l;
+    l.push_back("gml");
+    return l;
+  }
+  GMLImport(PluginContext* context):ImportModule(context) {
+    addInParameter<string>("file::filename",paramHelp[0],"");
   }
   ~GMLImport() {}
   bool importGraph() {
@@ -574,6 +580,6 @@ public:
     return true;
   }
 };
-/*@}*/
 
-IMPORTPLUGINOFGROUP(GMLImport,"GML","Auber","04/07/2001","GML Import plugin","1.1","File")
+
+PLUGIN(GMLImport)
