@@ -19,7 +19,7 @@
 #include <iostream>
 #include <string>
 #include <list>
-#include <string.h>
+#include <cstring>
 
 /*
   Il faut ajouter la gestion correcte des erreurs et cest nikel.
@@ -51,7 +51,7 @@ struct GMLTokenParser {
     bool endOfStream=false,strGet=false,slashMode=false,started=false,stop=false;
     char ch;
 
-    while ( (!stop) && (endOfStream=!(is.get(ch)).fail()) ) {
+    while ( (!stop) && (endOfStream=is.get(ch))) {
       curChar++;
 
       if (strGet)
@@ -159,7 +159,7 @@ struct GMLTokenParser {
 
     if (!started && !endOfStream) return ENDOFSTREAM;
 
-    char *endPtr=0;
+    char *endPtr=NULL;
     long resultl=strtol(val.str.c_str(),&endPtr,10);
 
     if (endPtr==(val.str.c_str()+val.str.length())) {
@@ -167,7 +167,7 @@ struct GMLTokenParser {
       return INTTOKEN;
     }
 
-    endPtr=0;
+    endPtr=NULL;
     double resultd=strtod(val.str.c_str(),&endPtr);
 
     if (endPtr==(val.str.c_str()+val.str.length())) {
