@@ -16,8 +16,10 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <tulip/TulipPlugin.h>
-#include <math.h>
+#include <tulip/TulipPluginHeaders.h>
+#include <tulip/StringCollection.h>
+
+#include <cmath>
 
 using namespace std;
 using namespace tlp;
@@ -31,7 +33,7 @@ const char
   HTML_HELP_DEF( "type", "unsigned int" )
   HTML_HELP_DEF( "default", "10" )
   HTML_HELP_BODY()
-  "This parameter defines the grid's node width."
+  "Grid's node width."
   HTML_HELP_CLOSE(),
 
   // height
@@ -39,7 +41,7 @@ const char
   HTML_HELP_DEF( "type", "unsigned int" )
   HTML_HELP_DEF( "default", "10" )
   HTML_HELP_BODY()
-  "This parameter defines the grid's node height."
+  "Grid's node height."
   HTML_HELP_CLOSE(),
   //Connectivity
   HTML_HELP_OPEN()
@@ -47,39 +49,40 @@ const char
   HTML_HELP_DEF( "values", "4 <br> 6 <br> 8" )
   HTML_HELP_DEF( "default", "4" )
   HTML_HELP_BODY()
-  "This parameter defines the connectivity number of each node."
+  "Connectivity number of each node."
   HTML_HELP_CLOSE(),
   // tore
   HTML_HELP_OPEN()
   HTML_HELP_DEF( "type", "bool" )
   HTML_HELP_DEF( "default", "false" )
   HTML_HELP_BODY()
-  "This parameter defines if the opposite node in the grid are connected. In a 4 connectivity the resulting object is a torus."
+  "If true, opposite nodes on each side of the grid are connected. In a 4 connectivity the resulting object is a torus."
   HTML_HELP_CLOSE(),
   // Line spacing
   HTML_HELP_OPEN()
   HTML_HELP_DEF( "type", "double" )
   HTML_HELP_DEF( "default", "1.0" )
   HTML_HELP_BODY()
-  "This parameter defines the spacing between each node in the grid."
+  "Spacing between nodes."
 };
 }
 /** \addtogroup import */
-/*@{*/
-/// Grid - Import a grid.
+
+/// Grid - Import of a grid.
 /** This plugin enables to create a grid.
  *
  *  User can specify the connectivity of each nodes in the grid, spacing between nodes and if opposite nodes are connected.
  */
 class Grid: public ImportModule {
 public:
-  Grid(AlgorithmContext context) :
+  PLUGININFORMATION("Grid","Jonathan Dubois","02/12/2003","Imports a new grid structured graph.","2.0","Graph")
+  Grid(tlp::PluginContext* context) :
     ImportModule(context) {
-    addParameter<unsigned int> ("width", paramHelp[0], "10");
-    addParameter<unsigned int> ("height", paramHelp[1], "10");
-    addParameter<StringCollection> ("connectivity", paramHelp[2], "4;6;8");
-    addParameter<bool> ("oppositeNodesConnected", paramHelp[3], "false");
-    addParameter<double> ("spacing", paramHelp[4], "1.0");
+    addInParameter<unsigned int> ("width", paramHelp[0], "10");
+    addInParameter<unsigned int> ("height", paramHelp[1], "10");
+    addInParameter<StringCollection> ("connectivity", paramHelp[2], "4;6;8");
+    addInParameter<bool> ("oppositeNodesConnected", paramHelp[3], "false");
+    addInParameter<double> ("spacing", paramHelp[4], "1.0");
   }
   ~Grid() {
   }
@@ -111,12 +114,12 @@ public:
 
       if (conn == 6) {
         layout->setNodeValue(current,
-                             Coord(static_cast<float>(i * 2 * h + shift + i * spacing),
-                                   static_cast<float>(iRow * 1.0 - hHeight + spacing), 0));
+                             Coord(i * 2 * h + shift + i * spacing,
+                                   iRow * (1.0 - hHeight + spacing), 0));
       }
       else
         layout->setNodeValue(current,
-                             Coord(i * static_cast<float>(1.0 + spacing), iRow * static_cast<float>(1.0
+                             Coord(i * (1.0 + spacing), iRow * (1.0
                                    + spacing), 0));
 
       if (previous.isValid())
@@ -189,7 +192,7 @@ public:
     StringCollection connectivity;
     double spacing = 1.0;
 
-    if (dataSet != 0) {
+    if (dataSet != NULL) {
       dataSet->get("width", width);
       dataSet->get("height", height);
       dataSet->get("oppositeNodesConnected", isTore);
@@ -227,7 +230,7 @@ public:
         if (pluginProgress)
           pluginProgress->setError("Error : cannot connect opposite nodes in an hexagonal grid with odd height");
         else
-          std::cerr << __PRETTY_FUNCTION__ << ":" << __LINE__ << " Error : cannot connect opposite nodes in an hexagonal grid with odd height"  <<std::endl;
+          tlp::warning() << __PRETTY_FUNCTION__ << ":" << __LINE__ << " Error : cannot connect opposite nodes in an hexagonal grid with odd height" << std::endl;
 
         return false;
       }
@@ -286,5 +289,5 @@ public:
     return true;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(Grid,"Grid","Jonathan Dubois","02/12/2003","","2.0","Graphs")
+
+PLUGIN(Grid)
