@@ -1,13 +1,32 @@
+/**
+ *
+ * This file is part of Tulip (www.tulip-software.org)
+ *
+ * Authors: David Auber and the Tulip development Team
+ * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ *
+ * Tulip is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
+ *
+ * Tulip is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ */
+
 #include <iostream>
 #include <fstream>
 #include <string>
 #include <cctype>
 #include <cstdlib>
 #include <algorithm>
-#include <string.h>
-#include <tulip/TulipPlugin.h>
+#include <cstring>
+#include <tulip/TulipPluginHeaders.h>
+
 
-/*@{*/
 /** \file
  *  \brief - Import UCINET DL format graph file.
  *  This plugin imports a graph from a file in UCINET DL input format,</br>
@@ -45,15 +64,13 @@ const char * paramHelp[] = {
 };
 }
 
-
-const unsigned int MAX_SIZE = 1024;
 namespace {
 bool getUnsignedInt(unsigned int& i, const string& str) {
   const char* ptr = str.c_str();
   char* endPtr;
   long int value = strtol(ptr, &endPtr, 10);
   i = (unsigned int) value;
-  return (value > 0) && (*endPtr == 0);
+  return (value >= 0) && (*endPtr == 0);
 }
 
 bool getDouble(double& d, const string& str) {
@@ -63,10 +80,6 @@ bool getDouble(double& d, const string& str) {
   return (*endPtr == 0);
 }
 
-bool nocasecmp(const string& str1, const string& str2) {
-  return strcasecmp(str1.c_str(), str2.c_str()) == 0;
-}
-
 bool nocasecmp(const string& str1, const char* str2) {
   return strcasecmp(str1.c_str(), str2) == 0;
 }
@@ -105,6 +118,44 @@ bool nextUnsignedInt(const string& str, unsigned int& value,
   return false;
 }
 
+bool nextString(const string& str, string& token,
+                string::size_type& pos) {
+  token.clear();
+  // Skip separators at the beginning.
+  string::size_type lastPos = str.find_first_not_of(" \r\t", pos);
+  string::size_type size = str.size();
+
+  if (string::npos != lastPos && str[lastPos] == '"') {
+    // found and open " which marks the beginning of a string description
+    // build token until the closing "
+    ++lastPos;
+    bool bslashFound = false;
+
+    for (pos = lastPos; pos < size; ++pos) {
+      char c = str[pos];
+
+      if (bslashFound) {
+        token.push_back(c);
+        bslashFound = false;
+      }
+      else {
+        if (c == '\\')
+          bslashFound = true;
+        else {
+          if (c == '"')
+            break;
+
+          token.push_back(c);
+        }
+      }
+    }
+
+    return (pos++ != size);
+  }
+
+  return false;
+}
+
 bool nextToken(const string& str, const string& separators, string& token,
                string::size_type& pos) {
   token.clear();
@@ -173,21 +224,30 @@ bool tokenize(const string& str, vector<string>& tokens,
 class ImportUCINET : public ImportModule {
 
 public :
-
-  ImportUCINET(AlgorithmContext context):ImportModule(context),
+  PLUGININFORMATION("UCINET","Patrick Mary","12/09/2011","Imports a new graph from a text file (.txt) in UCINET DL input format.","1.0","File")
+  std::list<std::string> fileExtensions() const {
+    std::list<std::string> l;
+    l.push_back("txt");
+    return l;
+  }
+  ImportUCINET(const tlp::PluginContext* context):ImportModule(context),
     nbNodes(0), defaultMetric("weight"),
     n(0), nr(0), nc(0), nm(0), current(0),
     dl_found(false), diagonal(true),
     diagonal_found(false),
-    labels_known(false),
+    labels_known(false), title_found(false),
     expectedLine(DL_HEADER),
     embedding(DL_NONE), dataFormat(DL_FM) {
-    addParameter<string>("file::filename", paramHelp[0]);
-    addParameter<string>("Default metric", paramHelp[1], "weight");
+    addInParameter<string>("file::filename", paramHelp[0],"");
+    addInParameter<string>("Default metric", paramHelp[1], "weight");
   }
 
   ~ImportUCINET() {}
 
+  std::string icon() const {
+    return ":/tulip/graphperspective/icons/32/import_ucinet.png";
+  }
+
   vector<node> nodes;
   unsigned int nbNodes;
   string defaultMetric;
@@ -204,7 +264,7 @@ public :
   // in the matrix data
   // diagonal_found indicates that the 'diagonal' token has been found
   // labels_known indicates the labels of nodes are known before reading data
-  bool dl_found, diagonal, diagonal_found, labels_known;
+  bool dl_found, diagonal, diagonal_found, labels_known, title_found;
   enum TypeOfLine {DL_HEADER = 0, DL_ROW_LABELS, DL_COL_LABELS,
                    DL_LABELS, DL_MATRIX_LABELS, DL_DATA
                   };
@@ -238,6 +298,25 @@ public :
         return false;
       }
 
+      if (nocasecmp(token, "title")) {
+        // no existing title
+        if (title_found) {
+          error << "TITLE already specified";
+          return false;
+        }
+
+        if (!skipEqualSign(str, pos) ||
+            !nextString(str, token, pos) ||
+            token.empty()) {
+          error << "invalid specification for parameter TITLE";
+          return false;
+        }
+
+        graph->setName(token);
+        title_found = true;
+        continue;
+      }
+
       if (nocasecmp(token, "n")) {
         // we must know nothing about the size of matrices
         if (n || nr || nc) {
@@ -399,13 +478,20 @@ public :
 
         diagonal_found = true;
 
-        if (!skipEqualSign(str, pos) ||
-            !nextToken(str, " \r\t,", token, pos)
+        if (!nextToken(str, " \r\t,", token, pos)
             || token.empty()) {
           error << "invalid specification for parameter DIAGONAL";
           return false;
         }
 
+        // specification says that DIAGONAL = PRESENT|ABSENT
+        // but = may not exist
+        if ((token == "=") && (!nextToken(str, " \r\t,", token, pos)
+                               || token.empty())) {
+          error << "invalid specification for parameter DIAGONAL";
+          return false;
+        }
+
         if (nocasecmp(token, "present")) {
           diagonal = true;
           continue;
@@ -449,8 +535,8 @@ public :
 
         // or 'labels:'
         if (nocasecmp(token, "labels:")) {
-          if (nr == 0) {
-            error << "specification of ROWS LABELS applies only to 2-mode matrix";
+          if (n == 0 && nr == 0) {
+            error << "specification of ROW LABELS applies only to 2-mode matrix";
             return false;
           }
 
@@ -491,8 +577,8 @@ public :
 
         // or 'labels:'
         if (nocasecmp(token, "labels:")) {
-          if (nc == 0) {
-            error << "specification of ROWS LABELS applies only to 2-mode matrix";
+          if (n == 0 && nc == 0) {
+            error << "specification of COLUMN LABELS applies only to 2-mode matrix";
             return false;
           }
 
@@ -573,7 +659,7 @@ public :
           metrics.push_back(graph->getProperty<DoubleProperty>(defaultMetric));
         }
         else {
-          if (metrics.size() == 0) {
+          if (metrics.empty()) {
             // create metrics with default name
             for (unsigned int i = 0; i < nm; ++i) {
               stringstream sstr;
@@ -737,7 +823,12 @@ public :
         // check if we first have row label
         if ((embedding & DL_ROWS) && (ic == 0) && (current == 0)) {
           graph->getProperty<StringProperty>("viewLabel")->setNodeValue(src, tokens[i]);
-          current = 1;
+
+          if (ir == 0 && nc == 1 && diagonal == false)
+            ++ir;
+          else
+            current = 1;
+
           continue;
         }
 
@@ -751,8 +842,15 @@ public :
             ir = 1;
             src = nodes[nc + 1];
           }
-          else
+          else {
+            if (ir == 0 && nc == 1) {
+              // nothing to read in this row
+              ++ir, current = 0;
+              continue;
+            }
+
             ++ic;
+          }
         }
 
         double value = 0;
@@ -770,7 +868,8 @@ public :
             }
           }
         }
-        else {
+        // ? indicates an unspecified value
+        else if (tokens[i] != "?") {
           error << "invalid value";
           return false;
         }
@@ -882,7 +981,7 @@ public :
     return false;
   }
 
-  bool import(const string &) {
+  bool importGraph() {
     string filename;
     string coord;
     dataSet->get<string>("file::filename", filename);
@@ -897,7 +996,6 @@ public :
 
     stringstream errors;
     size_t lineNumber = 0;
-    char* buffer = new char[MAX_SIZE];
 
     if (pluginProgress)
       pluginProgress->showPreview(false);
@@ -909,22 +1007,25 @@ public :
     unsigned int ic, ir, im;
     ic = ir = im = 0;
 
-    while (!in.eof()) {
-      in.getline(buffer, MAX_SIZE);
-      std::string line(buffer);
+    std::string line;
+
+    while (!in.eof() && std::getline(in, line)) {
       bool result = false;
 
+      ++lineNumber;
+
       switch(expectedLine) {
       case DL_HEADER:
         result = readHeader(line, errors);
         break;
 
       case DL_ROW_LABELS:
-        result = readLabels(line, errors, rowLabelToNode, nr, nc);
+        result = readLabels(line, errors, rowLabelToNode,
+                            nr ? nr : n, nc);
         break;
 
       case DL_COL_LABELS:
-        result = readLabels(line, errors, colLabelToNode, nc, 0);
+        result = readLabels(line, errors, colLabelToNode, nc ? nc : n, 0);
         break;
 
       case DL_LABELS:
@@ -974,7 +1075,7 @@ public :
           break;
 
         // check for empty line
-        if (tokens.size() == 0)
+        if (tokens.empty())
           break;
 
         // check for line separation between matrices
@@ -1007,22 +1108,17 @@ public :
           pluginProgress->setError(errors.str());
         }
 
-        delete [] buffer;
         return false;
       }
 
-      ++lineNumber;
-
       if (pluginProgress && ((lineNumber % 100) == 0) &&
           (pluginProgress->progress(lineNumber, 3 * nbNodes) != TLP_CONTINUE)) {
-        delete [] buffer;
         return false;
       }
     }
 
-    delete [] buffer;
     return true;
   }
 };
 
-IMPORTPLUGINOFGROUP(ImportUCINET, "UCINET dl","Patrick Mary","12/09/2011","Import UCINET","1.0","File")
+PLUGIN(ImportUCINET)
