@@ -19,12 +19,11 @@
 #include <time.h>
 #include <math.h>
 #include <climits>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 
 using namespace std;
 using namespace tlp;
-using namespace stdext;
 
 namespace {
 const char * paramHelp[] = {
@@ -33,7 +32,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "30" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the number of nodes used to build the planar graph." \
+  "Number of nodes in the final graph." \
   HTML_HELP_CLOSE(),
 };
 }
@@ -47,23 +46,24 @@ struct Triangle {
 }
 //=============================================================
 /** \addtogroup import */
-/*@{*/
-/// Planar Graph - Import of planer graph
+
+/// Planar Graph - Import of a planar graph
 /** This plugin enables to create a planar graph
  *
  *  User can specify the number of nodes.
  */
 class PlanarGraph:public ImportModule {
 public:
-  PlanarGraph(AlgorithmContext context):ImportModule(context) {
-    addParameter<unsigned int>("nodes", paramHelp[0], "30");
+  PLUGININFORMATION("Planar Graph","Auber","25/06/2005","Imports a new randomly generated planar graph.","1.0","Graph")
+  PlanarGraph(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<unsigned int>("nodes", paramHelp[0], "30");
   }
   ~PlanarGraph() {}
 
   bool importGraph() {
     unsigned int nbNodes  = 30;
 
-    if (dataSet!=0) {
+    if (dataSet!=NULL) {
       dataSet->get("nodes", nbNodes);
     }
 
@@ -82,7 +82,7 @@ public:
     graph->addEdge(f.a, f.b);
     graph->addEdge(f.b, f.c);
     graph->addEdge(f.c, f.a);
-    float val = static_cast<float>(nbNodes);
+    float val = nbNodes;
     newLayout->setNodeValue(f.a, Coord(-val, -val, 0));
     newLayout->setNodeValue(f.b, Coord(0, val, 0));
     newLayout->setNodeValue(f.c, Coord(val, -val, 0));
@@ -116,5 +116,5 @@ public:
     return  pluginProgress->state()!=TLP_CANCEL;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(PlanarGraph,"Planar Graph","Auber","25/06/2005","","1.0","Graphs")
+
+PLUGIN(PlanarGraph)
