@@ -16,8 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <time.h>
-#include <tulip/TulipPlugin.h>
+#include <ctime>
+#include <tulip/TulipPluginHeaders.h>
 
 using namespace std;
 using namespace tlp;
@@ -30,19 +30,11 @@ namespace std {
 template<>
 struct less<edgeS> {
   bool operator()(const edgeS &c,const edgeS &d) const {
-    if (c.source<d.source) return true;
-
-    if (c.source>d.source) return false;
-
-    if (c.target<d.target) return true;
-
-    if (c.target>d.target) return false;
-
-    return false;
+    return (c.source < d.source) ||
+           ((c.source == d.source) && (c.target<d.target));
   }
 };
-};
-
+}
 
 namespace {
 const char * paramHelp[] = {
@@ -51,7 +43,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "5" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the amount of node used to build the randomized graph." \
+  "Number of nodes in the final graph." \
   HTML_HELP_CLOSE(),
 
   // edges
@@ -59,14 +51,13 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "9" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the amount of edge used to build the randomized graph." \
+  "Number of edges in the final graph." \
   HTML_HELP_CLOSE(),
 };
 }
 
-
 /** \addtogroup import */
-/*@{*/
+
 /// Random Graph - Import of a random graph
 /** This plugin enables to create a random graph
  *
@@ -74,19 +65,20 @@ const char * paramHelp[] = {
  */
 class RandomGraph:public ImportModule {
 public:
-  RandomGraph(AlgorithmContext context):ImportModule(context) {
-    addParameter<unsigned int>("nodes",paramHelp[0],"5");
-    addParameter<unsigned int>("edges",paramHelp[1],"9");
+  PLUGININFORMATION("Random General Graph","Auber","16/06/2002","Imports a new randomly generated graph.","1.0","Graph")
+  RandomGraph(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<unsigned int>("nodes",paramHelp[0],"5");
+    addInParameter<unsigned int>("edges",paramHelp[1],"9");
   }
   ~RandomGraph() {
   }
 
   bool importGraph() {
-    srand(clock());
+    srand(time(NULL));
     unsigned int nbNodes  = 5;
     unsigned int nbEdges  = 9;
 
-    if (dataSet!=0) {
+    if (dataSet!=NULL) {
       dataSet->get("nodes", nbNodes);
       dataSet->get("edges", nbEdges);
     }
@@ -121,19 +113,20 @@ public:
     }
 
     vector<node> tmpVect(nbNodes);
+    graph->reserveNodes(nbNodes);
 
     for (unsigned int i=0; i<nbNodes; ++i) {
       tmpVect[i]=graph->addNode();
     }
 
-    set<edgeS>::const_iterator it;
+    graph->reserveEdges(myGraph.size());
 
-    for (it=myGraph.begin(); it!=myGraph.end(); ++it)   {
-      graph->addEdge(tmpVect[(*it).source],tmpVect[(*it).target]);
+    for (set<edgeS>::const_iterator it=myGraph.begin(); it!=myGraph.end(); ++it)   {
+      graph->addEdge(tmpVect[it->source],tmpVect[it->target]);
     }
 
     return true;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(RandomGraph,"Random General Graph","Auber","16/06/2002","","1.0","Graphs")
+
+PLUGIN(RandomGraph)
