@@ -16,8 +16,8 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <time.h>
-#include <tulip/TulipPlugin.h>
+#include <ctime>
+#include <tulip/TulipPluginHeaders.h>
 
 using namespace std;
 using namespace tlp;
@@ -50,19 +50,10 @@ struct less<edgeS> {
       ds=d.target;
     }
 
-    if (cs<ds) return true;
-
-    if (cs>ds) return false;
-
-    if (ct<dt) return true;
-
-    if (ct>dt) return false;
-
-    return false;
+    return (cs < ds) || ((cs == ds) && (ct < dt));
   }
 };
-};
-
+}
 
 namespace {
 
@@ -72,7 +63,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "5" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the amount of node used to build the randomized graph." \
+  "Number of nodes in the final graph." \
   HTML_HELP_CLOSE(),
 
   // edges
@@ -80,16 +71,14 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "9" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the amount of edge used to build the randomized graph." \
+  "Number of edges in the final graph." \
   HTML_HELP_CLOSE(),
 };
 
 }
 
-
-
 /** \addtogroup import */
-/*@{*/
+
 /// Random Simple Graph - Import of a random simple graph
 /** This plugin enables to create a random simple graph
  *
@@ -97,18 +86,18 @@ const char * paramHelp[] = {
  */
 class RandomSimpleGraph:public ImportModule {
 public:
-  RandomSimpleGraph(AlgorithmContext context):ImportModule(context) {
-    addParameter<unsigned int>("nodes",paramHelp[0],"5");
-    addParameter<unsigned int>("edges",paramHelp[1],"9");
+  PLUGININFORMATION("Random Simple Graph","Auber","16/06/2002","Imports a new randomly generated simple graph.","1.0","Graph")
+  RandomSimpleGraph(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<unsigned int>("nodes",paramHelp[0],"5");
+    addInParameter<unsigned int>("edges",paramHelp[1],"9");
   }
-  ~RandomSimpleGraph() {}
 
   bool importGraph() {
-    srand(clock());
+    srand(time(NULL));
     unsigned int nbNodes  = 5;
     unsigned int nbEdges  = 9;
 
-    if (dataSet!=0) {
+    if (dataSet!=NULL) {
       dataSet->get("nodes", nbNodes);
       dataSet->get("edges", nbEdges);
     }
@@ -151,19 +140,20 @@ public:
     }
 
     vector<node> tmpVect(nbNodes);
+    graph->reserveNodes(nbNodes);
 
     for (unsigned int i=0; i<nbNodes; ++i) {
       tmpVect[i]=graph->addNode();
     }
 
-    set<edgeS>::iterator it;
+    graph->reserveEdges(myGraph.size());
 
-    for (it=myGraph.begin(); it!=myGraph.end(); ++it)   {
-      graph->addEdge(tmpVect[(*it).source],tmpVect[(*it).target]);
+    for (set<edgeS>::iterator it=myGraph.begin(); it!=myGraph.end(); ++it)   {
+      graph->addEdge(tmpVect[it->source],tmpVect[it->target]);
     }
 
     return true;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(RandomSimpleGraph,"Random Simple Graph","Auber","16/06/2002","","1.0","Graphs")
+
+PLUGIN(RandomSimpleGraph)
