@@ -16,15 +16,12 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <time.h>
-#include <tulip/TulipPlugin.h>
-#include <tulip/StableIterator.h>
+#include <ctime>
+#include <tulip/TulipPluginHeaders.h>
 
 using namespace std;
 using namespace tlp;
 
-
-
 namespace {
 
 const char * paramHelp[] = {
@@ -33,7 +30,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "100" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the minimal amount of node used to build the randomized tree." \
+  "Minimal number of nodes in the tree." \
   HTML_HELP_CLOSE(),
 
   // maxsize
@@ -41,7 +38,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "1000" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the maximal amount of node used to build the randomized tree." \
+  "Maximal number of nodes in the tree." \
   HTML_HELP_CLOSE(),
 
   // tree layout
@@ -49,31 +46,22 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "bool" ) \
   HTML_HELP_DEF( "default", "false" ) \
   HTML_HELP_BODY() \
-  "This parameter indicates if the generated tree has to be drawn with a tree layout algorithm." \
+  "If true, the generated tree is drawn with a tree layout algorithm." \
   HTML_HELP_CLOSE(),
 };
 }
 
 /** \addtogroup import */
-/*@{*/
-/// Random Tree - Import of a random tree
+
+/// Random Tree - Import of a random uniform binary tree
 /** This plugin enables to create a random tree
  *
  *  User can specify the minimal/maximal numbers of nodes used to build of the tree.
  */
 class RandomTree:public ImportModule {
-public:
-  RandomTree(AlgorithmContext context):ImportModule(context) {
-    addParameter<unsigned int>("minsize",paramHelp[0],"100");
-    addParameter<unsigned int>("maxsize",paramHelp[1],"1000");
-    addParameter<bool>("tree layout",paramHelp[2],"false");
-    addDependency<LayoutAlgorithm>("Tree Leaf", "1.0");
-  }
-  ~RandomTree() {
-  }
 
   bool buildNode(node n, unsigned int sizeM) {
-    if (graph->numberOfNodes()>sizeM+2) return false;
+    if (graph->numberOfNodes()>=sizeM+2) return false;
 
     bool result=true;
     int randNumber=rand();
@@ -91,42 +79,56 @@ public:
     return result;
   }
 
+public:
+  PLUGININFORMATION("Uniform Random Binary Tree","Auber","16/02/2001","Imports a new randomly generated uniform binary tree.","1.1","Graph")
+  RandomTree(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<unsigned int>("Minimum size",paramHelp[0],"100");
+    addInParameter<unsigned int>("Maximum size",paramHelp[1],"1000");
+    addInParameter<bool>("tree layout",paramHelp[2],"false");
+    addDependency("Tree Leaf", "1.0");
+  }
+
   bool importGraph() {
-    srand(clock());
+    srand(time(NULL));
     unsigned int minSize  = 100;
     unsigned int maxSize  = 1000;
     bool needLayout = false;
 
-    if (dataSet!=0) {
-      dataSet->get("minsize", minSize);
-      dataSet->get("maxsize", maxSize);
+    if (dataSet!=NULL) {
+      if(dataSet->exist("Minimum size"))
+        dataSet->get("Minimum size", minSize);
+      else
+        dataSet->get("minsize", minSize);   //keep old name for backward compatibility
+
+      if(dataSet->exist("Maximum size"))
+        dataSet->get("Maximum size", maxSize);
+      else
+        dataSet->get("maxsize", maxSize); //keep old name for backward compatibility
+
       dataSet->get("tree layout", needLayout);
     }
 
-    if (maxSize == 0) {
+    if (maxSize < 1) {
       if (pluginProgress)
-        pluginProgress->setError(string("Error: maxsize cannot be null"));
+        pluginProgress->setError("Error: maximum size must be a strictly positive integer");
 
       return false;
     }
 
-    if (minSize > maxSize) {
+    if (maxSize < minSize) {
       if (pluginProgress)
-        pluginProgress->setError(string("Error: maxsize must be greater than minsize"));
+        pluginProgress->setError("Error: maximum size must be greater than minimum size");
 
       return false;
     }
 
-    if (pluginProgress)
-      pluginProgress->showPreview(false);
-
     bool ok=true;
     int i=0;
 
     while (ok) {
       if (pluginProgress->progress(i%100,100)!=TLP_CONTINUE) break;
 
-      i++;
+      ++i;
       graph->clear();
       node n=graph->addNode();
       ok = !buildNode(n,maxSize);
@@ -142,12 +144,12 @@ public:
       DataSet dSet;
       string errMsg;
       LayoutProperty *layout = graph->getProperty<LayoutProperty>("viewLayout");
-      return graph->computeProperty("Tree Leaf", layout, errMsg,
-                                    pluginProgress, &dSet);
+      return graph->applyPropertyAlgorithm("Tree Leaf", layout, errMsg,
+                                           pluginProgress, &dSet);
     }
 
     return true;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(RandomTree,"Uniform Random Binary Tree","Auber","16/02/2001","","1.1","Graphs")
+
+PLUGIN(RandomTree)
