@@ -16,15 +16,13 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <time.h>
-#include <tulip/TulipPlugin.h>
-#include <math.h>
+#include <ctime>
+#include <tulip/TulipPluginHeaders.h>
+#include <cmath>
 
 using namespace std;
 using namespace tlp;
 
-
-
 namespace {
 
 const char * paramHelp[] = {
@@ -33,28 +31,28 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "int" ) \
   HTML_HELP_DEF( "default", "10" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the minimal amount of node used to build the randomized tree." \
+  "Minimal number of nodes in the tree." \
   HTML_HELP_CLOSE(),
   // maxsize
   HTML_HELP_OPEN() \
   HTML_HELP_DEF( "type", "int" ) \
   HTML_HELP_DEF( "default", "100" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the maximal amount of node used to build the randomized tree." \
+  "Maximal number of nodes in the tree." \
   HTML_HELP_CLOSE(),
   // maxdegree
   HTML_HELP_OPEN() \
   HTML_HELP_DEF( "type", "int" ) \
   HTML_HELP_DEF( "default", "5" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the maximal degree of node used to build the randomized tree." \
+  "Maximal degree of the nodes." \
   HTML_HELP_CLOSE(),
   // tree layout
   HTML_HELP_OPEN() \
   HTML_HELP_DEF( "type", "bool" ) \
   HTML_HELP_DEF( "default", "false" ) \
   HTML_HELP_BODY() \
-  "This parameter indicates if the generated tree has to be drawn with a tree layout algorithm." \
+  "If true, the generated tree is drawn with a tree layout algorithm." \
   HTML_HELP_CLOSE(),
 };
 }
@@ -62,25 +60,16 @@ const char * paramHelp[] = {
 
 
 /** \addtogroup import */
-/*@{*/
+
 /// Random General Tree - Import of a random general tree
 /** This plugin enables to create a random general tree
  *
  *  User can specify the minimal/maximal number of nodes and the maximal degree.
  */
 class RandomTreeGeneral:public ImportModule {
-public:
-  RandomTreeGeneral(AlgorithmContext context):ImportModule(context) {
-    addParameter<int>("minsize",paramHelp[0],"10");
-    addParameter<int>("maxsize",paramHelp[1],"100");
-    addParameter<int>("maxdegree",paramHelp[2],"5");
-    addParameter<bool>("tree layout",paramHelp[3],"false");
-    addDependency<LayoutAlgorithm>("Tree Leaf", "1.0");
-  }
-  ~RandomTreeGeneral() {
-  }
+
   bool buildNode(node n,unsigned int sizeM,int arityMax) {
-    if (graph->numberOfNodes()>sizeM) return true;
+    if (graph->numberOfNodes()>=sizeM) return true;
 
     bool result=true;
     int randNumber=rand();
@@ -90,8 +79,10 @@ public:
       ++i;
 
     i = i % arityMax;
+    graph->reserveNodes(i);
+    graph->reserveEdges(i);
 
-    for (; i>0; i--) {
+    for (; i>0; --i) {
       node n1;
       n1=graph->addNode();
       graph->addEdge(n,n1);
@@ -101,31 +92,60 @@ public:
     return result;
   }
 
+public:
+  PLUGININFORMATION("Random General Tree","Auber","16/02/2001","Imports a new randomly generated tree.","1.1","Graph")
+  RandomTreeGeneral(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<unsigned>("Minimum size",paramHelp[0],"10");
+    addInParameter<unsigned>("Maximum size",paramHelp[1],"100");
+    addInParameter<unsigned>("Maximal node's degree",paramHelp[2],"5");
+    addInParameter<bool>("tree layout",paramHelp[3],"false");
+    addDependency("Tree Leaf", "1.0");
+  }
+
   bool importGraph() {
-    srand(clock());
+    srand(time(NULL));
 
     unsigned int sizeMin  = 10;
     unsigned int sizeMax  = 100;
     unsigned int arityMax = 5;
     bool needLayout = false;
 
-    if (dataSet!=0) {
-      dataSet->get("minsize", sizeMin);
-      dataSet->get("maxsize", sizeMax);
-      dataSet->get("maxdegree", arityMax);
+    if (dataSet!=NULL) {
+      if(dataSet->exist("Minimum size"))
+        dataSet->get("Minimum size", sizeMin);
+      else
+        dataSet->get("minsize", sizeMin);   //keep old parameter name for backward compatibility
+
+      if(dataSet->exist("Maximum size"))
+        dataSet->get("Maximum size", sizeMax);
+      else
+        dataSet->get("maxsize", sizeMax); //keep old parameter name for backward compatibility
+
+      if(dataSet->exist("Maximal node's degree"))
+        dataSet->get("Maximal node's degree", arityMax);
+      else
+        dataSet->get("maxdegree", arityMax); //keep old parameter name for backward compatibility
+
       dataSet->get("tree layout", needLayout);
     }
 
     if (arityMax < 1) {
       if (pluginProgress)
-        pluginProgress->setError("Error: maxdegree must be a strictly positive integer");
+        pluginProgress->setError("Error: maximum node's degree must be a strictly positive integer");
 
       return false;
     }
 
     if (sizeMax < 1) {
       if (pluginProgress)
-        pluginProgress->setError("Error: maxsize must be a strictly positive integer");
+        pluginProgress->setError("Error: maximum size must be a strictly positive integer");
+
+      return false;
+    }
+
+    if (sizeMax < sizeMin) {
+      if (pluginProgress)
+        pluginProgress->setError("Error: maximum size must be greater than minimum size");
 
       return false;
     }
@@ -141,11 +161,10 @@ public:
         if (pluginProgress->progress((i/100)%100,100)!=TLP_CONTINUE) break;
       }
 
-      i++;
+      ++i;
       graph->clear();
       node n=graph->addNode();
       ok=!buildNode(n,sizeMax,arityMax);
-      ok=false;
 
       if (graph->numberOfNodes()<sizeMin) ok=true;
     }
@@ -158,12 +177,12 @@ public:
       DataSet dSet;
       string errMsg;
       LayoutProperty *layout = graph->getProperty<LayoutProperty>("viewLayout");
-      return graph->computeProperty("Tree Leaf", layout, errMsg,
-                                    pluginProgress, &dSet);
+      return graph->applyPropertyAlgorithm("Tree Leaf", layout, errMsg,
+                                           pluginProgress, &dSet);
     }
 
     return true;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(RandomTreeGeneral,"Random General Tree","Auber","16/02/2001","","1.1","Graphs")
+
+PLUGIN(RandomTreeGeneral)
