@@ -19,7 +19,7 @@
 #include <time.h>
 #include <math.h>
 #include <climits>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 using namespace std;
 using namespace tlp;
@@ -33,7 +33,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "100" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the amount of node used to build the small-world graph." \
+  "Number of nodes in the final graph." \
   HTML_HELP_CLOSE(),
 
   // degree
@@ -41,7 +41,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "unsigned int" ) \
   HTML_HELP_DEF( "default", "10" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the average degree of node used to build the small-world graph." \
+  "Average degree of the nodes in the final graph." \
   HTML_HELP_CLOSE(),
 
   // degree
@@ -49,7 +49,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "bool" ) \
   HTML_HELP_DEF( "default", "false" ) \
   HTML_HELP_BODY() \
-  "If true long distance edges will be added in the grid approximation." \
+  "If true, long distance edges are added in the grid approximation." \
   HTML_HELP_CLOSE(),
 };
 }
@@ -60,18 +60,19 @@ const char * paramHelp[] = {
  */
 
 /** \addtogroup import */
-/*@{*/
+
 /// Grid Approximation - Import of a grid approximation
-/** This plugin enables to create a gride approximation
+/** This plugin enables to create a grid approximation
  *
  *  User can specify the number of nodes and their average degree.
  */
 class SmallWorldGraph:public ImportModule {
 public:
-  SmallWorldGraph(AlgorithmContext context):ImportModule(context) {
-    addParameter<unsigned int>("nodes",paramHelp[0],"200");
-    addParameter<unsigned int>("degree",paramHelp[1],"10");
-    addParameter<bool>("long edge",paramHelp[2],"false");
+  PLUGININFORMATION("Grid Approximation","Auber","25/06/2002","Imports a new grid approximation graph.","1.0","Graph")
+  SmallWorldGraph(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<unsigned int>("nodes",paramHelp[0],"200");
+    addInParameter<unsigned int>("degree",paramHelp[1],"10");
+    addInParameter<bool>("long edge",paramHelp[2],"false");
   }
   ~SmallWorldGraph() {}
 
@@ -80,7 +81,7 @@ public:
     unsigned int avgDegree = 10;
     bool enableLongEdge = false;
 
-    if (dataSet!=0) {
+    if (dataSet!=NULL) {
       dataSet->get("nodes", nbNodes);
       dataSet->get("degree", avgDegree);
       dataSet->get("long edge", enableLongEdge);
@@ -108,23 +109,18 @@ public:
 
     pluginProgress->showPreview(false);
 
+    graph->addNodes(nbNodes, sg);
+
     for (unsigned int i=0; i<nbNodes; ++i) {
-      sg[i]=graph->addNode();
       newLayout->setNodeValue(sg[i],Coord(static_cast<float>(rand()%WIDTH), static_cast<float>(rand()%HEIGHT), 0));
     }
 
-    unsigned int count = 0;
-    unsigned int iterations = nbNodes*(nbNodes-1)/2;
     double minSize = DBL_MAX;
 
     for (unsigned int i=0; i<nbNodes-1; ++i) {
       bool longEdge =false;
 
-      if (pluginProgress->progress(count,iterations)!=TLP_CONTINUE) break;
-
       for (unsigned int j=i+1; j<nbNodes; ++j) {
-        ++count;
-
         if (i!=j) {
           double distance = newLayout->getNodeValue(sg[i]).dist(newLayout->getNodeValue(sg[j]));
           minSize = std::min(distance, minSize);
@@ -142,10 +138,12 @@ public:
           }
         }
       }
+
+      if (pluginProgress->progress(i, nbNodes - 1)!=TLP_CONTINUE) break;
     }
 
     return  pluginProgress->state()!=TLP_CANCEL;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(SmallWorldGraph,"Grid Approximation","Auber","25/06/2002","","1.0","Graphs")
+
+PLUGIN(SmallWorldGraph)
