@@ -16,10 +16,11 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <QtGui/qapplication.h>
-#include <QtCore/qtimer.h>
 #include <iostream>
-#include <tulip/TulipPlugin.h>
+#include <qapplication.h>
+#include <qtimer.h>
+#include <tulip/TulipPluginHeaders.h>
+#include <tulip/DownloadManager.h>
 #include "WebImport.h"
 
 using namespace std;
@@ -29,7 +30,6 @@ class UrlElement {
 public:
   bool is_http;
   std::string data;
-  unsigned int serverport;
   std::string server;
   std::string url;
   std::string clean_url;
@@ -48,7 +48,7 @@ public:
 private:
   void fill(std::string &result);
   bool siteconnect(const std::string &server, const std::string &url,
-                   const int serverport, bool headonly);
+                   bool headonly);
 
 private:
   HttpContext *context;
@@ -63,7 +63,7 @@ public:
   }
 
   UrlElement getRedirection() {
-    return parseUrl(context->newLocation);
+    return parseUrl(context->data);
   }
   int getCode() {
     return context->code;
@@ -83,58 +83,108 @@ struct less<UrlElement> {
 };
 }
 
-HttpContext::HttpContext() {
-  // connect the requestFinished signal to our finished slot
-  connect(this, SIGNAL(requestFinished(int, bool)), this, SLOT(finished(int, bool)));
-  connect(this, SIGNAL(responseHeaderReceived(const QHttpResponseHeader &)),
-          this, SLOT(headerReceived(const QHttpResponseHeader &)));
+HttpContext::HttpContext():
+  status(false), code(-1), reply(NULL),
+  processed(false), redirected(false), isHtml(false) {
 }
 
-void HttpContext::finished(int id, bool error) {
+HttpContext::~HttpContext() {
+  if (reply)  {
+    reply->close();
+    reply->deleteLater();
+    reply = NULL;
+  }
+}
+
+void HttpContext::request(const std::string& url, bool head) {
+  if (reply)  {
+    reply->close();
+    reply->deleteLater();
+    reply = NULL;
+  }
+
+  processed = isHtml = redirected = false;
+  QNetworkRequest request(QUrl(url.c_str()));
+
+  if (head) {
+    reply = DownloadManager::getInstance()->head(request);
+    connect(reply, SIGNAL(finished()), this, SLOT(headerReceived()));
+  }
+  else {
+    reply = DownloadManager::getInstance()->get(request);
+    connect(reply, SIGNAL(finished()), this, SLOT(finished()));
+  }
+}
+
+void HttpContext::finished() {
   // check to see if it is the request we made
-  if(id !=rqid) return;
+  if (reply != qobject_cast<QNetworkReply*>(sender()))
+    return;
 
-  // set status of the request
-  status = !error;
   // OK
   processed = true;
+
+  // set status of the request
+  if ((status = (reply->error() == QNetworkReply::NoError)))
+    data = reply->readAll().data();
 }
 
-void HttpContext::headerReceived(const QHttpResponseHeader & resp) {
-  if ((isHtml = resp.isValid())) {
-    code = resp.statusCode();
+void HttpContext::headerReceived() {
+  // check to see if it is the request we made
+  if (reply != qobject_cast<QNetworkReply*>(sender()))
+    return;
 
-    if (code > 399) /* error codes */
-      isHtml = false;
-    else if ((code > 299) &&
-             (code < 305 || code == 307)) {
-      /* redirection codes */
-      redirected = true;
-      newLocation = resp.value(QString("Location")).toAscii().data();
+  processed = true;
+
+  if ((status = isHtml = (reply->error() == QNetworkReply::NoError))) {
+    QVariant value = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute);
+
+    if (value.canConvert<int>()) {
+      code = value.toInt();
+
+      if (code > 399) /* error codes */
+        isHtml = false;
+      else if ((code > 299) &&
+               (code < 305 || code == 307)) {
+        /* redirection codes */
+        redirected = true;
+        QVariant redirectionTarget = reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
+
+        if (!redirectionTarget.isNull())
+          data = redirectionTarget.toUrl().toString().toStdString();
+        else
+          data = "";
+      }
+
+      return;
     }
-    else   /* normal codes */
-      isHtml = resp.hasContentType() &&
-               resp.contentType().contains(QString("text/html"));
+
+    /* normal codes */
+    value = reply->header(QNetworkRequest::ContentTypeHeader);
+    status = isHtml = (value.canConvert<QString>() &&
+                       value.toString().contains(QString("text/html")));
+    reply->close();
   }
 }
 
 void HttpContext::timeout() {
-  cerr << "time-out occurs" << endl;
+  if (!processed)
+    tlp::warning() << "time-out occurs" << endl;
+
   // if timeout occurs
   // just indicates the we failed during processing
   processed = true;
-  status = false;
 }
 
 void HttpContext::setTimer(QTimer *timer) {
   connect(timer, SIGNAL(timeout()), SLOT(timeout()));
 }
 
-UrlElement::UrlElement():is_http(true),data(""),serverport(80),context(0)  {
+UrlElement::UrlElement():is_http(true),data(""),context(0)  {
 }
 UrlElement::UrlElement(const UrlElement &c):
   is_http(c.is_http),
-  data(""),serverport(c.serverport),server(c.server),url(c.url),clean_url(c.clean_url),context(0) {
+  data(""),server(c.server),url(c.url),clean_url(c.clean_url),context(NULL) {
 }
 
 void UrlElement::setUrl(const std::string& theUrl) {
@@ -148,15 +198,13 @@ void UrlElement::setUrl(const std::string& theUrl) {
 }
 
 void UrlElement::fill(std::string &result) {
-  if (context->bytesAvailable() > 0)
-    result += context->readAll().data();
+  result += context->data;
 }
 
 void UrlElement::clear() {
   if (context) {
-    context->clearPendingRequests();
     delete context;
-    context = 0;
+    context = NULL;
   }
 
   data = "";
@@ -164,7 +212,7 @@ void UrlElement::clear() {
 
 
 bool UrlElement::load() {
-  if (!siteconnect(server,url,serverport,false))
+  if (!siteconnect(server,url,false))
     return false;
 
   fill(data);
@@ -173,7 +221,7 @@ bool UrlElement::load() {
 
 static const char* not_html_extensions[] = {
   ".bmp", ".css", ".doc", ".ico", ".exe", ".gif", ".gz", ".js", ".jpeg", ".jpg",
-  ".pdf", ",.png", ".ps", ".tar", ".tgz", ".wav", ".zip", ".z",
+  ".pdf", ".png", ".ps", ".rss", ".tar", ".tgz", ".wav", ".zip", ".z",
   0 /* must be the last */
 };
 
@@ -188,42 +236,40 @@ bool UrlElement::isHtmlPage() {
     if (lowercase.rfind(not_html_extensions[i], len) != string::npos)
       return false;
 
-  if(!siteconnect(server,url,serverport,true))
+  if(!siteconnect(server,url,true))
     return false;
 
   return context->isHtml;
 }
 
-bool UrlElement::siteconnect(const std::string &server, const std::string &url,const int serverport, bool headonly) {
+bool UrlElement::siteconnect(const std::string &server, const std::string &path,
+                             bool headonly) {
   // check that we actually got data..
   if (server.empty()) return false;
 
   if (!context)
     context = new HttpContext();
 
-  context->setHost(QString(server.c_str()), serverport);
-  string theUrl("/");
+  string thePath("/");
 
-  // prefix the url with / if it doesn't start with it..
-  if (url.empty() || url.c_str()[0] != '/')
-    theUrl += url;
+  // prefix the path with / if it doesn't start with it..
+  if (path.c_str()[0] != '/')
+    thePath += url;
   else
-    theUrl = url;
+    thePath = url;
 
-  context->processed = context->isHtml = context->redirected = false;
+  string url("http://");
+  url += server.c_str() + thePath;
 
-  // start the request and store the request ID
-  if (headonly)
-    context->rqid = context->head(QString(theUrl.c_str()));
-  else
-    context->rqid = context->get(QString(theUrl.c_str()));
+  // start the request
+  context->request(url, headonly);
 
   // block until the request is finished
   // or there is timeout
   QTimer timer;
   timer.setSingleShot(true);
   context->setTimer(&timer);
-  timer.start(2000);
+  timer.start(20000);
 
   while(!context->processed) {
     QCoreApplication::processEvents();
@@ -328,14 +374,14 @@ UrlElement UrlElement::parseUrl (const std::string &href) {
           findUp = urlreference.rfind('/', findUp - 1);
 
           if (findUp==string::npos) {
-            cerr << "bad url reference, to much ../" << endl;
+            tlp::warning() << "bad url reference, to much ../" << endl;
             return newUrl;
           }
 
           urlreference = urlreference.substr(0, findUp + 1);
         }
         else {
-          cerr << "bad url reference, to much ../" << endl;
+          tlp::warning() << "bad url reference, to much ../" << endl;
           return newUrl;
         }
       }
@@ -346,7 +392,6 @@ UrlElement UrlElement::parseUrl (const std::string &href) {
     if (theUrl != "/") {
       newUrl.setUrl(theUrl);
       newUrl.server = this->server;
-      newUrl.serverport = this->serverport;
     }
   }
 
@@ -423,6 +468,8 @@ const char * paramHelp[] = {
 }
 
 struct WebImport:public ImportModule {
+  PLUGININFORMATION("Web Site","Auber","15/11/2004","Imports a new graph from Web site structure (one node per page).","1.0","Misc")
+
   std::deque<UrlElement> toVisit;
   std::set<UrlElement> visited;
   std::map<UrlElement, tlp::node> nodes;
@@ -434,17 +481,17 @@ struct WebImport:public ImportModule {
   bool visitOther;
   bool extractNonHttp;
 
-  WebImport(AlgorithmContext context):ImportModule(context) {
-    addParameter<string>("server",paramHelp[0],"www.labri.fr");
-    addParameter<string>("web page",paramHelp[1], "");
-    addParameter<int>("max size",paramHelp[2], "1000");
-    addParameter<bool>("non http links",paramHelp[3], "false");
-    addParameter<bool>("other server",paramHelp[4], "false");
-    addParameter<bool>("compute layout",paramHelp[5], "true");
-    addParameter<Color>("page color",paramHelp[6],"(240, 0, 120, 128)");
-    addParameter<Color>("link color",paramHelp[7],"(96,96,191,128)");
-    addParameter<Color>("redirection color",paramHelp[8],"(191,175,96,128)");
-    addDependency<LayoutAlgorithm>("GEM (Frick)", "1.2");
+  WebImport(tlp::PluginContext* context):ImportModule(context),labels(NULL), urls(NULL), colors(NULL), redirectionColor(NULL), maxSize(1000), nbNodes(0), visitOther(false), extractNonHttp(true) {
+    addInParameter<string>("server",paramHelp[0],"www.labri.fr");
+    addInParameter<string>("web page",paramHelp[1], "");
+    addInParameter<int>("max size",paramHelp[2], "1000");
+    addInParameter<bool>("non http links",paramHelp[3], "false");
+    addInParameter<bool>("other server",paramHelp[4], "false");
+    addInParameter<bool>("compute layout",paramHelp[5], "true");
+    addInParameter<Color>("page color",paramHelp[6],"(240, 0, 120, 128)");
+    addInParameter<Color>("link color",paramHelp[7],"(96,96,191,128)");
+    addInParameter<Color>("redirection color",paramHelp[8],"(191,175,96,128)");
+    addDependency("FM^3 (OGDF)", "1.2");
   }
 
   string urlDecode(const string& url) {
@@ -549,7 +596,7 @@ struct WebImport:public ImportModule {
   }
   //========================================================
   bool nextUrl(UrlElement & url) {
-    //cerr << __PRETTY_FUNCTION__ << endl;
+    //tlp::warning() << __PRETTY_FUNCTION__ << endl;
     while(!toVisit.empty()) {
       url = toVisit.front();
       toVisit.pop_front();
@@ -570,9 +617,9 @@ struct WebImport:public ImportModule {
 
     while ( len != string::npos ) {
       len = lowercase.rfind(balise, len);
-      bool urlFound = true;
 
       if( len != string::npos ) {
+        bool urlFound = true;
         // find the next '=' then the first '"'
         size_t start = len + balise.length();
         len--;
@@ -619,7 +666,7 @@ struct WebImport:public ImportModule {
   //========================================================
   // parsehtml - parse the given html and add to queue
   void parseHtml (UrlElement &url) {
-    //cerr << __PRETTY_FUNCTION__ << endl << flush;
+    //tlp::warning() << __PRETTY_FUNCTION__ << endl << flush;
     if (url.data.empty()) return;
 
     string lowercase(url.data);
@@ -639,19 +686,6 @@ struct WebImport:public ImportModule {
       toVisit.push_back(url);
   }
   //========================================================
-  void addServer(const string &servername) {
-    UrlElement tmpUrl;
-    tmpUrl.server = servername;
-    tmpUrl.setUrl("/");
-    tmpUrl.serverport = 80;
-    tmpUrl.data = "";
-
-    if (visited.find(tmpUrl)!=visited.end())
-      return;
-
-    toVisit.push_back(tmpUrl);
-  }
-  //========================================================
   void parseUrl (const string &href, UrlElement &starturl) {
     UrlElement newUrl = starturl.parseUrl(href);
 
@@ -675,7 +709,7 @@ struct WebImport:public ImportModule {
         }
 
 #ifndef NDEBUG
-        cerr << "Visiting: " << url.server << url.url << " ..." << flush;
+        tlp::warning() << "Visiting: " << url.server << url.url << " ..."  << std::endl << flush;
 #endif
 
         if (url.isRedirected()) {
@@ -683,7 +717,7 @@ struct WebImport:public ImportModule {
 
           if (redirection.isValid()) {
 #ifndef NDEBUG
-            cerr << endl << "redirected to " << redirection.server << redirection.url << endl;
+            tlp::warning() << endl << "redirected to " << redirection.server << redirection.url << endl;
 #endif
 
             if (addEdge(url, redirection,  "redirection", redirectionColor))
@@ -691,21 +725,21 @@ struct WebImport:public ImportModule {
                      visitOther || redirection.server == url.server);
           }
           else
-            cerr << endl << "invalid redirection" << endl;
+            tlp::warning() << endl << "invalid redirection" << endl;
         }
         else {
           url.load();
           parseHtml(url);
           url.clear();
 #ifndef NDEBUG
-          cerr << " done" << endl << flush;
+          tlp::warning() << " done" << endl << flush;
 #endif
         }
       }
 
 #ifndef NDEBUG
       else
-        cerr << "Omitting : " << url.server << url.url << " ==> [not html]"<< endl;
+        tlp::warning() << "Omitting : " << url.server << url.url << " ==> [not html]"<< endl;
 
 #endif
     }
@@ -726,7 +760,7 @@ struct WebImport:public ImportModule {
     visitOther = false;
     extractNonHttp = true;
 
-    if (dataSet != 0) {
+    if (dataSet != NULL) {
       dataSet->get("server", server);
       dataSet->get("web page", url);
       dataSet->get("max size", maxSize);
@@ -745,8 +779,8 @@ struct WebImport:public ImportModule {
       // remove http:// prefix
       server = server.substr(7);
 
-    // remove / prfix
-    if (server[0] == 0)
+    // remove / prefix
+    if (server[0] == '/')
       server = server.substr(1);
 
     if (server[server.size() - 1] == '/')
@@ -760,7 +794,6 @@ struct WebImport:public ImportModule {
       url = url.substr(1);
 
     mySite.setUrl(string("/") + url);
-    mySite.serverport = 80;
     mySite.data = "";
 
     labels = graph->getProperty<StringProperty>("viewLabel");
@@ -797,18 +830,17 @@ struct WebImport:public ImportModule {
       return false;
 
     if (computelayout) {
-      pluginProgress->setComment("Layouting extracted graph using GEM...");
+      pluginProgress->setComment("Layouting extracted graph using FM³...");
       string errMsg;
-      // apply GEM
+      // apply FM³
       DataSet tmp;
       LayoutProperty *layout = graph->getProperty<LayoutProperty>("viewLayout");
-      tmp.set("initial layout", layout);
-      return graph->computeProperty("GEM (Frick)", layout,
-                                    errMsg, pluginProgress, &tmp);
+      return graph->applyPropertyAlgorithm("FM^3 (OGDF)", layout, errMsg, pluginProgress, &tmp);
     }
 
     return true;
   }
 };
 
-IMPORTPLUGINOFGROUP(WebImport,"Web Site","Auber","15/11/2004","Import Web site plugin","1.0","Misc")
+
+PLUGIN(WebImport)
