@@ -19,7 +19,7 @@
 #include <string.h>
 #include <errno.h>
 #include <tulip/tuliphash.h>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 #include "dotImportCLUT.h"
 
 using namespace std;
@@ -29,10 +29,6 @@ using namespace tlp;
 #define uint unsigned int
 #endif
 
-#ifdef _WIN32
-#define uint unsigned int
-#endif
-
 namespace {
 #include "dotImportParser.h"
 #include "dotImportLexer.h"
@@ -44,13 +40,13 @@ static const char * paramHelp[] = {
   HTML_HELP_OPEN()            \
   HTML_HELP_DEF( "type", "pathname" )       \
   HTML_HELP_BODY()                  \
-  "This parameter defines the file pathname to import."       \
+  "File to import."       \
   HTML_HELP_CLOSE(),
 };
 }
 
 /** \addtogroup import */
-/*@{*/
+
 /** This plugin enables to import a graph coded with in dot format
  *
  *  File format:
@@ -66,11 +62,21 @@ static const char * paramHelp[] = {
  */
 class DotImport:public ImportModule {
 public:
-  DotImport(AlgorithmContext context):ImportModule(context) {
-    addParameter<string>("file::filename",paramHelp[0]);
+  PLUGININFORMATION("graphviz","Gerald Gainant", "01/03/2004","Imports a new graph from a file (.dot) in the dot input format.","1.0","File")
+  std::list<std::string> fileExtensions() const {
+    std::list<std::string> l;
+    l.push_back("dot");
+    return l;
+  }
+  DotImport(tlp::PluginContext* context):ImportModule(context) {
+    addInParameter<string>("file::filename",paramHelp[0],"");
   }
   ~DotImport() {}
 
+  std::string icon() const {
+    return ":/tulip/graphperspective/icons/32/import_graphviz.png";
+  }
+
   bool importGraph() {
 
     // Open input stream
@@ -102,6 +108,5 @@ public:
     return _dotyy.pStatus != TLP_CANCEL;
   }
 };
-/*@}*/
-IMPORTPLUGINOFGROUP(DotImport,"dot (graphviz)","Gerald Gainant", "01/03/2004","Import plugin for dot files",".01","File")
 
+PLUGIN(DotImport)
