@@ -18,8 +18,9 @@
  */
 
 #include <tulip/MouseInteractors.h>
-
-#include "NodeLinkDiagramComponentInteractor.h"
+#include <tulip/NodeLinkDiagramComponentInteractor.h>
+#include <tulip/NodeLinkDiagramComponent.h>
+#include "../utils/StandardInteractorPriority.h"
 
 using namespace tlp;
 
@@ -29,12 +30,12 @@ using namespace tlp;
 class InteractorDeleteElement  : public NodeLinkDiagramComponentInteractor {
 
 public:
-
+  PLUGININFORMATION("InteractorDeleteElement", "Tulip Team", "01/04/2009", "Delete Element Interactor", "1.0", "Modification")
   /**
    * Default constructor
    */
-  InteractorDeleteElement():NodeLinkDiagramComponentInteractor(":/i_del.png","Delete nodes or edges") {
-    setPriority(1);
+  InteractorDeleteElement(const tlp::PluginContext*):NodeLinkDiagramComponentInteractor(":/tulip/gui/icons/i_del.png","Delete nodes or edges") {
+    setPriority(StandardInteractorPriority::DeleteElement);
     setConfigurationWidgetText(QString("<h3>Delete interactor</h3>")+
                                "<b>Mouse left</b> click on an element to delete it");
   }
@@ -43,9 +44,15 @@ public:
    * Construct chain of responsibility
    */
   void construct() {
-    pushInteractorComponent(new MousePanNZoomNavigator);
-    pushInteractorComponent(new MouseElementDeleter);
+    push_back(new MousePanNZoomNavigator);
+    push_back(new MouseElementDeleter);
   }
+
+  bool isCompatible(const std::string &viewName) const {
+    return (viewName==NodeLinkDiagramComponent::viewName);
+  }
+
+
 };
 
-INTERACTORPLUGIN(InteractorDeleteElement, "InteractorDeleteElement", "Tulip Team", "01/04/2009", "Delete Element Interactor", "1.0");
+PLUGIN(InteractorDeleteElement)
