@@ -20,8 +20,11 @@
 #include <tulip/MouseInteractors.h>
 #include <tulip/MouseSelector.h>
 #include <tulip/MouseEdgeBendEditor.h>
+#include <tulip/NodeLinkDiagramComponentInteractor.h>
+#include <tulip/NodeLinkDiagramComponent.h>
 
-#include "NodeLinkDiagramComponentInteractor.h"
+#include "../utils/StandardInteractorPriority.h"
+#include "../utils/ViewNames.h"
 
 using namespace tlp;
 
@@ -31,18 +34,18 @@ using namespace tlp;
 class InteractorEditEdgeBends  : public NodeLinkDiagramComponentInteractor {
 
 public:
-
+  PLUGININFORMATION("InteractorEditEdgeBends", "Tulip Team", "01/04/2009", "Edit Edge Bends Interactor", "1.0", "Modification")
   /**
    * Default constructor
    */
-  InteractorEditEdgeBends():NodeLinkDiagramComponentInteractor(":/i_bends.png","Edit edge bends") {
-    setPriority(1);
+  InteractorEditEdgeBends(const tlp::PluginContext*):NodeLinkDiagramComponentInteractor(":/tulip/gui/icons/i_bends.png","Edit edge bends") {
+    setPriority(StandardInteractorPriority::EditEdgeBends);
     setConfigurationWidgetText(QString("<h3>Edit edge bends interactor</h3>")+
                                "Modify edge bends<br/><br/>"+
                                "Select edge: <ul><li>use rectangle selection</li></ul>" +
                                "Translate bend: <ul><li><b>Mouse left</b> down on a selected bend + moves</li></ul>" +
-                               "Change source node: <ul><li><b>Drag and drop</b> circle on source node</li></ul>"+
-                               "Change target node: <ul><li><b>Drag and drop</b> triangle on target node</li></ul>"+
+                               "Change source node: <ul><li><b>Drag and drop circle on source node</li></ul>"+
+                               "Change target node: <ul><li><b>Drag and drop triangle on target node</li></ul>"+
                                "Add bend: <ul><li><b>Double click with mouse left</b> click on the selected edge</li></ul>"+
 #if !defined(__APPLE__)
                                "Delete bend: <ul><li><b>Ctrl + Mouse left</b> click on a selected bend</li></ul>"
@@ -56,10 +59,17 @@ public:
    * Construct chain of responsibility
    */
   void construct() {
-    pushInteractorComponent(new MousePanNZoomNavigator);
-    pushInteractorComponent(new MouseSelector);
-    pushInteractorComponent(new MouseEdgeBendEditor);
+    push_back(new MousePanNZoomNavigator);
+    push_back(new MouseSelector);
+    push_back(new MouseEdgeBendEditor);
   }
+
+  bool isCompatible(const std::string &viewName) const {
+    return ((viewName==NodeLinkDiagramComponent::viewName)
+            ||(viewName==ViewName::GoogleMapsViewName)
+           );
+  }
+
 };
 
-INTERACTORPLUGIN(InteractorEditEdgeBends, "InteractorEditEdgeBends", "Tulip Team", "01/04/2009", "Edit Edge Bends Interactor", "1.0");
+PLUGIN(InteractorEditEdgeBends)
