@@ -18,8 +18,11 @@
  */
 
 #include <tulip/MouseInteractors.h>
+#include <tulip/NodeLinkDiagramComponentInteractor.h>
+#include <tulip/NodeLinkDiagramComponent.h>
 
-#include "NodeLinkDiagramComponentInteractor.h"
+#include "../utils/StandardInteractorPriority.h"
+#include "../utils/ViewNames.h"
 
 using namespace tlp;
 
@@ -29,14 +32,14 @@ using namespace tlp;
 class InteractorNavigation  : public NodeLinkDiagramComponentInteractor {
 
 public:
-
+  PLUGININFORMATION("InteractorNavigation", "Tulip Team", "01/04/2009", "Navigation Interactor", "1.0", "Navigation")
   /**
    * Default constructor
    */
-  InteractorNavigation():NodeLinkDiagramComponentInteractor(":/i_navigation.png","Navigate in graph") {
-    setPriority(5);
-    setConfigurationWidgetText(QString("<h3>Navigation interactor</h3>")+
-                               "3D Navigation in the graph<br><br>"+
+  InteractorNavigation(const tlp::PluginContext*):NodeLinkDiagramComponentInteractor(":/tulip/gui/icons/i_navigation.png","Navigate in graph") {
+    setPriority(StandardInteractorPriority::Navigation);
+    setConfigurationWidgetText(QString("<h3>Navigate in graph</h3>")+
+                               "3D Navigation in the graph<br/><br/>"+
                                "Translation: <ul><li><b>Mouse left</b> down + moves</li><li>or <b>Arrow</b> keys down</li></ul>" +
                                "X or Y rotation: <ul><li><b>Shift + Mouse left</b> down + up/down or left/right moves</li></ul>" +
 #if !defined(__APPLE__)
@@ -46,6 +49,8 @@ public:
                                "Z rotation: <ul><li><b>Alt + Mouse left</b> down + left/right moves</li><li> or <b>Insert</b> key</li></ul>" +
                                "Zoom/Unzoom: <ul><li><b>Alt + Mouse left</b> down + up/down moves</li><li> or <b>Pg up/Pg down</b> keys</li></ul>"
 #endif
+                               + "Meta node navigation: <ul><li><b>double Mouse left click</b> go inside the metanode</li>"+
+                               "<li><b>Ctrl + double Mouse left click</b> go outside the metanode</li></ul>"
                               );
   }
 
@@ -53,13 +58,20 @@ public:
    * Construct chain of responsibility
    */
   void construct() {
-    pushInteractorComponent(new MouseNKeysNavigator);
+    push_back(new MouseNKeysNavigator);
   }
 
-  QCursor getCursor() {
+  QCursor cursor() const {
     return QCursor(Qt::OpenHandCursor);
   }
 
+  bool isCompatible(const std::string &viewName) const {
+    return ((viewName==NodeLinkDiagramComponent::viewName)
+            ||(viewName==ViewName::MatrixViewName)
+            ||(viewName==ViewName::ParallelCoordinatesViewName)
+           );
+  }
+
 };
 
-INTERACTORPLUGIN(InteractorNavigation, "InteractorNavigation", "Tulip Team", "01/04/2009", "Navigation Interactor", "1.0");
+PLUGIN(InteractorNavigation)
