@@ -18,9 +18,12 @@
  */
 
 #include <tulip/MouseInteractors.h>
+#include <tulip/NodeLinkDiagramComponentInteractor.h>
 #include <tulip/MouseBoxZoomer.h>
+#include <tulip/NodeLinkDiagramComponent.h>
 
-#include "NodeLinkDiagramComponentInteractor.h"
+#include "../utils/StandardInteractorPriority.h"
+#include "../utils/ViewNames.h"
 
 using namespace tlp;
 
@@ -30,12 +33,12 @@ using namespace tlp;
 class InteractorRectangleZoom  : public NodeLinkDiagramComponentInteractor {
 
 public:
-
+  PLUGININFORMATION("InteractorRectangleZoom", "Tulip Team", "01/04/2009", "Rectangle Zoom Interactor", "1.0", "Navigation")
   /**
    * Default constructor
    */
-  InteractorRectangleZoom():NodeLinkDiagramComponentInteractor(":/i_zoom.png","Zoom on rectangle") {
-    setPriority(2);
+  InteractorRectangleZoom(const tlp::PluginContext*):NodeLinkDiagramComponentInteractor(":/tulip/gui/icons/i_zoom.png","Zoom on rectangle") {
+    setPriority(StandardInteractorPriority::ZoomOnRectangle);
     setConfigurationWidgetText(QString("<h3>Rectangle zoom interactor</h3>")+
                                "Zoom on selected rectangle.<br><b>Mouse left</b> down indicates the first corner, <b>Mouse left</b> up indicates the opposite corner.");
   }
@@ -44,13 +47,25 @@ public:
    * Construct chain of responsibility
    */
   void construct() {
-    pushInteractorComponent(new MousePanNZoomNavigator);
-    pushInteractorComponent(new MouseBoxZoomer);
+    push_back(new MousePanNZoomNavigator);
+    push_back(new MouseBoxZoomer);
   }
 
-  QCursor getCursor() {
+  QCursor cursor() const {
     return QCursor(Qt::CrossCursor);
   }
+
+  bool isCompatible(const std::string &viewName) const {
+    return ((viewName==NodeLinkDiagramComponent::viewName)
+            ||(viewName==ViewName::HistogramViewName)
+            ||(viewName==ViewName::MatrixViewName)
+            ||(viewName==ViewName::ParallelCoordinatesViewName)
+            ||(viewName==ViewName::PixelOrientedViewName)
+            ||(viewName==ViewName::ScatterPlot2DViewName)
+           );
+  }
+
+
 };
 
-INTERACTORPLUGIN(InteractorRectangleZoom, "InteractorRectangleZoom", "Tulip Team", "01/04/2009", "Rectangle Zoom Interactor", "1.0");
+PLUGIN(InteractorRectangleZoom)
