@@ -18,10 +18,13 @@
  */
 
 #include <tulip/MouseInteractors.h>
+#include <tulip/NodeLinkDiagramComponentInteractor.h>
 #include <tulip/MouseSelector.h>
 #include <tulip/MouseSelectionEditor.h>
+#include <tulip/NodeLinkDiagramComponent.h>
 
-#include "NodeLinkDiagramComponentInteractor.h"
+#include "../utils/StandardInteractorPriority.h"
+#include "../utils/ViewNames.h"
 
 using namespace tlp;
 
@@ -31,13 +34,13 @@ using namespace tlp;
 class InteractorSelectionModifier  : public NodeLinkDiagramComponentInteractor {
 
 public:
-
+  PLUGININFORMATION("InteractorSelectionModifier", "Tulip Team", "01/04/2009", "Selection Modifier Interactor", "1.0", "Modification")
   /**
    * Default constructor
    */
-  InteractorSelectionModifier():NodeLinkDiagramComponentInteractor(":/i_move.png","Move/Reshape selection") {
-    setPriority(3);
-    setConfigurationWidgetText(QString("<h3>Selection modifier interactor</h3>")+
+  InteractorSelectionModifier(const tlp::PluginContext*):NodeLinkDiagramComponentInteractor(":/tulip/gui/icons/i_move.png","Move/Reshape rectangle selection") {
+    setPriority(StandardInteractorPriority::RectangleSelectionModifier);
+    setConfigurationWidgetText(QString("<h3>Move/Reshape rectangle selection</h3>")+
                                "Modify selection<br/><br/>"+
                                "Resize : <ul><li><b>Mouse left</b> down on triangle + moves</li></ul>" +
                                "<ul><li><b>Mouse left</b> down on square + moves</li></ul>" +
@@ -55,14 +58,20 @@ public:
    * Construct chain of responsibility
    */
   void construct() {
-    pushInteractorComponent(new MousePanNZoomNavigator);
-    pushInteractorComponent(new MouseSelector);
-    pushInteractorComponent(new MouseSelectionEditor);
+    push_back(new MousePanNZoomNavigator);
+    push_back(new MouseSelector);
+    push_back(new MouseSelectionEditor);
   }
 
-  QCursor getCursor() {
+  QCursor cursor() const {
     return QCursor(Qt::CrossCursor);
   }
+
+  bool isCompatible(const std::string &viewName) const {
+    return ((viewName==NodeLinkDiagramComponent::viewName)
+            ||(viewName==ViewName::GoogleMapsViewName));
+  }
+
 };
 
-INTERACTORPLUGIN(InteractorSelectionModifier, "InteractorSelectionModifier", "Tulip Team", "01/04/2009", "Selection Modifier Interactor", "1.0");
+PLUGIN(InteractorSelectionModifier)
