@@ -21,7 +21,7 @@
 #include "BubbleTree.h"
 #include "DatasetTools.h"
 
-LAYOUTPLUGINOFGROUP(BubbleTree,"Bubble Tree","D.Auber/S.Grivet","16/05/2003","Stable","1.0","Tree");
+PLUGIN(BubbleTree)
 
 using namespace std;
 using namespace tlp;
@@ -160,7 +160,7 @@ double BubbleTree::computeRelativePosition(tlp::node n, TLP_HASH_MAP<tlp::node,
   }
 
   double angle = 0.;
-  vector<tlp::Circle<double> > circles(Nc);
+  vector<Circled > circles(Nc);
 
   for (unsigned int i=0; i<Nc; ++i) {
     double packRadius;
@@ -180,7 +180,7 @@ double BubbleTree::computeRelativePosition(tlp::node n, TLP_HASH_MAP<tlp::node,
     circles[i].radius = realCircleRadius[i];
   }
 
-  Circle<double> circleH = tlp::enclosingCircle(circles);
+  Circled circleH = tlp::enclosingCircle(circles);
   (*relativePosition)[n][2] = -circleH[0];
   (*relativePosition)[n][3] = -circleH[1];
   (*relativePosition)[n][4] = sqrt(circleH.radius*circleH.radius - circleH[1]*circleH[1])-fabs(circleH[0]);
@@ -235,9 +235,9 @@ void BubbleTree::calcLayout2(tlp::node n, TLP_HASH_MAP<tlp::node,tlp::Vector<dou
   rot2[2]=0.;
   zeta = rot1*zeta[0] + rot2*zeta[1];
 
-  layoutResult->setNodeValue(n, Coord(static_cast<float>(enclosingCircleCenter[0]+zeta[0]),
-                                      static_cast<float>(enclosingCircleCenter[1]+zeta[1]),
-                                      0.) );
+  result->setNodeValue(n, Coord(static_cast<float>(enclosingCircleCenter[0]+zeta[0]),
+                                static_cast<float>(enclosingCircleCenter[1]+zeta[1]),
+                                0.) );
 
   /*
    * Place bend on edge to prevent overlaping
@@ -257,7 +257,7 @@ void BubbleTree::calcLayout2(tlp::node n, TLP_HASH_MAP<tlp::node,tlp::Vector<dou
       delete itE;
       vector<Coord>tmp(1);
       tmp[0] = Coord(static_cast<float>(bend[0]), static_cast<float>(bend[1]), 0.);
-      layoutResult->setEdgeValue(ite,tmp);
+      result->setEdgeValue(ite,tmp);
     }
   }
 
@@ -284,7 +284,7 @@ void BubbleTree::calcLayout(tlp::node n, TLP_HASH_MAP< tlp::node, tlp::Vector< d
   /*
    * Make the recursive call, to place the children of n.
    */
-  layoutResult->setNodeValue(n,Coord(0., 0., 0.));
+  result->setNodeValue(n,Coord(0., 0., 0.));
   Iterator<node> *it = tree->getOutNodes(n);
 
   while (it->hasNext()) {
@@ -315,10 +315,10 @@ const char * paramHelp[] = {
 };
 }
 
-BubbleTree::BubbleTree(const tlp::PropertyContext &context):LayoutAlgorithm(context) {
+BubbleTree::BubbleTree(const tlp::PluginContext* context):LayoutAlgorithm(context) {
   addNodeSizePropertyParameter(this);
-  addParameter<bool>("complexity",paramHelp[0],"true");
-  addDependency<LayoutAlgorithm>("Connected Component Packing", "1.0");
+  addInParameter<bool>("complexity",paramHelp[0],"true");
+  addDependency("Connected Component Packing", "1.0");
 }
 
 BubbleTree::~BubbleTree() {}
@@ -335,17 +335,17 @@ bool BubbleTree::run() {
 
     for (unsigned int i = 0; i < components.size(); ++i) {
       Graph * tmp = graph->inducedSubGraph(components[i]);
-      tmp->computeProperty("Bubble Tree", layoutResult, err, pluginProgress, dataSet);
+      tmp->applyPropertyAlgorithm("Bubble Tree", result, err, pluginProgress, dataSet);
     }
 
     // call connected componnent packing
     LayoutProperty tmpLayout(graph);
     DataSet tmpdataSet;
-    tmpdataSet.set("coordinates", layoutResult);
-    graph->computeProperty("Connected Component Packing", &tmpLayout, err, pluginProgress, &tmpdataSet);
+    tmpdataSet.set("coordinates", result);
+    graph->applyPropertyAlgorithm("Connected Component Packing", &tmpLayout, err, pluginProgress, &tmpdataSet);
     // forget last temporary graph state
     graph->pop();
-    *layoutResult = tmpLayout;
+    *result = tmpLayout;
     return true;
   }
 
@@ -362,7 +362,7 @@ bool BubbleTree::run() {
   if (dataSet == 0 || !dataSet->get("complexity",nAlgo))
     nAlgo = true;
 
-  layoutResult->setAllEdgeValue(vector<Coord>(0));
+  result->setAllEdgeValue(vector<Coord>(0));
 
   if (pluginProgress)
     pluginProgress->showPreview(false);
@@ -371,8 +371,8 @@ bool BubbleTree::run() {
   // preserving layout updates
   std::vector<PropertyInterface*> propsToPreserve;
 
-  if (layoutResult->getName() != "")
-    propsToPreserve.push_back(layoutResult);
+  if (result->getName() != "")
+    propsToPreserve.push_back(result);
 
   graph->push(false, &propsToPreserve);
 
