@@ -20,10 +20,10 @@
 #define _BUBBLETREELAYOUT_H
 
 #include <tulip/tuliphash.h>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup layout */
-/*@{*/
+
 
 /** This plug-in implement the bubble tree drawing algorithm
  *  first published as:
@@ -53,7 +53,8 @@
  */
 class BubbleTree:public tlp::LayoutAlgorithm {
 public:
-  BubbleTree(const tlp::PropertyContext& context);
+  PLUGININFORMATION("Bubble Tree","D.Auber/S.Grivet","16/05/2003","Stable","1.0","Tree")
+  BubbleTree(const tlp::PluginContext* context);
   ~BubbleTree();
   bool run();
 private:
@@ -65,7 +66,7 @@ private:
   tlp::SizeProperty *nodeSize;
   bool nAlgo;
 };
-/*@}*/
+
 #endif
 
 
