@@ -19,7 +19,7 @@
 #include "Circular.h"
 #include "DatasetTools.h"
 
-LAYOUTPLUGINOFGROUP(Circular,"Circular","David Auber/ Daniel Archambault","25/11/2004","Ok","1.1","Basic");
+PLUGIN(Circular)
 
 using namespace std;
 using namespace tlp;
@@ -30,14 +30,14 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "values", "true/false" ) \
   HTML_HELP_DEF( "default", "false" )      \
   HTML_HELP_BODY()              \
-  "If true search the maximum length cycle. Be careful, this problem is NP-Complete else order the node using a depth first search" \
+  "If true, search first for the maximum length cycle (be careful, this problem is NP-Complete). If false, nodes are ordered using a depth first search." \
   HTML_HELP_CLOSE()
 };
 }
 
-Circular::Circular(const tlp::PropertyContext &context):LayoutAlgorithm(context) {
+Circular::Circular(const tlp::PluginContext* context):LayoutAlgorithm(context) {
   addNodeSizePropertyParameter(this);
-  addParameter<bool>("search cycle", paramHelp[0], "false");
+  addInParameter<bool>("search cycle", paramHelp[0], "false");
 }
 
 namespace {
@@ -73,14 +73,14 @@ void buildDfsOrdering(Graph *sg, vector<node> &vec) {
         if (!nodeVisited.get(current.id))
           visitNode(sg, current, vec, nodeVisited, toVisit);
 
-        itl++;
+        ++itl;
       }
     }
   }
 }
 //===============================================================================
 vector<node> extractCycle(node n, deque<node> &st) {
-  // cerr << __PRETTY_FUNCTION__ << endl;
+  // tlp::warning() << __PRETTY_FUNCTION__ << endl;
   vector<node> result;
   deque<node>::const_reverse_iterator it = st.rbegin();
 
@@ -130,7 +130,7 @@ void dfs(node n, const Graph * sg, deque<node> &st,vector<node> & maxCycle, Muta
 //=======================================================================
 vector<node> findMaxCycle(Graph * sg, PluginProgress *pluginProgress) {
   Graph * g = sg->addCloneSubGraph();
-  cerr << __PRETTY_FUNCTION__ << endl;
+  tlp::warning() << __PRETTY_FUNCTION__ << endl;
 
   // compute the connected components's subgraphs
   std::vector<std::set<node> > components;
@@ -167,7 +167,7 @@ vector<node> findMaxCycle(Graph * sg, PluginProgress *pluginProgress) {
 
 //this inline function computes the radius size given a size
 inline double computeRadius (const Size &s) {
-  return sqrt (s[0]*s[0]/4.0 + s[1]*s[1]/4.0);
+  return std::max(1E-3, sqrt (s[0]*s[0]/4.0 + s[1]*s[1]/4.0));
 }//end computeRad
 
 bool Circular::run() {
@@ -183,7 +183,7 @@ bool Circular::run() {
     }
   }
 
-  if ( dataSet != 0 )
+  if ( dataSet != NULL )
     dataSet->get("search cycle", searchCycle);
 
   //compute the sum of radii and the max radius of the graph
@@ -207,7 +207,7 @@ bool Circular::run() {
     double xcoord = maxRad/2.0;
     node itn;
     forEach(itn, graph->getNodes()) {
-      layoutResult->setNodeValue (itn, Coord (static_cast<float>(xcoord), 0, 0));
+      result->setNodeValue (itn, Coord (xcoord, 0, 0));
       xcoord *= -1;
     }
   }//end if
@@ -222,7 +222,7 @@ bool Circular::run() {
       angleAdjust = true;
     }//end if
 
-    //cerr << "*************************" << endl;
+    //tlp::warning() << "*************************" << endl;
 
     vector<node> cycleOrdering;
 
@@ -262,8 +262,8 @@ bool Circular::run() {
 
       //compute the position of the node.
       gamma += halfAngle;
-      layoutResult->setNodeValue(itn, Coord(static_cast<float>(rayon*cos(gamma)),
-                                            static_cast<float>(rayon*sin(gamma)), 0));
+      result->setNodeValue(itn, Coord(rayon*cos(gamma),
+                                      rayon*sin(gamma), 0));
       gamma += halfAngle;
     }//end while
   }//end else
