@@ -19,10 +19,10 @@
 #ifndef _BUBBLE_CIRCULARLAYOUT_H
 #define _BUBBLE_CIRCULARLAYOUT_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup layout */
-/*@{*/
+
 /**
  * This plugin is an implementation of a circular layout that takes
  * node size into account.  It manages size of nodes and use a standard dfs
@@ -48,8 +48,9 @@
  */
 class Circular:public tlp::LayoutAlgorithm {
 public:
-  Circular(const tlp::PropertyContext &context);
+  PLUGININFORMATION("Circular","David Auber/ Daniel Archambault","25/11/2004","Ok","1.1","Basic")
+  Circular(const tlp::PluginContext* context);
   bool run();
 };
-/*@}*/
+
 #endif
