@@ -16,12 +16,15 @@
  * See the GNU General Public License for more details.
  *
  */
+#include <cmath>
+
 #include <tulip/Circle.h>
+#include <tulip/StringCollection.h>
 
 #include "ConeTreeExtended.h"
 #include "DatasetTools.h"
 
-LAYOUTPLUGINOFGROUP(ConeTreeExtended,"Cone Tree","David Auber","01/04/2001","Stable","1.0","Tree");
+PLUGIN(ConeTreeExtended)
 
 using namespace std;
 using namespace tlp;
@@ -116,7 +119,7 @@ double ConeTreeExtended::treePlace3D(tlp::node n,
   if (newRadius==0) newRadius=static_cast<float>(radius);
 
   //compute Circle Hull
-  vector<tlp::Circle<float> > circles(subCircleRadius.size());
+  vector<Circlef > circles(subCircleRadius.size());
 
   for (unsigned int i=0; i<subCircleRadius.size(); ++i) {
     circles[i][0]=newRadius*static_cast<float>(cos(vangles[i]));
@@ -124,7 +127,7 @@ double ConeTreeExtended::treePlace3D(tlp::node n,
     circles[i].radius=static_cast<float>(subCircleRadius[i]);
   }
 
-  tlp::Circle<float> circleH=tlp::enclosingCircle(circles);
+  tlp::Circlef circleH=tlp::enclosingCircle(circles);
 
   //Place relative position
   itN = tree->getOutNodes(n);
@@ -142,7 +145,7 @@ double ConeTreeExtended::treePlace3D(tlp::node n,
 void ConeTreeExtended::calcLayout(tlp::node n, TLP_HASH_MAP<tlp::node,double> *px,
                                   TLP_HASH_MAP<tlp::node,double> *py,
                                   double x, double y, int level) {
-  layoutResult->setNodeValue(n,Coord(static_cast<float>(x+(*px)[n]), - static_cast<float>(yCoordinates[level]),static_cast<float>(y+(*py)[n])));
+  result->setNodeValue(n,Coord(static_cast<float>(x+(*px)[n]), - static_cast<float>(yCoordinates[level]),static_cast<float>(y+(*py)[n])));
   node itn;
   forEach(itn, tree->getOutNodes(n)) {
     calcLayout(itn, px, py, x+(*px)[n], y+(*py)[n], level + 1);
@@ -162,9 +165,9 @@ const char * paramHelp[] = {
 }
 #define ORIENTATION "vertical;horizontal;"
 //===============================================================
-ConeTreeExtended::ConeTreeExtended(const tlp::PropertyContext &context):LayoutAlgorithm(context) {
+ConeTreeExtended::ConeTreeExtended(const tlp::PluginContext* context):LayoutAlgorithm(context) {
   addNodeSizePropertyParameter(this);
-  addParameter<StringCollection> ("orientation", paramHelp[0], ORIENTATION );
+  addInParameter<StringCollection> ("orientation", paramHelp[0], ORIENTATION );
 }
 //===============================================================
 ConeTreeExtended::~ConeTreeExtended() {}
@@ -173,7 +176,7 @@ bool ConeTreeExtended::run() {
   nodeSize = NULL;
   string orientation = "vertical";
 
-  if (dataSet!=0) {
+  if (dataSet!=NULL) {
     getNodeSizePropertyParameter(dataSet, nodeSize);
     StringCollection tmp;
 
@@ -197,7 +200,7 @@ bool ConeTreeExtended::run() {
   }
 
   //===========================================================
-  layoutResult->setAllEdgeValue(vector<Coord>(0));
+  result->setAllEdgeValue(vector<Coord>(0));
 
   if (pluginProgress)
     pluginProgress->showPreview(false);
@@ -206,8 +209,8 @@ bool ConeTreeExtended::run() {
   // preserving layout updates
   std::vector<PropertyInterface*> propsToPreserve;
 
-  if (layoutResult->getName() != "")
-    propsToPreserve.push_back(layoutResult);
+  if (result->getName() != "")
+    propsToPreserve.push_back(result);
 
   graph->push(false, &propsToPreserve);
 
@@ -238,9 +241,9 @@ bool ConeTreeExtended::run() {
         nodeSize->setNodeValue(n, Size(tmp[1], tmp[0], tmp[2]));
       }
 
-      const Coord& tmpC = layoutResult->getNodeValue(n);
+      const Coord& tmpC = result->getNodeValue(n);
 
-      layoutResult->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
+      result->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
     }
   }
 
