@@ -20,9 +20,9 @@
 #define _TREE3DLAYOUT_H
 
 #include <tulip/tuliphash.h>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 /** \addtogroup layout */
-/*@{*/
+
 /// ConeTreeExtended.h - An implementation of the cone tree layout.
 /** This plugin is an extension of the Cone tree layout
  *  algorithm first published as:
@@ -49,7 +49,8 @@
  */
 class ConeTreeExtended:public tlp::LayoutAlgorithm {
 public:
-  ConeTreeExtended(const tlp::PropertyContext& context);
+  PLUGININFORMATION("Cone Tree","David Auber","01/04/2001","Stable","1.0","Tree")
+  ConeTreeExtended(const tlp::PluginContext* context);
   ~ConeTreeExtended();
   bool run();
 private:
@@ -66,7 +67,7 @@ private:
   std::vector<float> levelSize;
 
 };
-/*@}*/
+
 #endif
 
 
