@@ -16,9 +16,9 @@
  * See the GNU General Public License for more details.
  *
  */
-// #include <tulip/Graph.h>
-// #include <tulip/GraphTools.h>
+
 #include <tulip/DrawingTools.h>
+#include <tulip/StringCollection.h>
 
 #include "ConnectedComponentPacking.h"
 #include "rectanglePackingFonctions.h"
@@ -27,7 +27,7 @@
 using namespace std;
 using namespace tlp;
 
-LAYOUTPLUGINOFGROUP(ConnectedComponentPacking, "Connected Component Packing", "David Auber", "26/05/05", "beta", "1.0", "Misc");
+PLUGIN(ConnectedComponentPacking)
 
 const float spacing = 8;
 #define COMPLEXITY "auto;n5;n4logn;n4;n3logn;n3;n2logn;n2;nlogn;n;"
@@ -39,7 +39,7 @@ const char* paramHelp[] = {
   HTML_HELP_DEF("Values", "Any layout property") \
   HTML_HELP_DEF("Default", "viewLayout") \
   HTML_HELP_BODY() \
-  "Choose the input coordinates of nodes and edges" \
+  "Input coordinates of nodes and edges" \
   HTML_HELP_CLOSE(),
 //Rotation
   HTML_HELP_OPEN() \
@@ -47,37 +47,37 @@ const char* paramHelp[] = {
   HTML_HELP_DEF("Values", "Any double property used for rotation of nodes on z-axis") \
   HTML_HELP_DEF("Default", "viewRotation") \
   HTML_HELP_BODY() \
-  "Choose the input rotation of nodes on z-axis" \
+  "Input rotation of nodes on z-axis" \
   HTML_HELP_CLOSE(),
 //Complexity
   HTML_HELP_OPEN() \
   HTML_HELP_DEF("Type", "StringCollection") \
   HTML_HELP_DEF("Default", "auto") \
   HTML_HELP_BODY() \
-  "Choose the complexity of the algorithm.<br> n is the number of connected components in the graph" \
+  "Complexity of the algorithm.<br> n is the number of connected components in the graph." \
   HTML_HELP_CLOSE()
 };
 }
 
 //====================================================================
-ConnectedComponentPacking::ConnectedComponentPacking(const tlp::PropertyContext& context)
+ConnectedComponentPacking::ConnectedComponentPacking(const tlp::PluginContext* context)
   : LayoutAlgorithm(context) {
-  addParameter<LayoutProperty> ("coordinates",paramHelp[0],"viewLayout");
+  addInParameter<LayoutProperty> ("coordinates",paramHelp[0],"viewLayout");
   addNodeSizePropertyParameter(this);
-  addParameter<DoubleProperty> ("rotation",paramHelp[1],"viewRotation");
-  addParameter<StringCollection> ("complexity", paramHelp[2], COMPLEXITY );
+  addInParameter<DoubleProperty> ("rotation",paramHelp[1],"viewRotation");
+  addInParameter<StringCollection> ("complexity", paramHelp[2], COMPLEXITY );
 }
 //====================================================================
 bool ConnectedComponentPacking::run() {
 
-  LayoutProperty *layout = 0;
-  SizeProperty *size = 0;
-  DoubleProperty *rotation = 0;
+  LayoutProperty *layout = NULL;
+  SizeProperty *size = NULL;
+  DoubleProperty *rotation = NULL;
   string complexity("auto");
 
   workingGraph = graph->addCloneSubGraph("workingGraph");
 
-  if ( dataSet!=0 ) {
+  if ( dataSet!=NULL ) {
     dataSet->get("coordinates", layout);
     getNodeSizePropertyParameter(dataSet, size);
     dataSet->get("rotation", rotation);
@@ -87,13 +87,13 @@ bool ConnectedComponentPacking::run() {
       complexity = complexityCol.getCurrentString();
   }
 
-  if (layout==0)
+  if (layout==NULL)
     layout = workingGraph->getProperty<LayoutProperty>("viewLayout");
 
-  if (size==0)
+  if (size==NULL)
     size = workingGraph->getProperty<SizeProperty>("viewSize");
 
-  if (rotation==0)
+  if (rotation==NULL)
     rotation = workingGraph->getProperty<DoubleProperty>("viewRotation");
 
   if (complexity=="none")
@@ -159,7 +159,7 @@ bool ConnectedComponentPacking::run() {
 
   while(itN->hasNext()) {
     node n = itN->next();
-    layoutResult->setNodeValue(n, layout->getNodeValue(n));
+    result->setNodeValue(n, layout->getNodeValue(n));
   }
 
   delete itN;
@@ -167,7 +167,7 @@ bool ConnectedComponentPacking::run() {
 
   while(itE->hasNext()) {
     edge e = itE->next();
-    layoutResult->setEdgeValue(e, layout->getEdgeValue(e));
+    result->setEdgeValue(e, layout->getEdgeValue(e));
   }
 
   delete itE;
@@ -177,7 +177,7 @@ bool ConnectedComponentPacking::run() {
   while(it->hasNext()) {
     Graph *sg = it->next();
     Coord move(rectangles[i][0][0]-rectanglesBackup[i][0][0], rectangles[i][0][1]-rectanglesBackup[i][0][1], 0);
-    layoutResult->translate(move, sg);
+    result->translate(move, sg);
     ++i;
   }
 
