@@ -19,11 +19,12 @@
 #ifndef CONNECTEDCOMPONNENTPACKING_H
 #define CONNECTEDCOMPONNENTPACKING_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 class ConnectedComponentPacking: public tlp::LayoutAlgorithm {
 public:
-  ConnectedComponentPacking(const tlp::PropertyContext& context);
+  PLUGININFORMATION("Connected Component Packing", "David Auber", "26/05/05", "beta", "1.0", "Misc")
+  ConnectedComponentPacking(const tlp::PluginContext* context);
   bool run();
 
 private:
