@@ -17,6 +17,7 @@
  *
  */
 #include "DatasetTools.h"
+#include <tulip/StringCollection.h>
 
 #define ORTHOGONAL "orthogonal"
 #define ORIENTATION "up to down;down to up;right to left;left to right;"
@@ -72,18 +73,18 @@ const char* paramHelp[] = {
 
 //====================================================================
 void addOrientationParameters(LayoutAlgorithm* pLayout) {
-  pLayout->addParameter<StringCollection>(ORIENTATION_ID, paramHelp[0], ORIENTATION);
+  pLayout->addInParameter<StringCollection>(ORIENTATION_ID, paramHelp[0], ORIENTATION);
 }
 
 //====================================================================
 void addOrthogonalParameters(LayoutAlgorithm* pLayout) {
-  pLayout->addParameter<bool>(ORTHOGONAL,paramHelp[1],"false");
+  pLayout->addInParameter<bool>(ORTHOGONAL,paramHelp[1],"false");
 }
 
 //====================================================================
 void addSpacingParameters(LayoutAlgorithm* pLayout) {
-  pLayout->addParameter<float>("layer spacing", paramHelp[2], "64." );
-  pLayout->addParameter<float>("node spacing", paramHelp[3], "18." );
+  pLayout->addInParameter<float>("layer spacing", paramHelp[2], "64." );
+  pLayout->addInParameter<float>("node spacing", paramHelp[3], "18." );
 }
 void getSpacingParameters(DataSet* dataSet, float& nodeSpacing, float& layerSpacing) {
   layerSpacing = 64.;
@@ -105,7 +106,7 @@ void addNodeSizePropertyParameter(LayoutAlgorithm* pLayout, bool inout) {
 }
 
 bool getNodeSizePropertyParameter(DataSet* dataSet, SizeProperty* &sizes) {
-  return (dataSet != 0) && dataSet->get("node size", sizes);
+  return (dataSet != NULL) && dataSet->get("node size", sizes);
 }
 
 //====================================================================
@@ -113,7 +114,7 @@ DataSet setOrientationParameters(int pOrientation) {
   DataSet dataSet;
   StringCollection stringOrientation(ORIENTATION);
   stringOrientation.setCurrent(pOrientation);
-  dataSet.set<StringCollection>(ORIENTATION_ID, stringOrientation);
+  dataSet.set(ORIENTATION_ID, stringOrientation);
   return dataSet;
 }
 
@@ -123,7 +124,7 @@ orientationType getMask(DataSet* dataSet) {
   orientation.setCurrent(0);
   int current = 0;
 
-  if (dataSet != 0) {
+  if (dataSet != NULL) {
     StringCollection dataSetOrientation;
 
     if (dataSet->get(ORIENTATION_ID, dataSetOrientation)) {
@@ -161,7 +162,7 @@ orientationType getMask(DataSet* dataSet) {
 bool hasOrthogonalEdge(DataSet* dataSet) {
   bool orthogonalEdge = false;
 
-  if (dataSet != 0) {
+  if (dataSet != NULL) {
     dataSet->get(ORTHOGONAL, orthogonalEdge);
   }
 
