@@ -22,20 +22,15 @@
 #include "TreeTools.h"
 #include "Orientation.h"
 #include "DatasetTools.h"
-#include "EdgeTools.h"
 #include "Dendrogram.h"
 using namespace std;
 using namespace tlp;
 
 
-LAYOUTPLUGINOFGROUP(Dendrogram, "Dendrogram",
-                    "Julien Testut, Antony Durand, Pascal Ollier, "
-                    "Yashvin Nababsing, Sebastien Leclerc, "
-                    "Thibault Ruchon, Eric Dauchier",
-                    "03/12/04", "ok", "1.0","Tree");
+PLUGIN(Dendrogram)
 
 //====================================================================
-Dendrogram::Dendrogram(const tlp::PropertyContext& context)
+Dendrogram::Dendrogram(const tlp::PluginContext* context)
   :LayoutAlgorithm(context) {
   addNodeSizePropertyParameter(this);
   addOrientationParameters(this);
@@ -63,7 +58,7 @@ void Dendrogram::computeLevelHeights(tlp::Graph *tree, tlp::node n, unsigned int
 //====================================================================
 bool Dendrogram::run() {
   orientationType mask = getMask(dataSet);
-  OrientableLayout oriLayout(layoutResult, mask);
+  OrientableLayout oriLayout(result, mask);
   SizeProperty* size;
 
   if (!getNodeSizePropertyParameter(dataSet, size))
@@ -79,8 +74,8 @@ bool Dendrogram::run() {
   // preserving layout updates
   std::vector<PropertyInterface*> propsToPreserve;
 
-  if (layoutResult->getName() != "")
-    propsToPreserve.push_back(layoutResult);
+  if (result->getName() != "")
+    propsToPreserve.push_back(result);
 
   graph->push(false, &propsToPreserve);
 
@@ -106,7 +101,7 @@ bool Dendrogram::run() {
   setAllNodesCoordX(root, 0.f, &oriLayout, &oriSize);
   shiftAllNodes(root, 0.f, &oriLayout);
   setAllNodesCoordY(&oriLayout, &oriSize);
-  setOrthogonalEdge(&oriLayout, graph, spacing);
+  oriLayout.setOrthogonalEdge(graph, spacing);
 
   // forget last temporary graph state
   graph->pop();
