@@ -21,14 +21,14 @@
 
 #include <map>
 #include <vector>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 class OrientableLayout;
 class OrientableCoord;
 class OrientableSizeProxy;
 
 /** \addtogroup layout */
-/*@{*/
+
 /** This plugin is an implementation of a dendrogram, an extended implementation
  *  of a "Bio representation" which includes variable orientation
  *  and variable node sizelayout.
@@ -42,7 +42,12 @@ class OrientableSizeProxy;
  **/
 class Dendrogram: public tlp::LayoutAlgorithm {
 public:
-  Dendrogram(const tlp::PropertyContext& context);
+  PLUGININFORMATION("Dendrogram",
+                    "Julien Testut, Antony Durand, Pascal Ollier, "
+                    "Yashvin Nababsing, Sebastien Leclerc, "
+                    "Thibault Ruchon, Eric Dauchier",
+                    "03/12/04", "ok", "1.0","Tree")
+  Dendrogram(const tlp::PluginContext* context);
   ~Dendrogram();
 
   bool run();
@@ -73,7 +78,7 @@ private:
   void computeLevelHeights(tlp::Graph* tree, tlp::node n, unsigned int depth,
                            OrientableSizeProxy *oriSize);
 };
-/*@}*/
+
 #endif
 
 
