@@ -30,13 +30,13 @@ static const char * paramHelp[] = {
   HTML_HELP_OPEN() \
   HTML_HELP_DEF( "type", "Boolean" ) \
   HTML_HELP_BODY() \
-  "If true the layout is in 3D else it is computed in 2D" \
+  "If true, the layout is in 3D else it is computed in 2D." \
   HTML_HELP_CLOSE(),
   // edge length
   HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "DoubleProperty" ) \
+  HTML_HELP_DEF( "type", "NumericProperty" ) \
   HTML_HELP_BODY() \
-  "This DoubleProperty is used to compute the length of edges." \
+  "This metric is used to compute the length of edges." \
   HTML_HELP_CLOSE(),
   // initial layout
   HTML_HELP_OPEN() \
@@ -84,34 +84,19 @@ static const float AOSCILLATIONDEF = 1.f;
 static const float AROTATIONDEF    = 1.f;
 static const float ASHAKEDEF       = 0.3f;
 
+PLUGIN(GEMLayout)
 
-LAYOUTPLUGINOFGROUP(GEMLayout,"GEM (Frick)","Tulip Team","16/10/2008","Stable","1.2","Force Directed")
-
-GEMLayout::GEMLayout(const tlp::PropertyContext &context) : LayoutAlgorithm(context) {
-  addParameter<bool>("3D layout", paramHelp[0], "false");
-  addParameter<DoubleProperty>("edge length", paramHelp[1], 0, false);
-  addParameter<LayoutProperty>("initial layout", paramHelp[2], 0, false);
-  addParameter<unsigned int>("max iterations", paramHelp[3], 0);
-  addDependency<LayoutAlgorithm>("Connected Component Packing", "1.0");
-
-  i_maxtemp      = IMAXTEMPDEF;
-  a_maxtemp      = AMAXTEMPDEF;
-  i_starttemp    = ISTARTTEMPDEF;
-  a_starttemp    = ASTARTTEMPDEF;
-  i_finaltemp    = IFINALTEMPDEF;
-  a_finaltemp    = AFINALTEMPDEF;
-  i_maxiter      = IMAXITERDEF;
-  a_maxiter      = AMAXITERDEF;
-  i_gravity      = IGRAVITYDEF;
-  i_oscillation  = IOSCILLATIONDEF;
-  i_rotation     = IROTATIONDEF;
-  i_shake        = ISHAKEDEF;
-  a_gravity      = AGRAVITYDEF;
-  a_oscillation  = AOSCILLATIONDEF;
-  a_rotation     = AROTATIONDEF;
-  a_shake        = ASHAKEDEF;
-  _dim           = 2;
-
+GEMLayout::GEMLayout(const tlp::PluginContext* context) : LayoutAlgorithm(context),
+  Iteration(0), _temperature(0), _maxtemp(0), _oscillation(0), _rotation(0),
+  i_maxtemp(IMAXTEMPDEF), a_maxtemp(AMAXTEMPDEF), i_starttemp(ISTARTTEMPDEF),
+  a_starttemp(ASTARTTEMPDEF), i_finaltemp(IFINALTEMPDEF), a_finaltemp(AFINALTEMPDEF), i_maxiter(IMAXITERDEF), a_maxiter(AMAXITERDEF), i_gravity(IGRAVITYDEF),
+  a_gravity(AGRAVITYDEF), i_oscillation(IOSCILLATIONDEF), a_oscillation(AOSCILLATIONDEF), i_rotation(IROTATIONDEF), a_rotation(AROTATIONDEF), i_shake(ISHAKEDEF),
+  a_shake(ASHAKEDEF), _dim(2), _nbNodes(0), _useLength(false), metric(NULL), max_iter(0) {
+  addInParameter<bool>("3D layout", paramHelp[0], "false");
+  addInParameter<NumericProperty*>("edge length", paramHelp[1], "", false);
+  addInParameter<LayoutProperty>("initial layout", paramHelp[2], "", false);
+  addInParameter<unsigned int>("max iterations", paramHelp[3], "0");
+  addDependency("Connected Component Packing", "1.0");
 }
 //=========================================================
 GEMLayout::~GEMLayout() {
@@ -138,8 +123,8 @@ void GEMLayout::vertexdata_init(const float starttemp) {
 //=========================================================
 void GEMLayout::updateLayout() {
   for (unsigned int i = 0; i < graph->numberOfNodes(); ++i) {
-    //    cerr << "pos up ==> :" << _particules[i].pos << endl;
-    layoutResult->setNodeValue(_particules[i].n, _particules[i].pos);
+    //    tlp::warning() << "pos up ==> :" << _particules[i].pos << endl;
+    result->setNodeValue(_particules[i].n, _particules[i].pos);
   }
 }
 //=========================================================
@@ -168,7 +153,7 @@ Coord GEMLayout::computeForces(unsigned int v,
   double  maxEdgeLength;
 
   if (_useLength)
-    maxEdgeLength = std::max(2.0f, (float)metric->getEdgeMin());
+    maxEdgeLength = std::max(2.0f, (float)metric->getEdgeDoubleMin());
   else
     maxEdgeLength = EDGELENGTH;
 
@@ -189,13 +174,18 @@ Coord GEMLayout::computeForces(unsigned int v,
   edge e;
   forEach(e,  graph->getInOutEdges(vNode)) {
     node uNode = graph->opposite(e, vNode);
+
+    if (uNode == vNode)
+      // nothing to do if it is a self loop
+      continue;
+
     GEMparticule *gemQ = _nodeToParticules.get(uNode.id);
 
     if (!testPlaced || gemQ->in > 0) { //test whether the node is already placed
       float edgeLength;
 
       if (_useLength)
-        edgeLength = static_cast<float>(metric->getEdgeValue(e));
+        edgeLength = static_cast<float>(metric->getEdgeDoubleValue(e));
       else
         edgeLength = EDGELENGTH;
 
@@ -244,9 +234,14 @@ void GEMLayout::insert() {
 
     //
     _particules[v].in = 1;
+    node vNode = _particules[v].n;
     node uNode;
     //remove one to non-visited nodes
-    forEach(uNode, graph->getInOutNodes(_particules[v].n)) {
+    forEach(uNode, graph->getInOutNodes(vNode)) {
+      if (uNode == vNode)
+        // nothing to do if it is a self loop
+        continue;
+
       if (_nodeToParticules.get(uNode.id)->in <= 0)
         --(_nodeToParticules.get(uNode.id)->in);
     }
@@ -257,7 +252,11 @@ void GEMLayout::insert() {
     if (startNode >= 0) {
       int d = 0;
       node uNode;
-      forEach(uNode, graph->getInOutNodes(_particules[v].n)) {
+      forEach(uNode, graph->getInOutNodes(vNode)) {
+        if (uNode == vNode)
+          // nothing to do if it a self loop
+          continue;
+
         gemQ = _nodeToParticules.get(uNode.id);
 
         if (gemQ->in > 0) {
@@ -324,7 +323,7 @@ void GEMLayout::arrange() {
   double  maxEdgeLength;
 
   if (_useLength)
-    maxEdgeLength = std::max(2.0f, (float)metric->getEdgeMin());
+    maxEdgeLength = std::max(2.0f, (float)metric->getEdgeDoubleMin());
   else
     maxEdgeLength = EDGELENGTH;
 
@@ -339,7 +338,7 @@ void GEMLayout::arrange() {
   Iteration         = 0;
 
   while (_temperature > stop_temperature && Iteration < max_iter) {
-    //    cerr << "t°:"<< _temperature << "/" << stop_temperature << " it:" << Iteration << endl;
+    //    tlp::warning() << "t°:"<< _temperature << "/" << stop_temperature << " it:" << Iteration << endl;
     if (pluginProgress->progress(Iteration, max_iter/2)!=TLP_CONTINUE) return;
 
     if (pluginProgress->isPreviewMode()) updateLayout();
@@ -359,17 +358,17 @@ bool GEMLayout::run() {
 
     for (size_t i = 0; i < components.size(); ++i) {
       Graph * tmp = graph->inducedSubGraph(components[i]);
-      tmp->computeProperty("GEM (Frick)", layoutResult, err, pluginProgress, dataSet);
+      tmp->applyPropertyAlgorithm("GEM (Frick)", result, err, pluginProgress, dataSet);
     }
 
     // call connected component packing
     LayoutProperty tmpLayout(graph);
     DataSet ds;
-    ds.set("coordinates", layoutResult);
-    graph->computeProperty("Connected Component Packing", &tmpLayout, err, pluginProgress, &ds);
+    ds.set("coordinates", result);
+    graph->applyPropertyAlgorithm("Connected Component Packing", &tmpLayout, err, pluginProgress, &ds);
     // forget last temporary graph state
     graph->pop();
-    *layoutResult = tmpLayout;
+    *result = tmpLayout;
     return true;
   }
 
@@ -383,7 +382,7 @@ bool GEMLayout::run() {
   _useLength = false;
   max_iter = 0;
 
-  if ( dataSet!=0 ) {
+  if ( dataSet!=NULL ) {
     dataSet->get("3D layout", is3D);
     _useLength = dataSet->get("edge length", metric) && metric!=NULL;
     dataSet->get("max iterations", max_iter);
@@ -395,7 +394,7 @@ bool GEMLayout::run() {
 
   _nbNodes = graph->numberOfNodes();
 
-  layoutResult->setAllEdgeValue(vector<Coord>(0));
+  result->setAllEdgeValue(vector<Coord>(0));
 
   if (max_iter == 0)
     max_iter = std::max(a_maxiter * _nbNodes * _nbNodes, MIN_ITER);
@@ -409,7 +408,7 @@ bool GEMLayout::run() {
     _particules[i].n = n;
     _particules[i].id = i;
 
-    if (!initLayout && layout != 0)
+    if (!initLayout && layout != NULL)
       _particules[i].pos = layout->getNodeValue(n);
     else
       _particules[i].pos.fill(0);
@@ -418,7 +417,7 @@ bool GEMLayout::run() {
     ++i;
   }
 
-  if (initLayout && layout != 0) {
+  if (initLayout && layout != NULL) {
     if (i_finaltemp < i_starttemp) this->insert();
   }
 
