@@ -21,10 +21,10 @@
 
 #include <vector>
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup layout */
-/*@{*/
+
 /// An implementation of a spring-embedder layout.
 /** This plugin is an implementation of the GEM-2d layout
  *  algorithm first published as:
@@ -75,7 +75,8 @@
 
 class GEMLayout : public tlp::LayoutAlgorithm {
 public:
-  GEMLayout(const tlp::PropertyContext &context);
+  PLUGININFORMATION("GEM (Frick)","Tulip Team","16/10/2008","Stable","1.2","Force Directed")
+  GEMLayout(const tlp::PluginContext* context);
   ~GEMLayout();
   bool run();
 
@@ -94,7 +95,7 @@ private:
     float heat;        // heat
     float mass;        // weight = nr incident edges
     unsigned int id;
-    GEMparticule(float m = 0) {
+    GEMparticule(float m = 0) : in(0), id(UINT_MAX) {
       pos.fill(0);
       imp.fill(0);
       dir  = 0.0;
@@ -135,31 +136,36 @@ private:
    * from a configuration file.  Here they are hard-wired, but
    * this could be replaced by configuration from a file.
    */
-  float    i_maxtemp;
-  float    i_starttemp;
-  float    i_finaltemp;
-  int      i_maxiter;
-  float    i_gravity;
-  float    i_oscillation;
-  float    i_rotation;
-  float    i_shake;
+  const float    i_maxtemp;
+  const float    a_maxtemp;
 
-  float    a_maxtemp;
-  float    a_starttemp;
-  float    a_finaltemp;
-  int      a_maxiter;
-  float    a_gravity;
-  float    a_oscillation;
-  float    a_rotation;
-  float    a_shake;
+  const float    i_starttemp;
+  const float    a_starttemp;
 
+  const float    i_finaltemp;
+  const float    a_finaltemp;
+
+  const int      i_maxiter;
+  const int      a_maxiter;
+
+  const float    i_gravity;
+  const float    a_gravity;
+
+  const float    i_oscillation;
+  const float    a_oscillation;
+
+  const float    i_rotation;
+  const float    a_rotation;
+
+  const float    i_shake;
+  const float    a_shake;
 
   unsigned int _dim; //2 or 3;
   unsigned int _nbNodes; //number of nodes in the graph
   bool _useLength; //if we manage edge length
-  tlp::DoubleProperty * metric; //metric for edge length
+  tlp::NumericProperty* metric; //metric for edge length
   unsigned int max_iter; // the max number of iterations
 
 };
-/*@}*/
+
 #endif
