@@ -18,14 +18,17 @@
  */
 #include <string>
 #include <cassert>
-#include <math.h>
+#include <cmath>
 #include <stack>
+
 #include <tulip/SortIterator.h>
+#include <tulip/StringCollection.h>
+
 #include "HierarchicalGraph.h"
 #include "DatasetTools.h"
 
 
-LAYOUTPLUGINOFGROUP(HierarchicalGraph,"Hierarchical Graph","David Auber","23/05/2000","Alpha","1.0","Hierarchical");
+PLUGIN(HierarchicalGraph)
 
 using namespace std;
 using namespace tlp;
@@ -47,12 +50,12 @@ const char * paramHelp[] = {
 //================================================================================
 #define ORIENTATION "horizontal;vertical;"
 //================================================================================
-HierarchicalGraph::HierarchicalGraph(const tlp::PropertyContext &context):LayoutAlgorithm(context) {
+HierarchicalGraph::HierarchicalGraph(const tlp::PluginContext* context):LayoutAlgorithm(context) {
   addNodeSizePropertyParameter(this);
-  addParameter<StringCollection> ("orientation", paramHelp[0], ORIENTATION );
+  addInParameter<StringCollection> ("orientation", paramHelp[0], ORIENTATION );
   addSpacingParameters(this);
-  addDependency<DoubleAlgorithm>("Dag Level", "1.0");
-  addDependency<LayoutAlgorithm>("Hierarchical Tree (R-T Extended)", "1.1");
+  addDependency("Dag Level", "1.0");
+  addDependency("Hierarchical Tree (R-T Extended)", "1.1");
 }
 //================================================================================
 HierarchicalGraph::~HierarchicalGraph() {}
@@ -67,12 +70,12 @@ public:
 };
 //================================================================================
 void HierarchicalGraph::buildGrid(tlp::Graph *sg) {
-  //  cerr << __PRETTY_FUNCTION__  << endl;
+  //  tlp::warning() << __PRETTY_FUNCTION__  << endl;
   string erreurMsg;
   DoubleProperty dagLevel(sg);
 
-  if(!sg->computeProperty("Dag Level", &dagLevel,erreurMsg)) {
-    cerr << "[ERROR] : " << erreurMsg << __PRETTY_FUNCTION__ << endl;
+  if(!sg->applyPropertyAlgorithm("Dag Level", &dagLevel,erreurMsg)) {
+    tlp::warning() << "[ERROR] : " << erreurMsg << __PRETTY_FUNCTION__ << endl;
     return;
   }
 
@@ -85,7 +88,7 @@ void HierarchicalGraph::buildGrid(tlp::Graph *sg) {
     embedding->setNodeValue(n, grid[level].size());
     grid[level].push_back(n);
   }
-  //  cerr << __PRETTY_FUNCTION__  << endl;
+  //  tlp::warning() << __PRETTY_FUNCTION__  << endl;
 }
 //================================================================================
 unsigned int HierarchicalGraph::degree(tlp::Graph *sg, tlp::node n,bool sense) {
@@ -177,7 +180,7 @@ void HierarchicalGraph::crossReduction(tlp::Graph *sg) {
   }
   grid.push_back(vector<node>());
   grid[grid.size()-1].push_back(tmp);
-  //  cerr << __PRETTY_FUNCTION__  << endl;
+  //  tlp::warning() << __PRETTY_FUNCTION__  << endl;
   MutableContainer<bool> visited;
   visited.setAll(false);
   node root = sg->getSource();
@@ -221,11 +224,11 @@ void HierarchicalGraph::crossReduction(tlp::Graph *sg) {
   }
 
   sg->delNode(tmp, true);
-  //  cerr << __PRETTY_FUNCTION__  << endl;
+  //  tlp::warning() << __PRETTY_FUNCTION__  << endl;
 }
 //================================================================================
 void HierarchicalGraph::DagLevelSpanningTree(tlp::Graph* sg, tlp::DoubleProperty *embedding) {
-  //  cerr << __PRETTY_FUNCTION__  << endl;
+  //  tlp::warning() << __PRETTY_FUNCTION__  << endl;
   assert(AcyclicTest::isAcyclic(sg));
   LessThanEdge tmpL;
   tmpL.metric = embedding;
@@ -248,12 +251,12 @@ void HierarchicalGraph::DagLevelSpanningTree(tlp::Graph* sg, tlp::DoubleProperty
     }
   }
   assert(TreeTest::isTree(sg));
-  //  cerr << __PRETTY_FUNCTION__  << endl;
+  //  tlp::warning() << __PRETTY_FUNCTION__  << endl;
 }
 //==============================================================================================================
 void HierarchicalGraph::computeEdgeBends(const tlp::Graph *mySGraph, tlp::LayoutProperty &tmpLayout,
     const TLP_HASH_MAP<tlp::edge,tlp::edge> &replacedEdges, const std::vector<tlp::edge> &reversedEdges) {
-  //  cerr << "we compute bends on splitted edges" << endl;
+  //  tlp::warning() << "we compute bends on splitted edges" << endl;
   MutableContainer<bool> isReversed;
   isReversed.setAll(false);
 
@@ -299,12 +302,12 @@ void HierarchicalGraph::computeEdgeBends(const tlp::Graph *mySGraph, tlp::Layout
       edgeLine.push_back(p2);
     }
 
-    layoutResult->setEdgeValue(toUpdate,edgeLine);
+    result->setEdgeValue(toUpdate,edgeLine);
   }
 }
 //=======================================================================
 void HierarchicalGraph::computeSelfLoops(tlp::Graph *mySGraph, tlp::LayoutProperty &tmpLayout, std::vector<tlp::SelfLoops> &listSelfLoops) {
-  //cerr << "We compute self loops" << endl;
+  //tlp::warning() << "We compute self loops" << endl;
   while (!listSelfLoops.empty()) {
     tlp::SelfLoops tmp = listSelfLoops.back();
     listSelfLoops.pop_back();
@@ -327,18 +330,16 @@ void HierarchicalGraph::computeSelfLoops(tlp::Graph *mySGraph, tlp::LayoutProper
     for (it = edge3.begin(); it!=edge3.end(); ++it)
       tmpLCoord.push_back(*it);
 
-    layoutResult->setEdgeValue(tmp.old,tmpLCoord);
+    result->setEdgeValue(tmp.old,tmpLCoord);
     mySGraph->delNode(tmp.n1, true);
     mySGraph->delNode(tmp.n2, true);
   }
 
-  //  cerr << "we clean every added nodes and edges" << endl;
+  //  tlp::warning() << "we clean every added nodes and edges" << endl;
 }
 
-
-namespace {
 //============================================================================
-void dfsRecCall(Graph *sg, vector<node> &vec, MutableContainer<bool> &nodeVisited, node n) {
+/*static void dfsRecCall(Graph *sg, vector<node> &vec, MutableContainer<bool> &nodeVisited, node n) {
   nodeVisited.set(n.id, true);
   vec.push_back(n);
   node dest;
@@ -347,9 +348,9 @@ void dfsRecCall(Graph *sg, vector<node> &vec, MutableContainer<bool> &nodeVisite
       dfsRecCall(sg, vec, nodeVisited, dest);
     }
   }
-}
+  }*/
 //============================================================================
-void buildDfsOrdering(Graph *sg, vector<node> &vec) {
+/*static void buildDfsOrdering(Graph *sg, vector<node> &vec) {
   MutableContainer<bool> nodeVisited;
   nodeVisited.setAll(false);
   node n;
@@ -358,8 +359,7 @@ void buildDfsOrdering(Graph *sg, vector<node> &vec) {
       dfsRecCall(sg, vec, nodeVisited, n);
     }
   }
-}
-}
+  }*/
 //=======================================================================
 bool HierarchicalGraph::run() {
   //make acyclic
@@ -383,7 +383,7 @@ bool HierarchicalGraph::run() {
   nodeSpacing = 18;
   SizeProperty* nodeSize = NULL;
 
-  if (dataSet!=0) {
+  if (dataSet!=NULL) {
     getNodeSizePropertyParameter(dataSet, nodeSize);
     getSpacingParameters(dataSet, nodeSpacing, spacing);
     StringCollection tmp;
@@ -412,6 +412,7 @@ bool HierarchicalGraph::run() {
 
   // push a temporary graph state (not redoable)
   graph->push(false);
+  result->setAllEdgeValue(std::vector<tlp::Coord>());
 
   //========================================================================
   // Build a clone of this graph
@@ -429,7 +430,7 @@ bool HierarchicalGraph::run() {
   //========================================================================
   list<node> properAddedNodes;
   TLP_HASH_MAP<edge,edge> replacedEdges;
-  IntegerProperty *edgeLength = 0;
+  IntegerProperty *edgeLength = NULL;
 
   if (!TreeTest::isTree(mySGraph)) {
     //We transform the dag in a proper dag
@@ -470,7 +471,7 @@ bool HierarchicalGraph::run() {
   tmp.set("layer spacing", spacing);
   tmp.set("node spacing", nodeSpacing);
 
-  if (edgeLength!=0)
+  if (edgeLength!=NULL)
     tmp.set("edge length", edgeLength);
 
   tmp.set("orthogonal", true);
@@ -480,7 +481,7 @@ bool HierarchicalGraph::run() {
 #ifndef NDEBUG
   resultBool =
 #endif
-    mySGraph->computeProperty("Hierarchical Tree (R-T Extended)", &tmpLayout, erreurMsg, 0, &tmp);
+    mySGraph->applyPropertyAlgorithm("Hierarchical Tree (R-T Extended)", &tmpLayout, erreurMsg, 0, &tmp);
 
   if (edgeLength)
     delete edgeLength;
@@ -490,7 +491,7 @@ bool HierarchicalGraph::run() {
 
   node n;
   forEach(n, graph->getNodes()) {
-    layoutResult->setNodeValue(n, tmpLayout.getNodeValue(n));
+    result->setNodeValue(n, tmpLayout.getNodeValue(n));
   }
 
   computeEdgeBends(graph, tmpLayout, replacedEdges, reversedEdges);
@@ -534,9 +535,9 @@ bool HierarchicalGraph::run() {
       rev = 1.0;
     }
 
-    Coord srcPos = layoutResult->getNodeValue(src);
-    Coord tgtPos = layoutResult->getNodeValue(tgt);
-    vector<Coord> old = layoutResult->getEdgeValue(e);
+    Coord srcPos = result->getNodeValue(src);
+    Coord tgtPos = result->getNodeValue(tgt);
+    vector<Coord> old = result->getEdgeValue(e);
 
     if (old.empty()) {
       vector<Coord> pos(2);
@@ -544,7 +545,7 @@ bool HierarchicalGraph::run() {
       tgtPos[1] -= rev*(levelMaxSize[nodeLevel.get(tgt.id)]/2.f + spacing/4.f);
       pos[0] = srcPos;
       pos[1] = tgtPos;
-      layoutResult->setEdgeValue(e, pos);
+      result->setEdgeValue(e, pos);
     }
     else {
       vector<Coord> pos(4);
@@ -564,16 +565,16 @@ bool HierarchicalGraph::run() {
       pos[1] = src2Pos;
       pos[2] = tgt2Pos;
       pos[3] = tgtPos;
-      layoutResult->setEdgeValue(e, pos);
+      result->setEdgeValue(e, pos);
     }
   }
 
   //post processing align nodes
   forEach(n, graph->getNodes()) {
-    Coord tmp = layoutResult->getNodeValue(n);
+    Coord tmp = result->getNodeValue(n);
     const Size& tmpS = nodeSize->getNodeValue(n);
     tmp[1] -= (levelMaxSize[nodeLevel.get(n.id)] - tmpS[1]) / 2.f;
-    layoutResult->setNodeValue(n, tmp);
+    result->setNodeValue(n, tmp);
   }
 
   //rotate layout
@@ -582,12 +583,12 @@ bool HierarchicalGraph::run() {
     delete nodeSize;
     node n;
     forEach(n, graph->getNodes()) {
-      const Coord& tmpC = layoutResult->getNodeValue(n);
-      layoutResult->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
+      const Coord& tmpC = result->getNodeValue(n);
+      result->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
     }
     edge e;
     forEach(e, graph->getEdges()) {
-      LineType::RealType tmp = layoutResult->getEdgeValue(e);
+      LineType::RealType tmp = result->getEdgeValue(e);
       LineType::RealType tmp2;
       LineType::RealType::iterator it;
 
@@ -595,7 +596,7 @@ bool HierarchicalGraph::run() {
         tmp2.push_back(Coord(-(*it)[1], (*it)[0], (*it)[2]));
       }
 
-      layoutResult->setEdgeValue(e, tmp2);
+      result->setEdgeValue(e, tmp2);
     }
   }
 
