@@ -19,7 +19,7 @@
 #ifndef Tulip_HierarchicalGraph_H
 #define Tulip_Hierarchical_H
 #include <tulip/tuliphash.h>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 class LessThanNode2 {
 public:
@@ -30,9 +30,10 @@ public:
 };
 
 /** \addtogroup layout */
-/*@{*/
-/// An implementation of hierarchical graph drawing algorithm
+
 /**
+ * \file
+ * \brief An implementation of hierarchical graph drawing algorithm
  *
  * This plugin is an implementation of the hierarchical layout algorithm
  * first published as:
@@ -47,7 +48,8 @@ public:
 class HierarchicalGraph:public tlp::LayoutAlgorithm {
 
 public:
-  HierarchicalGraph(const tlp::PropertyContext& context);
+  PLUGININFORMATION("Hierarchical Graph","David Auber","23/05/2000","Alpha","1.0","Hierarchical")
+  HierarchicalGraph(const tlp::PluginContext* context);
   ~HierarchicalGraph();
   bool run();
 
@@ -69,7 +71,7 @@ private:
   float spacing;
   float nodeSpacing;
 };
-/*@}*/
+
 #endif
 
 
