@@ -21,18 +21,13 @@
 #include <algorithm>
 #include <tulip/GraphTools.h>
 #include "DatasetTools.h"
-#include "EdgeTools.h"
 #include "Orientation.h"
 #include "ImprovedWalker.h"
 
 using namespace std;
 using namespace tlp;
 
-LAYOUTPLUGINOFGROUP(ImprovedWalker, "Improved Walker",
-                    "Julien Testut, Antony Durand, Pascal Ollier, "
-                    "Yashvin Nababsing, Sebastien Leclerc, "
-                    "Thibault Ruchon, Eric Dauchier",
-                    "11/11/04", "ok", "1.0","Tree");
+PLUGIN(ImprovedWalker)
 
 //====================================================================
 const node  ImprovedWalker::BADNODE;
@@ -70,7 +65,7 @@ public:
   }
 };
 //====================================================================
-ImprovedWalker::ImprovedWalker(const tlp::PropertyContext& context) :
+ImprovedWalker::ImprovedWalker(const tlp::PluginContext* context) :
   LayoutAlgorithm(context) {
   addNodeSizePropertyParameter(this);
   addOrientationParameters(this);
@@ -89,11 +84,13 @@ bool ImprovedWalker::run() {
   // preserving layout updates
   std::vector<PropertyInterface*> propsToPreserve;
 
-  if (layoutResult->getName() != "")
-    propsToPreserve.push_back(layoutResult);
+  if (result->getName() != "")
+    propsToPreserve.push_back(result);
 
   graph->push(false, &propsToPreserve);
 
+  result->setAllEdgeValue(vector<Coord>());
+
   tree = TreeTest::computeTree(graph, pluginProgress);
 
   if (pluginProgress && pluginProgress->state() != TLP_CONTINUE) {
@@ -101,9 +98,11 @@ bool ImprovedWalker::run() {
     return false;
   }
 
+
+
   node root = tree->getSource();
   orientationType mask = getMask(dataSet);
-  oriLayout = new OrientableLayout(layoutResult, mask);
+  oriLayout = new OrientableLayout(result, mask);
   SizeProperty* size;
 
   if (!getNodeSizePropertyParameter(dataSet, size))
@@ -129,7 +128,7 @@ bool ImprovedWalker::run() {
   secondWalk(root,0,0);
 
   if (hasOrthogonalEdge(dataSet))
-    setOrthogonalEdge(oriLayout, tree, spacing);
+    oriLayout->setOrthogonalEdge(tree, spacing);
 
   // forget last temporary graph state
   graph->pop();
