@@ -21,7 +21,7 @@
 
 #include <map>
 #include <vector>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 #include "TreeTools.h"
 
 class OrientableLayout;
@@ -30,7 +30,7 @@ class OrientableSizeProxy;
 class ImprovedWalkerIterator;
 
 /** \addtogroup layout */
-/*@{*/
+
 /** This plugin is an implementation of a linear Walker's algorithm:
  *
  *  Christoph Buchheim and Michael Junger and Sebastian Leipert,
@@ -49,7 +49,12 @@ class ImprovedWalker : public tlp::LayoutAlgorithm {
   friend class ImprovedWalkerUnitTests;
 
 public:
-  ImprovedWalker(const tlp::PropertyContext&);
+  PLUGININFORMATION( "Improved Walker",
+                     "Julien Testut, Antony Durand, Pascal Ollier, "
+                     "Yashvin Nababsing, Sebastien Leclerc, "
+                     "Thibault Ruchon, Eric Dauchier",
+                     "11/11/04", "ok", "1.0","Tree")
+  ImprovedWalker(const tlp::PluginContext* context);
   ~ImprovedWalker();
 
   bool run();
@@ -182,5 +187,5 @@ inline tlp::node ImprovedWalker::findCommonAncestor(tlp::node left, tlp::node ri
   else
     return defaultAncestor;
 }
-/*@}*/
+
 #endif
