@@ -16,20 +16,23 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <algorithm>
-#include <tulip/TulipPlugin.h>
 
+#include <algorithm>
+
+#include <tulip/TulipPluginHeaders.h>
 #include <tulip/MapIterator.h>
 #include <tulip/PlanarConMap.h>
 #include <tulip/Ordering.h>
 #include <tulip/MutableContainer.h>
 #include <tulip/Bfs.h>
 #include <tulip/GraphTools.h>
+#include <tulip/StringCollection.h>
+#include <tulip/TulipViewSettings.h>
 
 #include "MixedModel.h"
 #include "DatasetTools.h"
 
-LAYOUTPLUGINOFGROUP(MixedModel,"Mixed Model","Romain BOURQUI ","09/11/2005","Ok","1.0","Planar");
+PLUGIN(MixedModel)
 
 using namespace std;
 using namespace tlp;
@@ -73,14 +76,14 @@ const char * paramHelp[] = {
 }
 #define ORIENTATION "vertical;horizontal;"
 //====================================================
-MixedModel::MixedModel(const tlp::PropertyContext &context):LayoutAlgorithm(context)  {
+MixedModel::MixedModel(const tlp::PluginContext* context):LayoutAlgorithm(context)  {
   addNodeSizePropertyParameter(this, true /* inout */);
-  addParameter<StringCollection> ("orientation", paramHelp[0], ORIENTATION );
-  addParameter<float> ("y node-node spacing",paramHelp[1],"2");
-  addParameter<float> ("x node-node and edge-node spacing",paramHelp[2],"2");
+  addInParameter<StringCollection> ("orientation", paramHelp[0], ORIENTATION );
+  addInParameter<float> ("y node-node spacing",paramHelp[1],"2");
+  addInParameter<float> ("x node-node and edge-node spacing",paramHelp[2],"2");
   addOutParameter<IntegerProperty>("node shape", paramHelp[3],
                                    "viewShape");
-  addDependency<LayoutAlgorithm>("Connected Component Packing", "1.0");
+  addDependency("Connected Component Packing", "1.0");
 }
 //====================================================
 MixedModel::~MixedModel() {
@@ -91,7 +94,7 @@ bool MixedModel::run() {
   sizeResult = NULL;
   glyphResult = NULL;
 
-  if (dataSet!=0) {
+  if (dataSet!=NULL) {
     getNodeSizePropertyParameter(dataSet, sizeResult);
     StringCollection tmp;
 
@@ -121,7 +124,7 @@ bool MixedModel::run() {
     }
   }
 
-  glyphResult->setAllEdgeValue(0);
+  glyphResult->setAllEdgeValue(EdgeShape::Polyline);
 
   // give some empirical feedback of what we are doing 1 %
   pluginProgress->progress(1, 1000);
@@ -148,26 +151,26 @@ bool MixedModel::run() {
     //====================================================
     //don't compute the canonical ordering if the nmber of nodes is less than 3
 
-    /* cout << currentGraph->numberOfNodes() << " nodes and " << currentGraph->numberOfEdges() << " edges " << endl;
-    cout << "Create map" << endl; */
+    /* tlp::debug() << currentGraph->numberOfNodes() << " nodes and " << currentGraph->numberOfEdges() << " edges " << endl;
+    tlp::debug() << "Create map" << endl; */
     if(currentGraph->numberOfNodes() == 1) {
       node n = currentGraph->getOneNode();
-      layoutResult->setNodeValue(n, Coord(0,0,0));
+      result->setNodeValue(n, Coord(0,0,0));
       continue;
     }
     else if(currentGraph->numberOfNodes() == 2 || currentGraph->numberOfNodes() == 3) {
       Iterator<node> * itn = currentGraph->getNodes();
       node n = itn->next();
       Coord c(sizeResult->getNodeValue(n));
-      layoutResult->setNodeValue(n, Coord(0,0,0));
+      result->setNodeValue(n, Coord(0,0,0));
       node n2 = itn->next();
       Coord c2(sizeResult->getNodeValue(n2));
-      layoutResult->setNodeValue(n2, Coord(spacing + c.getX()/2+c2.getX()/2,0,0));
+      result->setNodeValue(n2, Coord(spacing + c.getX()/2+c2.getX()/2,0,0));
 
       if(currentGraph->numberOfNodes() == 3) {
         node n3 = itn->next();
         Coord c3(sizeResult->getNodeValue(n2));
-        layoutResult->setNodeValue(n3, Coord(2.f * spacing + c.getX()/2.f + c2.getX()+c3.getX()/2.f,0,0));
+        result->setNodeValue(n3, Coord(2.f * spacing + c.getX()/2.f + c2.getX()+c3.getX()/2.f,0,0));
         edge e = currentGraph->existEdge(n,n3, false);
 
         if(e.isValid()) {
@@ -185,7 +188,7 @@ bool MixedModel::run() {
             bends.push_back(Coord(0,static_cast<float>(max),0));
           }
 
-          layoutResult->setEdgeValue(e, bends);
+          result->setEdgeValue(e, bends);
         }
 
       }
@@ -202,7 +205,7 @@ bool MixedModel::run() {
     Graph * G;
 
     if(!planar) {
-      // cout << "Graph is not planar ...";
+      // tlp::debug() << "Graph is not planar ...";
       BooleanProperty resultatAlgoSelection(currentGraph);
       Bfs sp(currentGraph, &resultatAlgoSelection);
       currentGraph->delSubGraph(sp.graph);
@@ -239,7 +242,7 @@ bool MixedModel::run() {
       }
 
       delete graphMap;
-      // cout << "... Planar subGraph computed" << endl;
+      // tlp::debug() << "... Planar subGraph computed" << endl;
     }
     else {
       G = currentGraph->addCloneSubGraph();
@@ -268,8 +271,8 @@ bool MixedModel::run() {
     // give some empirical feedback (5%)
     pluginProgress->progress(2, 100);
 
-    // cout << "Make the map planar ...";
-    // cout << "... end" << endl;
+    // tlp::debug() << "Make the map planar ...";
+    // tlp::debug() << "... end" << endl;
     // give some empirical feedback of what we are doing (10%)
     if (pluginProgress->progress(5, 100) !=TLP_CONTINUE)
       return pluginProgress->state()!= TLP_CANCEL;
@@ -291,20 +294,20 @@ bool MixedModel::run() {
     // Cout << "Partition initialization ...";
     initPartition() ;
 
-    // cout<<"... Partition initialized"<<endl;
+    // tlp::debug()<<"... Partition initialized"<<endl;
     if (pluginProgress->state() == TLP_CANCEL)
       return false;
 
-    // cout << "InOutPoint computation ..."  ;
+    // tlp::debug() << "InOutPoint computation ..."  ;
     assignInOutPoints();
-    // cout<<"... InOutPoints computed"<<endl;
+    // tlp::debug()<<"... InOutPoints computed"<<endl;
 
-    // cout << "Coordinate computation ..."  ;
+    // tlp::debug() << "Coordinate computation ..."  ;
     computeCoords();
-    // cout<<"... Coordinate computed"<<endl;
-    // cout << "Drawing edges and nodes ..." ;
+    // tlp::debug()<<"... Coordinate computed"<<endl;
+    // tlp::debug() << "Drawing edges and nodes ..." ;
     placeNodesEdges();
-    // cout << "... Edges and Nodes drawn" <<endl;
+    // tlp::debug() << "... Edges and Nodes drawn" <<endl;
 
     vector<edge>::const_iterator ite = dummy.begin();
 
@@ -312,12 +315,12 @@ bool MixedModel::run() {
       currentGraph->delEdge(*ite, true);
 
     ite = added_edges.begin();
-    const vector<Coord>& dv = layoutResult->getEdgeDefaultValue();
+    const vector<Coord>& dv = result->getEdgeDefaultValue();
 
     for (; ite!=added_edges.end(); ++ite) {
       edge e = *ite;
       currentGraph->delEdge(e, true);
-      layoutResult->setEdgeValue(e, dv);
+      result->setEdgeValue(e, dv);
     }
 
     delete carte;
@@ -331,13 +334,13 @@ bool MixedModel::run() {
     string err ="";
     LayoutProperty layout(graph);
     DataSet tmp;
-    tmp.set("coordinates", layoutResult);
-    graph->computeProperty(string("Connected Component Packing"),&layout,err,NULL,&tmp);
+    tmp.set("coordinates", result);
+    graph->applyPropertyAlgorithm(string("Connected Component Packing"),&layout,err,NULL,&tmp);
     Iterator<node> *itN = graph->getNodes();
 
     while(itN->hasNext()) {
       node n = itN->next();
-      layoutResult->setNodeValue(n, layout.getNodeValue(n));
+      result->setNodeValue(n, layout.getNodeValue(n));
     }
 
     delete itN;
@@ -345,7 +348,7 @@ bool MixedModel::run() {
 
     while(itE->hasNext()) {
       edge e = itE->next();
-      layoutResult->setEdgeValue(e, layout.getEdgeValue(e));
+      result->setEdgeValue(e, layout.getEdgeValue(e));
     }
 
     delete itE;
@@ -360,12 +363,12 @@ bool MixedModel::run() {
     forEach(n, graph->getNodes()) {
       const Size& tmp = sizeResult->getNodeValue(n);
       sizeResult->setNodeValue(n, Size(tmp[1], tmp[0], tmp[2]));
-      const Coord& tmpC = layoutResult->getNodeValue(n);
-      layoutResult->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
+      const Coord& tmpC = result->getNodeValue(n);
+      result->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
     }
     edge e;
     forEach(e, graph->getEdges()) {
-      LineType::RealType tmp = layoutResult->getEdgeValue(e);
+      LineType::RealType tmp = result->getEdgeValue(e);
       LineType::RealType tmp2;
       LineType::RealType::iterator it;
 
@@ -373,7 +376,7 @@ bool MixedModel::run() {
         tmp2.push_back(Coord(-(*it)[1], (*it)[0], (*it)[2]));
       }
 
-      layoutResult->setEdgeValue(e, tmp2);
+      result->setEdgeValue(e, tmp2);
     }
   }
 
@@ -427,7 +430,7 @@ void MixedModel::placeNodesEdges() {
     Coord c = nodeSize.get(n.id);
     c[0] -= edgeNodeSpacing;
     graph->getProperty<SizeProperty>("viewSize")->setNodeValue(n,Size(c[0],c[1],0.3f));
-    layoutResult->setNodeValue(n, NodeCoords[n]);
+    result->setNodeValue(n, NodeCoords[n]);
   }
 
   delete it;
@@ -481,10 +484,10 @@ void MixedModel::placeNodesEdges() {
 
 
       if(!bends.empty())
-        layoutResult->setEdgeValue(e, bends);
+        result->setEdgeValue(e, bends);
     }
 
-    // rs == rt, même partition donc pas de points intermédiaire à calculer
+    // rs == rt, même partition donc pas de points intermédiaire   calculer
     // en cas de post-processing, il faudra pe y changer
   }
 
@@ -503,8 +506,8 @@ void MixedModel::placeNodesEdges() {
       Coord c_n(-maxX+(NodeCoords[n].getX()+NodeCoords[v].getX())/2.f, -maxY+(NodeCoords[n].getY()+NodeCoords[v].getY())/2.f, -z_size);
       vector<Coord> bends;
       bends.push_back(c_n);
-      layoutResult->setEdgeValue(e, bends);
-      graph->getProperty<IntegerProperty>("viewShape")->setEdgeValue(e,4);
+      result->setEdgeValue(e, bends);
+      graph->getProperty<IntegerProperty>("viewShape")->setEdgeValue(e, EdgeShape::BezierCurve);
       graph->getProperty<ColorProperty>("viewColor")->setEdgeValue(e,Color(218,218,218));
     }
   }
@@ -522,33 +525,6 @@ void MixedModel::initPartition() {
       rank[V[i][j]] = i;
 }
 
-//====================================================
-void afficheCycle(tlp::PlanarConMap* m) {
-  assert(m);
-  cout<<"Cycles :"<<endl;
-  Iterator<node>* itn = m->getNodes();
-
-  node n;
-
-  while(itn->hasNext()) {
-    n = itn->next();
-    cout<<n.id<<" ( ";
-
-    edge e;
-    Iterator<edge>* ite = m->getInOutEdges(n);
-
-    while(ite->hasNext()) {
-      e = ite->next();
-      cout<<e.id<<" ";
-    }
-
-    cout<<" )"<<endl;
-    delete ite;
-  }
-
-  delete itn;
-}
-
 //====================================================
 void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc double
   assert(carte);
@@ -557,7 +533,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
   // empirical feedback (95% -> 99%)
   int minProgress = 950, deltaProgress = 40;
 
-  for(unsigned int k = 0; k < V.size(); k++) {
+  for(unsigned int k = 0; k < V.size(); ++k) {
     // give pluginProgress feedback
     if (pluginProgress->progress(minProgress +
                                  (deltaProgress * k)/ V.size(),
@@ -573,7 +549,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
       // ordonné les arcs "in"
       unsigned int i;
 
-      for(i = 0; !nl.isValid() && (i<C.size()-1); i++) {
+      for(i = 0; !nl.isValid() && (i<C.size()-1); ++i) {
         if(existEdge(C[i], V[k][0]).isValid()) {
           nl = C[i];
         }
@@ -595,7 +571,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
       assert(ir != C.end());
     }
 
-    for(unsigned int i = 0; i < p; i++) {
+    for(unsigned int i = 0; i < p; ++i) {
       node v = V[k][i];
       unsigned nbIn = 0, nbOut = 0;
       vector<edge> listOfEdgesIN;
@@ -623,7 +599,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
 
 
         if(r < k) {
-          nbIn++;
+          ++nbIn;
           trouve = true;
 
           if(pred == 'o') {
@@ -637,7 +613,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
         }
 
         if(r > k && !trouve) {
-          nbOut++;
+          ++nbOut;
           trouve = true;
 
           if(pred == 'i') {
@@ -652,7 +628,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
 
         if((i != 0)&&(!trouve)) { // test le voisin de gauche
           if(V[k][i-1] == n) {
-            nbIn++;
+            ++nbIn;
             trouve = true;
 
             if(pred == 'o') {
@@ -668,7 +644,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
 
         if( (i != V[k].size()-1) && !trouve) { // test le voisin de droite
           if(V[k][i+1] == n) {
-            nbIn++;
+            ++nbIn;
 
             if(pred == 'o') {
               pred = 'i';
@@ -748,7 +724,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
       int outMoins = (0 >= outPlus ? 0 : outPlus);
 
       if(dtmp != float(outPlus))
-        outPlus++;  // valeur entière supérieure
+        ++outPlus;  // valeur entière supérieure
 
       if( nbIn >= 2) {
         dl = 1;
@@ -845,7 +821,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
       if(nbOut>=1) {
         Coord c;
 
-        for(int x = -out_l, y = dl; x<=-1 ; x++,y++) {
+        for(int x = -out_l, y = dl; x<=-1 ; ++x,++y) {
           c.set(static_cast<float>(x), static_cast<float>(y));
           out_points[v].push_back(c);
         }
@@ -853,7 +829,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
         c.set(0,(out_l+dl-1 > out_r+dr-1) ? static_cast<float>(out_l+dl-1) : static_cast<float>(out_r+dr-1));
         out_points[v].push_back(c);
 
-        for(int x = 1, y = out_r+dr-1; y>=dr ; x++,y--) {
+        for(int x = 1, y = out_r+dr-1; y>=dr ; ++x,--y) {
           c.set(static_cast<float>(x),static_cast<float>(y));
           out_points[v].push_back(c);
         }
@@ -894,7 +870,7 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
 
       if(0>in_l) in_l = 0;
 
-      if(ftmp != float(in_r)) in_r++;
+      if(ftmp != float(in_r)) ++in_r;
 
       if(0>in_r) in_r = 0;
 
@@ -905,32 +881,32 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
         unsigned int j = 0;
         Coord c(-static_cast<float>(in_l),0);
         InPoints[listOfEdgesIN[j]].push_back(c);
-        j++;
+        ++j;
 
-        for(int x = -in_l, y = -1; x<=-1 ; x++,y--) {
+        for(int x = -in_l, y = -1; x<=-1 ; ++x,--y) {
           c.set(static_cast<float>(x), static_cast<float>(y));
           InPoints[listOfEdgesIN[j]].push_back(c);
-          j++;
+          ++j;
         }
 
         c.set(0, -static_cast<float>(in_r));
         InPoints[listOfEdgesIN[j]].push_back(c);
-        j++;
+        ++j;
 
-        for(int x = 1, y = -in_r; x<=in_r ; x++,y++) {
+        for(int x = 1, y = -in_r; x<=in_r ; ++x,++y) {
           c.set(static_cast<float>(x), static_cast<float>(y));
           InPoints[listOfEdgesIN[j]].push_back(c);
-          j++;
+          ++j;
         }
 
         c.set(static_cast<float>(in_r), 0);
         InPoints[listOfEdgesIN[j]].push_back(c);
-        j++;
+        ++j;
 
         assert( j == nbIn );
       }
       else {
-        for(unsigned int j = 0; j<nbIn; j++)
+        for(unsigned int j = 0; j<nbIn; ++j)
           InPoints[listOfEdgesIN[j]].push_back(Coord());
       }
 
@@ -938,12 +914,12 @@ void MixedModel::assignInOutPoints() { // on considère qu'il n'y a pas d'arc do
       unsigned s = listOfEdgesOUT.size();
       EdgesOUT[v] = vector<edge>(s);
 
-      for(unsigned int i = 0; i<s; i++)
+      for(unsigned int i = 0; i<s; ++i)
         EdgesOUT[v][s-(i+1)] = listOfEdgesOUT[i];
 
     }
 
-    // mise à jour du contour
+    // mise   jour du contour
     if(k == 0) C = V[0];
     else {
       C.erase(il+1, ir);
@@ -971,21 +947,21 @@ void MixedModel::computeCoords() {
 
   map<node, node> father;  // permet de connaître le noeud de référence
   father.clear();
-  assert(V.size() != 0);
+  assert(!V.empty());
 
   vector<node> C;  // chemin courant
   double out_r_moins1 = 0.0;
 
   //-------------  initialisation --------------------------
-  for(unsigned int i = 0; i<V[0].size(); i++) {
+  for(unsigned int i = 0; i<V[0].size(); ++i) {
     node v = V[0][i];
 
     double out_l = outl[v], out_r = outr[v];
     Coord c = nodeSize.get((V[0][i]).id);
     float x;
 
-    if(i == 0) x = (out_l < static_cast<double>(c.getX()/2.f) ? (c.getX()/2.f) : static_cast<float>(out_l)) ;
-    else  x = static_cast<float>(out_r_moins1) + (out_l < static_cast<double>(c.getX()/2.f) ? (c.getX()/2.f) : static_cast<float>(out_l))  + spacing;
+    if(i == 0) x = (out_l < static_cast<double>(c.getX()/2.f)) ? (c.getX()/2.f) : static_cast<float>(out_l) ;
+    else  x = static_cast<float>(out_r_moins1) + ((out_l < static_cast<double>(c.getX()/2.f)) ? (c.getX()/2.f) : static_cast<float>(out_l))  + spacing;
 
     NodeCoords[v] = Coord(x, 0, 0);  // y(vi) = 0
     out_r_moins1 = (out_r < (c.getX()/2.) ? (c.getX()/2.) : out_r);
@@ -995,10 +971,10 @@ void MixedModel::computeCoords() {
 
   unsigned int size_V = V.size();
 
-  for(unsigned int k = 1; k< size_V; k++) { // parcours de chaque partition
+  for(unsigned int k = 1; k< size_V; ++k) { // parcours de chaque partition
 
     unsigned int p  = V[k].size();  // taille de la partition Vk
-    node cl = leftV(k), cr = rightV(k); // recherche du left et right de Vk, qui là est cherché à l'aide de EdgesIN
+    node cl = leftV(k), cr = rightV(k); // recherche du left et right de Vk, qui l  est cherché   l'aide de EdgesIN
 
     vector<node>::iterator il = find(C.begin(), C.end(), cl);
     assert(il != C.end());
@@ -1008,7 +984,7 @@ void MixedModel::computeCoords() {
     float max_y = NodeCoords[(*il)].getY() + co.getY()/2.f ;
     float somme = 0; // relative to cl
 
-    for(vector<node>::iterator i = il+1; i != ir+1; i++) {
+    for(vector<node>::iterator i = il+1; i != ir+1; ++i) {
       Coord co2 = nodeSize.get((*i).id);
       float y =  NodeCoords[(*i)].getY() + co2.getY()/2.f ; //recherche max des y(ci) dans [cl...cr]
 
@@ -1021,18 +997,18 @@ void MixedModel::computeCoords() {
 
     node Z0 = V[k][0];
     co = nodeSize.get(Z0.id);
-    int max_y_taille = (int) (inr[Z0]<co.getY()/2. ? co.getY()/2. : inr[Z0]);
+    int max_y_taille = (int) ((inr[Z0]<co.getY()/2.) ? co.getY()/2. : inr[Z0]);
     int taille_tmp;
 
-    for(unsigned int i = 0; i<p; i++) {
+    for(unsigned int i = 0; i<p; ++i) {
       co = nodeSize.get((V[k][i]).id);
-      taille_tmp = (int) (inr[V[k][i]]<co.getY()/2. ? co.getY()/2. : inr[V[k][i]]);
+      taille_tmp = (int) ((inr[V[k][i]]<co.getY()/2.) ? co.getY()/2. : inr[V[k][i]]);
 
       if(taille_tmp > max_y_taille)
         max_y_taille = taille_tmp;
     }
 
-    for(unsigned int i = 0; i<p; i++) {
+    for(unsigned int i = 0; i<p; ++i) {
       // assign y-coords
       NodeCoords[V[k][i]] = Coord(0, max_y_taille + max_y + spacing, 0);
     }
@@ -1049,9 +1025,9 @@ void MixedModel::computeCoords() {
       vector<node>::iterator it = il;
       int t = 1;
 
-      for(; t<in_l+2 && it != ir; t++) {
+      for(; t<in_l+2 && it != ir; ++t) {
         do {
-          it++;
+          ++it;
         }
         while(!existEdge(Z0, (*it)).isValid());
       }
@@ -1063,7 +1039,7 @@ void MixedModel::computeCoords() {
       int out_l = outl[V[k][0]], out_r = outr[V[k][0]];
 
       float tmp = NodeCoords[(*it)].getX()+ dxt;
-      float ftmp = (out_l<(nodeSize.get(Z0.id)).getX()/2.f ? (nodeSize.get(Z0.id)).getX()/2.f : out_l) + dxl;
+      float ftmp = ((out_l<(nodeSize.get(Z0.id)).getX()/2.f) ? (nodeSize.get(Z0.id)).getX()/2.f : out_l) + dxl;
 
       if(tmp >= ftmp) NodeCoords[Z0].setX(tmp);
       else NodeCoords[Z0].setX(ftmp);
@@ -1071,12 +1047,12 @@ void MixedModel::computeCoords() {
       float delta = NodeCoords[Z0].getX() - (dxt +  NodeCoords[(*it)].getX());
 
       if(delta>0)
-        for(vector<node>::iterator i = it; i != ir+1; i++)
+        for(vector<node>::iterator i = it; i != ir+1; ++i)
           NodeCoords[(*i)].setX(NodeCoords[(*i)].getX() + delta);
       else delta = 0;
 
       tmp = NodeCoords[(*ir)].getX()+ delta - NodeCoords[Z0].getX();
-      ftmp = (out_r<(nodeSize.get(Z0.id)).getX()/2.f ? (nodeSize.get(Z0.id)).getX()/2.f : out_r) - dxr;
+      ftmp = ((out_r<(nodeSize.get(Z0.id)).getX()/2.f) ? (nodeSize.get(Z0.id)).getX()/2.f : out_r) - dxr;
 
       if(tmp >= ftmp) NodeCoords[(*ir)].setX(tmp);
       else NodeCoords[(*ir)].setX(ftmp);
@@ -1093,24 +1069,24 @@ void MixedModel::computeCoords() {
       float somme = 0;
 
       // assign x(zi)
-      for(unsigned int i = 0; i<p; i++) {
+      for(unsigned int i = 0; i<p; ++i) {
         out_l = outl[V[k][i]];
         out_r = outr[V[k][i]];
         Coord co2 = nodeSize.get((V[k][i]).id);
         double x;
 
-        if(i == 0) x = (out_l<co2.getX()/2. ? co2.getX()/2. : out_l) + dxl;
-        else x = out_r_moins1 + (out_l<co2.getX()/2. ? co2.getX()/2. : out_l)+1;
+        if(i == 0) x = ((out_l<co2.getX()/2.) ? co2.getX()/2. : out_l) + dxl;
+        else x = out_r_moins1 + ((out_l<co2.getX()/2.) ? co2.getX()/2. : out_l)+1;
 
         NodeCoords[V[k][i]].setX(static_cast<float>(x));
         somme += static_cast<float>(x);
 
-        out_r_moins1 = (int) (out_r<co2.getX()/2. ? co2.getX()/2. : out_r);
+        out_r_moins1 = (int) ((out_r<co2.getX()/2.) ? co2.getX()/2. : out_r);
       }
 
       //assign x(cr)
       co = nodeSize.get((V[k][p-1]).id);
-      float tmp = (out_r<co.getX()/2.f ? co.getX()/2.f : out_r) - dxr;
+      float tmp = ((out_r<co.getX()/2.f) ? co.getX()/2.f : out_r) - dxr;
 
       float xtmp = NodeCoords[cr].getX();
       double x;
@@ -1122,7 +1098,7 @@ void MixedModel::computeCoords() {
 
       float xZ0 = NodeCoords[Z0].getX();
 
-      for(vector<node>::iterator i = il+1; i != ir; i++) {
+      for(vector<node>::iterator i = il+1; i != ir; ++i) {
         NodeCoords[(*i)].setX(NodeCoords[(*i)].getX() - xZ0);
         father[(*i)] = Z0;
       }
@@ -1135,7 +1111,7 @@ void MixedModel::computeCoords() {
 
   float somme = 0;
 
-  for(unsigned int i = 0; i<C.size(); i++) {
+  for(unsigned int i = 0; i<C.size(); ++i) {
     somme += NodeCoords[C[i]].getX();
     NodeCoords[C[i]].setX(somme);
   }
@@ -1143,7 +1119,7 @@ void MixedModel::computeCoords() {
   for(int k = size_V - 1; k>=0; k--) {
     unsigned int p = V[k].size();
 
-    for(unsigned int i = 0; i<p; i++) {
+    for(unsigned int i = 0; i<p; ++i) {
       node v = V[k][i];
 
       if(find(C.begin(), C.end(), v) == C.end())
