@@ -21,7 +21,7 @@
 
 
 /** \addtogroup layout */
-/*@{*/
+
 /** This plugin is an implementation of the planar polyline graph
  *  drawing algorithm, the mixed model algorithm, first published as:
  *
@@ -44,7 +44,8 @@
  */
 class MixedModel : public tlp::LayoutAlgorithm {
 public:
-  MixedModel(const tlp::PropertyContext &context);
+  PLUGININFORMATION("Mixed Model","Romain BOURQUI ","09/11/2005","Ok","1.0","Planar")
+  MixedModel(const tlp::PluginContext* context);
   ~MixedModel();
   bool run();
   bool check(std::string &);
@@ -93,5 +94,5 @@ private:
   tlp::SizeProperty *sizeResult;
   tlp::IntegerProperty *glyphResult;
 };
-/*@}*/
+
 #endif
