@@ -1,5 +1,24 @@
+/**
+ *
+ * This file is part of Tulip (www.tulip-software.org)
+ *
+ * Authors: David Auber and the Tulip development Team
+ * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ *
+ * Tulip is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
+ *
+ * Tulip is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ */
 #include <ogdf/upward/DominanceLayout.h>
 #include "tulip2ogdf/OGDFLayoutPluginBase.h"
+#include <tulip/ConnectedTest.h>
 
 namespace {
 
@@ -19,7 +38,7 @@ const char * paramHelp[] = {
 
 // comments below have been extracted from OGDF/src/upward/DominanceLayout.cpp
 /** \addtogroup layout */
-/*@{*/
+
 /// An implementation of dominance layout algorithm.
 /**
  *
@@ -65,17 +84,26 @@ const char * paramHelp[] = {
 class OGDFDominance : public OGDFLayoutPluginBase {
 
 public:
-
-  OGDFDominance(const tlp::PropertyContext &context) :OGDFLayoutPluginBase(context, new ogdf::DominanceLayout()) {
-    addParameter<int>("minimum grid distance", paramHelp[0], "1");
-    addParameter<bool>("transpose", paramHelp[1], "false");
+  PLUGININFORMATION("Dominance (OGDF)","Hoi-Ming Wong","12/11/2007","Ok","1.0","Hierarchical")
+  OGDFDominance(const tlp::PluginContext* context) :OGDFLayoutPluginBase(context, new ogdf::DominanceLayout()) {
+    addInParameter<int>("minimum grid distance", paramHelp[0], "1");
+    addInParameter<bool>("transpose", paramHelp[1], "false");
   }
   ~OGDFDominance() {}
 
+  bool check(string& error) {
+    if (!tlp::ConnectedTest::isConnected(graph)) {
+      error += "graph is not connected";
+      return false;
+    }
+
+    return true;
+  }
+
   void beforeCall() {
     ogdf::DominanceLayout *dominance = static_cast<ogdf::DominanceLayout*>(ogdfLayoutAlgo);
 
-    if (dataSet != 0) {
+    if (dataSet != NULL) {
       int ival = 0;
 
       if (dataSet->get("minimum grid distance", ival))
@@ -84,7 +112,7 @@ public:
   }
 
   void afterCall() {
-    if (dataSet != 0) {
+    if (dataSet != NULL) {
       bool bval = false;
 
       if (dataSet->get("transpose", bval)) {
@@ -96,6 +124,6 @@ public:
   }
 
 };
-/*@}*/
 
-LAYOUTPLUGINOFGROUP(OGDFDominance,"Dominance (OGDF)","Hoi-Ming Wong","12/11/2007","Ok","1.0","Hierarchical");
+
+PLUGIN(OGDFDominance)
