@@ -1,15 +1,34 @@
-#include <ogdf/energybased/FMMMLayout.h>
+/**
+ *
+ * This file is part of Tulip (www.tulip-software.org)
+ *
+ * Authors: David Auber and the Tulip development Team
+ * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ *
+ * Tulip is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
+ *
+ * Tulip is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ */
 
 #include <tulip/ForEach.h>
+#include <tulip/StringCollection.h>
 
 #include "tulip2ogdf/OGDFLayoutPluginBase.h"
+#include <ogdf/energybased/FMMMLayout.h>
 
 using namespace std;
 
 namespace {
 
 const char * paramHelp[] = {HTML_HELP_OPEN()
-                            HTML_HELP_DEF( "type", "DoubleProperty" )
+                            HTML_HELP_DEF( "type", "NumericProperty" )
                             HTML_HELP_BODY()
                             "A double property containing unit edge length to use."
                             HTML_HELP_CLOSE(), HTML_HELP_OPEN()
@@ -221,7 +240,7 @@ const char * paramHelp[] = {HTML_HELP_OPEN()
 
 // comments below have been extracted from OGDF/src/energybased/FMMMLayout.cpp
 /** \addtogroup layout */
-/*@{*/
+
 /**
  * This is an implementation of Fast Multipole Multilevel Method (FM^3).
  * \author Stefan Hachul
@@ -266,53 +285,53 @@ class OGDFFm3: public OGDFLayoutPluginBase {
   tlp::StringCollection stringCollection;
 
 public:
-
-  OGDFFm3(const tlp::PropertyContext &context);
+  PLUGININFORMATION("FM^3 (OGDF)", "Stephan Hachul", "09/11/2007", "Alpha", "1.2" ,"Force Directed")
+  OGDFFm3(const tlp::PluginContext* context);
   ~OGDFFm3();
   void beforeCall();
   void callOGDFLayoutAlgorithm(ogdf::GraphAttributes &gAttributes);
 };
-/*@}*/
+
 
 /*Nom de la classe, Nom du plugins, nom de l'auteur,date de
  creation,informations, release, groupe*/
-LAYOUTPLUGINOFGROUP(OGDFFm3,"FM^3 (OGDF)", "Stephan Hachul", "09/11/2007", "Alpha", "1.2" ,"Force Directed");
+PLUGIN(OGDFFm3)
 
-OGDFFm3::OGDFFm3(const tlp::PropertyContext &context) :
+OGDFFm3::OGDFFm3(const tlp::PluginContext* context) :
   OGDFLayoutPluginBase(context, new ogdf::FMMMLayout()) {
-  addParameter<DoubleProperty> ("Edge Length Property", paramHelp[0],
-                                "viewMetric", false);
-  addParameter<SizeProperty> ("Node Size", paramHelp[1], "viewSize", false);
-  addParameter<double> ("Unit edge length", paramHelp[2], "10.0", false);
-  addParameter<bool> ("New initial placement", paramHelp[3], "true");
-  addParameter<int>("Fixed iterations", paramHelp[18], "30");
-  addParameter<double>("Threshold", paramHelp[19], "0.01");
-  addParameter<StringCollection> (ELT_PAGEFORMAT, paramHelp[4],
-                                  ELT_PAGEFORMATLIST);
-  addParameter<StringCollection> (ELT_QUALITYVSSPEED, paramHelp[5],
-                                  ELT_QUALITYVSSPEEDLIST);
-  addParameter<StringCollection> (ELT_EDGELENGTHMEASUREMENT, paramHelp[6],
-                                  ELT_EDGELENGTHMEASUREMENTLIST);
-  addParameter<StringCollection> (ELT_ALLOWEDPOSITIONS, paramHelp[7],
-                                  ELT_ALLOWEDPOSITIONSLIST);
-  addParameter<StringCollection> (ELT_TIPOVER, paramHelp[8], ELT_TIPOVERLIST);
-  addParameter<StringCollection> (ELT_PRESORT, paramHelp[9], ELT_PRESORTLIST);
-  addParameter<StringCollection> (ELT_GALAXYCHOICE, paramHelp[10],
-                                  ELT_GALAXYCHOICELIST);
-  addParameter<StringCollection> (ELT_MAXITERCHANGE, paramHelp[11],
-                                  ELT_MAXITERCHANGELIST);
-  addParameter<StringCollection> (ELT_INITIALPLACEMENTMULT, paramHelp[12],
-                                  ELT_INITIALPLACEMENTMULTLIST);
-  addParameter<StringCollection> (ELT_FORCEMODEL, paramHelp[13],
-                                  ELT_FORCEMODELLIST);
-  addParameter<StringCollection> (ELT_REPULSIVEFORCEMETHOD, paramHelp[14],
-                                  ELT_REPULSIVEFORCEMETHODLIST);
-  addParameter<StringCollection> (ELT_INITIALPLACEMENTFORCES, paramHelp[15],
-                                  ELT_INITIALPLACEMENTFORCESLIST);
-  addParameter<StringCollection> (ELT_REDUCEDTREECONSTRCUCTION, paramHelp[16],
-                                  ELT_REDUCEDTREECONSTRCUCTIONLIST);
-  addParameter<StringCollection> (ELT_SMALLESTCELLFINDING, paramHelp[17],
-                                  ELT_SMALLESTCELLFINDINGLIST);
+  addInParameter<NumericProperty*> ("Edge Length Property", paramHelp[0],
+                                    "viewMetric", false);
+  addInParameter<SizeProperty> ("Node Size", paramHelp[1], "viewSize", false);
+  addInParameter<double> ("Unit edge length", paramHelp[2], "10.0", false);
+  addInParameter<bool> ("New initial placement", paramHelp[3], "true");
+  addInParameter<int>("Fixed iterations", paramHelp[18], "30");
+  addInParameter<double>("Threshold", paramHelp[19], "0.01");
+  addInParameter<StringCollection> (ELT_PAGEFORMAT, paramHelp[4],
+                                    ELT_PAGEFORMATLIST);
+  addInParameter<StringCollection> (ELT_QUALITYVSSPEED, paramHelp[5],
+                                    ELT_QUALITYVSSPEEDLIST);
+  addInParameter<StringCollection> (ELT_EDGELENGTHMEASUREMENT, paramHelp[6],
+                                    ELT_EDGELENGTHMEASUREMENTLIST);
+  addInParameter<StringCollection> (ELT_ALLOWEDPOSITIONS, paramHelp[7],
+                                    ELT_ALLOWEDPOSITIONSLIST);
+  addInParameter<StringCollection> (ELT_TIPOVER, paramHelp[8], ELT_TIPOVERLIST);
+  addInParameter<StringCollection> (ELT_PRESORT, paramHelp[9], ELT_PRESORTLIST);
+  addInParameter<StringCollection> (ELT_GALAXYCHOICE, paramHelp[10],
+                                    ELT_GALAXYCHOICELIST);
+  addInParameter<StringCollection> (ELT_MAXITERCHANGE, paramHelp[11],
+                                    ELT_MAXITERCHANGELIST);
+  addInParameter<StringCollection> (ELT_INITIALPLACEMENTMULT, paramHelp[12],
+                                    ELT_INITIALPLACEMENTMULTLIST);
+  addInParameter<StringCollection> (ELT_FORCEMODEL, paramHelp[13],
+                                    ELT_FORCEMODELLIST);
+  addInParameter<StringCollection> (ELT_REPULSIVEFORCEMETHOD, paramHelp[14],
+                                    ELT_REPULSIVEFORCEMETHODLIST);
+  addInParameter<StringCollection> (ELT_INITIALPLACEMENTFORCES, paramHelp[15],
+                                    ELT_INITIALPLACEMENTFORCESLIST);
+  addInParameter<StringCollection> (ELT_REDUCEDTREECONSTRCUCTION, paramHelp[16],
+                                    ELT_REDUCEDTREECONSTRCUCTIONLIST);
+  addInParameter<StringCollection> (ELT_SMALLESTCELLFINDING, paramHelp[17],
+                                    ELT_SMALLESTCELLFINDINGLIST);
 }
 
 OGDFFm3::~OGDFFm3() {
@@ -520,13 +539,14 @@ void OGDFFm3::callOGDFLayoutAlgorithm(ogdf::GraphAttributes &gAttributes) {
 
   ogdf::FMMMLayout *fmmm = static_cast<ogdf::FMMMLayout*> (ogdfLayoutAlgo);
 
-  DoubleProperty *length = NULL;
+  NumericProperty *length = NULL;
 
   if (dataSet->get("Edge Length Property", length) && length) {
     EdgeArray<double> edgeLength(tlpToOGDF->getOGDFGraph());
     tlp::edge e;
     forEach(e, graph->getEdges()) {
-      edgeLength[tlpToOGDF->getOGDFGraphEdge(e.id)] = length->getEdgeValue(e);
+      edgeLength[tlpToOGDF->getOGDFGraphEdge(e.id)] =
+        length->getEdgeDoubleValue(e);
     }
     fmmm->call(gAttributes, edgeLength);
   }
