@@ -1,10 +1,28 @@
+/**
+ *
+ * This file is part of Tulip (www.tulip-software.org)
+ *
+ * Authors: David Auber and the Tulip development Team
+ * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ *
+ * Tulip is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
+ *
+ * Tulip is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ */
 #include <ogdf/energybased/multilevelmixer/MMMExampleFastLayout.h>
 
 #include "tulip2ogdf/OGDFLayoutPluginBase.h"
 
 // comments below have been extracted from OGDF/src/energybased/multilevelmixer/MMEExampleFastLayout.cpp
 /** \addtogroup layout */
-/*@{*/
+
 ///  useable example of the Modular Multilevel Mixer
 /**
  * An example Layout using the Modular Mutlievel Mixer.
@@ -54,11 +72,11 @@
 class OGDFMMMExampleFastLayout : public OGDFLayoutPluginBase {
 
 public:
-
-  OGDFMMMExampleFastLayout(const tlp::PropertyContext &context) :OGDFLayoutPluginBase(context, new ogdf::MMMExampleFastLayout()) {}
+  PLUGININFORMATION("MMM Example Fast Layout (OGDF)","Gereon Bartel","01/09/2010","Ok","1.0","Multilevel")
+  OGDFMMMExampleFastLayout(const tlp::PluginContext* context) :OGDFLayoutPluginBase(context, new ogdf::MMMExampleFastLayout()) {}
   ~OGDFMMMExampleFastLayout() {}
 
 };
-/*@}*/
 
-LAYOUTPLUGINOFGROUP(OGDFMMMExampleFastLayout,"MMM Example Fast Layout (OGDF)","Gereon Bartel","01/09/2010","Ok","1.0","Multilevel");
+
+PLUGIN(OGDFMMMExampleFastLayout)
