@@ -1,10 +1,28 @@
+/**
+ *
+ * This file is part of Tulip (www.tulip-software.org)
+ *
+ * Authors: David Auber and the Tulip development Team
+ * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ *
+ * Tulip is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
+ *
+ * Tulip is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ */
 #include <ogdf/energybased/multilevelmixer/MMMExampleNiceLayout.h>
 
 #include "tulip2ogdf/OGDFLayoutPluginBase.h"
 
 // comments below have been extracted from OGDF/src/energybased/multilevelmixer/MMEExampleNiceLayout.cpp
 /** \addtogroup layout */
-/*@{*/
+
 /// useable example of the Modular Multilevel Mixer
 /**
  * This example is tuned for nice drawings for most types of graphs.
@@ -53,11 +71,11 @@
 class OGDFMMMExampleNiceLayout : public OGDFLayoutPluginBase {
 
 public:
-
-  OGDFMMMExampleNiceLayout(const tlp::PropertyContext &context) :OGDFLayoutPluginBase(context, new ogdf::MMMExampleNiceLayout()) {}
+  PLUGININFORMATION("MMM Example Nice Layout (OGDF)","Gereon Bartel","01/09/2010","Ok","1.0","Multilevel")
+  OGDFMMMExampleNiceLayout(const tlp::PluginContext* context) :OGDFLayoutPluginBase(context, new ogdf::MMMExampleNiceLayout()) {}
   ~OGDFMMMExampleNiceLayout() {}
 
 };
-/*@}*/
 
-LAYOUTPLUGINOFGROUP(OGDFMMMExampleNiceLayout,"MMM Example Nice Layout (OGDF)","Gereon Bartel","01/09/2010","Ok","1.0","Multilevel");
+
+PLUGIN(OGDFMMMExampleNiceLayout)
