@@ -1,10 +1,28 @@
+/**
+ *
+ * This file is part of Tulip (www.tulip-software.org)
+ *
+ * Authors: David Auber and the Tulip development Team
+ * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ *
+ * Tulip is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
+ *
+ * Tulip is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ */
 #include <ogdf/energybased/multilevelmixer/MMMExampleNoTwistLayout.h>
 
 #include "tulip2ogdf/OGDFLayoutPluginBase.h"
 
 // comments below have been extracted from OGDF/src/energybased/multilevelmixer/MMEExampleNoTwistLayout.cpp
 /** \addtogroup layout */
-/*@{*/
+
 /// useable example of the Modular Multilevel Mixer
 /**
  *
@@ -56,11 +74,11 @@
 class OGDFMMMExampleNoTwistLayout : public OGDFLayoutPluginBase {
 
 public:
-
-  OGDFMMMExampleNoTwistLayout(const tlp::PropertyContext &context) :OGDFLayoutPluginBase(context, new ogdf::MMMExampleNoTwistLayout()) {}
+  PLUGININFORMATION("MMM Example No Twist Layout (OGDF)","Gereon Bartel","01/09/2010","Ok","1.0","Multilevel")
+  OGDFMMMExampleNoTwistLayout(const tlp::PluginContext* context) :OGDFLayoutPluginBase(context, new ogdf::MMMExampleNoTwistLayout()) {}
   ~OGDFMMMExampleNoTwistLayout() {}
 
 };
-/*@}*/
 
-LAYOUTPLUGINOFGROUP(OGDFMMMExampleNoTwistLayout,"MMM Example No Twist Layout (OGDF)","Gereon Bartel","01/09/2010","Ok","1.0","Multilevel");
+
+PLUGIN(OGDFMMMExampleNoTwistLayout)
