@@ -1,3 +1,22 @@
+/**
+ *
+ * This file is part of Tulip (www.tulip-software.org)
+ *
+ * Authors: David Auber and the Tulip development Team
+ * from LaBRI, University of Bordeaux 1 and Inria Bordeaux - Sud Ouest
+ *
+ * Tulip is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
+ *
+ * Tulip is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ */
+
 #include <ogdf/layered/SugiyamaLayout.h>
 #include <ogdf/layered/LongestPathRanking.h>
 #include <ogdf/layered/OptimalRanking.h>
@@ -5,6 +24,14 @@
 #include <ogdf/layered/MedianHeuristic.h>
 #include <ogdf/layered/SplitHeuristic.h>
 #include <ogdf/layered/FastHierarchyLayout.h>
+#include <ogdf/layered/CoffmanGrahamRanking.h>
+#include <ogdf/layered/SiftingHeuristic.h>
+#include <ogdf/layered/GreedyInsertHeuristic.h>
+#include <ogdf/layered/GreedySwitchHeuristic.h>
+#include <ogdf/layered/OptimalHierarchyLayout.h>
+#include <ogdf/layered/FastSimpleHierarchyLayout.h>
+
+#include <tulip/StringCollection.h>
 
 #include "tulip2ogdf/OGDFLayoutPluginBase.h"
 
@@ -20,6 +47,21 @@ const char * paramHelp[] = { HTML_HELP_OPEN()
                              "Sets the option runs to nRuns."
                              HTML_HELP_CLOSE(),
                              HTML_HELP_OPEN()
+                             HTML_HELP_DEF( "type", "double" )
+                             HTML_HELP_BODY()
+                             "The minimal distance between two nodes on the same layer."
+                             HTML_HELP_CLOSE(),
+                             HTML_HELP_OPEN()
+                             HTML_HELP_DEF( "type", "double" )
+                             HTML_HELP_BODY()
+                             "The minimal distance between two layers."
+                             HTML_HELP_CLOSE(),
+                             HTML_HELP_OPEN()
+                             HTML_HELP_DEF( "type", "bool" )
+                             HTML_HELP_BODY()
+                             "If false, adjust the distance of each layer to the longest edge (only for FastHierarchyLayout)."
+                             HTML_HELP_CLOSE(),
+                             HTML_HELP_OPEN()
                              HTML_HELP_DEF( "type", "bool" )
                              HTML_HELP_BODY()
                              "Sets the option for transposing layout vertically ."
@@ -51,36 +93,52 @@ const char * paramHelp[] = { HTML_HELP_OPEN()
                              HTML_HELP_CLOSE(),
                              HTML_HELP_OPEN()
                              HTML_HELP_DEF( "type", "StringCollection")
-                             HTML_HELP_DEF("values", "<FONT COLOR=\"red\"> LongestPathRanking : <FONT COLOR=\"black\"> the well-known longest-path ranking algorithm. <BR> <FONT COLOR=\"red\"> OptimalRanking : <FONT COLOR=\"black\"> the LP-based algorithm for computing a node ranking with minimal edge lengths. <BR> <FONT COLOR=\"red\"> SplitHeuristic : <FONT COLOR=\"black\"> the split heuristic for 2-layer crossing minimization.")
+                             HTML_HELP_DEF("values", "<FONT COLOR=\"red\"> CoffmanGrahamRanking: <FONT COLOR=\"black\"> The coffman graham ranking algorithm. <BR> <FONT COLOR=\"red\"> LongestPathRanking: <FONT COLOR=\"black\"> the well-known longest-path ranking algorithm. <BR> <FONT COLOR=\"red\"> OptimalRanking: <FONT COLOR=\"black\"> the LP-based algorithm for computing a node ranking with minimal edge lengths.")
                              HTML_HELP_DEF( "default", "LongestPathRanking " )
                              HTML_HELP_BODY()
                              "Sets the option for the node ranking (layer assignment)."
                              HTML_HELP_CLOSE(),
                              HTML_HELP_OPEN()
                              HTML_HELP_DEF( "type", "StringCollection")
-                             HTML_HELP_DEF("values", "<FONT COLOR=\"red\"> BarycenterHeuristic : <FONT COLOR=\"black\"> the barycenter heuristic for 2-layer crossing minimization. <BR> <FONT COLOR=\"red\"> MedianHeuristic : <FONT COLOR=\"black\"> the median heuristic for 2-layer crossing minimization. <BR> <FONT COLOR=\"red\"> SplitHeuristic : <FONT COLOR=\"black\"> the split heuristic for 2-layer crossing minimization.")
+                             HTML_HELP_DEF("values", "<FONT COLOR=\"red\"> BarycenterHeuristic: <FONT COLOR=\"black\"> the barycenter heuristic for 2-layer crossing minimization. <BR><FONT COLOR=\"red\"> GreedyInsertHeuristic: <FONT COLOR=\"black\"> The greedy-insert heuristic for 2-layer crossing minimization. <BR><FONT COLOR=\"red\"> GreedySwitchHeuristic: <FONT COLOR=\"black\"> The greedy-switch heuristic for 2-layer crossing minimization. <BR> <FONT COLOR=\"red\"> MedianHeuristic: <FONT COLOR=\"black\"> the median heuristic for 2-layer crossing minimization. <BR><FONT COLOR=\"red\"> SiftingHeuristic: <FONT COLOR=\"black\"> The sifting heuristic for 2-layer crossing minimization. <BR> <FONT COLOR=\"red\"> SplitHeuristic: <FONT COLOR=\"black\"> the split heuristic for 2-layer crossing minimization.")
                              HTML_HELP_DEF( "default", "BarycenterHeuristic " )
                              HTML_HELP_BODY()
                              "Sets the module option for the two-layer crossing minimization."
+                             HTML_HELP_CLOSE(),
+                             HTML_HELP_OPEN()
+                             HTML_HELP_DEF( "type", "StringCollection")
+                             HTML_HELP_DEF("values", "<FONT COLOR=\"red\"> FastHierarchyLayout: <FONT COLOR=\"black\"> Coordinate assignment phase for the Sugiyama algorithm by Buchheim et al.. <BR> <FONT COLOR=\"red\"> FastSimpleHierarchyLayout: <FONT COLOR=\"black\"> Coordinate assignment phase for the Sugiyama algorithm by Ulrik Brandes and Boris Koepf.")
+                             HTML_HELP_DEF( "default", "FastHierarchyLayout" )
+                             HTML_HELP_BODY()
+                             "The hierarchy layout module that computes the final layout."
                              HTML_HELP_CLOSE()
                            };
 }
 
 
 #define ELT_RANKING "Ranking"
-#define ELT_RANKINGLIST "LongestPathRanking;OptimalRanking"
+#define ELT_RANKINGLIST "LongestPathRanking;OptimalRanking;CoffmanGrahamRanking"
 #define ELT_LONGESTPATHRANKING 0
 #define ELT_OPTIMALRANKING 1
+#define ELT_COFFMANGRAHAMRANKING 2
 
 #define ELT_TWOLAYERCROSS "Two-layer crossing minimization"
-#define ELT_TWOLAYERCROSSLIST "BarycenterHeuristic;MedianHeuristic;SplitHeuristic"
+#define ELT_TWOLAYERCROSSLIST "BarycenterHeuristic;MedianHeuristic;SplitHeuristic;SiftingHeuristic;GreedyInsertHeuristic;GreedySwitchHeuristic"
 #define ELT_BARYCENTER 0
 #define ELT_MEDIAN 1
 #define ELT_SPLIT 2
+#define ELT_SIFTING 3
+#define ELT_GREEDYINSERT 4
+#define ELT_GREEDYSWITCH 5
+
+#define ELT_HIERARCHYLAYOUT "Layout"
+#define ELT_HIERARCHYLAYOUTLIST "FastHierarchyLayout;FastSimpleHierarchyLayout"
+#define ELT_FASTHIERARCHY 0
+#define ELT_FASTSIMPLEHIERARCHY 1
 
 // comments below have been extracted from OGDF/src/layered/sugiyama.cpp
 /** \addtogroup layout */
-/*@{*/
+
 /**
  * Implementation of Sugiyama algorithm (classes Hierarchy,
  * Level, SugiyamaLayout)
@@ -128,25 +186,31 @@ class OGDFSugiyama : public OGDFLayoutPluginBase {
 
 public:
 
-  OGDFSugiyama(const tlp::PropertyContext &context) :OGDFLayoutPluginBase(context, new ogdf::SugiyamaLayout()) {
-    addParameter<int>("fails", paramHelp[0], "4");
-    addParameter<int>("runs", paramHelp[1], "15");
-    addParameter<bool>("transpose", paramHelp[2], "false");
-    addParameter<bool>("arrangeCCs", paramHelp[3], "true");
-    addParameter<double>("minDistCC", paramHelp[4], "20");
-    addParameter<double>("pageRatio", paramHelp[5], "1.0");
-    addParameter<bool>("alignBaseClasses", paramHelp[6], "false");
-    addParameter<bool>("alignSiblings", paramHelp[7], "false");
-    addParameter<StringCollection>(ELT_RANKING, paramHelp[8], ELT_RANKINGLIST);
-    addParameter<StringCollection>(ELT_TWOLAYERCROSS, paramHelp[9], ELT_TWOLAYERCROSSLIST);
+  OGDFSugiyama(const tlp::PluginContext *context) :OGDFLayoutPluginBase(context, new ogdf::SugiyamaLayout()) {
+    addInParameter<int>("fails", paramHelp[0], "4");
+    addInParameter<int>("runs", paramHelp[1], "15");
+    addInParameter<double>("node distance", paramHelp[2], "3");
+    addInParameter<double>("layer distance", paramHelp[3], "3");
+    addInParameter<bool>("fixed layer distance", paramHelp[4], "true");
+    addInParameter<bool>("transpose", paramHelp[5], "true");
+    addInParameter<bool>("arrangeCCs", paramHelp[6], "true");
+    addInParameter<double>("minDistCC", paramHelp[7], "20");
+    addInParameter<double>("pageRatio", paramHelp[8], "1.0");
+    addInParameter<bool>("alignBaseClasses", paramHelp[9], "false");
+    addInParameter<bool>("alignSiblings", paramHelp[10], "false");
+    addInParameter<StringCollection>(ELT_RANKING, paramHelp[11], ELT_RANKINGLIST);
+    addInParameter<StringCollection>(ELT_TWOLAYERCROSS, paramHelp[12], ELT_TWOLAYERCROSSLIST);
+    addInParameter<StringCollection>(ELT_HIERARCHYLAYOUT, paramHelp[13], ELT_HIERARCHYLAYOUTLIST);
   }
 
   ~OGDFSugiyama() {}
 
+  PLUGININFORMATION("Sugiyama (OGDF)","Carsten Gutwenger","12/11/2007","Ok","1.5","Hierarchical")
+
   void beforeCall() {
     ogdf::SugiyamaLayout *sugiyama = static_cast<ogdf::SugiyamaLayout*>(ogdfLayoutAlgo);
 
-    if (dataSet != 0) {
+    if (dataSet != NULL) {
       int ival = 0;
       double dval = 0;
       bool bval = false;
@@ -177,9 +241,11 @@ public:
         if (sc.getCurrent() == ELT_LONGESTPATHRANKING) {
           sugiyama->setRanking(new ogdf::LongestPathRanking());
         }
-        else {
+        else if(sc.getCurrent() == ELT_OPTIMALRANKING) {
           sugiyama->setRanking(new ogdf::OptimalRanking());
         }
+        else
+          sugiyama->setRanking(new ogdf::CoffmanGrahamRanking());
       }
 
       if (dataSet->get(ELT_TWOLAYERCROSS, sc)) {
@@ -189,15 +255,43 @@ public:
         else if (sc.getCurrent() == ELT_MEDIAN) {
           sugiyama->setCrossMin(new ogdf::MedianHeuristic());
         }
-        else {
+        else if(sc.getCurrent()==ELT_SPLIT) {
           sugiyama->setCrossMin(new ogdf::SplitHeuristic());
         }
+        else if(sc.getCurrent()==ELT_SIFTING) {
+          sugiyama->setCrossMin(new ogdf::SiftingHeuristic());
+        }
+        else if(sc.getCurrent()==ELT_GREEDYINSERT) {
+          sugiyama->setCrossMin(new ogdf::GreedyInsertHeuristic());
+        }
+        else
+          sugiyama->setCrossMin(new ogdf::GreedySwitchHeuristic());
+      }
+
+      if(dataSet->get(ELT_HIERARCHYLAYOUT, sc)) {
+        double nodeDistance = 3;
+        double layerDistance = 3;
+        bool fixedLayerDistance = true;
+        dataSet->get("node distance", nodeDistance);
+        dataSet->get("layer distance", layerDistance);
+        dataSet->get("fixed layer distance", fixedLayerDistance);
+
+        if(sc.getCurrent()==ELT_FASTHIERARCHY) {
+          ogdf::FastHierarchyLayout *fhl = new FastHierarchyLayout();
+          fhl->nodeDistance(nodeDistance);
+          fhl->layerDistance(layerDistance);
+          fhl->fixedLayerDistance(fixedLayerDistance);
+          sugiyama->setLayout(fhl);
+        }
+        else {
+          sugiyama->setLayout(new ogdf::FastSimpleHierarchyLayout(static_cast<int>(nodeDistance), static_cast<int>(layerDistance)));
+        }
       }
     }
   }
 
   void afterCall() {
-    if (dataSet != 0) {
+    if (dataSet != NULL) {
       bool bval = false;
 
       if (dataSet->get("transpose", bval)) {
@@ -209,6 +303,6 @@ public:
   }
 
 };
-/*@}*/
 
-LAYOUTPLUGINOFGROUP(OGDFSugiyama,"Sugiyama (OGDF)","Carsten Gutwenger","12/11/2007","Ok","1.4","Hierarchical");
+
+PLUGIN(OGDFSugiyama)
