@@ -19,7 +19,7 @@
 #ifndef _RANDOMLAYOUT_H
 #define _RANDOMLAYOUT_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /// Random.h - An implementation of a random 3D layout.
 /** This plugin is an implementation of a random 3D layout
@@ -37,11 +37,10 @@
  */
 class Random:public tlp::LayoutAlgorithm {
 public:
-  Random(const tlp::PropertyContext& context);
-  ~Random();
+  PLUGININFORMATION("Random layout","David Auber","01/12/1999","Ok","1.1","Basic")
+  Random(const tlp::PluginContext* context);
 
   bool run();
-  bool check(std::string& erreurMsg);
 };
 
 #endif
