@@ -18,16 +18,17 @@
  */
 #include "RectanglePacking.h"
 #include <cstring>
+#include <float.h> //FLT_MAX
+#include <climits> //INT_MAX
 
 using namespace std;
 using namespace tlp;
 
-RectanglePacking::RectanglePacking(int numberRects) {
-
-  firstSequence = new RectangleRelativePositionList();
-  numberOfPositionnedRectangles = 0;
-  numberOfRectangles = numberRects;
-  placesOfRectanglesInSecondSequence = new int[numberOfRectangles];
+RectanglePacking::RectanglePacking(int numberRects) : firstSequence(new RectangleRelativePositionList()), placesOfRectanglesInSecondSequence(new int[numberRects]),
+  numberOfPositionnedRectangles(0), numberOfRectangles(numberRects), bestPlaceInFirstSequence(INT_MAX), bestPlaceInSecondSequence(INT_MAX),
+  newRectangleWidth(FLT_MAX), newRectangleHeight(FLT_MAX), newRectangleLeftAbscissa(FLT_MAX),
+  newRectangleLowOrdinate(FLT_MAX), bestRectangleLeftAbscissa(FLT_MAX), bestRectangleLowOrdinate(FLT_MAX), maxWidthOfBoundingBox(FLT_MAX),
+  maxHeightOfBoundingBox(FLT_MAX), bestWidthOfBoundingBox(FLT_MAX), bestHeightOfBoundingBox(FLT_MAX) {
 }
 
 RectanglePacking::~RectanglePacking() {
@@ -47,8 +48,8 @@ void RectanglePacking::optimalPositionOfNewRectangle(vector<Rectangle<float> >::
   newRectangleWidth = (*itNewRect)[1][0]-(*itNewRect)[0][0];
   newRectangleHeight = (*itNewRect)[1][1]-(*itNewRect)[0][1];
 
-  for(positionInFirstSequence = 1; positionInFirstSequence<=numberOfPositionnedRectangles+1; positionInFirstSequence++) {
-    for(positionInSecondSequence = 1; positionInSecondSequence<=numberOfPositionnedRectangles+1; positionInSecondSequence++) {
+  for(positionInFirstSequence = 1; positionInFirstSequence<=numberOfPositionnedRectangles+1; ++positionInFirstSequence) {
+    for(positionInSecondSequence = 1; positionInSecondSequence<=numberOfPositionnedRectangles+1; ++positionInSecondSequence) {
       newRectangleLeftAbscissa = 0;
       newRectangleLowOrdinate = 0;
       maxWidthOfBoundingBox = 0;
@@ -103,10 +104,10 @@ list<RectangleRelativePosition>::iterator RectanglePacking::positionOfNewRectang
   list<RectangleRelativePosition>::iterator itRectLeftOrBelowOfNewRect = firstSequence->begin();
   int positionRectLeftOrBelowOfNewRect;
 
-  for(positionRectLeftOrBelowOfNewRect = 1; positionRectLeftOrBelowOfNewRect < positionInFirstSequence; positionRectLeftOrBelowOfNewRect++) {
+  for(positionRectLeftOrBelowOfNewRect = 1; positionRectLeftOrBelowOfNewRect < positionInFirstSequence; ++positionRectLeftOrBelowOfNewRect) {
     coordinatesOfNewRectangle(itRectLeftOrBelowOfNewRect, positionInFirstSequence, positionInSecondSequence);
     dimensionsBoundingBoxOfRectanglesLeftOrBelowNewRectangle(itRectLeftOrBelowOfNewRect);
-    itRectLeftOrBelowOfNewRect++;
+    ++itRectLeftOrBelowOfNewRect;
   }
 
   return  itRectLeftOrBelowOfNewRect;
@@ -130,7 +131,7 @@ void RectanglePacking::repositionOfRectanglesRightOrAboveNewRectangle(list<Recta
 
     dimensionsBoundingBoxOfAllOptimalPositionnedRectangles(itRectOfSequenceToReposition);
 
-    positionRectangleToReposition++;
+    ++positionRectangleToReposition;
   }
 }
 
@@ -138,15 +139,15 @@ void RectanglePacking::modificationOfSequencePair(vector<Rectangle<float> >::ite
 
   list<RectangleRelativePosition>::iterator itRectToReposition;
 
-  for(int k=0; k<numberOfPositionnedRectangles; k++) {
+  for(int k=0; k<numberOfPositionnedRectangles; ++k) {
     if(placesOfRectanglesInSecondSequence[k] >= bestPlaceInSecondSequence) {
-      placesOfRectanglesInSecondSequence[k]++;
+      ++placesOfRectanglesInSecondSequence[k];
     }
   }
 
   placesOfRectanglesInSecondSequence[numberOfPositionnedRectangles] = bestPlaceInSecondSequence;
 
-  numberOfPositionnedRectangles++;
+  ++numberOfPositionnedRectangles;
 
   firstSequence->addRectangleRelativePosition(itNewRect, numberOfPositionnedRectangles , newRectangleWidth, newRectangleHeight, bestRectangleLeftAbscissa, bestRectangleLowOrdinate, itBestPositionInFirstSequence);
 
@@ -171,16 +172,16 @@ float RectanglePacking::calculateRatio() {
 
 
 void RectanglePacking::coordinatesOfNewRectangle(list<RectangleRelativePosition>::iterator itRectLeftOrBelowOfNewRect, int, int positionInSecondSequence) {
-
-  float rightAbscissa;
-  float highOrdinate;
-
   if(placesOfRectanglesInSecondSequence[itRectLeftOrBelowOfNewRect->rectangleNumber-1] >= positionInSecondSequence) {
+    float highOrdinate;
+
     if((highOrdinate = itRectLeftOrBelowOfNewRect->rectangleLowOrdinate + itRectLeftOrBelowOfNewRect->rectangleHeight) > newRectangleLowOrdinate) {
       newRectangleLowOrdinate = highOrdinate ;
     }
   }
   else {
+    float rightAbscissa;
+
     if((rightAbscissa= itRectLeftOrBelowOfNewRect->rectangleLeftAbscissa + itRectLeftOrBelowOfNewRect->rectangleWidth) > newRectangleLeftAbscissa) {
       newRectangleLeftAbscissa = rightAbscissa;
     }
@@ -217,16 +218,16 @@ void RectanglePacking::dimensionsBoundingBoxOfNewRectangleAndRectanglesLeftOrBel
 
 
 void RectanglePacking::modificationCoordinatesRectanglesRightOrAboveNewRectangleInFonctionNewRectangle(list<RectangleRelativePosition>::iterator itRectOfSequenceToReposition, int positionInSecondSequence) {
-
-  float rightAbscissa;
-  float highOrdinate;
-
   if(placesOfRectanglesInSecondSequence[itRectOfSequenceToReposition->rectangleNumber-1] < positionInSecondSequence ) {
+    float highOrdinate;
+
     if((highOrdinate = newRectangleLowOrdinate + newRectangleHeight) > itRectOfSequenceToReposition->rectangleTemporaryLowOrdinate) {
       itRectOfSequenceToReposition->rectangleTemporaryLowOrdinate = highOrdinate;
     }
   }
   else {
+    float rightAbscissa;
+
     if((rightAbscissa = newRectangleLeftAbscissa + newRectangleWidth) > itRectOfSequenceToReposition->rectangleTemporaryLeftAbscissa) {
       itRectOfSequenceToReposition->rectangleTemporaryLeftAbscissa = rightAbscissa;
     }
@@ -421,9 +422,6 @@ void RectanglePacking::endOfColumn(float & widthTemp, float & heightTemp, bool &
 }
 
 void RectanglePacking::continueLine(vector<Rectangle<float> >::iterator itr, float & widthTemp,float & heightTemp, bool & boolWidth, bool & boolHeight) {
-
-  float ratio;
-
   if((widthTemp==0) && (newRectangleWidth>bestWidthOfBoundingBox)) {
     (*itr)[0][0] = 0;
     (*itr)[1][0] = newRectangleWidth;
@@ -432,6 +430,8 @@ void RectanglePacking::continueLine(vector<Rectangle<float> >::iterator itr, flo
     bestWidthOfBoundingBox = newRectangleWidth;
     bestHeightOfBoundingBox += newRectangleHeight;
 
+    float ratio;
+
     if(bestHeightOfBoundingBox>bestWidthOfBoundingBox)
       ratio = bestHeightOfBoundingBox/bestWidthOfBoundingBox;
     else
@@ -460,9 +460,6 @@ void RectanglePacking::continueLine(vector<Rectangle<float> >::iterator itr, flo
 }
 
 void RectanglePacking::continueColumn(vector<Rectangle<float> >::iterator itr, float & widthTemp,float & heightTemp, bool & boolWidth, bool & boolHeight) {
-
-  float ratio;
-
   if((heightTemp==0) && (newRectangleHeight>bestHeightOfBoundingBox)) {
     (*itr)[0][0] = bestWidthOfBoundingBox;
     (*itr)[1][0] = bestWidthOfBoundingBox+newRectangleWidth;
@@ -471,6 +468,8 @@ void RectanglePacking::continueColumn(vector<Rectangle<float> >::iterator itr, f
     bestHeightOfBoundingBox = newRectangleHeight;
     bestWidthOfBoundingBox += newRectangleWidth;
 
+    float ratio;
+
     if(bestHeightOfBoundingBox>bestWidthOfBoundingBox)
       ratio = bestHeightOfBoundingBox/bestWidthOfBoundingBox;
     else
@@ -522,15 +521,15 @@ void RectanglePacking::optimalPositionOfNewRectangleLimPos(vector<Rectangle<floa
     numberOfLastTestedPosition=numberOfPositionnedRectangles -  numberTestedPositions + 2;
     quotient = (numberOfPositionnedRectangles+1)/numberTestedPositions;
 
-    for(int i=0; i<=numberTestedPositions-1; i++) {
+    for(int i=0; i<=numberTestedPositions-1; ++i) {
       testedPositions[i*quotient] = true;
 
-      for(int j=i*quotient+1; j<=(i+1)*quotient-1; j++) {
+      for(int j=i*quotient+1; j<=(i+1)*quotient-1; ++j) {
         testedPositions[j] = false;
       }
     }
 
-    for(int i=numberTestedPositions*quotient; i<=numberOfPositionnedRectangles; i++) {
+    for(int i=numberTestedPositions*quotient; i<=numberOfPositionnedRectangles; ++i) {
       testedPositions[i] = false;
     }
   }
@@ -539,7 +538,7 @@ void RectanglePacking::optimalPositionOfNewRectangleLimPos(vector<Rectangle<floa
   }
 
   for(positionInFirstSequence = numberOfPositionnedRectangles+1; positionInFirstSequence>=numberOfLastTestedPosition; positionInFirstSequence--) {
-    for(positionInSecondSequence = 1; positionInSecondSequence<=numberOfPositionnedRectangles+1; positionInSecondSequence++) {
+    for(positionInSecondSequence = 1; positionInSecondSequence<=numberOfPositionnedRectangles+1; ++positionInSecondSequence) {
       if((testedPositions[positionInSecondSequence-1])||(numberOfLastTestedPosition==1 )) {
         itPositionInFirstSequence = testOfPositionOfNewRectangle(positionInFirstSequence, positionInSecondSequence);
         ratio = calculateRatio();
