@@ -19,15 +19,15 @@
 #include <cmath>
 #include <algorithm>
 #include <tulip/TreeTest.h>
+#include <tulip/TulipViewSettings.h>
+
 #include "SquarifiedTreeMap.h"
 #include "TreeTools.h"
 
 using namespace std;
 using namespace tlp;
 
-LAYOUTPLUGINOFGROUP(SquarifiedTreeMap,"Squarified Tree Map",
-                    "Tulip Team",
-                    "25/05/2010", "ok", "2.0", "Tree");
+PLUGIN(SquarifiedTreeMap)
 //====================================================================
 
 const double SEPARATION_Z  = 10;
@@ -35,13 +35,11 @@ const double DEFAULT_RATIO = 1.4;
 const int DEFAULT_WIDTH   = 1024;
 const int DEFAULT_HEIGHT  = 1024;
 
-const int TEXTUREDGLYPHID = 17;
-
 namespace {
 const char * paramHelp[] = {
   // metric :
   HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "Metric" ) \
+  HTML_HELP_DEF( "type", "NumericProperty" ) \
   HTML_HELP_DEF( "values", "An existing metric property" ) \
   HTML_HELP_DEF( "default", "viewMetric if it exists" ) \
   HTML_HELP_BODY() \
@@ -82,11 +80,11 @@ const char * paramHelp[] = {
 };
 }
 //====================================================================
-SquarifiedTreeMap::SquarifiedTreeMap(const tlp::PropertyContext& context) :LayoutAlgorithm(context) {
+SquarifiedTreeMap::SquarifiedTreeMap(const tlp::PluginContext* context) :LayoutAlgorithm(context) {
   aspectRatio = DEFAULT_RATIO;
-  addParameter<DoubleProperty>("metric", paramHelp[0], 0, false);
-  addParameter<double>("Aspect Ratio", paramHelp[1], "1.");
-  addParameter<bool>("Treemap Type", paramHelp[2], "false");
+  addInParameter<NumericProperty*>("metric", paramHelp[0], "viewMetric", false);
+  addInParameter<double>("Aspect Ratio", paramHelp[1], "1.");
+  addInParameter<bool>("Treemap Type", paramHelp[2], "false");
   addOutParameter<SizeProperty>("Node Size", paramHelp[3],
                                 "viewSize");
   addOutParameter<IntegerProperty>("Node Shape", paramHelp[4],
@@ -100,20 +98,20 @@ SquarifiedTreeMap::~SquarifiedTreeMap() {
 //====================================================================
 bool SquarifiedTreeMap::check(std::string& errorMsg) {
   if (!TreeTest::isTree(graph)) {
-    errorMsg = "The Graph must be a Tree";
+    errorMsg = "The graph must be a tree.";
     return false;
   }
 
   metric = NULL;
 
-  if (dataSet != 0)
+  if (dataSet != NULL)
     dataSet->get("metric", metric);
 
   if (!metric && graph->existProperty("viewMetric")) {
     metric = graph->getProperty<DoubleProperty>("viewMetric");
 
-    if (metric->getNodeMin() < 0.) {
-      errorMsg = "Graph's nodes must have positive metric";
+    if (metric->getNodeDoubleMin() < 0.) {
+      errorMsg = "Graph's nodes must have a positive metric.";
       return false;
     }
   }
@@ -133,7 +131,7 @@ bool SquarifiedTreeMap::run() {
   sizeResult = NULL;
   glyphResult = NULL;
 
-  if (dataSet != 0) {
+  if (dataSet != NULL) {
     dataSet->get("Aspect Ratio", aspectRatio);
     dataSet->get("Treemap Type", shneidermanTreeMap);
     dataSet->get("Node Size", sizeResult);
@@ -151,32 +149,32 @@ bool SquarifiedTreeMap::run() {
     node n;
     forEach(n, graph->getNodes()) {
       if (graph->outdeg(n) != 0)
-        glyphResult->setNodeValue(n, TEXTUREDGLYPHID);
+        glyphResult->setNodeValue(n, NodeShape::Window);
     }
   }
 
-  Rectangle<double> initialSpace(0, 0, DEFAULT_WIDTH * aspectRatio, DEFAULT_HEIGHT);
+  Rectd initialSpace(0, 0, DEFAULT_WIDTH * aspectRatio, DEFAULT_HEIGHT);
 
   node root = graph->getSource();
   computeNodesSize(root);
 
   Vec2d center = initialSpace.center();
-  layoutResult->setNodeValue(root, Coord(static_cast<float>(center[0]), static_cast<float>(center[1]), 0));
+  result->setNodeValue(root, Coord(static_cast<float>(center[0]), static_cast<float>(center[1]), 0));
   Size initialSpaceSize(static_cast<float>(initialSpace.width()), static_cast<float>(initialSpace.height()), 0);
   sizeResult->setNodeValue(root, initialSpaceSize);
   vector<node> toTreat(orderedChildren(root));
 
   if (!toTreat.empty()) {
-    Rectangle<double> tmp = adjustRectangle(initialSpace);
+    Rectd tmp = adjustRectangle(initialSpace);
     squarify(toTreat, tmp, 1);
   }
 
   return true;
 }
 //====================================================================
-tlp::Rectangle<double> SquarifiedTreeMap::adjustRectangle(const tlp::Rectangle<double> &r) const {
+tlp::Rectd SquarifiedTreeMap::adjustRectangle(const tlp::Rectd &r) const {
   assert(r.isValid());
-  Rectangle<double> result(r);
+  Rectd result(r);
   Vec2d dist(r[1] - r[0]);
   //header size
   result[1][1] -= dist[1] * 0.1;
@@ -190,7 +188,7 @@ tlp::Rectangle<double> SquarifiedTreeMap::adjustRectangle(const tlp::Rectangle<d
   return result;
 }
 //====================================================================
-void SquarifiedTreeMap::layoutRow(const std::vector<tlp::node> &row, const int depth, const tlp::Rectangle<double> &rectArea) {
+void SquarifiedTreeMap::layoutRow(const std::vector<tlp::node> &row, const int depth, const tlp::Rectd &rectArea) {
   assert(rectArea.isValid());
   assert(!row.empty());
   vector<node>::const_iterator  it;
@@ -203,7 +201,7 @@ void SquarifiedTreeMap::layoutRow(const std::vector<tlp::node> &row, const int d
   Vec2d dist = rectArea[1] - rectArea[0];
 
   for (it = row.begin(); it!=row.end(); ++it) {
-    Rectangle<double> layoutRec(rectArea);
+    Rectd layoutRec(rectArea);
 
     if (rectArea.width() > rectArea.height()) {
       layoutRec[0][0] = rectArea[0][0] + (sum/rowArea) * dist[0];
@@ -217,12 +215,12 @@ void SquarifiedTreeMap::layoutRow(const std::vector<tlp::node> &row, const int d
     assert(layoutRec.isValid());
     sum += nodesSize.get(it->id);
     Vec2d center = layoutRec.center();
-    layoutResult->setNodeValue(*it, Coord(static_cast<float>(center[0]), static_cast<float>(center[1]), static_cast<float>(depth * SEPARATION_Z)));
-    sizeResult->setNodeValue(*it, Size(static_cast<float>(layoutRec.width()), static_cast<float>(layoutRec.height(), 0)));
+    result->setNodeValue(*it, Coord(static_cast<float>(center[0]), static_cast<float>(center[1]), static_cast<float>(depth * SEPARATION_Z)));
+    sizeResult->setNodeValue(*it, Size(static_cast<float>(layoutRec.width()), static_cast<float>(layoutRec.height()), 0));
 
     if (graph->outdeg(*it) > 0) {
       vector<node> toTreat(orderedChildren(*it));
-      Rectangle<double> newRec(adjustRectangle(layoutRec));
+      Rectd newRec(adjustRectangle(layoutRec));
       squarify(toTreat, newRec, depth + 1);
     }
   }
@@ -298,7 +296,7 @@ double SquarifiedTreeMap::evaluateRow(const std::vector<tlp::node> &row, tlp::no
 }
 
 //====================================================================
-void SquarifiedTreeMap::squarify(const std::vector<tlp::node> &toTreat, const tlp::Rectangle<double> &rectArea, const int depth) {
+void SquarifiedTreeMap::squarify(const std::vector<tlp::node> &toTreat, const tlp::Rectd &rectArea, const int depth) {
   assert(rectArea.isValid());
   assert(!toTreat.empty());
 
@@ -329,8 +327,8 @@ void SquarifiedTreeMap::squarify(const std::vector<tlp::node> &toTreat, const tl
 
       if (newRatio < ratio) {  //we finish to build that row
         break;
-        unTreated.push_back(*it);
-        unTreatedSurface += nodesSize.get(it->id);
+        /*unTreated.push_back(*it);
+        unTreatedSurface += nodesSize.get(it->id);*/
       }
       else {
         ratio = newRatio;
@@ -353,7 +351,7 @@ void SquarifiedTreeMap::squarify(const std::vector<tlp::node> &toTreat, const tl
   Vec2d dist = rectArea[1] - rectArea[0];
   assert(!rowNodes.empty());
 
-  Rectangle<double> rowRec(rectArea); //The rectangle for that row
+  Rectd rowRec(rectArea); //The rectangle for that row
 
   if (rectArea.width() > rectArea.height())
     rowRec[1][0] -= (unTreatedSurface/surface) * dist[0];
@@ -365,7 +363,7 @@ void SquarifiedTreeMap::squarify(const std::vector<tlp::node> &toTreat, const tl
   layoutRow(rowNodes, depth, rowRec);
 
   if (!unTreated.empty()) {
-    Rectangle<double> subRec(rectArea); //the rectangle of unTreated nodes
+    Rectd subRec(rectArea); //the rectangle of unTreated nodes
 
     if (rectArea.width() > rectArea.height())
       subRec[0][0] = rowRec[1][0];
@@ -381,14 +379,9 @@ void SquarifiedTreeMap::squarify(const std::vector<tlp::node> &toTreat, const tl
 void SquarifiedTreeMap::computeNodesSize(const tlp::node n) {
 
   if (graph->outdeg(n) == 0) { //the node is a leaf of the tree
-    double leafValue = 1.;
+    double leafValue = metric ? metric->getNodeDoubleValue(n) : 1.;
 
-    if (metric != 0) { //if there is a user defined metric on leaves use it.
-      if (metric->getNodeValue(n) > 0)
-        leafValue = metric->getNodeValue(n);
-    }
-
-    nodesSize.set(n.id , leafValue);
+    nodesSize.set(n.id , (leafValue > 0) ? leafValue : 1.);
     return;
   }
 
