@@ -22,7 +22,7 @@
 #include <vector>
 #include <utility>
 #include <tulip/tuliphash.h>
-#include "tulip/TulipPlugin.h"
+#include "tulip/TulipPluginHeaders.h"
 #include "tulip/Rectangle.h"
 
 typedef std::vector<tlp::node> VecNode;
@@ -30,7 +30,7 @@ typedef TLP_HASH_MAP<tlp::node, double> MapNode;
 typedef std::pair<tlp::node, double> PairNodeF;
 typedef std::vector<PairNodeF> PairVector;
 /** \addtogroup layout */
-/*@{*/
+
 /// SquarifiedTreeMap.h - An implementation of a squarified treemap layout.
 /** This plugin is an implementation of TreeMap and Squarified treemap layout.
  *
@@ -60,7 +60,10 @@ class SquarifiedTreeMap: public tlp::LayoutAlgorithm {
   friend class SquarifiedTreeMapUnitTests;
 
 public:
-  SquarifiedTreeMap(const tlp::PropertyContext&);
+  PLUGININFORMATION("Squarified Tree Map",
+                    "Tulip Team",
+                    "25/05/2010", "ok", "2.0", "Tree")
+  SquarifiedTreeMap(const tlp::PluginContext* context);
   ~SquarifiedTreeMap();
 
   bool check(std::string&);
@@ -68,7 +71,7 @@ public:
 
 private:
   tlp::SizeProperty*         sizeResult;
-  tlp::DoubleProperty*       metric;
+  tlp::NumericProperty*       metric;
   tlp::IntegerProperty*      glyphResult;
   tlp::MutableContainer<double>    nodesSize;
   bool shneidermanTreeMap;
@@ -80,11 +83,11 @@ private:
   * surface is sum of size of elements what belongs to the rectangle
   */
   double evaluateRow(const std::vector<tlp::node> &row, tlp::node n, double width, double length, double surface);
-  void layoutRow(const std::vector<tlp::node> &row, const int depth, const tlp::Rectangle<double> &rectArea);
-  void squarify(const std::vector<tlp::node> &toTreat, const tlp::Rectangle<double> &rectArea, const int depth);
+  void layoutRow(const std::vector<tlp::node> &row, const int depth, const tlp::Rectd &rectArea);
+  void squarify(const std::vector<tlp::node> &toTreat, const tlp::Rectd &rectArea, const int depth);
   //change the rectangle to take into account space reserved for the drawing of borders and headers
   //the function currently fix adjust the size for the 2D windwows glyph.
-  tlp::Rectangle<double> adjustRectangle(const tlp::Rectangle<double> &r) const;
+  tlp::Rectd adjustRectangle(const tlp::Rectd &r) const;
   //return a vector containing children of n ordered in decreasing order of their size.
   std::vector<tlp::node> orderedChildren(const tlp::node n) const;
   /**
@@ -94,5 +97,5 @@ private:
   */
   void   computeNodesSize(tlp::node n);
 };
-/*@}*/
+
 #endif
