@@ -19,15 +19,13 @@
 #ifndef _TREELEAFLAYOUT_H
 #define _TREELEAFLAYOUT_H
 
-#include <tulip/TulipPlugin.h>
-
-class OrientableLayout;
-class OrientableSizeProxy;
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup layout */
-/*@{*/
-/// An implementation of a simple tree layout.
+
 /**
+ * \file
+ * \brief An implementation of a simple tree layout.
  *
  * This plugin is an implementation of a simple tree layout.
  * All leaves are placed at a distance one (x-coordinates) and the order
@@ -45,21 +43,26 @@ class OrientableSizeProxy;
  *
  * \author David Auber University Bordeaux I France: Email:auber@tulip-software.org
  */
+class OrientableLayout;
+class OrientableSizeProxy;
+
 class TreeLeaf:public tlp::LayoutAlgorithm {
 public:
-  TreeLeaf(const tlp::PropertyContext &);
+  PLUGININFORMATION("Tree Leaf","David Auber","01/12/1999","A simple level-based tree layout","1.1","Tree")
+  TreeLeaf(const tlp::PluginContext* context);
   ~TreeLeaf();
   bool run();
 
 private:
-  float spacing;
+  float minLayerSpacing;
   float nodeSpacing;
+  bool uniformLayerDistance;
   std::vector<float> levelHeights;
   float dfsPlacement(tlp::Graph* tree, tlp::node n, float x, float y, unsigned int depth,
                      OrientableLayout *oriLayout, OrientableSizeProxy *oriSize);
   void computeLevelHeights(tlp::Graph* tree, tlp::node n, unsigned int depth,
                            OrientableSizeProxy *oriSize);
 };
-/*@}*/
+
 #endif
 
