@@ -18,14 +18,14 @@
  */
 #include <math.h>
 #include <stack>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 #include "DatasetTools.h"
 
 using namespace std;
 using namespace tlp;
 
 /** \addtogroup layout */
-/*@{*/
+
 /// An implementation of a radial drawing of trees.
 /**
  * This algorithm is inspired from
@@ -35,6 +35,7 @@ using namespace tlp;
  **/
 class TreeRadial:public LayoutAlgorithm {
 public:
+  PLUGININFORMATION("Tree Radial","Patrick Mary","14/05/2007","Ok","1.0","Tree")
   Graph *tree;
   vector<float> nRadii;
   vector<float> lRadii;
@@ -65,8 +66,8 @@ public:
     unsigned int depth;
     Iterator<node>* neighbours;
 
-    dfsNodeRadiiStruct() {}
-    dfsNodeRadiiStruct(node n, float r, unsigned int d, Iterator<node>* it):
+    dfsNodeRadiiStruct(node n = node(), float r = 0, unsigned int d = 0,
+                       Iterator<node>* it = NULL):
       current(n), radius(r), depth(d), neighbours(it) {}
   };
 
@@ -175,8 +176,8 @@ public:
     unsigned int depth;
     Iterator<node>* neighbours;
 
-    dfsAngularSpreadStruct() {}
-    dfsAngularSpreadStruct(node n, unsigned int d, Iterator<node>* it):
+    dfsAngularSpreadStruct(node n = node(), unsigned int d = 0,
+                           Iterator<node>* it = NULL):
       current(n), cAngle(0), depth(d), neighbours(it) {}
   };
 
@@ -241,11 +242,11 @@ public:
     if (depth > 0) {
       // layout the node in the middle of the sector
       double nAngle = (startAngle + endAngle)/2.0;
-      layoutResult->setNodeValue(n, Coord(lRadii[depth] * cos(nAngle),
+      result->setNodeValue(n, Coord(lRadii[depth] * cos(nAngle),
             lRadii[depth] * sin(nAngle),
             0));
     } else
-      layoutResult->setNodeValue(n, Coord(0, 0, 0));
+      result->setNodeValue(n, Coord(0, 0, 0));
     node on;
     const double& nSpread = angles->getNodeValue(n);
     checkAngle = false;
@@ -269,9 +270,9 @@ public:
     unsigned int depth;
     Iterator<node>* neighbours;
 
-    dfsDoLayoutStruct() {}
-    dfsDoLayoutStruct(node n, double bAngle, double eAngle, double spread,
-                      bool flag, unsigned int d, Iterator<node>* it):
+    dfsDoLayoutStruct(node n = node(), double bAngle = 0, double eAngle = 0,
+                      double spread = 0, bool flag = false, unsigned int d = 0,
+                      Iterator<node>* it = NULL):
       current(n), startAngle(bAngle), endAngle(eAngle),
       sAngle(eAngle - bAngle), nSpread(spread),
       checkAngle(flag), depth(d), neighbours(it) {}
@@ -306,12 +307,12 @@ public:
         if (depth > 0) {
           // layout the node in the middle of the sector
           double nAngle = (startAngle + endAngle)/2.0;
-          layoutResult->setNodeValue(n, Coord(lRadii[depth] * static_cast<float>(cos(nAngle)),
-                                              lRadii[depth] * static_cast<float>(sin(nAngle)),
-                                              0));
+          result->setNodeValue(n, Coord(lRadii[depth] * static_cast<float>(cos(nAngle)),
+                                        lRadii[depth] * static_cast<float>(sin(nAngle)),
+                                        0));
         }
         else
-          layoutResult->setNodeValue(n, Coord(0, 0, 0));
+          result->setNodeValue(n, Coord(0, 0, 0));
 
         visited.set(n.id, true);
       }
@@ -342,11 +343,9 @@ public:
     }
   }
 
-
-  TreeRadial(const PropertyContext &context):LayoutAlgorithm(context) {
+  TreeRadial(const PluginContext* context):LayoutAlgorithm(context), tree(NULL) {
     addNodeSizePropertyParameter(this);
     addSpacingParameters(this);
-    addDependency<LayoutAlgorithm>("Tree Leaf", "1.0");
   }
 
   bool run() {
@@ -357,8 +356,8 @@ public:
     // preserving layout updates
     std::vector<PropertyInterface*> propsToPreserve;
 
-    if (layoutResult->getName() != "")
-      propsToPreserve.push_back(layoutResult);
+    if (result->getName() != "")
+      propsToPreserve.push_back(result);
 
     graph->push(false, &propsToPreserve);
 
@@ -377,14 +376,12 @@ public:
 
     getSpacingParameters(dataSet, nSpacing, lSpacing);
 
-    LayoutProperty tmpLayout(graph);
-
     node n;
     SizeProperty *circleSizes = new SizeProperty(graph);
     forEach(n, tree->getNodes()) {
       const Size& boundingBox = sizes->getNodeValue (n);
-      double diam = 2*sqrt (boundingBox.getW() * boundingBox.getW()/4.0 +
-                            boundingBox.getH() * boundingBox.getH()/4.0);
+      double diam = 2.*sqrt (boundingBox.getW() * boundingBox.getW()/4.0 +
+                             boundingBox.getH() * boundingBox.getH()/4.0);
       circleSizes->setNodeValue (n, Size (static_cast<float>(diam), static_cast<float>(diam), 1.0f));
     }
     sizes = circleSizes;
@@ -400,13 +397,13 @@ public:
     doLayout(root, angles);
 
     delete sizes;
-
+    //clear all bends in the Layout
+    result->setAllEdgeValue(vector<Coord>());
     // forget last temporary graph state
     graph->pop();
 
     return true;
   }
 };
-/*@}*/
-LAYOUTPLUGINOFGROUP(TreeRadial,"Tree Radial","Patrick Mary","14/05/2007","Ok","1.0","Tree");
 
+PLUGIN(TreeRadial)
