@@ -17,10 +17,13 @@
  *
  */
 #include <tulip/GraphTools.h>
+#include <tulip/StringCollection.h>
+
 #include "TreeReingoldAndTilfordExtended.h"
 #include "DatasetTools.h"
 
-LAYOUTPLUGINOFGROUP(TreeReingoldAndTilfordExtended,"Hierarchical Tree (R-T Extended)","David Auber and Romain Bourqui","24/09/2010","Beta","1.1","Tree");
+PLUGIN(TreeReingoldAndTilfordExtended)
+
 using namespace std;
 using namespace tlp;
 
@@ -68,16 +71,16 @@ const char * paramHelp[] = {
 //=============================================================================
 #define ORIENTATION "vertical;horizontal;"
 //=============================================================================
-TreeReingoldAndTilfordExtended::TreeReingoldAndTilfordExtended(const tlp::PropertyContext &context):
+TreeReingoldAndTilfordExtended::TreeReingoldAndTilfordExtended(const tlp::PluginContext* context):
   LayoutAlgorithm(context),
   lengthMetric(0) {
   addNodeSizePropertyParameter(this);
-  addParameter<IntegerProperty>("edge length", paramHelp[0], 0, false);
-  addParameter<StringCollection>("orientation", paramHelp[1], ORIENTATION );
-  addParameter<bool>("orthogonal", paramHelp[2], "true" );
+  addInParameter<IntegerProperty>("edge length", paramHelp[0], "", false);
+  addInParameter<StringCollection>("orientation", paramHelp[1], ORIENTATION );
+  addInParameter<bool>("orthogonal", paramHelp[2], "true" );
   addSpacingParameters(this);
-  addParameter<bool>("bounding circles", paramHelp[3], "false");
-  addParameter<bool>("compact layout", paramHelp[4], "true");
+  addInParameter<bool>("bounding circles", paramHelp[3], "false");
+  addInParameter<bool>("compact layout", paramHelp[4], "true");
 }
 //=============================================================================
 TreeReingoldAndTilfordExtended::~TreeReingoldAndTilfordExtended() {
@@ -215,7 +218,7 @@ list<LR> * TreeReingoldAndTilfordExtended::mergeLRList(std::list<LR>*L, std::lis
 }
 //=============================================================================
 list<LR> * TreeReingoldAndTilfordExtended::TreePlace(tlp::node n, TLP_HASH_MAP<tlp::node,double> *p) {
-  //cerr << "TreeReingoldAndTilfordExtended::TreePlace n id:" << n.id() << endl;
+  //tlp::warning() << "TreeReingoldAndTilfordExtended::TreePlace n id:" << n.id() << endl;
   if (tree->outdeg(n)==0) {
     list<LR> *result = new list<LR>();
     LR tmpLR;
@@ -334,14 +337,14 @@ void TreeReingoldAndTilfordExtended::TreeLevelSizing(tlp::node n, std::map<int,d
 void TreeReingoldAndTilfordExtended::calcLayout(tlp::node n, TLP_HASH_MAP<tlp::node,double> *p,
     double x, double y, int level,
     map<int,double> &maxLevelSize) {
-  //cerr << "TreeReingoldAndTilfordExtended::calcLayout" << endl;
+  //tlp::warning() << "TreeReingoldAndTilfordExtended::calcLayout" << endl;
   Coord tmpCoord;
 
   if(!compactLayout)
     tmpCoord.set(static_cast<float>(x+(*p)[n]), -static_cast<float>(y), 0);
   else tmpCoord.set(static_cast<float>(x+(*p)[n]), - static_cast<float>(y+maxLevelSize[level]/2.f), 0);
 
-  layoutResult->setNodeValue(n,tmpCoord);
+  result->setNodeValue(n,tmpCoord);
 
   if (useLength) {
     edge ite;
@@ -376,26 +379,26 @@ void TreeReingoldAndTilfordExtended::calcLayout(tlp::node n, TLP_HASH_MAP<tlp::n
     }
   }
 
-  //cerr << "TreeReingoldAndTilfordExtended::EndCalcLayout" << endl;
+  //tlp::warning() << "TreeReingoldAndTilfordExtended::EndCalcLayout" << endl;
 }
 //===============================================================
 bool TreeReingoldAndTilfordExtended::run() {
   TLP_HASH_MAP<node,double> posRelative;
 
-  layoutResult->setAllEdgeValue(vector<Coord>(0));
+  result->setAllEdgeValue(vector<Coord>(0));
 
   if (!getNodeSizePropertyParameter(dataSet, sizes))
     sizes = graph->getProperty<SizeProperty>("viewSize");
 
   getSpacingParameters(dataSet, nodeSpacing, spacing);
   orientation = "horizontal";
-  lengthMetric = 0;
+  lengthMetric = NULL;
   ortho = true;
   useLength = false;
   compactLayout = true;
   bool boundingCircles = false;
 
-  if (dataSet!=0) {
+  if (dataSet!=NULL) {
     useLength = dataSet->get("edge length", lengthMetric);
     dataSet->get("orthogonal", ortho);
     dataSet->get("bounding circles", boundingCircles);
@@ -409,6 +412,15 @@ bool TreeReingoldAndTilfordExtended::run() {
       compactLayout = true;
   }
 
+  bool deleteLenghtMetric = false;
+
+  if (lengthMetric == NULL) {
+    lengthMetric = new IntegerProperty(graph);
+    lengthMetric->setAllNodeValue(1);
+    lengthMetric->setAllEdgeValue(1);
+    deleteLenghtMetric = true;
+  }
+
   //use bounding circles if specified
   if (boundingCircles) {
     node n;
@@ -432,8 +444,8 @@ bool TreeReingoldAndTilfordExtended::run() {
   // preserving layout updates
   std::vector<PropertyInterface*> propsToPreserve;
 
-  if (layoutResult->getName() != "")
-    propsToPreserve.push_back(layoutResult);
+  if (result->getName() != "")
+    propsToPreserve.push_back(result);
 
   graph->push(false, &propsToPreserve);
 
@@ -441,6 +453,10 @@ bool TreeReingoldAndTilfordExtended::run() {
 
   if (pluginProgress && pluginProgress->state() != TLP_CONTINUE) {
     graph->pop();
+
+    if (deleteLenghtMetric)
+      delete lengthMetric;
+
     return false;
   }
 
@@ -474,24 +490,24 @@ bool TreeReingoldAndTilfordExtended::run() {
       LineType::RealType tmp;
       node src = tree->source(e);
       node tgt = tree->target(e);
-      const Coord& srcPos = layoutResult->getNodeValue(src);
-      const Coord& tgtPos = layoutResult->getNodeValue(tgt);
+      const Coord& srcPos = result->getNodeValue(src);
+      const Coord& tgtPos = result->getNodeValue(tgt);
 
       if (srcPos[0] != tgtPos[0])
         tmp.push_back(Coord(tgtPos[0], srcPos[1], 0));
 
-      layoutResult->setEdgeValue(e, tmp);
+      result->setEdgeValue(e, tmp);
     }
 
     if (orientation == "horizontal") {
       forEach(e, tree->getEdges()) {
-        LineType::RealType tmp = layoutResult->getEdgeValue(e);
+        LineType::RealType tmp = result->getEdgeValue(e);
         LineType::RealType tmp2;
 
         if (!tmp.empty())
           tmp2.push_back(Coord(-tmp[0][1], tmp[0][0], tmp[0][2]));
 
-        layoutResult->setEdgeValue(e, tmp2);
+        result->setEdgeValue(e, tmp2);
       }
     }
   }
@@ -500,8 +516,8 @@ bool TreeReingoldAndTilfordExtended::run() {
   if (orientation == "horizontal") {
     node n;
     forEach(n, tree->getNodes()) {
-      const Coord& tmpC = layoutResult->getNodeValue(n);
-      layoutResult->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
+      const Coord& tmpC = result->getNodeValue(n);
+      result->setNodeValue(n, Coord(-tmpC[1], tmpC[0], tmpC[2]));
     }
   }
 
@@ -511,6 +527,9 @@ bool TreeReingoldAndTilfordExtended::run() {
   if (boundingCircles)
     delete sizes;
 
+  if (deleteLenghtMetric)
+    delete lengthMetric;
+
   return true;
 }
 //=============================================================================
