@@ -21,7 +21,7 @@
 #include <string>
 #include <math.h>
 #include <tulip/tuliphash.h>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 struct LR {
   double L;
@@ -29,7 +29,7 @@ struct LR {
   int size;
 };
 /** \addtogroup layout */
-/*@{*/
+
 /** This plugin is an implementation of the hierarchical tree layout
  *  algorithm first published as:
  *
@@ -50,7 +50,8 @@ struct LR {
  */
 class TreeReingoldAndTilfordExtended:public tlp::LayoutAlgorithm {
 public:
-  TreeReingoldAndTilfordExtended(const tlp::PropertyContext &);
+  PLUGININFORMATION("Hierarchical Tree (R-T Extended)","David Auber and Romain Bourqui","24/09/2010","Beta","1.1","Tree")
+  TreeReingoldAndTilfordExtended(const tlp::PluginContext* context);
   ~TreeReingoldAndTilfordExtended();
   bool run();
 
@@ -71,7 +72,7 @@ private:
   float nodeSpacing;
   bool compactLayout;
 };
-/*@}*/
+
 #endif
 
 
