@@ -16,19 +16,17 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <assert.h>
 #include <set>
 #include <tulip/tuliphash.h>
 #include <tulip/TriconnectedTest.h>
 #include "Tutte.h"
 
-
-LAYOUTPLUGINOFGROUP(Tutte,"3-Connected (Tutte)","David Auber","06/11/2002","Beta","1.0","Planar");
+PLUGIN(Tutte)
 
 using namespace std;
 using namespace tlp;
 //====================================================
-Tutte::Tutte(const tlp::PropertyContext &context):LayoutAlgorithm(context)
+Tutte::Tutte(const tlp::PluginContext* context):LayoutAlgorithm(context)
 {}
 //====================================================
 Tutte::~Tutte() {}
@@ -116,7 +114,7 @@ list<node> findCycle(Graph *sg) {
 }
 //====================================================
 bool Tutte::run() {
-  layoutResult->setAllEdgeValue(vector<Coord>(0));
+  result->setAllEdgeValue(vector<Coord>(0));
   std::list<node> tmp;
   tmp=findCycle(graph);
   std::list<node>::iterator itL;
@@ -125,10 +123,10 @@ bool Tutte::run() {
   float gamma;
   int i=0;
   int rayon=100;
-  gamma=static_cast<float>(2*M_PI/tmp.size());
+  gamma=2*M_PI/tmp.size();
 
   for (itL=tmp.begin(); itL!=tmp.end(); ++itL) {
-    layoutResult->setNodeValue(*itL,Coord(rayon*cos(gamma*i)+rayon*2,rayon*sin(gamma*i)+rayon*2,0));
+    result->setNodeValue(*itL,Coord(rayon*cos(gamma*i)+rayon*2,rayon*sin(gamma*i)+rayon*2,0));
     i++;
   }
 
@@ -153,19 +151,19 @@ bool Tutte::run() {
 
     for (itn=toMove.begin(); itn!=toMove.end(); ++itn) {
       tmpCoord.set(0,0,0);
-      Coord baseCoord=layoutResult->getNodeValue(*itn);
+      Coord baseCoord=result->getNodeValue(*itn);
       int i=0;
       itN=graph->getInOutNodes(*itn);
 
       while (itN->hasNext()) {
         node itAdj=itN->next();
-        const Coord& tmpCoord2=layoutResult->getNodeValue(itAdj);
+        const Coord& tmpCoord2=result->getNodeValue(itAdj);
         tmpCoord.set(tmpCoord.getX()+tmpCoord2.getX(),tmpCoord.getY()+tmpCoord2.getY(),0);
         ++i;
       }
 
       delete itN;
-      layoutResult->setNodeValue(*itn,Coord(tmpCoord.getX()/i,tmpCoord.getY()/i,0));
+      result->setNodeValue(*itn,Coord(tmpCoord.getX()/i,tmpCoord.getY()/i,0));
 
       if (fabs(baseCoord.getX()-tmpCoord.getX()/i)>0.02) ok=true;
 
@@ -195,7 +193,7 @@ bool Tutte::check(std::string &erreurMsg) {
   }
 
   if (!result)
-    erreurMsg="Graph must be Triconnected";
+    erreurMsg="The graph must be triconnected.";
   else
     erreurMsg="";
 
