@@ -19,10 +19,10 @@
 #ifndef _TutteLAYOUT_H
 #define _TutteLAYOUT_H
 #include <cmath>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup layout */
-/*@{*/
+
 /** This plugin is an implementation of the Tutte layout for 3-Connected graph
  *  algorithm first published as:
  *
@@ -35,11 +35,12 @@
 */
 class Tutte:public tlp::LayoutAlgorithm {
 public:
-  Tutte(const tlp::PropertyContext &);
+  PLUGININFORMATION("3-Connected (Tutte)","David Auber","06/11/2002","Beta","1.0","Planar")
+  Tutte(const tlp::PluginContext* context);
   ~Tutte();
 
   bool run();
   bool check(std::string &);
 };
-/*@}*/
+
 #endif
