@@ -20,9 +20,7 @@
 #include <stack>
 #include <queue>
 #include <tulip/tuliphash.h>
-#include <tulip/TulipPlugin.h>
-
-
+#include <tulip/TulipPluginHeaders.h>
 
 using namespace std;
 using namespace tlp;
@@ -38,15 +36,17 @@ static const char * paramHelp[] = {
   HTML_HELP_DEF( "type", "bool" ) \
   HTML_HELP_DEF( "default", "false" )  \
   HTML_HELP_BODY() \
-  "If true the node mesure will be normalized unweight not directed : m(n) = 2*c(n) / (#V - 1)(#V - 2) "  \
-  "If true the node mesure will be normalized unweight directed     : m(n) = c(n) / (#V - 1)(#V - 2) " \
-  "If true the edge mesure will be normalized unweight not directed : m(e) = 2*c(n) / (#V / 2)(#V / 2) "  \
-  "If true the edge mesure will be normalized unweight directed     : m(n) = c(n) / (#V / 2)(#V / 2) " \
+  "If true the node measure will be normalized<br/>" \
+  " - if not directed : m(n) = 2*c(n) / (#V - 1)(#V - 2)<br/>"  \
+  " - if directed     : m(n) = c(n) / (#V - 1)(#V - 2)<br/>"    \
+  "If true the edge measure will be normalized<br/>" \
+  " - if not directed : m(e) = 2*c(e) / (#V / 2)(#V / 2)<br/>"  \
+  " - if directed     : m(e) = c(e) / (#V / 2)(#V / 2)" \
   HTML_HELP_CLOSE()
 };
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugin is an implementation of betweeness centrality parameter.
  *  (see http://en.wikipedia.org/wiki/Centrality#Betweenness_centrality for more details)
  *
@@ -78,17 +78,18 @@ static const char * paramHelp[] = {
  */
 class BetweennessCentrality:public DoubleAlgorithm {
 public:
-  BetweennessCentrality(const PropertyContext &context):DoubleAlgorithm(context) {
-    addParameter<bool>("directed", paramHelp[0], "false");
-    addParameter<bool>("norm", paramHelp[1], "false", false);
-  };
+  PLUGININFORMATION("Betweenness Centrality","David Auber","03/01/2005","Computes the betweeness centrality.","1.2","Graph")
+  BetweennessCentrality(const PluginContext* context):DoubleAlgorithm(context) {
+    addInParameter<bool>("directed", paramHelp[0], "false");
+    addInParameter<bool>("norm", paramHelp[1], "false", false);
+  }
   bool run() {
-    doubleResult->setAllNodeValue(0.0);
-    doubleResult->setAllEdgeValue(0.0);
+    result->setAllNodeValue(0.0);
+    result->setAllEdgeValue(0.0);
     bool directed = false;
     bool norm = false;
 
-    if ( dataSet!=0 ) {
+    if ( dataSet!=NULL ) {
       dataSet->get("directed",directed);
       dataSet->get("norm", norm);
     }
@@ -134,7 +135,7 @@ public:
           }
 
           if (d.get(w.id) == d.get(v.id)+1) {
-            sigma.set(w.id, sigma.get(w.id) + sigma.get(v.id));
+            sigma.add(w.id, sigma.get(v.id));
             P[w].push_back(v);
           }
         }
@@ -152,14 +153,14 @@ public:
 
         for (; itn!=P[w].end(); ++itn) {
           node v = *itn;
-          delta.set(v.id, delta.get(v.id) + double(sigma.get(v.id)) / double(sigma.get(w.id)) * (1.0 + delta.get(w.id)));
+          delta.add(v.id, (double(sigma.get(v.id)) / double(sigma.get(w.id)) * (1.0 + delta.get(w.id))));
           edge e  = graph->existEdge(v,w,directed);
 
           if(e.isValid())
-            doubleResult->setEdgeValue(e, doubleResult->getEdgeValue(e) + double(sigma.get(v.id)) / double(sigma.get(w.id)) * (1.0 + delta.get(w.id)));
+            result->setEdgeValue(e, result->getEdgeValue(e) + double(sigma.get(v.id)) / double(sigma.get(w.id)) * (1.0 + delta.get(w.id)));
         }
 
-        if (w != s) doubleResult->setNodeValue(w, doubleResult->getNodeValue(w) + delta.get(w.id));
+        if (w != s) result->setNodeValue(w, result->getNodeValue(w) + delta.get(w.id));
       }
     }
 
@@ -175,10 +176,10 @@ public:
 
         //In the undirected case, the metric must be divided by two, then
         if(norm)
-          doubleResult->setNodeValue(s,doubleResult->getNodeValue(s)/((n-1.0)*(n-2.0)));
-        else {
-          if(!directed) doubleResult->setNodeValue(s,doubleResult->getNodeValue(s)/2.0);
-        }
+          result->setNodeValue(s,result->getNodeValue(s)/((n-1.0)*(n-2.0)));
+
+        if(!directed)
+          result->setNodeValue(s,result->getNodeValue(s)/2.0);
       }
 
       delete it;
@@ -188,20 +189,19 @@ public:
       while(itE->hasNext()) {
         edge e = itE->next();
 
-        if(norm) {
-          if(directed)
-            doubleResult->setEdgeValue(e,4.0*doubleResult->getEdgeValue(e)/(n*n));
-          else
-            doubleResult->setEdgeValue(e,2.0*doubleResult->getEdgeValue(e)/(n*n));
-        }
-        else if(!directed) doubleResult->setEdgeValue(e,doubleResult->getEdgeValue(e)/(2.0));
+        if(norm)
+          result->setEdgeValue(e,4.0*result->getEdgeValue(e)/(n*n));
+
+        if(!directed)
+          result->setEdgeValue(e,result->getEdgeValue(e)/(2.0));
       }
 
       delete itE;
     }
 
+
     return pluginProgress->state()!=TLP_CANCEL;
   }
 };
-/*@}*/
-DOUBLEPLUGINOFGROUP(BetweennessCentrality,"Betweenness Centrality","David Auber","03/01/2005","Alpha","1.2","Graph");
+
+PLUGIN(BetweennessCentrality)
