@@ -19,7 +19,7 @@
 #include <iostream>
 #include <stack>
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 using namespace std;
 using namespace tlp;
@@ -67,7 +67,6 @@ struct dfsBicoTestStruct {
   node opp;
   Iterator<edge>* ite;
 
-  dfsBicoTestStruct() {}
   dfsBicoTestStruct(node n, node o, Iterator<edge> *it):
     v(n), opp(o), ite(it) {}
 };
@@ -191,12 +190,12 @@ int biconnectedComponents(const Graph& graph, MutableContainer<int>& compnum) {
   return(count2 + num_isolated);
 }
 //=============================================================================================
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 using namespace std;
 using namespace tlp;
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugin is an implementation of a biconnected component decomposition algorithm. It assigns
  *  the same value to all the edges in the same component.
  *
@@ -207,24 +206,25 @@ using namespace tlp;
  */
 class BiconnectedComponent:public DoubleAlgorithm {
 public:
-  BiconnectedComponent(const PropertyContext &context):DoubleAlgorithm(context) {};
+  PLUGININFORMATION("Biconnected Component","David Auber","03/01/2005","Implements a biconnected component decomposition.","1.0","Component")
+  BiconnectedComponent(const tlp::PluginContext* context):DoubleAlgorithm(context) {}
   bool run() {
     MutableContainer<int> compo;
     compo.setAll(-1);
     biconnectedComponents(*graph, compo);
-    doubleResult->setAllEdgeValue(-1);
-    doubleResult->setAllNodeValue(-1);
+    result->setAllEdgeValue(-1);
+    result->setAllNodeValue(-1);
     Iterator<edge> *it = graph->getEdges();
 
     while(it->hasNext()) {
       edge e = it->next();
-      doubleResult->setEdgeValue(e, compo.get(e.id));
+      result->setEdgeValue(e, compo.get(e.id));
     }
 
     delete it;
     return true;
   }
 };
-/*@}*/
+
 //=============================================================================================
-DOUBLEPLUGINOFGROUP(BiconnectedComponent,"Biconnected Component","David Auber","03/01/2005","Alpha","1.0","Component");
+PLUGIN(BiconnectedComponent)
