@@ -19,12 +19,11 @@
 #ifndef _CLUSTERMETRIC_H
 #define _CLUSTERMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup metric */
-/*@{*/
-/** This plugin is an implementation of the Algorithm Parameter.
- *  algorithm published in :
+
+/** This plugin computes the Cluster metric described in :
  *
  *  Y. Chiricota. F.Jourdan, an G.Melancon \n
  *  "Software component capture using graph clustering",\n
@@ -34,14 +33,13 @@
  *  Extended to unbounded depth (for the neigbors) :
  *
  *  \note This algorithm works on general graphs. The algorithm use the parameter
- *  depth in order to determine the depth of the neighbors. If no depth
- *  is given, the plugins automatically popup a qt windows to ask the user for this
- *  parameter.
+ *  depth in order to determine the depth of the neighbors.
  *
  */
 class ClusterMetric:public tlp::DoubleAlgorithm {
 public:
-  ClusterMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Cluster","David Auber","26/02/2003","Computes the Cluster metric described in\nY. Chiricota. F.Jourdan, an G.Melancon\n'Software component capture using graph clustering',\nIWPC 2002","1.0","Graph")
+  ClusterMetric(const tlp::PluginContext* context);
   bool run();
 
 private:
@@ -49,7 +47,7 @@ private:
   double getEdgeValue(const tlp::edge n);
   void buildSubGraph(tlp::node n, tlp::node startNode,std::set<tlp::node> &selected,unsigned int depth);
 };
-/*@}*/
+
 #endif
 
 
