@@ -21,9 +21,9 @@
 
 using namespace tlp;
 
-DOUBLEPLUGINOFGROUP(ConnectedComponent,"Connected Component","David Auber","01/07/2002","Alpha","1.0","Component");
+PLUGIN(ConnectedComponent)
 
-ConnectedComponent::ConnectedComponent(const tlp::PropertyContext &context):DoubleAlgorithm(context) {}
+ConnectedComponent::ConnectedComponent(const tlp::PluginContext* context):DoubleAlgorithm(context) {}
 //======================================================
 ConnectedComponent::~ConnectedComponent() {}
 //======================================================
@@ -37,7 +37,7 @@ bool ConnectedComponent::run() {
     std::set<node>& component = components[curComponent];
 
     for(std::set<node>::const_iterator itNode = component.begin(); itNode!=component.end(); ++itNode) {
-      doubleResult->setNodeValue(*itNode, curComponent);
+      result->setNodeValue(*itNode, curComponent);
     }
   }
 
@@ -48,10 +48,10 @@ bool ConnectedComponent::run() {
     edge ite=itE->next();
     node source= graph->source(ite);
     //    node target= graph->target(ite);
-    //    if (doubleResult->getNodeValue(source) == doubleResult->getNodeValue(target))
-    doubleResult->setEdgeValue(ite, doubleResult->getNodeValue(source));
+    //    if (result->getNodeValue(source) == result->getNodeValue(target))
+    result->setEdgeValue(ite, result->getNodeValue(source));
     //    else
-    //  doubleResult->setEdgeValue(ite,curComponent);
+    //  result->setEdgeValue(ite,curComponent);
   }
 
   delete itE;
