@@ -19,10 +19,10 @@
 #ifndef _ConnectedComponent_H
 #define _ConnectedComponent_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugin is an implementation of the connected component decompostion algorithm. each
  *  node and edge that belongs to the same component receive the same value.
  *
@@ -32,9 +32,10 @@
  */
 class ConnectedComponent:public tlp::DoubleAlgorithm {
 public:
-  ConnectedComponent(const tlp::PropertyContext &);
+  PLUGININFORMATION("Connected Component","David Auber","01/07/2002","Implements the connected component decompostion.","1.0","Component")
+  ConnectedComponent(const tlp::PluginContext* context);
   ~ConnectedComponent();
   bool run();
 };
-/*@}*/
+
 #endif
