@@ -16,15 +16,14 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <cassert>
 #include "DagLevelMetric.h"
 
-DOUBLEPLUGINOFGROUP(DagLevelMetric,"Dag Level","David Auber","10/03/2000","Alpha","1.0","Tree");
+PLUGIN(DagLevelMetric)
 
 using namespace std;
 using namespace tlp;
 
-DagLevelMetric::DagLevelMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context) {}
+DagLevelMetric::DagLevelMetric(const tlp::PluginContext* context):DoubleAlgorithm(context) {}
 
 DagLevelMetric::~DagLevelMetric() {}
 //======================================================
@@ -33,7 +32,7 @@ bool DagLevelMetric::run() {
   dagLevel(graph, level, pluginProgress);
   node n;
   forEach(n, graph->getNodes())
-  doubleResult->setNodeValue(n, level.get(n.id));
+  result->setNodeValue(n, level.get(n.id));
   return true;
 }
 //======================================================
@@ -43,7 +42,7 @@ bool DagLevelMetric::check(std::string &erreurMsg) {
     return true;
   }
   else {
-    erreurMsg="The Graph must be a acylic";
+    erreurMsg="The graph must be a acylic.";
     return false;
   }
 }
