@@ -19,9 +19,9 @@
 #ifndef _DagLevelMETRIC_H
 #define _DagLevelMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugin is an implementation of a DAG layer decomposition
  *
  *  \note This algorithm works on general DAG, the complexity is in O(|E|+|V|);
@@ -29,10 +29,11 @@
  */
 class DagLevelMetric:public tlp::DoubleAlgorithm {
 public:
-  DagLevelMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Dag Level","David Auber","10/03/2000","Implements a DAG layer decomposition.","1.0","Hierarchical")
+  DagLevelMetric(const tlp::PluginContext* context);
   ~DagLevelMetric();
   bool run();
   bool check(std::string& erreurMsg);
 };
-/*@}*/
+
 #endif
