@@ -19,10 +19,10 @@
 #ifndef _DEGREEMETRIC_H
 #define _DEGREEMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugin compute the degree of each node
  *
  *  \note This plug-in exists to obtain a uniform interface in the
@@ -33,8 +33,10 @@
  */
 class DegreeMetric:public tlp::DoubleAlgorithm {
 public:
-  DegreeMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Degree","David Auber","04/10/2001","Assigns its degree to each node.","1.0","Graph")
+  DegreeMetric(const tlp::PluginContext* context);
   bool run();
+  bool check(std::string& errorMsg);
 };
-/*@}*/
+
 #endif
