@@ -19,24 +19,26 @@
 #ifndef _DEPTHMETRIC_H
 #define _DEPTHMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugins compute for each node n, the maximum path-length between n and the other node.
  *  The graph must be acyclic.
  *
  *  \note This algorithm works on general graphs.
  *
  */
-class DepthMetric:public tlp::DoubleAlgorithm {
+class DepthMetric :public tlp::DoubleAlgorithm {
 public:
-  DepthMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Depth","David Auber","15/02/2001","Compute for each node n on an acyclic graph,\nthe maximum path-length between n and the other node.","1.1","Hierarchical")
+  DepthMetric(const tlp::PluginContext* context);
   bool run();
   bool check(std::string &);
 private:
   double getNodeValue(const tlp::node n);
+  tlp::NumericProperty* edgeWeight;
 };
-/*@}*/
+
 #endif
