@@ -23,10 +23,7 @@
 #include <tulip/ConnectedTest.h>
 #include "Eccentricity.h"
 
-
-
-DOUBLEPLUGINOFGROUP(EccentricityMetric,"Eccentricity","Auber/Munzner","18/06/2004","Alpha","2.0","Graph");
-
+PLUGIN(EccentricityMetric)
 
 using namespace std;
 using namespace tlp;
@@ -39,7 +36,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "values", "[true , false]" ) \
   HTML_HELP_DEF( "default", "false" ) \
   HTML_HELP_BODY() \
-  "If true the closeness centrality will be computed (i.e. the mean of shortest-paths lengths from a node to others)"\
+  "If true, the closeness centrality is computed (i.e. the average distance from the node to all others)."\
   HTML_HELP_CLOSE(),
   // norm
   HTML_HELP_OPEN() \
@@ -47,9 +44,9 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "values", "[true , false]" ) \
   HTML_HELP_DEF( "default", "false" ) \
   HTML_HELP_BODY() \
-  "If true the returned values are normalized. " \
+  "If true, the returned values are normalized. " \
   "For the closeness centrality, the reciprocal of the sum of distances is returned. " \
-  "The eccentricity values is divided by the graph diameter. " \
+  "The eccentricity values are divided by the graph diameter. " \
   "<b> Warning : </b> The normalized eccentricity values sould be computed on a (strongly) connected graph."
   HTML_HELP_CLOSE(),
   // directed
@@ -58,34 +55,29 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "values", "[true , false]" ) \
   HTML_HELP_DEF( "default", "false" ) \
   HTML_HELP_BODY() \
-  "Indicates if the graph should be considered as directed or not."\
+  "If true, the graph is considered directed."\
   HTML_HELP_CLOSE(),
 };
 }
 
-EccentricityMetric::EccentricityMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context) {
-  addParameter<bool>("closeness centrality",paramHelp[0],"false");
-  addParameter<bool>("norm",paramHelp[1],"true");
-  addParameter<bool>("directed",paramHelp[2],"false");
+EccentricityMetric::EccentricityMetric(const tlp::PluginContext* context):DoubleAlgorithm(context), allPaths(false), norm(true), directed(false) {
+  addInParameter<bool>("closeness centrality",paramHelp[0],"false");
+  addInParameter<bool>("norm",paramHelp[1],"true");
+  addInParameter<bool>("directed",paramHelp[2],"false");
 }
 //====================================================================
 EccentricityMetric::~EccentricityMetric() {
 }
 //====================================================================
-bool EccentricityMetric::check(string &/*err*/) {
-  return true;
-}
-//====================================================================
 double EccentricityMetric::compute(node n) {
 
   MutableContainer<unsigned int> distance;
   distance.setAll(0);
   double val;
 
-  if (directed)
-    val = tlp::maxDistance(graph, n, distance, DIRECTED);
-  else
-    val = tlp::maxDistance(graph, n, distance, UNDIRECTED);
+  val = directed ?
+        tlp::maxDistance(graph, n, distance, DIRECTED) :
+        tlp::maxDistance(graph, n, distance, UNDIRECTED);
 
   if(!allPaths)
     return val;
@@ -115,7 +107,7 @@ bool EccentricityMetric::run() {
   norm     = true;
   directed = false;
 
-  if (dataSet!=0) {
+  if (dataSet!=NULL) {
     dataSet->get("closeness centrality", allPaths);
     dataSet->get("norm", norm);
     dataSet->get("directed", directed);
@@ -144,7 +136,7 @@ bool EccentricityMetric::run() {
   #pragma omp parallel for
 #endif
 
-  for (int ni = 0; ni < static_cast<int>(nbElem); ++ni) {
+  for (int ni = 0; ni < static_cast<int>(nbElem) ; ++ni) {
     if (stopfor) continue;
 
 #ifdef _OPENMP
@@ -165,7 +157,11 @@ bool EccentricityMetric::run() {
 #endif
     res[ni] = compute(vecNodes[ni]);
 
-    if(!allPaths && norm) {
+    if(!allPaths && norm)
+#ifdef _OPENMP
+      #pragma omp critical(DIAMETER)
+#endif
+    {
       if(diameter<res[ni])
         diameter=res[ni];
     }
@@ -173,27 +169,27 @@ bool EccentricityMetric::run() {
 
   for (size_t ni = 0; ni < nbElem; ++ni) {
     if(!allPaths && norm)
-      doubleResult->setNodeValue(vecNodes[ni], res[ni]/diameter);
+      result->setNodeValue(vecNodes[ni], res[ni]/diameter);
     else
-      doubleResult->setNodeValue(vecNodes[ni], res[ni]);
+      result->setNodeValue(vecNodes[ni], res[ni]);
   }
 
   /*
     double t2 = omp_get_wtime();
     for (size_t ni = 0; ni < nbElem; ++ni) {
       double val = compute(vecNodes[ni]);
-      doubleResult->setNodeValue(vecNodes[ni], val);
+      result->setNodeValue(vecNodes[ni], val);
     }
     double t3 = omp_get_wtime();
-    cout << "omp : " << t2 - t1 << "s" << endl << flush;
-    cout << "sng : " << t3 - t2 << "s" << endl << flush;
+    tlp::debug() << "omp : " << t2 - t1 << "s" << endl << flush;
+    tlp::debug() << "sng : " << t3 - t2 << "s" << endl << flush;
   */
   /*
   Iterator<node> *itN = graph->getNodes();
   for (unsigned int i=0; itN->hasNext(); ++i) {
     if (pluginProgress->progress(i, graph->numberOfNodes())!=TLP_CONTINUE) break;
     node n = itN->next();
-    doubleResult->setNodeValue(n, compute(n));
+    result->setNodeValue(n, compute(n));
   }
   */
   return pluginProgress->state()!=TLP_CANCEL;
