@@ -19,10 +19,10 @@
 #ifndef _ECCENTRICITYMETRIC_H
 #define _ECCENTRICITYMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugin compute the eccentricity/closeness centrality of each node
  *
  * Eccentricity is the maximum distance to go from a node to all others.
@@ -48,16 +48,16 @@
  */
 class EccentricityMetric:public tlp::DoubleAlgorithm {
 public:
-  EccentricityMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Eccentricity","Auber/Munzner","18/06/2004","Computes the eccentricity/closeness centrality of each node.","2.0","Graph")
+  EccentricityMetric(const tlp::PluginContext* context);
   ~EccentricityMetric();
   bool run();
   double compute(tlp::node n);
-  bool check(std::string &);
 private:
   bool allPaths;
   bool norm;
   bool directed;
 
 };
-/*@}*/
+
 #endif
