@@ -20,19 +20,19 @@
 
 using namespace tlp;
 
-DOUBLEPLUGINOFGROUP(IdMetric,"Id","David Auber","06/04/2000","Alpha","1.0","Misc");
+PLUGIN(IdMetric)
 
 //==================================================================
-IdMetric::IdMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context) {
+IdMetric::IdMetric(const tlp::PluginContext* context):DoubleAlgorithm(context) {
 }
 //==================================================================
 bool IdMetric::run() {
   node n;
   forEach(n, graph->getNodes())
-  doubleResult->setNodeValue(n, n.id);
+  result->setNodeValue(n, n.id);
   edge e;
   forEach(e, graph->getEdges())
-  doubleResult->setEdgeValue(e, e.id);
+  result->setEdgeValue(e, e.id);
   return true;
 }
 //=================================================================
