@@ -20,19 +20,20 @@
 #ifndef _IDMETRIC_H
 #define _IDMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugins assigns id to nodes and edges. The ids are those used by tulip.
  *
  */
 class IdMetric:public tlp::DoubleAlgorithm {
 public:
-  IdMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Id","David Auber","06/04/2000","Assigns their Tulip id to nodes adn edges.","1.0","Misc")
+  IdMetric(const tlp::PluginContext* context);
   bool run();
 };
-/*@}*/
+
 
 
 #endif
