@@ -19,40 +19,39 @@
 #include <stack>
 #include "LeafMetric.h"
 
-DOUBLEPLUGINOFGROUP(LeafMetric,"Leaf","David Auber","20/12/1999","Alpha","1.0","Tree");
+PLUGIN(LeafMetric)
 
 using namespace std;
 using namespace tlp;
 
 //=======================================================================
-LeafMetric::LeafMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context) {}
+LeafMetric::LeafMetric(const tlp::PluginContext* context):DoubleAlgorithm(context) {}
 
 // structure below is used to implement dfs loop
 struct dfsLeafStruct {
   node current;
   Iterator<node>* outNodes;
-  double result;
+  double res;
 
-  dfsLeafStruct() {}
   dfsLeafStruct(node n, Iterator<node>* nodes):
-    current(n), outNodes(nodes), result(0.0) {}
+    current(n), outNodes(nodes), res(0.0) {}
 };
 //=======================================================================
 // original recursive algorithm
 /*double LeafMetric::getNodeValue(const tlp::node n) {
-  if (doubleResult->getNodeValue(n) != 0)
-    return doubleResult->getNodeValue(n);
-  double result=0;
+  if (result->getNodeValue(n) != 0)
+    return result->getNodeValue(n);
+  double res=0;
   node _n;
   forEach(_n, graph->getOutNodes(n))
-    result += getNodeValue(_n);
-  if (result==0) result=1.0;
-  doubleResult->setNodeValue(n, result);
-  return result;
+    res += getNodeValue(_n);
+  if (res==0) res=1.0;
+  result->setNodeValue(n, res);
+  return res;
   }*/
 //=======================================================================
 double LeafMetric::getNodeValue(tlp::node current) {
-  double value = doubleResult->getNodeValue(current);
+  double value = result->getNodeValue(current);
 
   if (value != 0.0)
     return value;
@@ -61,24 +60,24 @@ double LeafMetric::getNodeValue(tlp::node current) {
   stack<dfsLeafStruct> dfsLevels;
   Iterator<node>* outNodes = graph->getOutNodes(current);
   dfsLeafStruct dfsParams(current, outNodes);
-  double result = 0.0;
+  double res = 0.0;
   dfsLevels.push(dfsParams);
 
   while(!dfsLevels.empty()) {
     while (outNodes->hasNext()) {
       node neighbour = outNodes->next();
-      value = doubleResult->getNodeValue(neighbour);
+      value = result->getNodeValue(neighbour);
 
-      // compute result
+      // compute res
       if (value != 0.0)
-        result += value;
+        res += value;
       else {
-        // store result for current
-        dfsLevels.top().result = result;
+        // store res for current
+        dfsLevels.top().res = res;
         // push new dfsParams on stack
         current = dfsParams.current = neighbour;
         outNodes = dfsParams.outNodes = graph->getOutNodes(neighbour);
-        result = dfsParams.result = 0.0;
+        res = dfsParams.res = 0.0;
         dfsLevels.push(dfsParams);
         // and go deeper
         break;
@@ -89,11 +88,11 @@ double LeafMetric::getNodeValue(tlp::node current) {
       // new dfsParams has been pushed on stack
       continue;
 
-    // save current result
-    if (result == 0.0)
-      result = 1.0;
+    // save current res
+    if (res == 0.0)
+      res = 1.0;
 
-    doubleResult->setNodeValue(current, result);
+    result->setNodeValue(current, res);
     // unstack current dfsParams
     delete outNodes;
     dfsLevels.pop();
@@ -105,20 +104,20 @@ double LeafMetric::getNodeValue(tlp::node current) {
     dfsParams = dfsLevels.top();
     current = dfsParams.current;
     outNodes = dfsParams.outNodes;
-    // update new current result if any
-    dfsParams.result += result;
-    result = dfsParams.result;
+    // update new current res if any
+    dfsParams.res += res;
+    res = dfsParams.res;
   }
 
-  return result;
+  return res;
 }
 //=======================================================================
 bool LeafMetric::run() {
-  doubleResult->setAllNodeValue(0);
-  doubleResult->setAllEdgeValue(0);
+  result->setAllNodeValue(0);
+  result->setAllEdgeValue(0);
   node n;
   forEach(n, graph->getNodes())
-  doubleResult->setNodeValue(n, getNodeValue(n));
+  result->setNodeValue(n, getNodeValue(n));
   return true;
 }
 //=======================================================================
@@ -126,7 +125,7 @@ bool LeafMetric::check(std::string &erreurMsg) {
   if (AcyclicTest::isAcyclic(graph))
     return true;
   else {
-    erreurMsg="The Graph must be a Acyclic";
+    erreurMsg="The graph must be a acyclic.";
     return false;
   }
 }
