@@ -19,10 +19,10 @@
 #ifndef _LEAFMETRIC_H
 #define _LEAFMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugin computes the number of leaves in the subtree induced by each node.
  *
  *  \note This algorithm assigns to each node a value defined as following : If two nodes are in the same
@@ -32,13 +32,14 @@
  */
 class LeafMetric:public tlp::DoubleAlgorithm {
 public:
-  LeafMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Leaf","David Auber","20/12/1999","Computes the number of leaves in the subtree\ninduced by each node of an acyclic graph.","1.0","Hierarchical")
+  LeafMetric(const tlp::PluginContext* context);
   bool check(std::string &);
   bool run();
 private:
   double getNodeValue(const tlp::node n);
 };
-/*@}*/
+
 #endif
 
 
