@@ -19,40 +19,39 @@
 #include <stack>
 #include "NodeMetric.h"
 
-DOUBLEPLUGINOFGROUP(NodeMetric,"Node","David Auber","20/12/1999","Alpha","1.0","Tree");
+PLUGIN(NodeMetric)
 
 using namespace std;
 using namespace tlp;
 
 //====================================================================
-NodeMetric::NodeMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context)
+NodeMetric::NodeMetric(const tlp::PluginContext* context):DoubleAlgorithm(context)
 {}
 
 // structure below is used to implement dfs loop
 struct dfsStruct {
   node current;
   Iterator<node>* outNodes;
-  double result;
+  double res;
 
-  dfsStruct() {}
   dfsStruct(node n, Iterator<node>* nodes):
-    current(n), outNodes(nodes), result(1.0) {}
+    current(n), outNodes(nodes), res(1.0) {}
 };
 //=======================================================================
 // original recursive algorithm
 /*double NodeMetric::getNodeValue(const tlp::node n) {
-  if (doubleResult->getNodeValue(n)!=0)
-    return doubleResult->getNodeValue(n);
-  double result = 1;
+  if (result->getNodeValue(n)!=0)
+    return result->getNodeValue(n);
+  double res = 1;
   node _n;
   forEach(_n, graph->getOutNodes(n))
-    result += getNodeValue(_n);
-  doubleResult->setNodeValue(n, result);
-  return result;
+    res += getNodeValue(_n);
+  result->setNodeValue(n, res);
+  return res;
   }*/
 //=======================================================================
 double NodeMetric::getNodeValue(tlp::node current) {
-  double value = doubleResult->getNodeValue(current);
+  double value = result->getNodeValue(current);
 
   if (value != 0.0)
     return value;
@@ -61,24 +60,24 @@ double NodeMetric::getNodeValue(tlp::node current) {
   stack<dfsStruct> dfsLevels;
   Iterator<node>* outNodes = graph->getOutNodes(current);
   dfsStruct dfsParams(current, outNodes);
-  double result = 1.0;
+  double res = 1.0;
   dfsLevels.push(dfsParams);
 
   while(!dfsLevels.empty()) {
     while (outNodes->hasNext()) {
       node neighbour = outNodes->next();
-      value = doubleResult->getNodeValue(neighbour);
+      value = result->getNodeValue(neighbour);
 
-      // compute result
+      // compute res
       if (value != 0.0)
-        result += value;
+        res += value;
       else {
-        // store result for current
-        dfsLevels.top().result = result;
+        // store res for current
+        dfsLevels.top().res = res;
         // push new dfsParams on stack
         current = dfsParams.current = neighbour;
         outNodes = dfsParams.outNodes = graph->getOutNodes(neighbour);
-        result = dfsParams.result = 1.0;
+        res = dfsParams.res = 1.0;
         dfsLevels.push(dfsParams);
         // and go deeper
         break;
@@ -89,8 +88,8 @@ double NodeMetric::getNodeValue(tlp::node current) {
       // new dfsParams has been pushed on stack
       continue;
 
-    // save current result
-    doubleResult->setNodeValue(current, result);
+    // save current res
+    result->setNodeValue(current, res);
     // unstack current dfsParams
     delete outNodes;
     dfsLevels.pop();
@@ -102,21 +101,20 @@ double NodeMetric::getNodeValue(tlp::node current) {
     dfsParams = dfsLevels.top();
     current = dfsParams.current;
     outNodes = dfsParams.outNodes;
-    // update new current result if any
-    dfsParams.result += result;
-    result = dfsParams.result;
+    // update new current res if any
+    dfsParams.res += res;
+    res = dfsParams.res;
   }
 
-  return result;
+  return res;
 }
 //====================================================================
 bool NodeMetric::run() {
-  doubleResult->setAllEdgeValue(0);
-  doubleResult->setAllNodeValue(0);
-  node n;
-  forEach(n, graph->getNodes()) {
-    doubleResult->setNodeValue(n, getNodeValue(n));
-  }
+  result->setAllEdgeValue(0);
+  result->setAllNodeValue(0);
+  node _n;
+  forEach(_n, graph->getNodes())
+  result->setNodeValue(_n,getNodeValue(_n));
   return true;
 }
 //====================================================================
@@ -126,7 +124,7 @@ bool NodeMetric::check(std::string &erreurMsg) {
     return true;
   }
   else  {
-    erreurMsg="The Graph must be acyclic";
+    erreurMsg="The graph must be acyclic.";
     return false;
   }
 }
