@@ -19,13 +19,13 @@
 #ifndef _NODEMETRIC_H
 #define _NODEMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 
 
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugin computes the number of nodes in the subtree induced by each node.
  *
  *  \note This algorithm assigns to each node a value defined as following : If two nodes are in the same
@@ -35,12 +35,13 @@
  */
 class NodeMetric:public tlp::DoubleAlgorithm {
 public:
-  NodeMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Node","David Auber","20/12/1999","Computes the number of nodes in the subtree\ninduced by each node of an acyclic graph.","1.0","Hierarchical")
+  NodeMetric(const tlp::PluginContext* context);
   bool run();
   bool check(std::string &);
 private:
   double getNodeValue(const tlp::node n);
 };
-/*@}*/
+
 #endif
 
