@@ -19,47 +19,46 @@
 #include <stack>
 #include "PathLengthMetric.h"
 
-DOUBLEPLUGINOFGROUP(PathLengthMetric,"Path Length","David Auber","15/02/2001","Alpha","1.0","Tree");
+PLUGIN(PathLengthMetric)
 
 using namespace std;
 using namespace tlp;
 
 //=======================================
-PathLengthMetric::PathLengthMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context) {
+PathLengthMetric::PathLengthMetric(const tlp::PluginContext* context):DoubleAlgorithm(context), leafMetric(NULL) {
   // Leaf metric needed
-  addDependency<DoubleAlgorithm>("Leaf", "1.0");
+  addDependency("Leaf", "1.0");
 }
 
 // structure below is used to implement dfs loop
 struct dfsStruct {
   node current;
   Iterator<node>* outNodes;
-  double result;
+  double res;
 
-  dfsStruct() {}
   dfsStruct(node n, Iterator<node>* nodes):
-    current(n), outNodes(nodes), result(0.0) {}
+    current(n), outNodes(nodes), res(0.0) {}
 };
 //=======================================
 // original recursive algorithm
 /*double PathLengthMetric::getNodeValue(const tlp::node n) {
   if (graph->outdeg(n)==0) return 0.0;
-  if (doubleResult->getNodeValue(n) > 0.1)
-    return doubleResult->getNodeValue(n);
-  double result=0;
+  if (result->getNodeValue(n) > 0.1)
+    return result->getNodeValue(n);
+  double res=0;
   node child;
   forEach(child, graph->getOutNodes(n)) {
-    result += getNodeValue(child);
+    res += getNodeValue(child);
   }
-  result += leafMetric->getNodeValue(n);
-  doubleResult->setNodeValue(n, result);
-  return result;
+  res += leafMetric->getNodeValue(n);
+  result->setNodeValue(n, res);
+  return res;
   }*/
 //=======================================================================
 double PathLengthMetric::getNodeValue(tlp::node current) {
   if (graph->outdeg(current) == 0) return 0.0;
 
-  double value = doubleResult->getNodeValue(current);
+  double value = result->getNodeValue(current);
 
   if (value > 0.1)
     return value;
@@ -68,27 +67,27 @@ double PathLengthMetric::getNodeValue(tlp::node current) {
   stack<dfsStruct> dfsLevels;
   Iterator<node>* outNodes = graph->getOutNodes(current);
   dfsStruct dfsParams(current, outNodes);
-  double result = 0.0;
+  double res = 0.0;
   dfsLevels.push(dfsParams);
 
   while(!dfsLevels.empty()) {
     while (outNodes->hasNext()) {
       node neighbour = outNodes->next();
-      value = doubleResult->getNodeValue(neighbour);
+      value = result->getNodeValue(neighbour);
 
       // compute result
       if (value > 0.1)
-        result += value;
+        res += value;
       else {
         outNodes = graph->getOutNodes(neighbour);
 
         if (outNodes->hasNext()) {
           // store result for current
-          dfsLevels.top().result = result;
+          dfsLevels.top().res = res;
           // push new dfsParams on stack
           current = dfsParams.current = neighbour;
           dfsParams.outNodes = outNodes;
-          result = dfsParams.result = 0.0;
+          res = dfsParams.res = 0.0;
           dfsLevels.push(dfsParams);
           // and go deeper
           break;
@@ -104,9 +103,9 @@ double PathLengthMetric::getNodeValue(tlp::node current) {
       // new dfsParams has been pushed on stack
       continue;
 
-    result += leafMetric->getNodeValue(current);
+    res += leafMetric->getNodeValue(current);
     // save current result
-    doubleResult->setNodeValue(current, result);
+    result->setNodeValue(current, res);
     // unstack current dfsParams
     delete outNodes;
     dfsLevels.pop();
@@ -119,21 +118,21 @@ double PathLengthMetric::getNodeValue(tlp::node current) {
     current = dfsParams.current;
     outNodes = dfsParams.outNodes;
     // update new current result if any
-    dfsParams.result += result;
-    result = dfsParams.result;
+    dfsParams.res += res;
+    res = dfsParams.res;
   }
 
-  return result;
+  return res;
 }
 //=======================================
 bool PathLengthMetric::run() {
-  doubleResult->setAllNodeValue(0);
-  doubleResult->setAllEdgeValue(0);
+  result->setAllNodeValue(0);
+  result->setAllEdgeValue(0);
   leafMetric = new DoubleProperty(graph);
   string erreurMsg;
 
-  if (!graph->computeProperty("Leaf", leafMetric, erreurMsg)) {
-    cerr << erreurMsg << endl;
+  if (!graph->applyPropertyAlgorithm("Leaf", leafMetric, erreurMsg)) {
+    tlp::warning() << erreurMsg << endl;
     return false;
   }
 
@@ -148,7 +147,7 @@ bool PathLengthMetric::check(std::string &erreurMsg) {
   if (AcyclicTest::isAcyclic(graph))
     return true;
   else {
-    erreurMsg="The Graph must be acyclic";
+    erreurMsg="The graph must be acyclic.";
     return false;
   }
 }
