@@ -20,11 +20,12 @@
 #ifndef _PATHLENGTHMETRIC_H
 #define _PATHLENGTHMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 class PathLengthMetric:public tlp::DoubleAlgorithm {
 public:
-  PathLengthMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Path Length","David Auber","15/02/2001","Alpha","1.0","Hierarchical")
+  PathLengthMetric(const tlp::PluginContext* context);
   bool run();
   bool check(std::string &);
 private:
