@@ -20,20 +20,19 @@
 
 using namespace tlp;
 
-
-DOUBLEPLUGINOFGROUP(RandomMetric,"Random metric","David Auber","04/10/2001","Alpha","1.1","Misc")
+PLUGIN(RandomMetric)
 
 //===========================================
-RandomMetric::RandomMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context)
+RandomMetric::RandomMetric(const tlp::PluginContext* context):DoubleAlgorithm(context)
 {}
 //===========================================
 bool RandomMetric::run() {
   node n;
   forEach(n, graph->getNodes())
-  doubleResult->setNodeValue(n, (double)rand() / double(RAND_MAX));
+  result->setNodeValue(n, (double)rand() / double(RAND_MAX));
   edge e;
   forEach(e, graph->getEdges())
-  doubleResult->setEdgeValue(e, (double)rand() / double(RAND_MAX));
+  result->setEdgeValue(e, (double)rand() / double(RAND_MAX));
   return true;
 }
 //===========================================
