@@ -19,19 +19,20 @@
 #ifndef _RANDOMMETRIC_H
 #define _RANDOMMETRIC_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup metric */
-/*@{*/
+
 /** This plugins assigns random values to nodes and edges. the values are between 0 and 1.
  *
  */
 class RandomMetric:public tlp::DoubleAlgorithm {
 public:
-  RandomMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Random metric","David Auber","04/10/2001","Assigns random values to nodes and edges.","1.0","Misc")
+  RandomMetric(const tlp::PluginContext* context);
   bool run();
 };
-/*@}*/
+
 #endif
 
 
