@@ -18,11 +18,14 @@
  */
 
 #include <cmath>
-#include <stdio.h>
+#include <cstdio>
+
 #include <tulip/StringProperty.h>
+#include <tulip/StringCollection.h>
+
 #include "StrahlerMetric.h"
 
-DOUBLEPLUGINOFGROUP(StrahlerMetric,"Strahler","David Auber","06/04/2000","Alpha","1.0","Graph");
+PLUGIN(StrahlerMetric)
 
 using namespace std;
 using namespace tlp;
@@ -49,35 +52,19 @@ struct equal_to<couple> {
 template<>
 struct less<couple> {
   bool operator()(const couple &c,const couple &d) {
-    if (c.r<d.r) return true;
-
-    if (c.r>d.r) return false;
-
-    if (c.p<d.p) return true;
-
-    if (c.p>d.p) return false;
-
-    return false;
+    return (c.r < d.r) ||
+           ((c.r == d.r) && (c.p < d.p));
   }
 };
-};
-
-int max(int i1,int i2) {
-  if (i1>i2) return i1;
-  else return i2;
 }
 
-int min(int i1,int i2) {
-  if (i1<i2) return i1;
-  else return i2;
-}
 struct StackEval {
   StackEval(int f,int u):freeS(f),usedS(u) {}
   int freeS,usedS;
 };
 
 struct GreaterStackEval {
-  bool operator()(const StackEval e1,const StackEval e2) {
+  bool operator()(const StackEval& e1,const StackEval& e2) {
     return (e1.freeS>e2.freeS);
   }
 };
@@ -162,7 +149,7 @@ Strahler StrahlerMetric::topSortStrahler(tlp::node n, int &curPref,
 
   for (list<StackEval>::iterator it=tmpEval.begin(); it!=tmpEval.end(); ++it) {
     result.usedStack+=it->usedS;
-    result.stacks=max(result.stacks,it->freeS+it->usedS);
+    result.stacks=std::max(result.stacks,it->freeS+it->usedS);
     result.stacks-=it->usedS;
   }
 
@@ -200,7 +187,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF( "values", "true, false" ) \
   HTML_HELP_DEF( "default", "false" ) \
   HTML_HELP_BODY() \
-  "If true, for each node the strahler number will be computed from a spanning tree having that node as root: complexity o(n^2). If false the strahler number will be computed from a spanning tree having the heuristicly estimated graph center as root." \
+  "If true, for each node the Strahler number is computed from a spanning tree having that node as root: complexity o(n^2). If false the Strahler number is computed from a spanning tree having the heuristicly estimated graph center as root." \
   HTML_HELP_CLOSE(),
   //Orientation
   HTML_HELP_OPEN()         \
@@ -208,7 +195,7 @@ const char * paramHelp[] = {
   HTML_HELP_DEF("Values", "all <BR> ramification<BR> nested cycles") \
   HTML_HELP_DEF( "default", "all" )  \
   HTML_HELP_BODY() \
-  "This parameter enables to choose the type of computation"  \
+  "Type of computation"  \
   HTML_HELP_CLOSE()
 };
 }
@@ -218,9 +205,9 @@ const char * paramHelp[] = {
 #define REGISTERS 1
 #define STACKS 2
 //==============================================================================
-StrahlerMetric::StrahlerMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context) {
-  addParameter<bool>("All nodes", paramHelp[0], "false");
-  addParameter<StringCollection>(COMPUTATION_TYPE, paramHelp[1], COMPUTATION_TYPES);
+StrahlerMetric::StrahlerMetric(const tlp::PluginContext* context):DoubleAlgorithm(context), allNodes(false) {
+  addInParameter<bool>("All nodes", paramHelp[0], "false");
+  addInParameter<StringCollection>(COMPUTATION_TYPE, paramHelp[1], COMPUTATION_TYPES);
 }
 //==============================================================================
 bool StrahlerMetric::run() {
@@ -228,7 +215,7 @@ bool StrahlerMetric::run() {
   StringCollection computationTypes(COMPUTATION_TYPES);
   computationTypes.setCurrent(0);
 
-  if (dataSet!=0) {
+  if (dataSet!=NULL) {
     dataSet->get("All nodes", allNodes);
     dataSet->get(COMPUTATION_TYPE, computationTypes);
   }
@@ -266,16 +253,16 @@ bool StrahlerMetric::run() {
 
       switch(computationTypes.getCurrent()) {
       case ALL:
-        doubleResult->setNodeValue(itn,sqrt((double)cachedValues[itn].strahler*(double)cachedValues[itn].strahler
-                                            +(double)cachedValues[itn].stacks*(double)cachedValues[itn].stacks));
+        result->setNodeValue(itn,sqrt((double)cachedValues[itn].strahler*(double)cachedValues[itn].strahler
+                                      +(double)cachedValues[itn].stacks*(double)cachedValues[itn].stacks));
         break;
 
       case REGISTERS:
-        doubleResult->setNodeValue(itn, (double)cachedValues[itn].strahler);
+        result->setNodeValue(itn, (double)cachedValues[itn].strahler);
         break;
 
       case STACKS:
-        doubleResult->setNodeValue(itn, (double)cachedValues[itn].stacks);
+        result->setNodeValue(itn, (double)cachedValues[itn].stacks);
       }
 
       visited.clear();
@@ -297,16 +284,16 @@ bool StrahlerMetric::run() {
 
       switch(computationTypes.getCurrent()) {
       case ALL:
-        doubleResult->setNodeValue(itn,sqrt((double)cachedValues[itn].strahler*(double)cachedValues[itn].strahler
-                                            +(double)cachedValues[itn].stacks*(double)cachedValues[itn].stacks));
+        result->setNodeValue(itn,sqrt((double)cachedValues[itn].strahler*(double)cachedValues[itn].strahler
+                                      +(double)cachedValues[itn].stacks*(double)cachedValues[itn].stacks));
         break;
 
       case REGISTERS:
-        doubleResult->setNodeValue(itn, (double)cachedValues[itn].strahler);
+        result->setNodeValue(itn, (double)cachedValues[itn].strahler);
         break;
 
       case STACKS:
-        doubleResult->setNodeValue(itn, (double)cachedValues[itn].stacks);
+        result->setNodeValue(itn, (double)cachedValues[itn].stacks);
       }
     }
 
@@ -315,8 +302,3 @@ bool StrahlerMetric::run() {
 
   return pluginProgress->state()!=TLP_CANCEL;
 }
-
-bool StrahlerMetric::check(std::string &erreurMsg) {
-  erreurMsg="";
-  return true;
-}
