@@ -20,7 +20,7 @@
 #define _STRAHLERGRAPH2METRIC_H
 
 #include <tulip/tuliphash.h>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 struct Strahler {
   Strahler(int stra=1,int sta=0,int used=0):strahler(stra),stacks(sta),usedStack(used) {}
   int strahler;
@@ -29,9 +29,9 @@ struct Strahler {
 };
 
 /** \addtogroup metric */
-/*@{*/
-/** This plugin is an implementation of the Strahler Parameter.
- *  algorithm first published as:
+
+/** This plugin is an implementation of the Strahler numbers computation,
+ *  first published as:
  *
  *  A.N. Strahler, \n
  *  "Hypsomic analysis of erosional topography",\n
@@ -50,15 +50,15 @@ struct Strahler {
  *  the algorithm automatically choose the nodes with higher outdegree as
  *  starting nodes.
  *
- *  The algorithm use the (bool)"viewSelection" property to determine
+ *  The algorithm use the "viewSelection" boolean property to determine
  *  the starting nodes.
  *
  */
 class StrahlerMetric:public tlp::DoubleAlgorithm {
 public:
-  StrahlerMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Strahler","David Auber","06/04/2000","Computes the Strahler numbers.","1.0","Graph")
+  StrahlerMetric(const tlp::PluginContext* context);
   bool run();
-  bool check(std::string &);
 
 private:
   Strahler topSortStrahler(tlp::node n,int &curPref,
@@ -69,7 +69,7 @@ private:
                            TLP_HASH_MAP<tlp::node,Strahler> &cachedValues);
   bool allNodes;
 };
-/*@}*/
+
 #endif
 
 
