@@ -18,12 +18,12 @@
  */
 #include "StrengthMetric.h"
 
-DOUBLEPLUGINOFGROUP(StrengthMetric,"Strength","David Auber","26/02/2003","Alpha","1.0","Graph");
+PLUGIN(StrengthMetric)
 
 using namespace std;
 using namespace tlp;
 
-StrengthMetric::StrengthMetric(const tlp::PropertyContext &context):DoubleAlgorithm(context) {}
+StrengthMetric::StrengthMetric(const tlp::PluginContext* context):DoubleAlgorithm(context) {}
 
 StrengthMetric::~StrengthMetric() {}
 //=============================================================
@@ -76,7 +76,7 @@ double StrengthMetric::e(const TLP_HASH_SET<tlp::node> &U) {
 }
 //=============================================================
 double StrengthMetric::s(TLP_HASH_SET<tlp::node> &U, TLP_HASH_SET<tlp::node> &V) {
-  if ((U.size()==0) || (V.size()==0)) return 0;
+  if ((U.empty()) || (V.empty())) return 0;
 
   return (e(U,V) / double(U.size()*V.size()));
 }
@@ -88,8 +88,9 @@ double StrengthMetric::s(const TLP_HASH_SET<tlp::node> &U) {
 }
 //=============================================================
 double StrengthMetric::getEdgeValue(const tlp::edge ee ) {
-  node u=graph->source(ee);
-  node v=graph->target(ee);
+  const std::pair<node, node>& eEnds = graph->ends(ee);
+  node u = eEnds.first;
+  node v = eEnds.second;
   TLP_HASH_SET<node> Nu,Nv,Wuv;
 
   //Compute Nu
@@ -103,7 +104,7 @@ double StrengthMetric::getEdgeValue(const tlp::edge ee ) {
 
   delete itN;
 
-  if (Nu.size()==0) return 0;
+  if (Nu.empty()) return 0;
 
   //Compute Nv
   itN=graph->getInOutNodes(v);
@@ -116,7 +117,7 @@ double StrengthMetric::getEdgeValue(const tlp::edge ee ) {
 
   delete itN;
 
-  if (Nv.size()==0) return 0;
+  if (Nv.empty()) return 0;
 
   //Compute Wuv, choose the minimum set to minimize operation
   TLP_HASH_SET<node> *A, *B;
@@ -169,19 +170,19 @@ double StrengthMetric::getEdgeValue(const tlp::edge ee ) {
 }
 //=============================================================
 double StrengthMetric::getNodeValue(const tlp::node n ) {
-  //  cerr << __PRETTY_FUNCTION__ << endl;
+  //  tlp::warning() << __PRETTY_FUNCTION__ << endl;
   if (graph->deg(n)==0) return 0;
 
-  double result=0;
+  double res=0;
   Iterator<edge> *itE = graph->getInOutEdges(n);
 
   while (itE->hasNext()) {
     edge ite = itE->next();
-    result += doubleResult->getEdgeValue(ite);
+    res += result->getEdgeValue(ite);
   }
 
   delete itE;
-  return result/double(graph->deg(n));
+  return res/double(graph->deg(n));
 }
 //=============================================================
 bool StrengthMetric::run() {
@@ -197,7 +198,7 @@ bool StrengthMetric::run() {
   }
 
   forEach(e, graph->getEdges()) {
-    doubleResult->setEdgeValue(e, getEdgeValue(e));
+    result->setEdgeValue(e, getEdgeValue(e));
 
     if (pluginProgress && ((++steps % (maxSteps / 10)) == 0)) {
       pluginProgress->progress(++steps, maxSteps);
@@ -215,7 +216,7 @@ bool StrengthMetric::run() {
 
   pluginProgress->setComment("Computing Strength metric on nodes...");
   forEach(n, graph->getNodes()) {
-    doubleResult->setNodeValue(n, getNodeValue(n));
+    result->setNodeValue(n, getNodeValue(n));
 
     if (pluginProgress && ((++steps % (maxSteps / 10)) == 0)) {
       pluginProgress->progress(++steps, maxSteps);
