@@ -19,12 +19,11 @@
 #ifndef _STRENGTHMETRIC_H
 #define _STRENGTHMETRIC_H
 #include <tulip/tuliphash.h>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup metric */
-/*@{*/
-/** This plugin is an implementation of the Strength Parameter.
- *  algorithm first published in :
+
+/** This plugin computes the Strength metric described in :
  *
  *  Y. Chiricota. F.Jourdan, and G.Melancon\n
  *  "Software component capture using graph clustering", \n
@@ -34,7 +33,8 @@
  */
 class StrengthMetric:public tlp::DoubleAlgorithm {
 public:
-  StrengthMetric(const tlp::PropertyContext &);
+  PLUGININFORMATION("Strength","David Auber","26/02/2003","Computes the Strength metric described in\nY. Chiricota. F.Jourdan, an G.Melancon\n'Software component capture using graph clustering',\nIWPC 2002","1.0","Graph")
+  StrengthMetric(const tlp::PluginContext* context);
   ~StrengthMetric();
   double getNodeValue(const tlp::node n);
   double getEdgeValue(const tlp::edge n);
@@ -45,5 +45,5 @@ private:
   double s(TLP_HASH_SET<tlp::node> &U, TLP_HASH_SET<tlp::node> &V);
   double s(const TLP_HASH_SET<tlp::node> &U);
 };
-/*@}*/
+
 #endif
