@@ -20,7 +20,7 @@
 #include "StrongComponent.h"
 #include <tulip/DoubleProperty.h>
 
-DOUBLEPLUGINOFGROUP(StrongComponent,"Strongly Connected Component","David Auber","12/06/2001","Alpha","1.0","Component");
+PLUGIN(StrongComponent)
 
 using namespace std;
 using namespace tlp;
@@ -40,7 +40,7 @@ int StrongComponent::attachNumerotation(tlp::node n,
   id++;
   minAttach[n]=myId;
   renum.push(n);
-  int result=myId;
+  int res=myId;
   Iterator<node> *itN=graph->getOutNodes(n);
 
   for (; itN->hasNext();) {
@@ -49,32 +49,32 @@ int StrongComponent::attachNumerotation(tlp::node n,
     if (!finished[tmpN]) {
       int tmp=attachNumerotation(tmpN,visited,finished,minAttach,id,renum,curComponent);
 
-      if (result>tmp) result=tmp;
+      if (res>tmp) res=tmp;
     }
   }
 
   delete itN;
-  minAttach[n]=result;
+  minAttach[n]=res;
 
-  if (result==myId) {
+  if (res==myId) {
     while (renum.top()!=n) {
       node tmp=renum.top();
       renum.pop();
       finished[tmp]=true;
-      minAttach[tmp]=result;
-      doubleResult->setNodeValue(tmp,curComponent);
+      minAttach[tmp]=res;
+      result->setNodeValue(tmp,curComponent);
     }
 
     finished[n]=true;
-    doubleResult->setNodeValue(n,curComponent);
+    result->setNodeValue(n,curComponent);
     curComponent++;
     renum.pop();
   }
 
-  return result;
+  return res;
 }
 
-StrongComponent::StrongComponent(const tlp::PropertyContext &context):DoubleAlgorithm(context) {}
+StrongComponent::StrongComponent(const tlp::PluginContext* context):DoubleAlgorithm(context) {}
 
 StrongComponent::~StrongComponent() {}
 
@@ -102,13 +102,12 @@ bool StrongComponent::run() {
 
   while (itE->hasNext()) {
     edge ite=itE->next();
-    node source= graph->source(ite);
-    node target= graph->target(ite);
+    const std::pair<node, node>& eEnds = graph->ends(ite);
 
-    if (doubleResult->getNodeValue(source)==doubleResult->getNodeValue(target))
-      doubleResult->setEdgeValue(ite,doubleResult->getNodeValue(source));
+    if (result->getNodeValue(eEnds.first)==result->getNodeValue(eEnds.second))
+      result->setEdgeValue(ite,result->getNodeValue(eEnds.first));
     else
-      doubleResult->setEdgeValue(ite,curComponent);
+      result->setEdgeValue(ite,curComponent);
   }
 
   delete itE;
@@ -116,11 +115,3 @@ bool StrongComponent::run() {
 
   return true;
 }
-
-bool StrongComponent::check(std::string &erreurMsg) {
-  erreurMsg="";
-  return true;
-}
-
-void StrongComponent::reset() {
-}
