@@ -21,14 +21,14 @@
 #define _StrongComponent_H
 #include <stack>
 #include <tulip/tuliphash.h>
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 struct NodeInfo {
   NodeInfo(int stra=0,int sta=0):prefixOrder(stra),minAttach(sta) {}
   int prefixOrder;
   int minAttach;
 };
 
-/** This plugin is an implementation of the Stongly connected algorithm.
+/** This plugin is an implementation of a strongly connected components decomposition.
  *
  *  \note This algorithm assigns to each node a value defined as following : If two nodes are in the same
  *  strongly connected component they have the same value else they have a
@@ -37,11 +37,10 @@ struct NodeInfo {
  */
 class StrongComponent:public tlp::DoubleAlgorithm {
 public:
-  StrongComponent(const tlp::PropertyContext &);
+  PLUGININFORMATION("Strongly Connected Component","David Auber","12/06/2001","Implements a strongly connected components decomposition.","1.0","Component")
+  StrongComponent(const tlp::PluginContext* context);
   ~StrongComponent();
   bool run();
-  bool check(std::string &);
-  void reset();
 
 private:
   int  attachNumerotation(tlp::node, TLP_HASH_MAP<tlp::node,bool> &,
