@@ -21,7 +21,7 @@
 
 using namespace tlp;
 
-BOOLEANPLUGIN(InducedSubGraphSelection,"Induced Sub-Graph","David Auber","08/08/2001","Alpha","1.0");
+PLUGIN(InducedSubGraphSelection)
 
 //=================================================================================
 namespace {
@@ -30,25 +30,25 @@ const char * paramHelp[] = {
   HTML_HELP_OPEN() \
   HTML_HELP_DEF( "type", "Selection" ) \
   HTML_HELP_BODY() \
-  "This selection defines the original set of nodes used to extend the current selection to the induced sub-graph." \
+  "Set of nodes for which the induced sub-graph is computed." \
   HTML_HELP_CLOSE(),
 };
 }
 //=================================================================================
-InducedSubGraphSelection::InducedSubGraphSelection(const tlp::PropertyContext &context):
+InducedSubGraphSelection::InducedSubGraphSelection(const tlp::PluginContext* context):
   BooleanAlgorithm(context) {
-  addParameter<BooleanProperty>("Nodes", paramHelp[0], "viewSelection");
+  addInParameter<BooleanProperty>("Nodes", paramHelp[0], "viewSelection");
 }
 //=================================================================================
 bool InducedSubGraphSelection::run() {
-  booleanResult->setAllNodeValue(false);
-  booleanResult->setAllEdgeValue(false);
-  BooleanProperty *entrySelection = 0;
+  result->setAllNodeValue(false);
+  result->setAllEdgeValue(false);
+  BooleanProperty *entrySelection = NULL;
 
-  if (dataSet!=0)
+  if (dataSet!=NULL)
     dataSet->get("Nodes", entrySelection);
 
-  if (entrySelection == 0)
+  if (entrySelection == NULL)
     entrySelection = graph->getProperty<BooleanProperty>("viewSelection");
 
   Iterator<node> *itN = graph->getNodes();
@@ -57,7 +57,7 @@ bool InducedSubGraphSelection::run() {
     node itn=itN->next() ;
 
     if (entrySelection->getNodeValue(itn)) {
-      booleanResult->setNodeValue(itn, true);
+      result->setNodeValue(itn, true);
       Iterator<edge> *itE = graph->getOutEdges(itn);
 
       while (itE->hasNext()) {
@@ -65,7 +65,7 @@ bool InducedSubGraphSelection::run() {
         node target = graph->target(e);
 
         if (entrySelection->getNodeValue(target))
-          booleanResult->setEdgeValue(e, true);
+          result->setEdgeValue(e, true);
       }
 
       delete itE;
