@@ -19,10 +19,10 @@
 #ifndef Tulip_InducedSubGraphSelection_H
 #define Tulip_InducedSubGraphSelection_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup selection */
-/*@{*/
+
 /// This selection plugins enables to find a subgraph induced by a set of nodes.
 /**
  * Let V' a subset of nodes, G' is an induced subgraph of G if all edges
@@ -34,10 +34,11 @@
  */
 class InducedSubGraphSelection:public tlp::BooleanAlgorithm {
 public:
-  InducedSubGraphSelection(const tlp::PropertyContext& context);
+  PLUGININFORMATION("Induced Sub-Graph","David Auber","08/08/2001","Alpha","1.0", "Selection")
+  InducedSubGraphSelection(const tlp::PluginContext* context);
   bool run();
 };
-/*@}*/
+
 #endif
 
 
