@@ -18,7 +18,7 @@
  */
 #include "Kruskal.h"
 
-BOOLEANPLUGIN(Kruskal,"Kruskal","Anthony DON","14/04/03","Alpha","1.0");
+PLUGIN(Kruskal)
 
 using namespace std;
 using namespace tlp;
@@ -26,16 +26,16 @@ using namespace tlp;
 namespace {
 const char * paramHelp[] = {
   HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "DoubleProperty" ) \
+  HTML_HELP_DEF( "type", "NumericProperty" ) \
   HTML_HELP_DEF( "default", "\"viewMetric\"" ) \
   HTML_HELP_BODY() \
-  "This parameter defines the metric used for edges weight." \
+  "Metric containing the edges weights." \
   HTML_HELP_CLOSE(),
 };
 }
 //======================================================
-Kruskal::Kruskal(const tlp::PropertyContext &context):BooleanAlgorithm(context) {
-  addParameter<DoubleProperty> ("edge weight", paramHelp[0], "viewMetric");
+Kruskal::Kruskal(const tlp::PluginContext* context):BooleanAlgorithm(context) {
+  addInParameter<NumericProperty*> ("edge weight", paramHelp[0], "viewMetric");
 }
 //======================================================
 Kruskal::~Kruskal() {
@@ -48,7 +48,7 @@ bool Kruskal::check(std::string &erreurMsg) {
     return true;
   }
   else {
-    erreurMsg = "The Graph must be connected";
+    erreurMsg = "The graph must be connected.";
     return false;
   }
 }
@@ -56,16 +56,16 @@ bool Kruskal::check(std::string &erreurMsg) {
 /// Compute the Minimum Spanning Tree
 bool Kruskal::run() {
   /* Initialisation */
-  DoubleProperty *edgeWeight = 0;
+  NumericProperty *edgeWeight = NULL;
 
-  if ( dataSet!=0) {
+  if ( dataSet!=NULL) {
     dataSet->get("edge weight", edgeWeight);
   }
 
-  if (edgeWeight == 0)
+  if (edgeWeight == NULL)
     edgeWeight = graph->getProperty<DoubleProperty>("viewMetric");
 
-  selectMinimumSpanningTree(graph, booleanResult, edgeWeight, pluginProgress);
+  selectMinimumSpanningTree(graph, result, edgeWeight, pluginProgress);
 
   return true;
 }
