@@ -19,10 +19,10 @@
 #ifndef _KRUSKAL_H
 #define _KRUSKAL_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup selection */
-/*@{*/
+
 
 /// This selection plugins implements the so called Kruskal algorithm. This algorithm enables to find a minimum spanning tree in a connected graph.
 /**
@@ -39,10 +39,11 @@
 class Kruskal:public tlp::BooleanAlgorithm {
 
 public:
-  Kruskal(const tlp::PropertyContext& context);
+  PLUGININFORMATION("Kruskal","Anthony DON","14/04/03","Alpha","1.0", "Selection")
+  Kruskal(const tlp::PluginContext* context);
   ~Kruskal();
   bool run();
   bool check(std::string &);
 };
-/*@}*/
+
 #endif
