@@ -16,22 +16,22 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <assert.h>
 #include "LoopSelection.h"
 
-BOOLEANPLUGIN(LoopSelection,"Loop Selection","David Auber","20/01/2003","Alpha","1.0");
+PLUGIN(LoopSelection)
 
 using namespace std;
 using namespace tlp;
 
-LoopSelection::LoopSelection(const tlp::PropertyContext &context):BooleanAlgorithm(context) {}
+LoopSelection::LoopSelection(const tlp::PluginContext* context):BooleanAlgorithm(context) {}
 //============================================
 bool LoopSelection::run() {
-  booleanResult->setAllNodeValue(false);
+  result->setAllNodeValue(false);
   edge e;
-  forEach(e, graph->getEdges())
-  booleanResult->setEdgeValue(e,
-                              graph->source(e)==graph->target(e));
+  forEach(e, graph->getEdges()) {
+    const std::pair<node, node>& eEnds = graph->ends(e);
+    result->setEdgeValue(e, eEnds.first == eEnds.second);
+  }
   return true;
 }
 //============================================
