@@ -19,10 +19,10 @@
 #ifndef Tulip_LoopSelection_H
 #define Tulip_LoopSelection_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup selection */
-/*@{*/
+
 
 /**
  * This selection plugins enables to find loops in a graph
@@ -33,10 +33,11 @@
  */
 class LoopSelection:public tlp::BooleanAlgorithm {
 public:
-  LoopSelection(const tlp::PropertyContext &);
+  PLUGININFORMATION("Loop Selection","David Auber","20/01/2003","Alpha","1.0", "Selection")
+  LoopSelection(const tlp::PluginContext* context);
   bool run();
 };
-/*@}*/
+
 #endif
 
 
