@@ -16,27 +16,26 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <assert.h>
 #include "MultipleEdgeSelection.h"
 #include <tulip/BooleanProperty.h>
 #include <tulip/SimpleTest.h>
 
-BOOLEANPLUGIN(MultipleEdgeSelection,"Multiple Edge","David Auber","20/01/2003","Alpha","1.0");
+PLUGIN(MultipleEdgeSelection)
 
 using namespace std;
 using namespace tlp;
 
-MultipleEdgeSelection::MultipleEdgeSelection(const tlp::PropertyContext &context):BooleanAlgorithm(context) {}
+MultipleEdgeSelection::MultipleEdgeSelection(const tlp::PluginContext* context):BooleanAlgorithm(context) {}
 
 bool MultipleEdgeSelection::run() {
   vector<edge> multipleEdges;
   SimpleTest::simpleTest(graph, &multipleEdges);
-  booleanResult->setAllNodeValue(false);
-  booleanResult->setAllEdgeValue(false);
+  result->setAllNodeValue(false);
+  result->setAllEdgeValue(false);
   vector<edge>::const_iterator it;
 
   for (it = multipleEdges.begin(); it != multipleEdges.end(); ++it)
-    booleanResult->setEdgeValue(*it, true);
+    result->setEdgeValue(*it, true);
 
   return true;
 }
