@@ -19,9 +19,9 @@
 #ifndef Tulip_ParaSelection_H
 #define Tulip_ParaSelection_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 /** \addtogroup selection */
-/*@{*/
+
 
 /**
  * This selection plugins enables to find the multiple-edges and parallel-edges in a graph.
@@ -34,10 +34,11 @@
  */
 class MultipleEdgeSelection:public tlp::BooleanAlgorithm {
 public:
-  MultipleEdgeSelection(const tlp::PropertyContext &);
+  PLUGININFORMATION("Multiple Edge","David Auber","20/01/2003","Alpha","1.0", "Selection")
+  MultipleEdgeSelection(const tlp::PluginContext* context);
   bool run();
 };
-/*@}*/
+
 #endif
 
 
