@@ -16,24 +16,27 @@
  * See the GNU General Public License for more details.
  *
  */
+
 #include "ReachableSubGraphSelection.h"
 
+#include <tulip/StringCollection.h>
+
 using namespace tlp;
 
-BOOLEANPLUGIN(ReachableSubGraphSelection,"Reachable Sub-Graph","David Auber","01/12/1999","Alpha","1.0");
+PLUGIN(ReachableSubGraphSelection)
 
 namespace {
 const char * paramHelp[] = {
   // direction
   HTML_HELP_OPEN() \
-  HTML_HELP_DEF( "type", "int" ) \
-  HTML_HELP_DEF( "values", "{0,1,2}" ) \
-  HTML_HELP_DEF( "default", "0" ) \
+  HTML_HELP_DEF( "type", "StringCollection" ) \
+  HTML_HELP_DEF( "values", "{output edges, input edges, all edges}" ) \
+  HTML_HELP_DEF( "default", "output edges" ) \
   HTML_HELP_BODY() \
   "This parameter defines the navigation direction. Following values are corrects :" \
-  "<ul><li>0: follow ouput edges (directed);</li>" \
-  "<li>1: follow input edges (reverse-directed);</li>" \
-  "<li>2: all edges (undirected).</li></ul>" \
+  "<ul><li>output edges: follow ouput edges (directed);</li>" \
+  "<li>input edges: follow input edges (reverse-directed);</li>" \
+  "<li>all edges: all edges (undirected).</li></ul>" \
   HTML_HELP_CLOSE(),
 
   // startingNodes
@@ -53,13 +56,20 @@ const char * paramHelp[] = {
   "This parameter defines the maximal distance of reachable nodes." \
   HTML_HELP_CLOSE(),
 };
+
+std::string edgesDirectionLabels[] = {
+  "output edges",
+  "input edges",
+  "all edges",
+};
 }
 
 
-ReachableSubGraphSelection::ReachableSubGraphSelection(const tlp::PropertyContext &context):BooleanAlgorithm(context) {
-  addParameter<int> ("direction",paramHelp[0],"0");
-  addParameter<BooleanProperty> ("startingnodes",paramHelp[1],"viewSelection");
-  addParameter<int> ("distance",paramHelp[2],"5");
+
+ReachableSubGraphSelection::ReachableSubGraphSelection(const tlp::PluginContext *context):BooleanAlgorithm(context) {
+  addInParameter<StringCollection> ("edges direction",paramHelp[0],"output edges;input edges;all edges");
+  addInParameter<BooleanProperty> ("startingnodes",paramHelp[1],"viewSelection");
+  addInParameter<int> ("distance",paramHelp[2],"5");
 }
 
 ReachableSubGraphSelection::~ReachableSubGraphSelection() {}
@@ -67,17 +77,50 @@ ReachableSubGraphSelection::~ReachableSubGraphSelection() {}
 ///===========================================================
 bool ReachableSubGraphSelection::run() {
   unsigned int maxDistance = 5;
-  unsigned int direction = 0;
+  StringCollection edgeDirectionCollecion;
+  EDGE_TYPE edgeDirection=DIRECTED;
   BooleanProperty * startNodes=graph->getProperty<BooleanProperty>("viewSelection");
 
-  if ( dataSet!=0) {
+  if ( dataSet!=NULL) {
     dataSet->get("distance", maxDistance);
-    dataSet->get("direction", direction);
+
+    //Get the edge orientation
+    if(dataSet->get("edges direction",edgeDirectionCollecion)) {
+      if(edgeDirectionCollecion.getCurrentString() == edgesDirectionLabels[0]) {
+        edgeDirection = DIRECTED;
+      }
+      else if(edgeDirectionCollecion.getCurrentString()== edgesDirectionLabels[1]) {
+        edgeDirection = INV_DIRECTED;
+      }
+      else if(edgeDirectionCollecion.getCurrentString()== edgesDirectionLabels[2]) {
+        edgeDirection = UNDIRECTED;
+      }
+    }
+    else {
+      //If the new parameter is not defined search for the old one.
+      int direction=0;
+
+      if(dataSet->get("direction",direction)) {
+        switch(direction) {
+        case 0:
+          edgeDirection = DIRECTED;
+          break;
+
+        case 1:
+          edgeDirection = INV_DIRECTED;
+          break;
+
+        case 2:
+          edgeDirection = UNDIRECTED;
+        }
+      }
+    }
+
     dataSet->get("startingnodes", startNodes);
   }
 
-  booleanResult->setAllEdgeValue(false);
-  booleanResult->setAllNodeValue(false);
+  result->setAllEdgeValue(false);
+  result->setAllNodeValue(false);
 
   if (startNodes) {
     Iterator<node>* itN = startNodes->getNodesEqualTo(true);
@@ -88,7 +131,7 @@ bool ReachableSubGraphSelection::run() {
       node current = itN->next();
       reachables.insert(current);
       reachableNodes(graph, current, reachables, maxDistance,
-                     (EDGE_TYPE) direction);
+                     edgeDirection);
     }
 
     delete itN;
@@ -98,7 +141,7 @@ bool ReachableSubGraphSelection::run() {
 
     // select nodes
     while (itr != ite) {
-      booleanResult->setNodeValue((*itr), true);
+      result->setNodeValue((*itr), true);
       ++itr;
     }
 
@@ -109,9 +152,9 @@ bool ReachableSubGraphSelection::run() {
       edge e = itE->next();
       const std::pair<node, node>& ends = graph->ends(e);
 
-      if (booleanResult->getNodeValue(ends.first) &&
-          booleanResult->getNodeValue(ends.second))
-        booleanResult->setEdgeValue(e, true);
+      if (result->getNodeValue(ends.first) &&
+          result->getNodeValue(ends.second))
+        result->setEdgeValue(e, true);
     }
 
     delete itE;
