@@ -16,29 +16,27 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <cassert>
-
 #include <tulip/BooleanProperty.h>
 #include <tulip/AcyclicTest.h>
 
 #include "SpanningDagSelection.h"
 
-BOOLEANPLUGIN(SpanningDagSelection,"Spanning Dag","David Auber","01/12/1999","Alpha","1.0");
+PLUGIN(SpanningDagSelection)
 
 using namespace std;
 using namespace tlp;
 
 //=================================================================
-SpanningDagSelection::SpanningDagSelection(const tlp::PropertyContext &context):BooleanAlgorithm(context) {}
+SpanningDagSelection::SpanningDagSelection(const tlp::PluginContext* context):BooleanAlgorithm(context) {}
 //=================================================================
 bool SpanningDagSelection::run() {
-  booleanResult->setAllNodeValue(true);
-  booleanResult->setAllEdgeValue(true);
+  result->setAllNodeValue(true);
+  result->setAllEdgeValue(true);
   vector<edge> obstructions;
   AcyclicTest::acyclicTest(graph, &obstructions);
 
   for (vector<edge>::const_iterator it = obstructions.begin(); it != obstructions.end(); ++it) {
-    booleanResult->setEdgeValue(*it, false);
+    result->setEdgeValue(*it, false);
   }
 
   return true;
