@@ -19,13 +19,13 @@
 #ifndef Tulip_SpanningDagSelection_H
 #define Tulip_SpanningDagSelection_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 template<typename T>
 class MutableConatainer;
 
 /** \addtogroup selection */
-/*@{*/
+
 
 /**
  * This selection plugins enables to find a subgraph of G that is acyclic.
@@ -36,8 +36,9 @@ class MutableConatainer;
 class SpanningDagSelection:public tlp::BooleanAlgorithm {
 
 public:
-  SpanningDagSelection(const tlp::PropertyContext &);
+  PLUGININFORMATION("Spanning Dag","David Auber","01/12/1999","Alpha","1.0", "Selection")
+  SpanningDagSelection(const tlp::PluginContext* context);
   bool run();
 };
-/*@}*/
+
 #endif
