@@ -19,10 +19,10 @@
 #ifndef Tulip_SPANNINGTREESELECTION_H
 #define Tulip_SPANNINGTREESELECTION_H
 
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 
 /** \addtogroup selection */
-/*@{*/
+
 
 /**
  * This selection plugins enables to find a subgraph of G that is a forest (a set of trees).
@@ -32,9 +32,10 @@
  */
 class SpanningTreeSelection:public tlp::BooleanAlgorithm {
 public:
-  SpanningTreeSelection(const tlp::PropertyContext &);
+  PLUGININFORMATION("Spanning Forest","David Auber","01/12/1999","Alpha","1.0", "Selection")
+  SpanningTreeSelection(const tlp::PluginContext* context);
   ~SpanningTreeSelection();
   bool run();
 };
-/*@}*/
+
 #endif
