@@ -16,13 +16,13 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <tulip/TulipPlugin.h>
+#include <tulip/TulipPluginHeaders.h>
 #include <cmath>
 
 using namespace tlp;
 
 /** \addtogroup size */
-/*@{*/
+
 /// AutoSize.cpp - Compute size in order to prevent node-node overlapping
 /**
  * This plug-ins compute size of nodes and edges such that, node-node overlapping do not exists (if it is possible).
@@ -32,19 +32,19 @@ using namespace tlp;
  */
 class AutoSize:public SizeAlgorithm {
 public:
-  AutoSize(const PropertyContext &context):SizeAlgorithm(context) {}
+  PLUGININFORMATION("Auto Sizing","Auber","04/05/2001","","1.0", "Size")
+  AutoSize(const tlp::PluginContext* context):SizeAlgorithm(context) {}
 
   bool run() {
     node n;
     forEach(n,graph->getNodes())
-    sizeResult->setNodeValue(n, getNodeValue(n));
+    result->setNodeValue(n, getNodeValue(n));
     edge e;
     forEach(e,graph->getEdges())
-    sizeResult->setEdgeValue(e, getEdgeValue(e));
+    result->setEdgeValue(e, getEdgeValue(e));
     return true;
   }
 
-
 private:
   Size getNodeValue(const node n) {
     LayoutProperty *entryLayout=graph->getProperty<LayoutProperty>("viewLayout");
@@ -86,12 +86,12 @@ private:
     }
 
     delete itN;
-    return Size(static_cast<float>(dist/2),static_cast<float>(dist/2),static_cast<float>(dist/2));
+    return Size(dist/2,dist/2,dist/2);
   }
 
   Size getEdgeValue(const edge e) {
-    Size s = sizeResult->getNodeValue(graph->source(e));
-    Size t = sizeResult->getNodeValue(graph->target(e));
+    Size s = result->getNodeValue(graph->source(e));
+    Size t = result->getNodeValue(graph->target(e));
     Coord tmp(s.getW(),s.getH(),s.getD());
     Coord tmp2(t.getW(),t.getH(),t.getD());
     float sizes=tmp.norm();
@@ -100,5 +100,5 @@ private:
   }
 
 };
-/*@}*/
-SIZEPLUGIN(AutoSize,"Auto Sizing","Auber","04/05/2001","","1.0")
+
+PLUGIN(AutoSize)
