@@ -20,6 +20,8 @@
 #ifndef CRASHHANDLING_H_
 #define CRASHHANDLING_H_
 
+#include <string>
+
 #define TLP_PLATEFORM_HEADER "TLP_PLATEFORM"
 #define TLP_ARCH_HEADER "TLP_ARCH"
 #define TLP_COMPILER_HEADER "TLP_COMPILER"
@@ -28,6 +30,8 @@
 #define TLP_STACK_BEGIN_HEADER "TLP_STACK_BEGIN"
 #define TLP_STACK_END_HEADER "TLP_STACK_END"
 
+extern void setDumpPath(std::string);
+
 extern void start_crash_handler();
 
 #endif /* CRASHHANDLING_H_ */
