@@ -16,18 +16,24 @@
  * See the GNU General Public License for more details.
  *
  */
-
 #include "ImageWriter.h"
-#include "PNGWriter.h"
-#include "JPEGWriter.h"
-
+#ifdef HAVE_LIBPNG
+#  include "PNGWriter.h"
+#endif
+#ifdef HAVE_LIBJPEG
+#  include "JPEGWriter.h"
+#endif
 
 using namespace std;
 
 namespace tlprender {
 const string SUPPORTED_IMAGE_FORMATS[] = {
+#ifdef HAVE_LIBPNG
   "png",
+#endif
+#ifdef HAVE_LIBJPEG
   "jpeg",
+#endif
   ""
 };
 
@@ -40,11 +46,18 @@ ImageWriter::ImageWriter(const GLubyte *imagebuffer, const int width, const int
 {}
 
 ImageWriter *ImageWriter::getImageWriter(string &type, const GLubyte *buffer, const int width, const int height) {
+#ifdef HAVE_LIBPNG
+
   if (type=="png") return new tlprender::PNGWriter(buffer, width, height);
-  else if (type=="jpeg") return new tlprender::JPEGWriter(buffer, width, height);
-  else {
-    return NULL;
-  }
+  else
+#endif
+#ifdef HAVE_LIBJPEG
+    if (type=="jpeg") return new tlprender::JPEGWriter(buffer, width, height);
+    else
+#endif
+    {
+      return NULL;
+    }
 }
 
 void ImageWriter::setTitle(const string &s) {
