@@ -60,13 +60,12 @@ private:
   std::vector<Point> vertices;
   GLfloat avgZ;
 public:
-  unsigned int nodeNum;
   Shape();
   ~Shape();
   bool isValid() const;
   void begin();
   void add(const int x, const int y, const GLfloat z);
-  inline void add(const Point p) {
+  inline void add(const Point& p) {
     vertices.push_back(p);
   }
 
