@@ -16,7 +16,6 @@
  * See the GNU General Public License for more details.
  *
  */
-
 #include <iostream>
 #include <fstream>
 #include <sstream>
@@ -80,7 +79,7 @@ static bool outputMap(true);
 static bool outputHtmlBody(true);
 static bool saveTLP(false);
 static string saveTLPFile;
-static string importPluginName("tlp");
+static string importPluginName("TLP Import");
 static string filename(DEFAULT_FILENAME);
 static string imageFormat(tlprender::SUPPORTED_IMAGE_FORMATS[0]); //default image format
 static tlprender::ImageWriter *imageWriter(NULL);
@@ -204,7 +203,7 @@ void importGraph(const string &filename, const string &importPluginName, GlScene
   DataSet dataSet;
 
   StructDef parameter=
-    ImportModuleFactory::factory->getPluginParameters(importPluginName);
+    ImportModulelISTER::getPluginParameters(importPluginName);
   Iterator<pair<string,string> > *itP=parameter.getField();
 
   for (; itP->hasNext();) {
@@ -223,7 +222,7 @@ void importGraph(const string &filename, const string &importPluginName, GlScene
   Graph *newGraph = tlp::newGraph();
   tlp::importGraph(importPluginName, dataSet, NULL,newGraph);
 
-  if (newGraph!=0) {
+  if (newGraph!=NULL) {
     string sceneData;
     dataSet.get<std::string>("scene", sceneData);
 
@@ -384,11 +383,11 @@ int main (int argc, char **argv) {
     DataSet dataSet;
     ostream *os = new ofstream(saveTLPFile.c_str());
     StructDef parameter =
-      ExportModuleFactory::factory->getPluginParameters("tlp");
+      ExportModuleLister::getPluginParameters("TLP Export");
 
     dataSet.set("displaying", glOffscreen.scene.getGlGraphComposite()->getRenderingParameters().getParameters());
 
-    if (!tlp::exportGraph(glOffscreen.scene.getGlGraphComposite()->getInputData()->getGraph(), *os, "tlp", dataSet, NULL)) {
+    if (!tlp::exportGraph(glOffscreen.scene.getGlGraphComposite()->getInputData()->getGraph(), *os, "TLP Export", dataSet, NULL)) {
       cerr << programName << ": saving graph to \"" << saveTLPFile << "\" failed. Exiting" << endl;
       return EXIT_FAILURE;
     }
@@ -459,15 +458,19 @@ void parseCommandLine(int argc, char **argv) {
 
     case 'f':
       imageFormat = optarg;
+#ifdef HAVE_LIBPNG
 
       if (imageFormat == "png");
-      else if (imageFormat == "jpeg");
       else
-
-      {
-        cerr << "Error: unsupported image format: " << imageFormat << endl;
-        help();
-      }
+#endif
+#ifdef HAVE_LIBJPEG
+        if (imageFormat == "jpeg");
+        else
+#endif
+        {
+          cerr << "Error: unsupported image format: " << imageFormat << endl;
+          help();
+        }
 
       break;
 
