@@ -1,11 +1,11 @@
 /*
- * $Revision: 2027 $
- * 
+ * $Revision: 2564 $
+ *
  * last checkin:
- *   $Author: gutwenger $ 
- *   $Date: 2010-09-01 11:55:17 +0200 (Wed, 01 Sep 2010) $ 
+ *   $Author: gutwenger $
+ *   $Date: 2012-07-07 00:03:48 +0200 (Sa, 07. Jul 2012) $
  ***************************************************************/
- 
+
 /** \file
  * \brief Declaration and implementation of the class PQNode.
  *
@@ -13,45 +13,36 @@
  * class template PQNode is used as an abstract base class for all
  * nodes in a PQ-tree. The derived classes are a class template for
  * Q- and P-nodes internalNodes (PQInternalNode) and a class template
- * PQLeaf for the leaves of the tree.  
- * 
+ * PQLeaf for the leaves of the tree.
+ *
  * \author Sebastian Leipert
- * 
+ *
  * \par License:
  * This file is part of the Open Graph Drawing Framework (OGDF).
  *
- * Copyright (C). All rights reserved.
+ * \par
+ * Copyright (C)<br>
  * See README.txt in the root directory of the OGDF installation for details.
- * 
+ *
  * \par
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
  *
  * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- * 
- * \par
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * \par
- * You should have received a copy of the GNU General Public 
+ * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- * 
+ *
  * \see  http://www.gnu.org/copyleft/gpl.html
  ***************************************************************/
 
@@ -72,23 +63,6 @@
 namespace ogdf {
 
 
-//Status Definitions
-#define EMPTY          1
-#define PARTIAL        2
-#define FULL           3
-#define PERTINENT      4
-#define TO_BE_DELETED  5
-
-//Mark Definitions for Bubble Phase
-#define UNMARKED       0
-#define QUEUED         1
-#define BLOCKED        2
-#define UNBLOCKED      3
-
-enum SibDirection {
-	NODIR, LEFT, RIGHT
-};
-
 template<class T,class X,class Y> class PQTree;
 template<class T,class X,class Y> class PQLeafKey;
 template<class T,class X,class Y> class PQNodeKey;
@@ -98,29 +72,29 @@ template<class T,class X,class Y> class PQInternalKey;
 template<class T,class X,class Y> class PQNode: public PQNodeRoot
 {
 	/**
-	 * All members and member function of PQNode are needed 
+	 * All members and member function of PQNode are needed
 	 * by the class template PQTree. Therefore the class PQTree
 	 * was made friendof PQNode, since this prevents the use of a large
-	 * amount of extra public functions. 
+	 * amount of extra public functions.
 	 */
 	friend class PQTree<T,X,Y>;
 
 public:
 
 	/**
-	 * The (first) constructor combines the node with its information and 
-	 * will automatically set the \a m_nodePointer (see basicKey) of 
+	 * The (first) constructor combines the node with its information and
+	 * will automatically set the \a m_nodePointer (see basicKey) of
 	 * the element of type PQNodeKey.
 	 */
-    PQNode(int count, PQNodeKey<T,X,Y>* infoPtr);
+	PQNode(int count, PQNodeKey<T,X,Y>* infoPtr);
+
 
-	
 	/**
-	 * The (second) constructor is called, 
+	 * The (second) constructor is called,
 	 * if no information is available or neccessary.
 	 */
-    PQNode(int count);
-      
+	PQNode(int count);
+
 	/**
 	 * The destructor does not delete any accompanying information class as PQLeafKey,
 	 * PQNodeKey and PQInternalKey.	This has been avoided, since applications may
@@ -137,30 +111,28 @@ public:
 	}
 
 	/**
-	 * The function changeEndmost() replaces the old endmost child \a oldEnd 
+	 * The function changeEndmost() replaces the old endmost child \a oldEnd
 	 * of the node by a new child \a newEnd.
 	 * If the node is a Q-node, then it must have two valid
-	 * pointers to its endmost children. If one of the endmost children is 
+	 * pointers to its endmost children. If one of the endmost children is
 	 * \a oldEnd, it is replaced by \a newEnd.
 	 * The function changeEndmost() returns 1 if it succeeded in
 	 * replacing \a oldEnd by \a newEnd. Otherwise the function returns
 	 * 0, leaving with an error message.
 	 */
-	bool changeEndmost(PQNode<T,X,Y>* oldEnd,
-					   PQNode<T,X,Y>* newEnd);
+	bool changeEndmost(PQNode<T,X,Y>* oldEnd, PQNode<T,X,Y>* newEnd);
 
 	/**
 	 * The function changeSiblings() replaces the old sibling \a oldSib of the
-	 * node by a new sibling \a newSib. 
+	 * node by a new sibling \a newSib.
 	 * If the node has \a oldSib as sibling, then it changes the
 	 * sibling pointer that references to \a oldSib and places \a newSib
 	 * at its position.
-	 * The function changeSiblings() returns 1 if it succeeded in 
+	 * The function changeSiblings() returns 1 if it succeeded in
 	 * replacing \a oldSib by \a newSib. Otherwise the function returns
 	 * 0, leaving with an error message.
 	 */
-	bool changeSiblings(PQNode<T,X,Y>* oldSib,
-                        PQNode<T,X,Y>* newSib);
+	bool changeSiblings(PQNode<T,X,Y>* oldSib, PQNode<T,X,Y>* newSib);
 
 	/**
 	 * The function endmostChild() checks if a node is endmost child of
@@ -171,11 +143,11 @@ public:
 	bool endmostChild() {
 		return (m_sibLeft == 0 || m_sibRight == 0);
 	}
- 
+
 	/**
-	 * Returns one of the endmost children of node, if node is a Q-node. 
+	 * Returns one of the endmost children of node, if node is a Q-node.
 	 * The function getEndmost() accepts as input a pointer to a
-	 * PQNode stored in \a other. The returned endmost child is unequal 
+	 * PQNode stored in \a other. The returned endmost child is unequal
 	 * to the one specified in \a other.  In case that an arbitrary endmost child
 	 * should be looked up, set \a other = 0. This makes the function
 	 * getEndmost() return an arbitrary endmost child (it returns the
@@ -191,21 +163,21 @@ public:
 	}
 
 	/**
-	 * Returns one of the endmost children of node, if node is a Q-node. 
+	 * Returns one of the endmost children of node, if node is a Q-node.
 	 * The function accepts an integer denoting a direction causing the
-	 * function to return either the left or the endmost child. 
+	 * function to return either the left or the endmost child.
 	 */
 	PQNode<T,X,Y>* getEndmost(int side) const {
 		if (side == LEFT || side == 0)
 			return m_leftEndmost;
-		else if(side == RIGHT) 
+		else if(side == RIGHT)
 			return m_rightEndmost;
-		
+
 		return 0;
 	}
 
 	//! Returns the identification number of a node.
-	PQNodeKey<T,X,Y>* getNodeInfo() const {return m_pointerToInfo;};
+	PQNodeKey<T,X,Y>* getNodeInfo() const { return m_pointerToInfo; }
 
 	/**
 	 * The function getSib() returns one of the siblings of the node.
@@ -215,11 +187,11 @@ public:
 	PQNode<T,X,Y>* getSib(int side) const {
 		if (side == LEFT)
 			return m_sibLeft;
-		else if (side == RIGHT) 
+		else if (side == RIGHT)
 			return m_sibRight;
-		
+
 		return 0;
-	};
+	}
 
 	/**
 	 * The function getNextSib() returns one of the siblings of the node.
@@ -235,7 +207,7 @@ public:
 			return m_sibLeft;
 		else if (m_sibRight != other)
 			return m_sibRight;
-		
+
 		return 0;
 	}
 
@@ -265,16 +237,16 @@ public:
 	 * always needed and therefore has to be set within special functions,
 	 * used in a pre-run before applying the bubble Phase of the PQTree.
 	 */
-	PQNode<T,X,Y>* parent(PQNode<T,X,Y>* newParent) 
+	PQNode<T,X,Y>* parent(PQNode<T,X,Y>* newParent)
 	{
 		return m_parent = newParent;
 	}
 
-	//! Returns the type of the parent of a node. 
+	//! Returns the type of the parent of a node.
 	int parentType() const { return m_parentType; }
 
-	/** 
-	 * Sets the type of the parent of a node. 
+	/**
+	 * Sets the type of the parent of a node.
 	 * This does not change the type of the parent!
 	*/
 	void parentType(int newParentType) { m_parentType = newParentType; }
@@ -286,7 +258,7 @@ public:
 	void pertChildCount(int count) { m_pertChildCount = count; }
 
 	/**
-	 * The default function putSibling() 
+	 * The default function putSibling()
 	 * stores a new sibling at a free sibling pointer
 	 * of the node. This is only possible, if the node has at most one sibling.
 	 * The function then detects a non used sibling pointer and places \a newSib
@@ -295,7 +267,7 @@ public:
 	 * \a newSib cannot be stored. If there was at a maximum one sibling stored,
 	 * the function will place \a newSib on the free pointer and return either
 	 * \a LEFT or \a RIGHT, depending wich pointer has been used.
-     *
+	 *
 	 * This function will always scan the pointer to the left brother first.
 	 */
 	SibDirection putSibling(PQNode<T,X,Y>* newSib)
@@ -304,36 +276,35 @@ public:
 			m_sibLeft = newSib;
 			return LEFT;
 		}
-		
+
 		OGDF_ASSERT(m_sibRight == 0);
 		m_sibRight = newSib;
 		return RIGHT;
 	}
 
 	/**
-	 * The function putSibling() 
+	 * The function putSibling()
 	 * with preference stores a new sibling at a free sibling pointer
 	 * of the node. This is only possible, if the node has at most one sibling.
 	 * The function then detects a non used sibling pointer and places \a newSib
 	 * onto it. putSibling() returns 0 if there have been two siblings
 	 * detected, occupying the two possible pointers. In this case the new sibling
-	 * \a newSib could not be stored. If there was at a maximum one sibling 
-	 * stored, the function will place \a newSib on the free pointer and 
+	 * \a newSib could not be stored. If there was at a maximum one sibling
+	 * stored, the function will place \a newSib on the free pointer and
 	 * return either \a LEFT or \a RIGHT, depending wich pointer has been used.
-     *
+	 *
 	 * This function scans the brother first, which has been specified in the
 	 * preference. If the preference has value \a LEFT, it scans the pointer
 	 * to the left brother first. If the value is \a RIGHT, it scans the pointer
 	 * to the right brother first.
 	 */
-	SibDirection putSibling(PQNode<T,X,Y>* newSib,
-                    int preference)
+	SibDirection putSibling(PQNode<T,X,Y>* newSib, int preference)
 	{
 		if (preference == LEFT)
 			return putSibling(newSib);
 
 		OGDF_ASSERT(preference == RIGHT);
-		
+
 		if (m_sibRight == 0)
 		{
 			m_sibRight = newSib;
@@ -346,7 +317,7 @@ public:
 	}
 
 	//! Returns a pointer to the reference child if node is a P-node.
-	PQNode<T,X,Y>* referenceChild() const { return m_referenceChild; } 
+	PQNode<T,X,Y>* referenceChild() const { return m_referenceChild; }
 
 	//! Returns the pointer to the parent if node is a reference child.
 	PQNode<T,X,Y>* referenceParent() const { return m_referenceParent; }
@@ -355,11 +326,11 @@ public:
 	bool  setNodeInfo(PQNodeKey<T,X,Y>* pointerToInfo) {
 		m_pointerToInfo = pointerToInfo;
 		if (pointerToInfo != 0)
-		{    
+		{
 			m_pointerToInfo->setNodePointer(this);
 			return true;
 		}
-		
+
 		return false;
 	}
 
@@ -374,12 +345,12 @@ public:
 	//! Sets a specified pointer variable in a derived class to the	specified adress of \a pointerToKey that is of type PQLeafKey.
 	/**
 	 * If a derived class, such as PQInternalNode, is not supposed to store
-	 * informations of type PQLeafKey, setKey() ignores the informations as long as 
+	 * informations of type PQLeafKey, setKey() ignores the informations as long as
 	 * \a pointerToKey = 0. The return value then is 1.
 	 * In case that \a pointerToKey != 0, the return value is 0.
-     *
+	 *
 	 * If a derived class, such as PQLeaf is supposed to
-	 * store informations of type PQLeafKey, \a pointerToKey 
+	 * store informations of type PQLeafKey, \a pointerToKey
 	 * has to be instantiated by the client. The function setKey() does
 	 * not instantiate the corresponding variable in the derived class.
 	 * The return value is always 1 unless \a pointerKey was equal to 0.
@@ -390,23 +361,23 @@ public:
 	 * getInternal() returns a pointer to the PQInternalKey
 	 * information of a node, in case that
 	 * the node is supposed to have PQInternalKey information,
-	 * such as elements of the derived class template PQInternalNode. 
+	 * such as elements of the derived class template PQInternalNode.
 	 * The internal information is of type PQInternalKey.
 	 */
 	virtual PQInternalKey<T,X,Y>* getInternal() const = 0;
-	
+
 	/*
 	 * setInternal() sets a specified pointer variable in a derived class
 	 * to the specified adress of \a pointerToInternal that is of type
 	 * PQInternalKey.
-     *
+	 *
 	 * If a derived class, such as PQLeaf,
 	 * is not supposed to store informations of type PQInternalKey,
 	 * setInternal() ignores the informations as long as
 	 * \a pointerToInternal = 0. The return value then is 1.
 	 * In case that \a pointerToInternal != 0, the return value is 0.
-     *
-	 * If a derived class, such as PQInternalNode is 
+	 *
+	 * If a derived class, such as PQInternalNode is
 	 * supposed to store informations of type PQInternalKey,
 	 * \a pointerToInternal has to be instantiated by the client. The
 	 * function setInternal() does
@@ -423,14 +394,14 @@ public:
 	 * the first pass of Booth and Luekers algorithm called Bubble(). A
 	 * node then is either marked \a BLOCKED, \a UNBLOCKED or \a QUEUED	(see PQNode).
 	 */
-	virtual int mark() const = 0;          
-	
+	virtual PQNodeMark mark() const = 0;
+
 	//! mark() sets the variable \a m_mark in the derived class PQLeaf and PQInternalNode.
-	virtual void mark(int) = 0;
+	virtual void mark(PQNodeMark) = 0;
 
 	//! Returns the variable \a m_status in the derived class PQLeaf and PQInternalNode.
 	/**
-	 * Its objective is to manage 
+	 * Its objective is to manage
 	 * status of a node in the PQ-tree. A status is
 	 * any kind of information of the current situation in the frontier of
 	 * a node (the frontier of a node are all descendant leaves of the
@@ -439,10 +410,10 @@ public:
 	 * (e.g. in computing planar subgraphs this
 	 * function probably has to be overloaded by the client.
 	 */
-	virtual int status() const = 0;        
-	
+	virtual PQNodeStatus status() const = 0;
+
 	//! Sets the variable \a m_status in the derived class PQLeaf and PQInternalNode.
-	virtual void status(int) = 0;
+	virtual void status(PQNodeStatus) = 0;
 
 	//! Returns the variable \a m_type in the derived class PQLeaf and PQInternalNode.
 	/**
@@ -450,22 +421,22 @@ public:
 	 * node the current node is. The type of a node in the class template
 	 * PQTree is either \a PNode, \a QNode or \a leaf (see PQNode).
 	 * There may be of course more types such as <em>sequence indicators</em>.
-     *
+	 *
 	 * Observe that the derived class template PQLeaf does
 	 * not have a variable \a m_type, since it obviously is of type	\a leaf.
 	 */
-	virtual PQNodeType type() const = 0;          
+	virtual PQNodeType type() const = 0;
 
 	//! Sets the variable \a m_type in the derived class PQLeaf and PQInternalNode.
 	virtual void type(PQNodeType) = 0;
-      
+
 
 protected:
 
-   
-    /// Stores the number of children of the node.
+
+	// Stores the number of children of the node.
 	int m_childCount;
-    
+
 	/**
 	 * Needed for debuging
 	 * purposes. The PQ-trees can be visualized with the help of the <em>Tree
@@ -473,7 +444,7 @@ protected:
 	 * tree in the correct file format.
 	 */
 	int m_debugTreeNumber;
-    
+
 	/**
 	 * Each node that has been introduced once into
 	 * the tree gets a unique number. If the node is removed from the
@@ -487,27 +458,27 @@ protected:
 	 */
 	int m_identificationNumber;
 
-    //! Stores the type of the parent which can be either a P- or Q-node.
-	int m_parentType;    
-    
-	//! Stores the number of pertinent children of the node.
-	int m_pertChildCount; 
+	//! Stores the type of the parent which can be either a P- or Q-node.
+	int m_parentType;
 
-    //! Stores the number of pertinent leaves in the frontier of the node.
-	int m_pertLeafCount; 
+	//! Stores the number of pertinent children of the node.
+	int m_pertChildCount;
+
+	//! Stores the number of pertinent leaves in the frontier of the node.
+	int m_pertLeafCount;
 
 	//! Stores a pointer to the first full child of a Q-node.
 	PQNode<T,X,Y> *m_firstFull;
 
-	PQNode<T,X,Y> *m_leftEndmost;   	
+	PQNode<T,X,Y> *m_leftEndmost;
 
 	/**
 	 * Is a pointer to the parent. Observe that this
 	 * pointer may not be up to date after a few applications of the
-	 * reduction. 
+	 * reduction.
 	 */
-	PQNode<T,X,Y> *m_parent; 
-	
+	PQNode<T,X,Y> *m_parent;
+
 	/**
 	 * Stores a pointer to one child, the <b>reference child</b> of the
 	 * doubly linked cirkular list of children of a
@@ -520,19 +491,19 @@ protected:
 	 * Is a pointer to the parent, in case that the
 	 * parent is a P-node and the node itself is its reference child.
 	 * The pointer is needed in order to identify the reference child
-	 * among all children of a P-node.	
+	 * among all children of a P-node.
 	 */
 	PQNode<T,X,Y> *m_referenceParent;
 
 	//! Stores the right endmost child of a Q-node.
-	PQNode<T,X,Y> *m_rightEndmost;    
+	PQNode<T,X,Y> *m_rightEndmost;
 
 	/**
 	 * Stores a pointer ot the left sibling of PQNode.
 	 * If PQNode is child of a Q-node and has no left sibling,
 	 * \a m_sibLeft is set to 0. If PQNode is child of a P-node,
 	 * all children of the P-node are linked in a cirkular list. In the
-	 * latter case, \a m_sibLeft is never 0.	
+	 * latter case, \a m_sibLeft is never 0.
 	 */
 	PQNode<T,X,Y> *m_sibLeft;
 
@@ -544,13 +515,13 @@ protected:
 	 * latter case, \a m_sibRight is never 0.
 	 */
 	PQNode<T,X,Y> *m_sibRight;
-	
-	//! Stores a pointer to the corresponding information of the node. 
+
+	//! Stores a pointer to the corresponding information of the node.
 	PQNodeKey<T,X,Y> *m_pointerToInfo;
 
 
 	//! Stores all full children of a node during a reduction.
-	List<PQNode<T,X,Y>*> *fullChildren; 
+	List<PQNode<T,X,Y>*> *fullChildren;
 
 	//! Stores all partial children of a node during a reduction.
 	List<PQNode<T,X,Y>*> *partialChildren;
@@ -568,9 +539,8 @@ The function [[changeEndmost]] returns [[1]] if it succeeded in
 replacing [[oldEnd]] by [[newEnd]]. Otherwise the function returns
 [[0]], leaving with an error message.
 */
-template<class T,class X,class Y> 
-bool PQNode<T,X,Y>::changeEndmost(PQNode<T,X,Y>* oldEnd,
-                               PQNode<T,X,Y>* newEnd)
+template<class T,class X,class Y>
+bool PQNode<T,X,Y>::changeEndmost(PQNode<T,X,Y>* oldEnd, PQNode<T,X,Y>* newEnd)
 {
 	if (m_leftEndmost == oldEnd)
 	{
@@ -587,7 +557,7 @@ bool PQNode<T,X,Y>::changeEndmost(PQNode<T,X,Y>* oldEnd,
 
 /*
 The function [[changeSiblings]] replaces the old sibling [[oldSib]] of the
-node by a new sibling [[newSib]]. 
+node by a new sibling [[newSib]].
 
 If the node has [[oldSib]] as sibling, then it changes the
 sibling pointer that references to [[oldSib]] and places [[newSib]]
@@ -597,9 +567,8 @@ The function [[changeSiblings]] returns [[1]] if it succeeded in replacing
 [[oldSib]] by [[newSib]]. Otherwise the function returns
 [[0]], leaving with an error message.
 */
-template<class T,class X,class Y> 
-bool PQNode<T,X,Y>::changeSiblings(PQNode<T,X,Y>* oldSib,
-                                PQNode<T,X,Y>* newSib)
+template<class T,class X,class Y>
+bool PQNode<T,X,Y>::changeSiblings(PQNode<T,X,Y>* oldSib, PQNode<T,X,Y>* newSib)
 {
 	if (m_sibLeft == oldSib)
 	{
@@ -613,68 +582,67 @@ bool PQNode<T,X,Y>::changeSiblings(PQNode<T,X,Y>* oldSib,
 	}
 	return false;
 }
-   
+
 
 /*
-The (first) constructor combines the node with its information and 
-will automatically set the [[m_nodePointer]] (see \ref{basicKey}) of 
+The (first) constructor combines the node with its information and
+will automatically set the [[m_nodePointer]] (see \ref{basicKey}) of
 the element of type [[PQNodeKey]] (see \ref{PQNodeKey}).
 */
 template<class T,class X,class Y>
 PQNode<T,X,Y>::PQNode(int count,PQNodeKey<T,X,Y>* infoPtr)
 {
+	m_identificationNumber = count;
+	m_childCount = 0;
+	m_pertChildCount = 0;
+	m_pertLeafCount = 0;
+	m_debugTreeNumber = 0;
+	m_parentType = 0;
 
-   m_identificationNumber = count;
-   m_childCount = 0;
-   m_pertChildCount = 0;
-   m_pertLeafCount = 0;
-   m_debugTreeNumber = 0;
-   m_parentType = 0;
+	m_parent = 0;
+	m_firstFull = 0;
+	m_sibLeft = 0;
+	m_sibRight = 0;
+	m_referenceChild = 0;
+	m_referenceParent = 0;
+	m_leftEndmost = 0;
+	m_rightEndmost = 0;
 
-   m_parent = 0;
-   m_firstFull = 0;
-   m_sibLeft = 0;
-   m_sibRight = 0;
-   m_referenceChild = 0;
-   m_referenceParent = 0;
-   m_leftEndmost = 0;
-   m_rightEndmost = 0;   
+	fullChildren = OGDF_NEW List<PQNode<T,X,Y>*>;
+	partialChildren = OGDF_NEW List<PQNode<T,X,Y>*>;
 
-   fullChildren = OGDF_NEW List<PQNode<T,X,Y>*>;
-   partialChildren = OGDF_NEW List<PQNode<T,X,Y>*>;
-
-   m_pointerToInfo = infoPtr;
-   infoPtr->setNodePointer(this);
+	m_pointerToInfo = infoPtr;
+	infoPtr->setNodePointer(this);
 }
 
 
 /*
-The (second) constructor is called, 
+The (second) constructor is called,
 if no information is available or neccessary.
 */
 template<class T,class X,class Y>
 PQNode<T,X,Y>::PQNode(int count)
 {
-   m_identificationNumber = count;
-   m_childCount = 0;
-   m_pertChildCount = 0;
-   m_pertLeafCount = 0;
-   m_debugTreeNumber = 0;
-   m_parentType = 0;
+	m_identificationNumber = count;
+	m_childCount = 0;
+	m_pertChildCount = 0;
+	m_pertLeafCount = 0;
+	m_debugTreeNumber = 0;
+	m_parentType = 0;
 
-   m_parent = 0;
-   m_firstFull = 0;
-   m_sibLeft = 0;
-   m_sibRight = 0;
-   m_referenceChild = 0;
-   m_referenceParent = 0;
-   m_leftEndmost = 0;
-   m_rightEndmost = 0;   
+	m_parent = 0;
+	m_firstFull = 0;
+	m_sibLeft = 0;
+	m_sibRight = 0;
+	m_referenceChild = 0;
+	m_referenceParent = 0;
+	m_leftEndmost = 0;
+	m_rightEndmost = 0;
 
-   fullChildren = OGDF_NEW List<PQNode<T,X,Y>*>;
-   partialChildren = OGDF_NEW List<PQNode<T,X,Y>*>;
+	fullChildren = OGDF_NEW List<PQNode<T,X,Y>*>;
+	partialChildren = OGDF_NEW List<PQNode<T,X,Y>*>;
 
-   m_pointerToInfo = 0;
+	m_pointerToInfo = 0;
 }
 
 }
