@@ -1,51 +1,42 @@
 /*
- * $Revision: 2027 $
- * 
+ * $Revision: 2599 $
+ *
  * last checkin:
- *   $Author: gutwenger $ 
- *   $Date: 2010-09-01 11:55:17 +0200 (Wed, 01 Sep 2010) $ 
+ *   $Author: chimani $
+ *   $Date: 2012-07-15 22:39:24 +0200 (So, 15. Jul 2012) $
  ***************************************************************/
- 
+
 /** \file
  * \brief Implementation of some graph generators
- * 
+ *
  * \author Carsten Gutwenger, Markus Chimani
- * 
+ *
  * \par License:
  * This file is part of the Open Graph Drawing Framework (OGDF).
  *
- * Copyright (C). All rights reserved.
+ * \par
+ * Copyright (C)<br>
  * See README.txt in the root directory of the OGDF installation for details.
- * 
+ *
  * \par
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
  *
  * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- * 
- * \par
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * \par
- * You should have received a copy of the GNU General Public 
+ * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- * 
+ *
  * \see  http://www.gnu.org/copyleft/gpl.html
  ***************************************************************/
 
@@ -56,7 +47,7 @@
 #include <ogdf/basic/EdgeArray.h>
 #include <ogdf/basic/NodeArray.h>
 #include <ogdf/basic/FaceArray.h>
-#include <ogdf/planarity/PlanarModule.h>
+#include <ogdf/basic/extended_graph_alg.h>
 #include <ogdf/basic/Array2D.h>
 
 
@@ -92,20 +83,20 @@ void randomGraph(Graph &G, int n, int m)
 bool randomSimpleGraph(Graph &G, int n, int m)
 {
 	G.clear();
-	
+
 	if(n < 1)
-		return false;	
-	
+		return false;
+
 	int max = n * (n-1) / 2;
 	if(m > max || m < n)
 		return false;
-	
+
 	Array<node> v(n);
 
 	int i;
 	for(i = 0; i < n; i++)
 		v[i] = G.newNode();
-	
+
 	bool remove;
 	if(m > max /2) {
 		m = max - m;
@@ -117,7 +108,7 @@ bool randomSimpleGraph(Graph &G, int n, int m)
 	Array<bool> used(max);
 	for(i = max; i-->0;)
 		used[i] = remove;
-		
+
 	int a,b;
 	while(m > 0) {
 		a = randomNumber(0,n-1);
@@ -127,7 +118,7 @@ bool randomSimpleGraph(Graph &G, int n, int m)
 			int c = a;
 			a = b;
 			b = c;
-		}		
+		}
 		if(used[i = __IDX(a,b,n,max)] == remove) {
 			used[i] = !remove;
 			m--;
@@ -138,7 +129,7 @@ bool randomSimpleGraph(Graph &G, int n, int m)
 		for(b = a+1; b < n; b++)
 			if(used[__IDX(a,b,n,max)])
 				G.newEdge(v[a],v[b]);
-	
+
 	return true;
 }
 
@@ -339,8 +330,7 @@ void planarTriconnectedGraph(Graph &G, int n, double p1, double p2)
 	// start with K_4
 	completeGraph(G,4);
 
-	PlanarModule pm;
-	pm.planarEmbed(G);
+	planarEmbedPlanarGraph(G);
 
 	// nodes[0],...,nodes[i-1] is array of all nodes
 	Array<node> nodes(n);
@@ -404,8 +394,7 @@ void planarTriconnectedGraph(Graph &G, int n, int m)
 	// start with K_4
 	completeGraph(G,4);
 
-	PlanarModule pm;
-	pm.planarEmbed(G);
+	planarEmbedPlanarGraph(G);
 
 	// nodes[0],...,nodes[i-1] is array of all nodes
 	Array<node> nodes(n);
@@ -481,6 +470,84 @@ void planarTriconnectedGraph(Graph &G, int n, int m)
 	}
 }
 
+void planarConnectedGraph(Graph &G, int n, int m)
+{
+	if (n < 1) n = 1;
+	if (m < n-1) m = n-1;
+	if (m > 3*n-6) m = 3*n-6;
+
+	G.clear();
+	Array<node> nodes(n);
+
+	// we start with a triangle
+	nodes[0] = G.newNode();
+
+	//build tree
+	int i;
+	for(i=1; i<n; ++i) {
+		node on = nodes[randomNumber(0,i-1)];
+		node nn = nodes[i] = G.newNode();
+		G.firstNode()->degree();
+		if(on->degree() > 1) {
+			adjEntry adj = on->firstAdj();
+			for(int fwd = randomNumber(0,on->degree()-1); fwd>0; --fwd)
+				adj = adj->succ();
+			G.newEdge(nn, adj);
+		} else {
+			G.newEdge(nn, on);
+		}
+	}
+
+	List<face> bigFaces; // not a triangle
+
+	CombinatorialEmbedding E(G);
+	bigFaces.pushBack(E.firstFace());
+	for(i = m-n+1; i-->0;) {
+		ListIterator<face> fi = bigFaces.chooseIterator();
+		face f = *fi;
+		bigFaces.del(fi);
+
+		List<adjEntry> fnodes;
+		adjEntry adj;
+		forall_face_adj(adj, f) {
+			fnodes.pushBack(adj);
+		}
+		fnodes.permute();
+		adjEntry adj1,adj2;
+		bool okay = false;
+		do {
+			adj1 = fnodes.popFrontRet();
+			node n1 = adj1->theNode();
+			forall_listiterators(adjEntry, it, fnodes) {
+				adj2 = *it;
+				node n2 = adj2->theNode();
+
+				if(n1==n2 || adj1->faceCyclePred() == adj2 || adj2->faceCyclePred() == adj1) {
+					continue;
+				}
+				edge e;
+				okay = true;
+				forall_adj_edges(e,n1) {
+					if(e->opposite(n1) == n2) {
+						okay = false;
+						break;
+					}
+				}
+				if(okay) break;
+			}
+		} while(!okay);
+
+		edge ne = E.splitFace(adj1,adj2);
+
+		face f1 = E.rightFace(ne->adjSource());
+		face f2 = E.rightFace(ne->adjTarget());
+
+		if (f1->size() > 3) bigFaces.pushBack(f1);
+		if (f2->size() > 3) bigFaces.pushBack(f2);
+	}
+}
+
+
 void planarBiconnectedGraph(Graph &G, int n, int m, bool multiEdges)
 {
 	if (n < 3) n = 3;
@@ -490,7 +557,7 @@ void planarBiconnectedGraph(Graph &G, int n, int m, bool multiEdges)
 	int ke = n-3, kf = m-n;
 
 	G.clear();
-	
+
 	Array<edge> edges(m);
 	Array<face> bigFaces(m);
 	//random_source S;
@@ -582,23 +649,23 @@ void planarBiconnectedGraph(Graph &G, int n, int m, bool multiEdges)
 	}
 }
 
-void planarCNBGraph(Graph &G, int n, int m,	int b)	
+void planarCNBGraph(Graph &G, int n, int m,	int b)
 {
 	G.clear();
 	if (b <= 0) b = 1;
 	if (n <= 0) n = 1;
 	if ((m <= 0) || (m > 3*n-6)) m = 3*n-6;
-	
+
 	node cutv;
 	G.newNode();
-	
+
 	for (int nB=1; nB<=b; nB++){
 		cutv = G.chooseNode();
 		// set number of nodes for the current created block
 		int actN = randomNumber(1, n);
-		
+
 		node v1 = G.newNode();
-		
+
 		if (actN <= 1){
 			G.newEdge(v1, cutv);
 		}
@@ -606,7 +673,7 @@ void planarCNBGraph(Graph &G, int n, int m,	int b)
 			if (actN == 2){
 				node v2 = G.newNode();
 				G.newEdge(v1, v2);
-				
+
 				int rnd = randomNumber(1, 2);
 				edge newE;
 				int rnd2 = randomNumber(1, 2);
@@ -629,13 +696,13 @@ void planarCNBGraph(Graph &G, int n, int m,	int b)
 					actM = randomNumber(1, m);
 				if (actM < actN)
 					actM = actN;
-				
+
 				int ke = actN-3, kf = actM-actN;
-				
+
 				Array<node> nodes(actN);
 				Array<edge> edges(actM);
 				Array<face> bigFaces(actM);
-					
+
 				// we start with a triangle
 				node v2 = G.newNode(), v3 = G.newNode();
 				nodes[0] = v1;
@@ -644,27 +711,27 @@ void planarCNBGraph(Graph &G, int n, int m,	int b)
 				edges[0] = G.newEdge(v1,v2);
 				edges[1] = G.newEdge(v2,v3);
 				edges[2] = G.newEdge(v3,v1);
-				
+
 				int actInsertedNodes = 3;
-				
+
 				CombinatorialEmbedding E(G);
 				FaceArray<int> posBigFaces(E);
 				int nBigFaces = 0, nEdges = 3;
-				
+
 				while(ke+kf > 0) {
 					int p = randomNumber(1,ke+kf);
-			
+
 					if (nBigFaces == 0 || p <= ke) {
 						int eNr = randomNumber(0,nEdges-1);
 						edge e  = edges[eNr];
 						face f  = E.rightFace(e->adjSource());
 						face fr = E.rightFace(e->adjTarget());
-						
+
 						node u = e->source();
 						node v = e->target();
-						
+
 						edges[nEdges++] = E.split(e);
-						
+
 						if (e->source() != v && e->source() != u)
 							nodes[actInsertedNodes++] = e->source();
 						else
@@ -678,29 +745,29 @@ void planarCNBGraph(Graph &G, int n, int m,	int b)
 							posBigFaces[fr] = nBigFaces;
 							bigFaces[nBigFaces++] = fr;
 						}
-			
+
 						ke--;
 					}
-					else {						
+					else {
 						int pos = randomNumber(0,nBigFaces-1);
 						face f = bigFaces[pos];
 						int df = f->size();
 						int i = randomNumber(0,df-1), j = randomNumber(2,df-2);
-			
+
 						adjEntry adj1;
 						for (adj1 = f->firstAdj(); i > 0; adj1 = adj1->faceCycleSucc())
 							i--;
-			
+
 						adjEntry adj2;
 						for (adj2 = adj1; j > 0; adj2 = adj2->faceCycleSucc())
 							j--;
-			
+
 						edge e = E.splitFace(adj1,adj2);
 						edges[nEdges++] = e;
-						
+
 						face f1 = E.rightFace(e->adjSource());
 						face f2 = E.rightFace(e->adjTarget());
-			
+
 						bigFaces[pos] = f1;
 						posBigFaces[f1] = pos;
 						if (f2->size() >= 4) {
@@ -710,17 +777,17 @@ void planarCNBGraph(Graph &G, int n, int m,	int b)
 						if (f1->size() == 3) {
 							bigFaces[pos] = bigFaces[--nBigFaces];
 						}
-						
+
 						kf--;
 					}
 				}
-						
+
 				// delete multi edges
 				SListPure<edge> allEdges;
 				EdgeArray<int> minIndex(G), maxIndex(G);
-		
+
 				parallelFreeSortUndirected(G,allEdges,minIndex,maxIndex);
-		
+
 				SListConstIterator<edge> it = allEdges.begin();
 				edge ePrev = *it, e;
 				for(it = ++it; it.valid(); ++it, ePrev = e) {
@@ -733,9 +800,9 @@ void planarCNBGraph(Graph &G, int n, int m,	int b)
 							e->adjSource()->faceCycleSucc()->twin(), ogdf::before);
 					}
 				}
-				
+
 				node cutv2 = nodes[randomNumber(0,actN-1)];
-				
+
 				int rnd = randomNumber(1,2);
 				edge newE = G.newEdge(cutv2, cutv);
 				if (rnd == 1){
@@ -743,7 +810,7 @@ void planarCNBGraph(Graph &G, int n, int m,	int b)
 				}
 			}
 	}
-};
+}
 
 
 void constructCConnectedCluster(node v,ClusterGraph &C);
@@ -767,11 +834,11 @@ void randomClusterGraph(ClusterGraph &C,Graph &G,int cNum)
 	}
 
 	for (int i = 0; i < cNum; i++)
-	{	
+	{
 		int rand = randomNumber(0,n-1);
 
 		node start = numNode[rand];
-	
+
 		constructCluster(start,C);
 	}
 
@@ -796,11 +863,11 @@ void randomClusterPlanarGraph(ClusterGraph &C,Graph &G,int cNum)
 	}
 
 	for (int i = 0; i < cNum; i++)
-	{	
+	{
 		int rand = randomNumber(0,n-1);
 
 		node start = numNode[rand];
-	
+
 		constructCConnectedCluster(start,C);
 	}
 
@@ -824,7 +891,7 @@ void randomClusterPlanarGraph(ClusterGraph &C,Graph &G,int cNum)
 		cluster cl = (*C.rootCluster()->cBegin());
 		C.delCluster(cl);
 	}
-		
+
 
 	OGDF_ASSERT(C.consistencyCheck());
 
@@ -840,11 +907,11 @@ void constructCConnectedCluster(node v,ClusterGraph &C)
 	if (newCluster.size() > 1)
 	{
 		cluster cl = C.newCluster(C.clusterOf(v));
-//		cout << " Cluster " << cl->index() << endl; 		
+//		cout << " Cluster " << cl->index() << endl;
 		while (!newCluster.empty())
 		{
 			node w = newCluster.popFrontRet();
-//			cout << " Node in cluster " << w << endl; 
+//			cout << " Node in cluster " << w << endl;
 			C.reassignNode(w,cl);
 		}
 	}
@@ -879,7 +946,7 @@ void constructCluster(node v,ClusterGraph &C)
 		node w = newCluster.popFrontRet();
 		C.reassignNode(w,cl);
 	}
-	
+
 }//constructcluster
 
 //insert nodes in v's cluster to new cluster with a certain probability
@@ -888,19 +955,19 @@ void bfs(node v,SList<node> &newCluster,NodeArray<bool> &visited,ClusterGraph &C
 
 	edge e;
 	SListPure<node> bfsL;
-	forall_adj_edges (e,v) 
+	forall_adj_edges (e,v)
 	{
 		node w = e->opposite(v);
 		int probability = randomNumber(0,99);
 		if (probability < 70 && !visited[w])
 		{
 			visited[w] = true;
-			if (C.clusterOf(v) == C.clusterOf(w)) 
+			if (C.clusterOf(v) == C.clusterOf(w))
 			{
 				newCluster.pushBack(w);
 				bfsL.pushBack(w);
 			}
-		}					
+		}
 		else
 			visited[w] = true;
 	}
@@ -908,6 +975,80 @@ void bfs(node v,SList<node> &newCluster,NodeArray<bool> &visited,ClusterGraph &C
 		bfs(bfsL.popFrontRet(),newCluster,visited,C);
 }
 
+
+void randomTree(Graph& G, int n) {
+	G.clear();
+	G.newNode();
+	for(int i=1; i<n; i++) {
+		node on = G.chooseNode();
+		G.newEdge(on, G.newNode());
+	}
+}
+
+void regularTree(Graph& G, int n, int children) {
+	G.clear();
+	node* id2node = new node[n];
+	id2node[0] = G.newNode();
+	for(int i=1; i<n; i++) {
+		G.newEdge(id2node[(i-1)/children], id2node[i] = G.newNode());
+	}
+	delete[] id2node;
+}
+
+void createClustersHelper(ClusterGraph& C, const node curr, const node pred, const cluster predC, List<cluster>& internal, List<cluster>& leaves) {
+	cluster currC = predC ? C.createEmptyCluster(predC) : C.rootCluster();
+	if(curr->degree()==1 && pred!=0) {
+		leaves.pushBack(currC);
+	} else {
+		edge e;
+		forall_adj_edges(e,curr) {
+			node next = e->opposite(curr);
+			if(next == pred) continue;
+			createClustersHelper(C,  next,curr,currC,  internal,leaves);
+		}
+		internal.pushBack(currC);
+	}
+}
+
+void randomClusterGraph(ClusterGraph& C, const Graph& G, const node root, int moreInLeaves) {
+	C.init(G);
+
+	// Build cluster structure (and store which clusters are internal and which are leaves)
+	List<cluster> internal;
+	List<cluster> leaves;
+	createClustersHelper(C,  root,0,0,  internal,leaves);
+
+	// Assign nodes to clusters
+	List<node> nodes;
+	G.allNodes<List<node> >(nodes);
+
+	// Step 1: Ensure two node per leaf-cluster
+	nodes.permute();
+	forall_listiterators(cluster, it, leaves) {
+		C.reassignNode(nodes.popFrontRet(),*it);
+		C.reassignNode(nodes.popFrontRet(),*it);
+	}
+
+	// Step 2: Distribute the other nodes
+	int n = G.numberOfNodes();
+	int numI = internal.size();
+	int numL = leaves.size();
+	double chanceForInternal = ( numI*n/double(numL*moreInLeaves+numI) ) / double(n-2*numL);
+	// a leaf-cluster should have (on average) moreInLeaves-times as many vertices as in internal-cluster.
+	// #verticesInInternalCluster = n / (numL*moreInLeaves + numI)
+	// #nodesToDistribute = n - 2*numL
+	// => chance that a node goes into an internal cluster = numI * #verticesInInternalCluster / (n-2*numL)
+	while(!nodes.empty()) {
+		cluster cl;
+		if(randomDouble(0,1) < chanceForInternal) {
+			cl = * internal.get(randomNumber(0,internal.size()-1));
+		} else {
+			cl = * leaves.get(randomNumber(0,leaves.size()-1));
+		}
+		C.reassignNode(nodes.popFrontRet(),cl);
+	}
+}
+
 void completeGraph(Graph &G, int n)
 {
 	G.clear();
@@ -969,14 +1110,14 @@ void suspension(Graph &G, int n)
 		node n0 = G.newNode();
 		forall_listiterators(node, it, nds)
 			G.newEdge(n0,*it);
-	}	
+	}
 }
 
 void cubeGraph(Graph &G, int n)
 {
 	OGDF_ASSERT( n>=0 && n < 8*(int)sizeof(int)-1 ); // one sign bit, one less to be safe
 	G.clear();
-	
+
 	int c = 1 << n;
 	Array<node> lu(c);
 	for(int i=0; i<c; ++i) {
@@ -986,12 +1127,59 @@ void cubeGraph(Graph &G, int n)
 			if(q&i) G.newEdge(lu[i^q],lu[i]);
 			q <<= 1;
 		}
-	}	
+	}
 }
 
+void gridGraph(Graph &G, int n, int m, bool loopN, bool loopM) {
+	G.clear();
+	Array<node> front(0,n-1,0);
+	Array<node> fringe(0,n-1,0);
+	node first = 0;
+	node last = 0;
+	node cur;
+	for(int j=m; j-->0;) {
+		for(int i=n; i-->0;) {
+			cur = G.newNode();
+			if(!last) first=cur;
+			else G.newEdge(last,cur);
+			if(fringe[i]) G.newEdge(fringe[i],cur);
+			else front[i] = cur;
+			fringe[i] = cur;
+			last = cur;
+		}
+		if(loopN)
+			G.newEdge(last, first);
+		last = 0;
+	}
+	if(loopM) {
+		for(int i=n; i-->0;) {
+			G.newEdge(fringe[i],front[i]);
+		}
+	}
+}
+
+void petersenGraph(Graph &G, int n, int m) {
+	G.clear();
+	Array<node> inner(0, n-1, 0);
+	node first = 0;
+	node last = 0;
+	for(int i=n; i-->0;) {
+		node outn = G.newNode();
+		node inn = G.newNode();
+		G.newEdge(outn,inn);
+		inner[i]=inn;
+		if(!last) first=outn;
+		else G.newEdge(last,outn);
+		last = outn;
+	}
+	G.newEdge(last, first);
+	for(int i=n; i-->0;) {
+		G.newEdge(inner[i],inner[(i+m)%n]);
+	}
+}
 
 void randomDiGraph(Graph &G, int n, double p) {
-	
+
 	OGDF_ASSERT(n>=0 && p<=1 && p>=0);
 
 	for(int i=0; i<n; i++)
