@@ -1,55 +1,46 @@
 /*
- * $Revision: 2047 $
- * 
+ * $Revision: 2573 $
+ *
  * last checkin:
- *   $Author: klein $ 
- *   $Date: 2010-10-13 17:12:21 +0200 (Wed, 13 Oct 2010) $ 
+ *   $Author: gutwenger $
+ *   $Date: 2012-07-10 18:48:33 +0200 (Di, 10. Jul 2012) $
  ***************************************************************/
- 
+
 /** \file
- * \brief Implements the class ClusterGraph, providing 
- * extra functionality for clustered graphs. 
- * A clustered graph C=(G,T) consists of an undirected graph G 
- * and a rooted tree T in which the leaves of T correspond 
+ * \brief Implements the class ClusterGraph, providing
+ * extra functionality for clustered graphs.
+ * A clustered graph C=(G,T) consists of an undirected graph G
+ * and a rooted tree T in which the leaves of T correspond
  * to the vertices of G=(V,E).
- * 
- * \author Sebastian Leipert
- * 
+ *
+ * \author Sebastian Leipert, Karsten Klein
+ *
  * \par License:
  * This file is part of the Open Graph Drawing Framework (OGDF).
  *
- * Copyright (C). All rights reserved.
+ * \par
+ * Copyright (C)<br>
  * See README.txt in the root directory of the OGDF installation for details.
- * 
+ *
  * \par
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
  *
  * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- * 
- * \par
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * \par
- * You should have received a copy of the GNU General Public 
+ * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- * 
+ *
  * \see  http://www.gnu.org/copyleft/gpl.html
  ***************************************************************/
 
@@ -63,9 +54,10 @@
 #include <string.h>
 
 #include <ogdf/basic/String.h>
-#include <ogdf/fileformats/GmlParser.h>
 #include <ogdf/basic/AdjEntryArray.h>
 
+#include <ogdf/fileformats/GmlParser.h>
+
 
 namespace ogdf {
 
@@ -75,7 +67,7 @@ namespace ogdf {
 //node search in cluster hierarchy
 //---------------------------------------------------------
 void ClusterElement::getClusterInducedNodes(List<node> &clusterNodes) {
-	
+
 	ListConstIterator<node> nit;
 	for (nit=m_entries.begin(); nit.valid(); ++nit) {
 		clusterNodes.pushBack(*nit);
@@ -87,13 +79,13 @@ void ClusterElement::getClusterInducedNodes(List<node> &clusterNodes) {
 }
 
 void ClusterElement::getClusterNodes(List<node> &clusterNodes) {
-	
+
 	clusterNodes.clear();
 	getClusterInducedNodes(clusterNodes);
 }
 
 void ClusterElement::getClusterInducedNodes(NodeArray<bool> &clusterNode, int& num) {
-	
+
 	ListConstIterator<node> nit;
 	for (nit=m_entries.begin(); nit.valid(); ++nit) {
 		clusterNode[*nit] = true;
@@ -109,7 +101,7 @@ int ClusterElement::getClusterNodes(NodeArray<bool> &clusterNode)
 {
 	int num = 0;
 	getClusterInducedNodes(clusterNode, num);
-	
+
 	return num;
 }
 
@@ -129,7 +121,7 @@ ClusterGraph::ClusterGraph()
 	m_depthUpToDate = false;
 
 	m_nClusters = 0;
-	m_lcaNumber = 0; 
+	m_lcaNumber = 0;
 	m_clusterArrayTableSize = MIN_CLUSTER_TABLE_SIZE;
 	m_adjAvailable = false;
 	m_lcaNumber = 0;
@@ -154,9 +146,8 @@ ClusterGraph::ClusterGraph(const Graph &G) : GraphObserver(&G), m_pGraph(&G)
 	m_depthUpToDate = false;
 
 	m_nClusters = 0;
-	m_lcaNumber = 0; 
-	m_clusterArrayTableSize = G.nextPower2(MIN_CLUSTER_TABLE_SIZE,
-										   G.nodeArrayTableSize());
+	m_lcaNumber = 0;
+	m_clusterArrayTableSize = G.nextPower2(MIN_CLUSTER_TABLE_SIZE, G.nodeArrayTableSize());
 	//m_clusterDepth.init(*this, 0);
 	initGraph(G);
 }
@@ -177,7 +168,7 @@ ClusterGraph::ClusterGraph(const ClusterGraph &C) :
 	m_depthUpToDate = false;
 
 	m_nClusters = 0;
-	m_lcaNumber = 0; 
+	m_lcaNumber = 0;
 
 	m_clusterArrayTableSize = C.m_clusterArrayTableSize;
 	shallowCopy(C);
@@ -204,7 +195,7 @@ ClusterGraph::ClusterGraph(
 	m_depthUpToDate = false;
 
 	m_nClusters = 0;
-	m_lcaNumber = 0; 
+	m_lcaNumber = 0;
 
 	m_clusterArrayTableSize = C.m_clusterArrayTableSize;
 	deepCopy(C,G,originalClusterTable,originalNodeTable);
@@ -232,7 +223,7 @@ ClusterGraph::ClusterGraph(
 	m_depthUpToDate = false;
 
 	m_nClusters = 0;
-	m_lcaNumber = 0; 
+	m_lcaNumber = 0;
 
 	m_clusterArrayTableSize = C.m_clusterArrayTableSize;
 	deepCopy(C, G, originalClusterTable, originalNodeTable, edgeCopy);
@@ -254,7 +245,7 @@ ClusterGraph::ClusterGraph(const ClusterGraph &C,Graph &G) :
 	m_depthUpToDate = false;
 
 	m_nClusters = 0;
-	m_lcaNumber = 0; 
+	m_lcaNumber = 0;
 
 	m_clusterArrayTableSize = C.m_clusterArrayTableSize;
 	deepCopy(C,G);
@@ -283,9 +274,8 @@ void ClusterGraph::init(const Graph &G)
 	m_pGraph = &G;
 
 	m_nClusters = 0;
-	m_lcaNumber = 0; 
-	m_clusterArrayTableSize = G.nextPower2(MIN_CLUSTER_TABLE_SIZE,
-										   G.nodeArrayTableSize());
+	m_lcaNumber = 0;
+	m_clusterArrayTableSize = G.nextPower2(MIN_CLUSTER_TABLE_SIZE, G.nodeArrayTableSize());
 	//m_clusterDepth.init(*this, 0);
 	initGraph(G);
 }
@@ -322,7 +312,7 @@ void ClusterGraph::shallowCopy(const ClusterGraph &C)
 	//m_clusterDepth.init(*this, 0);
 
 	initGraph(G);
-	
+
 	m_updateDepth = C.m_updateDepth;
 	m_depthUpToDate = C.m_depthUpToDate;
 
@@ -364,7 +354,7 @@ void ClusterGraph::shallowCopy(const ClusterGraph &C)
 // Initialize the graph
 void ClusterGraph::initGraph(const Graph &G)
 {
-	
+
 	reregister(&G); //will in some constructors cause double registration
 
 	m_lcaNumber = 0;
@@ -413,8 +403,7 @@ void ClusterGraph::reinitGraph(const Graph &G)
 
 		OGDF_ASSERT_IF(dlConsistencyChecks, G.consistencyCheck());
 
-		m_clusterArrayTableSize = G.nextPower2(MIN_CLUSTER_TABLE_SIZE,
-										   G.nodeArrayTableSize());
+		m_clusterArrayTableSize = G.nextPower2(MIN_CLUSTER_TABLE_SIZE, G.nodeArrayTableSize());
 
 		if (numberOfClusters() != 0)
 		{
@@ -446,7 +435,7 @@ void ClusterGraph::deepCopy(const ClusterGraph &C,Graph &G)
 	deepCopy(C,G,originalClusterTable, originalNodeTable, edgeCopy);
 }
 
-void ClusterGraph::deepCopy(const ClusterGraph &C,Graph &G,	
+void ClusterGraph::deepCopy(const ClusterGraph &C,Graph &G,
 							ClusterArray<cluster> &originalClusterTable,
 							NodeArray<node> &originalNodeTable)
 {
@@ -458,7 +447,7 @@ void ClusterGraph::deepCopy(const ClusterGraph &C,Graph &G,
 	deepCopy(C,G,originalClusterTable, originalNodeTable, edgeCopy);
 }
 
-void ClusterGraph::deepCopy(const ClusterGraph &C,Graph &G,	
+void ClusterGraph::deepCopy(const ClusterGraph &C,Graph &G,
 							ClusterArray<cluster> &originalClusterTable,
 							NodeArray<node> &originalNodeTable,
 							EdgeArray<edge> &edgeCopy)
@@ -492,7 +481,7 @@ void ClusterGraph::deepCopy(const ClusterGraph &C,Graph &G,
 					originalNodeTable[e->adjTarget()->theNode()]);
 		edgeCopy[e] = eNew;
 	}//foralledges
-	
+
 	//m_clusterDepth.init(*this, 0);
 
 
@@ -555,7 +544,7 @@ cluster ClusterGraph::commonCluster(SList<node>& nodes)
 	if (nodes.size() == 1) return clusterOf(v1);
 	sIt++;
 	node v2 = (*sIt);
-	
+
 	cluster lowestCommon = commonCluster(v1, v2);
 	commonPathHit[lowestCommon] = 2;
 	pathCluster = lowestCommon;
@@ -590,7 +579,7 @@ cluster ClusterGraph::commonCluster(SList<node>& nodes)
 		runs++;
 	}
 	return lowestCommon;
-	
+
 
 }//commoncluster
 
@@ -602,7 +591,7 @@ cluster ClusterGraph::commonCluster(node v, node w) const
 }//commonCluster
 
 //lowest common cluster of v,w and its ancestors
-cluster ClusterGraph::commonClusterLastAncestors(node v, 
+cluster ClusterGraph::commonClusterLastAncestors(node v,
 												 node w,
 												 cluster& c1,
 												 cluster& c2) const
@@ -612,7 +601,7 @@ cluster ClusterGraph::commonClusterLastAncestors(node v,
 }//commonClusterLastAncestors
 //lowest common cluster and path between v and w containing it
 //note that eL is directed from v to w
-cluster ClusterGraph::commonClusterPath(node v, 
+cluster ClusterGraph::commonClusterPath(node v,
 										node w,
 										List<cluster>& eL) const
 {
@@ -621,7 +610,7 @@ cluster ClusterGraph::commonClusterPath(node v,
 }//commonClusterLastAncestors
 
 //note that eL is directed from v to w
-cluster ClusterGraph::commonClusterAncestorsPath(node v, 
+cluster ClusterGraph::commonClusterAncestorsPath(node v,
 												 node w,
 												 cluster& c1,
 												 cluster& c2,
@@ -637,11 +626,11 @@ cluster ClusterGraph::commonClusterAncestorsPath(node v,
 	//clusters from v and w to common
 	List<cluster> vList;
 	List<cluster> wList;
-	
+
 	//CASE1 no search necessary
 	//if both nodes are in the same cluster, we return this cluster
 	//and have to check if c1 == c2 to have a (v,w) representation edge
-	if (cv == cw) 
+	if (cv == cw)
 	{
 		c1 = c2 = cv;
 		eL.pushBack(c1);
@@ -650,7 +639,7 @@ cluster ClusterGraph::commonClusterAncestorsPath(node v,
 
 	if (m_lcaNumber == INT_MAX - 1) m_lcaNumber = 0;
 	else m_lcaNumber++;
-	if (!m_lcaSearch) 
+	if (!m_lcaSearch)
 	{
 		m_lcaSearch = OGDF_NEW ClusterArray<int>(*this, -1);
 		m_vAncestor = OGDF_NEW ClusterArray<cluster>(*this, 0);
@@ -659,7 +648,7 @@ cluster ClusterGraph::commonClusterAncestorsPath(node v,
 
 	//CASE2: one of the nodes hangs at root: save root as ancestor
 	//any other case: save cluster of node as ancestor, too, to check this
-	//case:: common = xCluster != yCluster 
+	//case:: common = xCluster != yCluster
 	//(*m_vAncestor)[rootCluster()] = rootCluster();
 	//(*m_wAncestor)[rootCluster()] = rootCluster();
 	(*m_vAncestor)[cv] = 0;
@@ -675,9 +664,9 @@ cluster ClusterGraph::commonClusterAncestorsPath(node v,
 	vList.pushBack(cv);
 	wList.pushBack(cw);
 
-	//we break and return if we find a common node 
+	//we break and return if we find a common node
 	//before we reach the rootcluster
-    do
+	do
 	{
 		if (cv->parent()) //root reached?
 		{
@@ -688,7 +677,7 @@ cluster ClusterGraph::commonClusterAncestorsPath(node v,
 			{
 				c1 = (*m_vAncestor)[cv];
 				c2 = (*m_wAncestor)[cv];
-				//setup list 
+				//setup list
 				ListIterator<cluster> itC = vList.begin();
 
 				while (itC.valid())
@@ -710,7 +699,7 @@ cluster ClusterGraph::commonClusterAncestorsPath(node v,
 			vList.pushBack(cv);
 			(*m_lcaSearch)[cv] = m_lcaNumber;
 		}//if not root reached on cvpath
-		
+
 		if (cw->parent())
 		{
 			(*m_wAncestor)[cw->parent()] = cw;
@@ -720,7 +709,7 @@ cluster ClusterGraph::commonClusterAncestorsPath(node v,
 			{
 				c1 = (*m_vAncestor)[cw];
 				c2 = (*m_wAncestor)[cw];
-				//setup list 
+				//setup list
 				ListIterator<cluster> itC = vList.begin();
 				while (itC.valid() && ((*itC) != cw))
 				{
@@ -742,7 +731,7 @@ cluster ClusterGraph::commonClusterAncestorsPath(node v,
 			wList.pushBack(cw);
 			(*m_lcaSearch)[cw] = m_lcaNumber;
 
-		}//if not root reached on cwpath 
+		}//if not root reached on cwpath
 	}	while ( cv->parent() || cw->parent() );
 
 	//v,w should be at least together in the rootcluster
@@ -752,10 +741,11 @@ cluster ClusterGraph::commonClusterAncestorsPath(node v,
 
 }//commonclusterlastAncestors
 
-void ClusterGraph::copyLCA(const ClusterGraph &C, 
-						   ClusterArray<cluster>*)
+void ClusterGraph::copyLCA(
+	const ClusterGraph &C,
+	ClusterArray<cluster>* clusterCopy)
 {
-	if (m_lcaSearch) 
+	if (m_lcaSearch)
 	{
 		delete m_lcaSearch;
 		delete m_vAncestor;
@@ -800,7 +790,7 @@ void ClusterGraph::emptyClusters(SList<cluster>& emptyCluster,
 	}//if checkcluster given
 	else
 	{
-		forall_clusters(cc, *this) 
+		forall_clusters(cc, *this)
 		{
 			if (cc->cCount() + cc->nCount() == 0)
 				if (cc != rootCluster()) //we dont add rootcluster
@@ -814,11 +804,11 @@ void ClusterGraph::emptyClusters(SList<cluster>& emptyCluster,
 	while (itC.valid())
 	{
 		//count deleted children
-		cluster runc = (*itC)->parent(); 
+		cluster runc = (*itC)->parent();
 		if (runc)  //is always the case as long as root was not inserted to list
 		{
 			delCount[runc]++;
-			while ((runc->nCount() == 0) && (runc->cCount() == delCount[runc])) 
+			while ((runc->nCount() == 0) && (runc->cCount() == delCount[runc]))
 			{
 				if (runc == rootCluster()) break;
 				emptyParent.pushBack(runc);
@@ -839,7 +829,7 @@ void ClusterGraph::emptyClusters(SList<cluster>& emptyCluster,
 // newCluster, delCluster, createCluster
 //---------------------------------------------------------
 
-// Inserts a new cluster prescribing its parent 
+// Inserts a new cluster prescribing its parent
 cluster ClusterGraph::newCluster(cluster parent, int id)
 {
 	OGDF_ASSERT(parent);
@@ -866,7 +856,7 @@ cluster ClusterGraph::newCluster(int id)
 	if (id >= m_clusterIdCount) m_clusterIdCount = id+1;
 	if (m_clusterIdCount >= m_clusterArrayTableSize)
 	{
-		m_clusterArrayTableSize = 
+		m_clusterArrayTableSize =
 			m_pGraph->nextPower2(m_clusterArrayTableSize, id);
 		for(ListIterator<ClusterArrayBase*> it = m_regClusterArrays.begin();
 			it.valid(); ++it)
@@ -886,7 +876,7 @@ cluster ClusterGraph::newCluster(int id)
 	return c;
 }
 
-// Inserts a new cluster 
+// Inserts a new cluster
 //has to be updated in the same way as newcluster(id)
 cluster ClusterGraph::newCluster()
 {
@@ -918,7 +908,7 @@ cluster ClusterGraph::createEmptyCluster(const cluster parent, int clusterId)
 {
 	//if no id given, use next free id
 	if (clusterId < 0) clusterId = m_clusterIdCount;
-	//create the new cluster 
+	//create the new cluster
 	cluster cnew;
 	if (parent)
 		cnew = newCluster(parent, clusterId);
@@ -930,7 +920,7 @@ cluster ClusterGraph::createEmptyCluster(const cluster parent, int clusterId)
 cluster ClusterGraph::createCluster(SList<node>& nodes, const cluster parent)
 {
 	cluster c;
-	if (m_allowEmptyClusters) 
+	if (m_allowEmptyClusters)
 	{
 		c = doCreateCluster(nodes, parent);
 		return c;
@@ -945,7 +935,7 @@ cluster ClusterGraph::createCluster(SList<node>& nodes, const cluster parent)
 		while (sIt.valid())
 		{
 			delCluster((*sIt));
-			
+
 			//root cluster can never be empty, as we deleted a node
 			sIt++;
 		}//While
@@ -953,7 +943,7 @@ cluster ClusterGraph::createCluster(SList<node>& nodes, const cluster parent)
 	return c;
 }
 
-cluster ClusterGraph::doCreateCluster(SList<node>& nodes, 
+cluster ClusterGraph::doCreateCluster(SList<node>& nodes,
 		const cluster parent,
 		int clusterId)
 {
@@ -962,7 +952,7 @@ cluster ClusterGraph::doCreateCluster(SList<node>& nodes,
 
 	//if no id given, use next free id
 	if (clusterId < 0) clusterId = m_clusterIdCount;
-	//create the new cluster 
+	//create the new cluster
 	cluster cnew;
 	if (parent)
 		cnew = newCluster(parent, clusterId);
@@ -980,12 +970,12 @@ cluster ClusterGraph::doCreateCluster(SList<node>& nodes,
 	return cnew;
 }//createcluster
 
-cluster ClusterGraph::doCreateCluster(SList<node>& nodes, 
+cluster ClusterGraph::doCreateCluster(SList<node>& nodes,
 		SList<cluster>& emptyCluster,
 		const cluster parent,
 		int clusterId)
 {
-	// Even if m_allowEmptyClusters is set we check if a cluster 
+	// Even if m_allowEmptyClusters is set we check if a cluster
 	// looses all of its nodes and has
 	// no more entries and childs. This can be used for special cluster
 	// object handling or for deletion if m_allowEmptyClusters is not set
@@ -993,7 +983,7 @@ cluster ClusterGraph::doCreateCluster(SList<node>& nodes,
 	// running time max(#cluster, length(nodelist))
 	// TODO: Parameter, der dies auslaesst, da hohe Laufzeit
 	// hier macht das nur Sinn, wenn es schneller ist als forallclusters,
-	// sonst koennte man es ja auch aussen testen, aber bisher ist es nicht 
+	// sonst koennte man es ja auch aussen testen, aber bisher ist es nicht
 	// schneller implementiert
 	// Vorgehen: hash auf cluster index, falls nicht gesetzt, in liste einfuegen
 	// und als checkcluster an emptycluster uebergeben
@@ -1002,7 +992,7 @@ cluster ClusterGraph::doCreateCluster(SList<node>& nodes,
 
 	//if no id given, use next free id
 	if (clusterId < 0) clusterId = m_clusterIdCount;
-	//create the new cluster 
+	//create the new cluster
 	cluster cnew;
 	if (parent)
 		cnew = newCluster(parent, clusterId);
@@ -1034,11 +1024,11 @@ cluster ClusterGraph::doCreateCluster(SList<node>& nodes,
 void ClusterGraph::delCluster(cluster c)
 {
 	OGDF_ASSERT(c != 0 && c->graphOf() == this && c != m_rootCluster)
-	
+
 	// notify observers
 	for(ListIterator<ClusterGraphObserver*> it = m_regObservers.begin();
 			it.valid(); ++it) (*it)->clusterDeleted(c);
-			
+
 	--m_nClusters;
 	m_adjAvailable = false;
 
@@ -1098,7 +1088,7 @@ void ClusterGraph::pullUpSubTree(cluster c)
 void ClusterGraph::clear()
 {
 	//split condition
-	if (m_lcaSearch) 
+	if (m_lcaSearch)
 	{
 		delete m_lcaSearch;
 		delete m_vAncestor;
@@ -1107,7 +1097,7 @@ void ClusterGraph::clear()
 	if (m_nClusters != 0)
 	{
 		clearClusterTree(m_rootCluster);
-		m_clusters.del(m_rootCluster); 
+		m_clusters.del(m_rootCluster);
 	}
 	//no clusters, so we can restart at 0
 	m_clusterIdCount = 0;
@@ -1168,14 +1158,14 @@ void ClusterGraph::clearClusterTree(cluster c,List<node> &attached)
 		trace = children.popFrontRet();
 		clearClusterTree(trace,attached);
 	}
-	m_clusters.del(c); 
+	m_clusters.del(c);
 }
 
 //don't delete root cluster
 void ClusterGraph::semiClear()
 {
 	//split condition
-	if (m_lcaSearch) 
+	if (m_lcaSearch)
 	{
 		delete m_lcaSearch;
 		delete m_vAncestor;
@@ -1222,7 +1212,7 @@ void ClusterGraph::moveCluster(cluster c, cluster newParent)
 	cluster oldParent = c->parent();
 	//we dont move root
 	OGDF_ASSERT(oldParent)
-	
+
 	//check if we move to a descendant
 	cluster crun = newParent->parent();
 	bool descendant = false;
@@ -1242,11 +1232,11 @@ void ClusterGraph::moveCluster(cluster c, cluster newParent)
 
 	// save postorder for old parent
 	bool newOrder = false;
-	if (!m_postOrderStart) 
+	if (!m_postOrderStart)
 	{
 		newOrder = true;
 	}
-	
+
 	//temporarily only recompute postorder for all clusters
 
 	oldParent->m_children.del(c->m_it);
@@ -1265,7 +1255,7 @@ void ClusterGraph::moveCluster(cluster c, cluster newParent)
 		//no sense, you could just delete the cluster or move
 		//the children
 		//move all children to oldparent
-		
+
 		while (!c->m_children.empty())
 		{
 			cluster child = c->m_children.popFrontRet();
@@ -1289,7 +1279,7 @@ void ClusterGraph::moveCluster(cluster c, cluster newParent)
 
 	// update postorder for new parent
 	// we only recompute postorder for all clusters
-	// because of special cases like move to descendant... 
+	// because of special cases like move to descendant...
 	if (newOrder) postOrder();
 	else postOrder();
 
@@ -1316,14 +1306,14 @@ cluster ClusterGraph::leftMostCluster(cluster c) const
 
 //searches for predecessor of SUBTREE at c
 cluster ClusterGraph::postOrderPredecessor(cluster c) const
-{	
+{
 	//all clusters on a path from root to leftmost cluster in tree
 	//have no predecessor for their subtree
 	cluster run = c;
 	ListConstIterator<cluster> it;
 	do
 	{
-		//predecessor of clustertree is	0 
+		//predecessor of clustertree is	0
 		if (run == m_rootCluster) return 0;
 		it = run->m_it;
 		//a child to the left is the immediate predecessor,
@@ -1331,9 +1321,9 @@ cluster ClusterGraph::postOrderPredecessor(cluster c) const
 		if (it == (run->m_parent)->m_children.begin())
 			run = run->parent();
 		else return (*(it.pred()));
-	
+
 	} while (run);
-	
+
 	return 0;
 }//postorderpredecessor
 
@@ -1364,7 +1354,7 @@ void ClusterGraph::reassignNode(node v, cluster c)
 
 
 //Unassigns a node of cluster
-//Note: Nodes can already be unassigned by the nodeDeleted function. 
+//Note: Nodes can already be unassigned by the nodeDeleted function.
 void ClusterGraph::unassignNode(node v)
 {
 	m_adjAvailable = false;
@@ -1396,7 +1386,7 @@ void ClusterGraph::postOrder() const
 	}
 	if (c != 0)
 		c->m_pNext = 0;
-	else 
+	else
 		m_postOrderStart->m_pNext = 0;
 #ifdef OGDF_DEBUG
 	forall_clusters(c, *this)
@@ -1414,7 +1404,7 @@ void ClusterGraph::checkPostOrder() const
 	cluster c = 0;
 	cluster prev = L.popFrontRet();
 	OGDF_ASSERT(prev->m_pPrev == 0);
-	
+
 	while (!L.empty())
 	{
 		c = L.popFrontRet();
@@ -1426,7 +1416,7 @@ void ClusterGraph::checkPostOrder() const
 	{
 		OGDF_ASSERT(c->m_pNext == 0)
 	}
-	else 
+	else
 	{
 		OGDF_ASSERT(m_postOrderStart->m_pNext == 0);
 	}
@@ -1435,7 +1425,7 @@ void ClusterGraph::checkPostOrder() const
 void ClusterGraph::postOrder(cluster c,SListPure<cluster> &L) const
 {
 	ListIterator<cluster> it;
-	for (it = c->m_children.begin(); it.valid(); it++) 
+	for (it = c->m_children.begin(); it.valid(); it++)
 		postOrder((*it),L);
 	L.pushBack(c);
 }
@@ -1462,7 +1452,7 @@ bool ClusterGraph::consistencyCheck()
 	{
 		visitedClusters[c] = true;
 		ListIterator<node> itn;
-		for (itn = c->m_entries.begin(); itn.valid(); itn++) 
+		for (itn = c->m_entries.begin(); itn.valid(); itn++)
 		{
 			node v = *itn;
 			if (m_nodeMap[v] != c)
@@ -1485,7 +1475,7 @@ bool ClusterGraph::consistencyCheck()
 bool ClusterGraph::representsCombEmbedding()
 {
 
-	if (!m_adjAvailable) 
+	if (!m_adjAvailable)
 		return false;
 
 	if (!consistencyCheck())
@@ -1498,10 +1488,10 @@ bool ClusterGraph::representsCombEmbedding()
 
 		#ifdef OGDF_DEBUG
 		if (int(ogdf::debugLevel) >= int(dlHeavyChecks)){
-			cout << "__________________________________________________________________" 
+			cout << "__________________________________________________________________"
 				 << endl << endl
 				 << "Testing cluster " << c << endl
-				 << "Check on AdjList of c" << endl; 
+				 << "Check on AdjList of c" << endl;
 			adjEntry adjDD;
 			forall_cluster_adj(adjDD,c)
 				cout << adjDD << ";  ";
@@ -1511,7 +1501,7 @@ bool ClusterGraph::representsCombEmbedding()
 
 		if (c != m_rootCluster)
 		{
-			
+
 			ListIterator<adjEntry> it;
 			it = c->firstAdj();
 			adjEntry start = *it;
@@ -1528,7 +1518,7 @@ bool ClusterGraph::representsCombEmbedding()
 				ListIterator<adjEntry> succ = it.succ();
 				adjEntry adj = *it;
 				adjEntry succAdj;
-				
+
 				if (succ.valid())
 					succAdj = *succ;
 				else
@@ -1537,9 +1527,9 @@ bool ClusterGraph::representsCombEmbedding()
 				#ifdef OGDF_DEBUG
 				if (int(ogdf::debugLevel) >= int(dlHeavyChecks)){
 					cout << "Check next " << endl;
-					cout << "current in adj list of" << adj << endl; 
-					cout << "succ in adj list of c " << succAdj << endl; 
-					cout << "cyclic succ in outer face " << adj->cyclicSucc() << endl; 
+					cout << "current in adj list of" << adj << endl;
+					cout << "succ in adj list of c " << succAdj << endl;
+					cout << "cyclic succ in outer face " << adj->cyclicSucc() << endl;
 				}
 				#endif
 
@@ -1555,8 +1545,8 @@ bool ClusterGraph::representsCombEmbedding()
 					#ifdef OGDF_DEBUG
 					if (int(ogdf::debugLevel) >= int(dlHeavyChecks)){
 						cout << "Running along the outer face ... " << endl;
-						cout << "next adj " << next << endl; 
-						cout << "twin adj " << twin << endl; 
+						cout << "next adj " << next << endl;
+						cout << "twin adj " << twin << endl;
 					}
 					#endif
 
@@ -1570,8 +1560,8 @@ bool ClusterGraph::representsCombEmbedding()
 						#ifdef OGDF_DEBUG
 						if (int(ogdf::debugLevel) >= int(dlHeavyChecks)){
 							cout << "Running along the outer face ... " << endl;
-							cout << "next adj " << next << endl; 
-							cout << "twin adj " << twin << endl; 
+							cout << "next adj " << next << endl;
+							cout << "twin adj " << twin << endl;
 						}
 						#endif
 						if (visitedAdjEntries[twin])
@@ -1584,11 +1574,11 @@ bool ClusterGraph::representsCombEmbedding()
 				// next edge is also outgoing
 
 				it = succ;
-			}	
+			}
 		}
 	}
 
-	
+
 	return true;
 
 }
@@ -1614,7 +1604,7 @@ ListIterator<ClusterGraphObserver*> ClusterGraph::registerObserver(ClusterGraphO
 {
 	return m_regObservers.pushBack(pObserver);
 }
-	
+
 //! Unregisters a ClusterGraphObserver.
 void ClusterGraph::unregisterObserver(ListIterator<ClusterGraphObserver*> it) const
 {
@@ -1640,29 +1630,28 @@ void ClusterGraph::writeGML(ostream &os)
 	int nextId = 0;
 
 	os << "Creator \"ogdf::ClusterGraph::writeGML\"\n";
-	os << "directed 1\n";
-
 	os << "graph [\n";
+	os << "  directed 1\n";
 
 	node v;
 	forall_nodes(v,*m_pGraph) {
-		os << "node [\n";
-		os << "id " << (nId[v] = nextId++) << "\n";
-		os << "]\n"; // node
+		os << "  node [\n";
+		os << "    id " << (nId[v] = nextId++) << "\n";
+		os << "  ]\n"; // node
 	}
 
 	edge e;
 	forall_edges(e,*m_pGraph) {
-		os << "edge [\n";
-		os << "source " << nId[e->source()] << "\n";
-		os << "target " << nId[e->target()] << "\n";
-		os << "]\n"; // edge
+		os << "  edge [\n";
+		os << "    source " << nId[e->source()] << "\n";
+		os << "    target " << nId[e->target()] << "\n";
+		os << "  ]\n"; // edge
 	}
 
-	String scip = "\0";
+	String scip = "  ";
 	nextId = 0;
 	writeCluster(os,nId,cId,nextId,m_rootCluster,scip);
-		
+
 	os << "]\n"; // graph
 }
 
@@ -1678,13 +1667,13 @@ void ClusterGraph::writeCluster(ostream &os,
 	String newScip = scip;
 	newScip+="  ";
 	os << scip << "cluster [\n";
-	os << scip << "id " << (cId[c] = nextId++) << "\n";
+	os << scip << "  id " << (cId[c] = nextId++) << "\n";
 	ListIterator<cluster> it;
-	for (it = c->m_children.begin(); it.valid(); it++) 
+	for (it = c->m_children.begin(); it.valid(); it++)
 		writeCluster(os,nId,cId,nextId,*it,newScip);
 	ListIterator<node> itn;
-	for (itn = c->m_entries.begin(); itn.valid(); itn++) 
-		os << scip << "node " << nId[*itn] << "\n";
+	for (itn = c->m_entries.begin(); itn.valid(); itn++)
+		os << scip << "  node " << nId[*itn] << "\n";
 	os << scip << "]\n"; // cluster
 }
 
@@ -1706,25 +1695,76 @@ void ClusterGraph::writeGraphWinCluster(ostream &os,
 	else
 	{
 		os << scip << "cluster [\n";
-//		os << scip << "id " << (cId[c] = nextId++) << "\n";
-		os << scip << "id " << c->index() << "\n";
+//		os << scip << "  id " << (cId[c] = nextId++) << "\n";
+		os << scip << "  id " << c->index() << "\n";
 		char newLabel[124];
 //		sprintf(newLabel,"C%d",cId[c]);
 		ogdf::sprintf(newLabel,124,"C%d",c->index());
 		cStr[c] = newLabel;
-		os << scip << "label \"" << cStr[c] << "\"\n"; 
+		os << scip << "  label \"" << cStr[c] << "\"\n";
 
 	}
 	ListIterator<cluster> it;
-	for (it = c->m_children.begin(); it.valid(); it++) 
+	for (it = c->m_children.begin(); it.valid(); it++)
 		writeGraphWinCluster(os,nId,nStr,cId,cStr,nextId,*it,newScip);
 	ListIterator<node> itn;
-	for (itn = c->m_entries.begin(); itn.valid(); itn++) 
-		os << scip << "vertex \"v" << nId[*itn] << "\"\n";
+	for (itn = c->m_entries.begin(); itn.valid(); itn++)
+		os << scip << "  vertex \"v" << nId[*itn] << "\"\n";
 	os << scip << "]\n"; // cluster
 }
 
 
+//++++++++++++++++++++++++++++++++++++++++++++
+//reading graph,  cluster structure
+bool ClusterGraph::readClusterGML(const char* fileName,
+								Graph& G)
+{
+	ifstream is(fileName);
+	if (!is)
+		return false; // couldn't open file
+
+	return readClusterGML(is, G);
+}
+
+bool ClusterGraph::readClusterGML(istream& is,
+								Graph& G)
+{
+	bool result;
+	GmlParser gml(is);
+	if (gml.error())
+		return false;
+
+	result = gml.read(G);
+
+	if (!result) return false;
+
+	return gml.readCluster(G, *this);
+}
+
+
+// read Cluster Graph from OGML file
+//bool ClusterGraph::readClusterGraphOGML(const char* fileName,
+//												 ClusterGraph& CG,
+//												 Graph& G)
+//{
+//	ifstream is(fileName);
+//	// not able to open file
+//	if (!is) return false;
+//
+//	OgmlParser *op = new OgmlParser();
+//	// build graph
+//	// method read contains the validation
+//	if (!op->read(fileName, G, CG, *this)){
+//		delete(op);
+//		cerr << "ERROR occured while reading. Aborting." << endl << flush;
+//		return false;
+//	}
+//
+//	delete(op);
+//	return true;
+//};
+
+
 } // end namespace ogdf
 
 //****************************************************************
