@@ -1,57 +1,48 @@
 /*
- * $Revision: 2040 $
- * 
+ * $Revision: 2610 $
+ *
  * last checkin:
- *   $Author: klein $ 
- *   $Date: 2010-09-29 14:20:11 +0200 (Wed, 29 Sep 2010) $ 
+ *   $Author: klein $
+ *   $Date: 2012-07-16 10:04:15 +0200 (Mo, 16. Jul 2012) $
  ***************************************************************/
- 
+
 /** \file
  * \brief Implementation of the master class for the Branch&Cut algorithm
  * for the Maximum C-Planar SubGraph problem
- * 
+ *
  * This class is managing the optimization.
  * Variables and initial constraints are generated and pools are initialized.
  * Since variables correspond to the edges of a complete graph, node pairs
  * are used mostly instead of edges.
- * 
+ *
  * \author Markus Chimani, Mathias Jansen, Karsten Klein
- * 
+ *
  * \par License:
  * This file is part of the Open Graph Drawing Framework (OGDF).
  *
- * Copyright (C). All rights reserved.
+ * \par
+ * Copyright (C)<br>
  * See README.txt in the root directory of the OGDF installation for details.
- * 
+ *
  * \par
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
  *
  * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- * 
- * \par
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * \par
- * You should have received a copy of the GNU General Public 
+ * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- * 
+ *
  * \see  http://www.gnu.org/copyleft/gpl.html
  ***************************************************************/
 
@@ -121,7 +112,7 @@ Master::Master(
 	m_strongVariableViolation(strongVariableViolation),
 	ABA_MASTER("MaxCPlanar", true, dopricing, ABA_OPTSENSE::Max)
 {
-	
+
 	// Reference to the given ClusterGraph and the underlying Graph.
 	m_C = &C;
 	m_G = &(C.getGraph());
@@ -129,11 +120,11 @@ Master::Master(
 	m_solutionGraph = new GraphCopy(*m_G);
 	// Define the maximum number of variables needed.
 	// The actual number needed may be much smaller, so there
-	// is room for improvement... 
+	// is room for improvement...
 	//ToDo: Just count how many vars are added
 
 	//Max number of edges
-	//KK: Check this change, added div 2 
+	//KK: Check this change, added div 2
 	int nComplete = (m_G->numberOfNodes()*(m_G->numberOfNodes()-1)) / 2;
 	m_nMaxVars = nComplete;
 	//to use less variables in case we have only the root cluster,
@@ -144,7 +135,7 @@ Master::Master(
 	// Computing the main objective function coefficient for the connection edges.
 	//int nConnectionEdges = nComplete - m_G->numberOfEdges();
 	m_epsilon = (double)(0.2/(2*(m_G->numberOfNodes())));
-	
+
 	// Setting parameters
 	m_out = ol;
 	m_nKuratowskiIterations = kuratowskiIterations;
@@ -160,7 +151,7 @@ Master::Master(
 	m_heuristicFractionalBound = heuristicOEdgeBound;
 	m_nHeuristicPermutationLists = heuristicNPermLists;
 	m_mpHeuristic = true;
-	
+
 	// Further settings
 	m_nCConsAdded = 0;
 	m_nKConsAdded = 0;
@@ -175,7 +166,7 @@ Master::Master(
 	m_varsBranch = 0;
 	m_activeRepairs = 0;
 	m_repairStat.init(100);
-	
+
 	outLevel(ol);
 }
 
@@ -193,7 +184,7 @@ ABA_SUB *Master::firstSub() {
 
 // Replaces current m_solutionGraph by new GraphCopy based on \a connection list
 void Master::updateBestSubGraph(List<nodePair> &original, List<nodePair> &connection, List<edge> &deleted) {
-	
+
 	// Creates a new GraphCopy \a m_solutionGraph and deletes all edges
 	// TODO: Extend GraphCopySimple to be usable here: Allow
 	// edge deletion and add pure node initialization
@@ -208,52 +199,86 @@ void Master::updateBestSubGraph(List<nodePair> &original, List<nodePair> &connec
 		m_solutionGraph->delEdge(e);
 		e = succ;
 	}
-	
+
 	// Delete all edges that have been stored previously in edge lists
 	m_allOneEdges.clear();
 	m_originalOneEdges.clear();
 	m_connectionOneEdges.clear();
 	m_deletedOriginalEdges.clear();
-	
+
 	// Update the edge lists according to new solution
 	ListConstIterator<nodePair> oit = original.begin();
 	node cv,cw;
 	while (oit.valid()) {
-		
+
 		// Add all original edges to \a m_solutionGraph
 		cv = m_solutionGraph->copy((*oit).v1);
 		cw = m_solutionGraph->copy((*oit).v2);
 		m_solutionGraph->newEdge(cv,cw);
-		
+
 		m_allOneEdges.pushBack(*oit);
 		m_originalOneEdges.pushBack(*oit);
-		
+
 		oit++;
 	}
-	
+
 	ListConstIterator<nodePair> cit = connection.begin();
 	while (cit.valid()) {
-		
+
 		// Add all new connection edges to \a m_solutionGraph
 		cv = m_solutionGraph->copy((*cit).v1);
 		cw = m_solutionGraph->copy((*cit).v2);
 		m_solutionGraph->newEdge(cv,cw);
-		
+
 		m_allOneEdges.pushBack(*cit);
 		m_connectionOneEdges.pushBack(*cit);
-		
+
 		cit++;
 	}
-	
+
 	ListConstIterator<edge> dit = deleted.begin();
 	while (dit.valid()) {
-		
+
 		m_deletedOriginalEdges.pushBack(*dit);
-		
+
 		dit++;
 	}
 #ifdef OGDF_DEBUG
 	m_solutionGraph->writeGML("UpdateSolutionGraph.gml");
+//Just for special debugging purposes:
+	if (true) {//note that we output the original graph plus added edges, but don't remove deleted ones
+		ClusterArray<cluster> ca(*m_C);
+		Graph GG;
+		NodeArray<node> na(*m_G);
+		ClusterGraph CG(*m_C,GG, ca, na);
+
+		cit = connection.begin();
+
+		List<edge> le;
+
+		while (cit.valid()) {
+
+			// Add all new connection edges to \a m_solutionGraph
+			cv = na[(*cit).v1];
+			cw = na[(*cit).v2];
+			edge e = GG.newEdge(cv,cw);
+			le.pushBack(e);
+
+			cit++;
+		}
+
+		ClusterGraphAttributes CGA(CG, GraphAttributes::edgeType | GraphAttributes::nodeType |
+				GraphAttributes::nodeGraphics | GraphAttributes::edgeGraphics | GraphAttributes::edgeColor);
+		ListConstIterator<edge> it = le.begin();
+		while (it.valid())
+		{
+			cout << (*it)->graphOf() << "\n";
+			cout << &GG << "\n";
+			CGA.colorEdge(*it) = "#FF0000";
+			it++;
+		}
+		CGA.writeGML("PlanarExtensionMCPSP.gml");
+	}
 #endif
 }
 
@@ -310,34 +335,34 @@ void Master::clusterConnection(cluster c, GraphCopy &gc, double &upperBoundC) {
 		for (it=clusterNodes.begin(); it.valid(); ++it) {
 			vInC[gc.copy(*it)] = true;
 		}
-		
+
 		// Delete all nodes from \a inducedC that do not belong to the cluster,
 		// in order to obtain the cluster induced graph.
 		v = inducedC->firstNode();
-		while (v!=0)  { 
+		while (v!=0)  {
 			w = v->succ();
 			if (!vInC[inducedC->original(v)]) inducedC->delNode(v);
 			v = w;
 		}
-		
+
 		// Determine number of connected components of cluster induced graph.
-		//Todo: check could be skipped 
+		//Todo: check could be skipped
 		if (!isConnected(*inducedC)) {
-			
+
 			NodeArray<int> conC(*inducedC);
 			int nCC = connectedComponents(*inducedC,conC);
 			//at least #connected components - 1 edges have to be added.
 			upperBoundC -= (nCC-1)*m_largestConnectionCoeff;
 		}
 		delete inducedC;
-	// Cluster \a c is an "inner" cluster. Process all child clusters first.	
+	// Cluster \a c is an "inner" cluster. Process all child clusters first.
 	} else {	//c->cCount is != 0, process all child clusters first
-		
+
 		ListConstIterator<cluster> cit;
 		for (cit=c->cBegin(); cit.valid(); ++cit) {
 			clusterConnection(*cit,gc,upperBoundC);
 		}
-		
+
 		// Create cluster induced graph.
 		GraphCopy *inducedC = new GraphCopy((const Graph&)gc);
 		node v,w;
@@ -353,7 +378,7 @@ void Master::clusterConnection(cluster c, GraphCopy &gc, double &upperBoundC) {
 			if (!vInC[inducedC->original(v)]) inducedC->delNode(v);
 			v = w;
 		}
-		
+
 		// Now collapse each child cluster to one node and determine #connected components of \a inducedC.
 		List<node> oChildClusterNodes;
 		List<node> cChildClusterNodes;
@@ -372,20 +397,20 @@ void Master::clusterConnection(cluster c, GraphCopy &gc, double &upperBoundC) {
 		}
 		// Now, check \a inducedC for connectivity.
 		if (!isConnected(*inducedC)) {
-			
+
 			NodeArray<int> conC(*inducedC);
 			int nCC = connectedComponents(*inducedC,conC);
 			//at least #connected components - 1 edges have to added.
 			upperBoundC -= (nCC-1)*m_largestConnectionCoeff;
 		}
-		delete inducedC;		
+		delete inducedC;
 	}
 }//clusterConnection
 
 double Master::heuristicInitialLowerBound()
 {
 	double lbound = 0.0;
-	//In case we only have a single (root) cluster, we can 
+	//In case we only have a single (root) cluster, we can
 	//use the result of a fast Max Planar Subgraph heuristic
 	//to initialize the lower bound
 	if ( (m_C->numberOfClusters() == 1) && (m_mpHeuristic) )
@@ -400,24 +425,24 @@ double Master::heuristicInitialLowerBound()
     	List<edge> delEdgesListFast;
     	fastHeur.call(*m_G, delEdgesListFast);
     	lbound = m_G->numberOfEdges()-min(delEdgesList.size(), delEdgesListFast.size());
-    	
+
     	if (!isConnected(*m_G)) lbound = lbound-1.0; //#edges*epsilon
 	}//if heuristics used
 	return lbound;
 }//heuristicInitialLowerBound
 
 double Master::heuristicInitialUpperBound() {
-	
+
 	double upperBoundO = m_G->numberOfEdges();
 	double upperBoundC = 0.0;
-	
+
 	// Checking graph for planarity
 	// If \a m_G is planar \a upperBound is simply set to the number of edges of \a m_G.
 	GraphCopy gc(*m_G);
 	BoyerMyrvold bm;
-	if (bm.planarDestructive(gc)) upperBoundO = m_G->numberOfEdges();
+	if (bm.isPlanarDestructive(gc)) upperBoundO = m_G->numberOfEdges();
 	else {
-	
+
 		// Extract all possible Kuratowski subdivisions.
 		// Compare extracted subdivisions and try to obtain the
 		// maximum number of independent subdivisions, i.e. a maximum
@@ -425,49 +450,49 @@ double Master::heuristicInitialUpperBound() {
 		// Due to the complexity of this task, we only check if
 		// a subdivision (sd) does overlap with a subdivision for which
 		// we already decreased the upper bound. In this case,
-		// upperBound stays the same.   
-		
+		// upperBound stays the same.
+
 		upperBoundO = m_G->numberOfEdges();
-		
+
 		GraphCopy *gCopy = new GraphCopy(*m_G);
 		SList<KuratowskiWrapper> subDivs;
 
 		bm.planarEmbedDestructive(*gCopy,subDivs,-1);
 		//we store a representative and its status for each edge
-		//note that there might be an overlap, in that case 
-		//we keep a representative with status false if existing 
+		//note that there might be an overlap, in that case
+		//we keep a representative with status false if existing
 		//to check if we can safely reduce the upper bound (ub)
 		EdgeArray<edge> subRep(*gCopy, NULL); //store representing edge for sd
-		EdgeArray<bool> coverStatus(*gCopy, false); //false means not covered by ub decrease yet 
-		 
+		EdgeArray<bool> coverStatus(*gCopy, false); //false means not covered by ub decrease yet
+
 		//runtime for the check: we run over all edges in all subdivisions
 		if (subDivs.size() > 0) { // At least one edge has to be deleted to obtain planarity.
-			
+
 			// We run over all subdivisions and check for overlaps
 			SListConstIterator<KuratowskiWrapper> sit = subDivs.begin();
 			SListConstIterator<edge> eit;
-			while( sit.valid() ) 
+			while( sit.valid() )
 			{
 				bool covered = false; //may the sd already be covered by a decrease in ub
 				//for each edge we set the representative to be the first edge of sd
 				edge sdRep = *((*sit).edgeList.begin());//sd is always non-empty
 				//we check if any of the edges in sd were already visited and if
-				//the representative has status false, in this case, we are not 
+				//the representative has status false, in this case, we are not
 				//allowed to decrease the ub
-				for (eit=(*sit).edgeList.begin(); eit.valid(); ++eit) 
+				for (eit=(*sit).edgeList.begin(); eit.valid(); ++eit)
 				{
 					//we already encountered this edge
 					if (subRep[*eit] != NULL)
 					{
 						//and decreased ub for an enclosing sd
 						//(could we just break in the if case?)
-						if (coverStatus[subRep[*eit]]) covered = true; 
+						if (coverStatus[subRep[*eit]]) covered = true;
 						else subRep[*eit] = sdRep; //might need an update
 					}
 					else subRep[*eit] = sdRep;
 				}
-				if (!covered) 
-				{	
+				if (!covered)
+				{
 					coverStatus[sdRep] = true;
 					upperBoundO--;
 				}//not yet covered, independent
@@ -475,8 +500,8 @@ double Master::heuristicInitialUpperBound() {
 			}//while
 		}
 		delete gCopy;
-	}	
-	
+	}
+
 	/*
 	 * Heuristic can be improved by checking, how many additional C-edges have to be added at least.
 	 * A first simple approach is the following:
@@ -488,19 +513,19 @@ double Master::heuristicInitialUpperBound() {
 	 * a counter. For "inner" clusters we have to collapse all child clusters to one node,
 	 * in order to obtain a correct result.
 	 */
-	
+
 	GraphCopy gcc(*m_G);
 	cluster c = m_C->rootCluster();
 	clusterConnection(c, gcc, upperBoundC);
-	
+
 	// Return-value results from the max. number of O-edges that might be contained
 	// in an optimal solution minus \a epsilon times the number of C-edges that have
 	// to be added at least in any optimal solution. (\a upperBoundC is non-positive)
-	return (upperBoundO + upperBoundC);	
+	return (upperBoundO + upperBoundC);
 }
 
 void Master::nodeDistances(node u, NodeArray<NodeArray<int> > &dist) {
-	
+
 	// Computing the graphtheoretical distances of node u
 	NodeArray<bool> visited(*m_G);
 	List<node> queue;
@@ -535,7 +560,7 @@ bool Master::goodVar(node a, node b) {
 	GraphCopy GC(*m_G);
 	edge e = GC.newEdge(GC.copy(a),GC.copy(b));
 	BoyerMyrvold bm;
-	int ret =  bm.planarDestructive(GC);
+	int ret =  bm.isPlanarDestructive(GC);
 	Logger::slout() << ret << "\n";
 	return ret;
 }
@@ -549,32 +574,32 @@ void Master::initializeOptimization() {
 		//TODO Shortcut: lowerbound number original edges (-1) if not pricing
 		//enumerationStrategy(BreadthFirst);
 	}
-	
+
 	if (pricing())
 		varElimMode(NoVarElim);
-	else 
+	else
 		varElimMode(ReducedCost);
 	conElimMode(Basic);
 	if(pricing())
-		pricingFreq(1);	
-	
+		pricingFreq(1);
+
 	//----------------------------Creation of Variables--------------------------------//
-	
+
 	// Lists for original and connection edges
 	List<EdgeVar*> origVars;    // MCh: ArrayBuffer would speed this up
 	List<EdgeVar*> connectVars; // MCh: ArrayBuffer would speed this up
-	
-	//cluster connectivity only necessary if there are clusters (not for max planar subgraph) 
-	bool toBeConnected = (!( (m_C->numberOfClusters() == 1) && (isConnected(*m_G)) ) ); 
-	
+
+	//cluster connectivity only necessary if there are clusters (not for max planar subgraph)
+	bool toBeConnected = (!( (m_C->numberOfClusters() == 1) && (isConnected(*m_G)) ) );
+
     int nComplete = (m_G->numberOfNodes()*(m_G->numberOfNodes()-1))/2;
     int nConnectionEdges = nComplete - m_G->numberOfEdges();
-    
+
     double perturbMe = (m_usePerturbation)? 0.2*m_epsilon : 0;
     m_deltaCount = nConnectionEdges;
    	m_delta  = (m_deltaCount > 0) ? perturbMe/m_deltaCount : 0;
     double coeff;
-        
+
     // In order not to place the initial upper bound too low,
     // we use the largest connection edge coefficient for each C-edge
     // to lower the upper bound (since these coeffs are negative,
@@ -585,11 +610,11 @@ void Master::initializeOptimization() {
     forall_nodes(u,*m_G) {
         v = u->succ();
         while (v!=NULL) {//todo could skip searchedge if toBeConnected
-            if(m_G->searchEdge(u,v)) 
+            if(m_G->searchEdge(u,v))
             	origVars.pushBack(new EdgeVar(this,1.0+rand()*perturbMe,EdgeVar::ORIGINAL,u,v));
             else if (toBeConnected) {
             	if( (!m_checkCPlanar) || goodVar(u,v)) {
-	            	if(pricing()) 
+	            	if(pricing())
 	            		m_inactiveVariables.pushBack(nodePair(u,v));
 	            	else
 	            		connectVars.pushBack( new EdgeVar(this, nextConnectCoeff(), EdgeVar::CONNECT, u,v) );
@@ -600,16 +625,16 @@ void Master::initializeOptimization() {
         }
     }
     m_varsPotential = m_inactiveVariables.size();
-    
+
 	//-------------------Creation of ChunkConnection-Constraints------------------------//
-	
+
     int nChunks = 0;
-    
+
 	List<ChunkConnection*> constraintsCC;
-	
+
 	// The Graph, in which each cluster-induced Graph is temporarily stored
 	Graph subGraph;
-	
+
 	// Since the function inducedSubGraph(..) creates a new Graph \a subGraph, the original
 	// nodes have to be mapped to the copies. This mapping is stored in \a orig2new.
 	NodeArray<node> orig2new;
@@ -618,14 +643,14 @@ void Master::initializeOptimization() {
 	ListConstIterator<node> it;
 	cluster c;
 	forall_clusters(c,*m_C) {
-		
+
 		List<node> clusterNodes;
 		c->getClusterNodes(clusterNodes);
-		
+
 		// Compute the cluster-induced Subgraph
 		it = clusterNodes.begin();
 		inducedSubGraph(*m_G, it, subGraph, orig2new);
-		
+
 		// Compute the number of connected components
 		NodeArray<int> components(subGraph);
 		int nCC = connectedComponents(subGraph,components);
@@ -633,15 +658,15 @@ void Master::initializeOptimization() {
 		// If the cluster consists of more than one connected component,
 		// ChunkConnection constraints can be created.
 		if (nCC > 1) {
-			
+
 			// Determine each connected component (chunk) of the current cluster-induced Graph
 			for (int i=0; i<nCC; ++i) {
-				
-				ArrayBuffer<node> cC(subGraph.numberOfNodes()); 
-				ArrayBuffer<node> cCComplement(subGraph.numberOfNodes()); 
+
+				ArrayBuffer<node> cC(subGraph.numberOfNodes());
+				ArrayBuffer<node> cCComplement(subGraph.numberOfNodes());
 				node v;
 				forall_nodes(v,*m_G/*subGraph*/) {
-					node n = orig2new[v]; 
+					node n = orig2new[v];
 					if(n) {
 						if (components[n] == i) cC.push(v);
 						else cCComplement.push(v);
@@ -651,20 +676,23 @@ void Master::initializeOptimization() {
 				constraintsCC.pushBack(new ChunkConnection(this, cC, cCComplement));
 				// Avoiding duplicates if cluster consists of 2 chunks
 				if (nCC == 2) break;
-				
+
 			}//connected component has been processed
 		}//end if(nCC > 1)
 	}//end forall_clusters
 	if(pricing())
 		generateVariablesForFeasibility(constraintsCC, connectVars);
-		
+
 	//------------Creation of MinimalClusterConnection-Constraints---------------//
 	/*
 	List<MinimalClusterConnection*> constraintsMCC;
 	cluster succ;
 	ClusterArray<bool> connected(*m_C);
+	// For each cluster run through all cluster vertices and check if
+	// they have an outgoing edge to a different cluster.
+	// In this case, mark that cluster in connected as true.
 	forall_clusters(c,*m_C) {
-		
+
 		succ = c->succ();
 		connected.fill(false);
 		List<node> clusterNodes;
@@ -678,7 +706,7 @@ void Master::initializeOptimization() {
 				}
 			}
 		}
-			
+
 		//checking if there is an entry in \a connected of value false
 		//if so, cluster \a c is not connected to this one and a constraint is created
 		List<nodePair> mcc_edges;
@@ -706,18 +734,18 @@ void Master::initializeOptimization() {
 		}
 	}
 	*/
-	
+
 	//------------Creation of MaxPlanarEdges-Constraints---------------//
-	
+
 	List<MaxPlanarEdgesConstraint*> constraintsMPE;
-	
+
 	int nMaxPlanarEdges = 3*m_G->numberOfNodes() - 6;
 	constraintsMPE.pushBack(new MaxPlanarEdgesConstraint(this,nMaxPlanarEdges));
-	
+
 	List<node> clusterNodes;
 	List<nodePair> clusterEdges;
 	forall_clusters(c,*m_C) {
-		
+
 		if (c == m_C->rootCluster()) continue;
 		clusterNodes.clear(); clusterEdges.clear();
 		c->getClusterNodes(clusterNodes);
@@ -737,13 +765,13 @@ void Master::initializeOptimization() {
 			constraintsMPE.pushBack(new MaxPlanarEdgesConstraint(this,maxPlanarEdges,clusterEdges));
 		}
 	}
-	
-	
+
+
 	//------------------------Adding Constraints to the Pool---------------------//
-	
+
 	// Adding constraints to the standardpool
 	ABA_BUFFER<ABA_CONSTRAINT *> initConstraints(this,constraintsCC.size()/*+constraintsMCC.size()*/+constraintsMPE.size());
-	
+
 	ListConstIterator<ChunkConnection*> ccIt;
 	updateAddedCCons(constraintsCC.size());
 	for (ccIt = constraintsCC.begin(); ccIt.valid(); ++ccIt) {
@@ -760,13 +788,13 @@ void Master::initializeOptimization() {
 	//output these constraints in a file that can be read by the module
 	if (m_porta)
 	{
-		
+
 		ofstream ofs(getStdConstraintsFileName());
 		if (!ofs) cerr << "Could not open output stream for PORTA constraints file\n";
 		else
 		{
 			ofs << "# Chunkconnection constraints\n";
-			//holds the coefficients in a single constraint for all vars defined 
+			//holds the coefficients in a single constraint for all vars defined
 			//so far
 			List<double> theCoeffs;
 			ListIterator<ChunkConnection*> csIt;
@@ -793,7 +821,7 @@ void Master::initializeOptimization() {
 //					dIt++;
 //				}//while
 //				ofs << "<= " << (*mccIt)->rhs();
-//				ofs << "\n";				
+//				ofs << "\n";
 //			}
 			ofs << "# MaxPlanarEdges constraints\n";
 			ListConstIterator<MaxPlanarEdgesConstraint*> mpeIt;
@@ -807,13 +835,13 @@ void Master::initializeOptimization() {
 				}//while
 				ofs << "<= " << (*mpeIt)->rhs();
 				ofs << "\n";
-			}			
+			}
 			ofs.close();
 		}
 	}
-	
+
 	//---------------------Adding Variables to the Pool---------------------//
-	
+
 	// Adding variables to the standardpool
 	ABA_BUFFER<ABA_VARIABLE *> edgeVariables(this,origVars.size()+connectVars.size());
 	ListConstIterator<EdgeVar*> eIt;
@@ -823,10 +851,10 @@ void Master::initializeOptimization() {
 	for (eIt = connectVars.begin(); eIt.valid(); ++eIt) {
 		edgeVariables.push(*eIt);
 	}
-	
-	
+
+
 	//---------------------Initializing the Pools---------------------------//
-	
+
 	int poolsize = (getGraph()->numberOfNodes() * getGraph()->numberOfNodes());
 	if (m_useDefaultCutPool)
 		initializePools(initConstraints, edgeVariables, m_nMaxVars, poolsize, true);
@@ -838,9 +866,9 @@ void Master::initializeOptimization() {
 		m_cutKuraPool = new ABA_STANDARDPOOL<ABA_CONSTRAINT, ABA_VARIABLE>(this, poolsize, true);
 	}
 
-	
+
 	//---------------------Initialize Upper Bound---------------------------//
-	
+
 	//if we check only for c-planarity, we cannot set bounds
 	if (!m_checkCPlanar)
 	{
@@ -848,12 +876,12 @@ void Master::initializeOptimization() {
 		dualBound(upperBound); // TODO-TESTING
 
 	//---------------------Initialize Lower Bound---------------------------//
-	
+
 		primalBound(heuristicInitialLowerBound()); // TODO-TESTING
 	} else {
 		//primalBound(-m_G->numberOfNodes()*3);
 	}
-	
+
 	//----------------------Setting Parameters------------------------------//
 
 //	conElimMode(ABA_MASTER::NonBinding);
@@ -864,13 +892,13 @@ void Master::initializeOptimization() {
 	Logger::ssout() << "#Edges: " << m_G->numberOfEdges() << "\n";
 	Logger::ssout() << "#Clusters: " << m_C->numberOfClusters() << "\n";
 	Logger::ssout() << "#Chunks: " << nChunks << "\n";
-	
-	
+
+
 }
 
 // returns coefficients of all variables in orig and connect in constraint con
 // as list coeffs
-void Master::getCoefficients(ABA_CONSTRAINT* con,  const List<EdgeVar* > & orig, 
+void Master::getCoefficients(ABA_CONSTRAINT* con,  const List<EdgeVar* > & orig,
 	const List<EdgeVar* > & connect, List<double> & coeffs)
 {
 	coeffs.clear();
@@ -886,7 +914,7 @@ void Master::getCoefficients(ABA_CONSTRAINT* con,  const List<EdgeVar* > & orig,
 		coeffs.pushBack(con->coeff(*cIt));
 		cIt++;
 	}//while
-	
+
 }
 
 
@@ -898,17 +926,20 @@ void Master::terminateOptimization() {
 	Logger::slout() << "Terminate Optimization:\n";
 	Logger::slout() << "(primal Bound: " << primalBound() << ")\n";
 	Logger::slout() << "(dual Bound: " << dualBound() << ")\n";
-	Logger::slout() << "*** " << (feasibleFound() ? "" : "NON ") << "C-PLANAR ***\n";
+	Logger::slout() << "*** " << (m_deletedOriginalEdges.size() == 0 ? "" : "NON ") << "C-PLANAR ***\n";
+	Logger::slout() << "*** " << (feasibleFound() ? "" : "NO ") << "feasible solution found ***\n";
 	Logger::slout() << "=================================================\n";
-	
+
 	Logger::ssout() << "\n";
 
-	Logger::ssout() << "C-Planar: " << feasibleFound() << "\n";
+	Logger::ssout() << "C-Planar: " << (feasibleFound() && (m_deletedOriginalEdges.size() == 0)) << "\n";
+	Logger::ssout() << "FeasibleFound: " << feasibleFound() << "\n";
 	Logger::ssout() << "Time: "<< getDoubleTime(totalTime()) << "\n";
 	Logger::ssout() << "LP-Time: " << getDoubleTime(lpSolverTime()) << "\n";
 	Logger::ssout() << "\n";
 	Logger::ssout() << "#BB-nodes: " << nSub() << "\n";
-	Logger::ssout() << "#LP-relax: " << m_solvesLP << "\n";	
+	Logger::ssout() << "#LP-relax: " << m_solvesLP << "\n";
+	Logger::ssout() << "Added Edges: " <<m_connectionOneEdges.size()<<"\n";
 
 	Logger::ssout() << "#Cut Constraints: " << m_nCConsAdded << "\n";
 	Logger::ssout() << "#Kura Constraints: " << m_nKConsAdded << "\n";
@@ -918,7 +949,7 @@ void Master::terminateOptimization() {
 	Logger::ssout() << "#Vars-max: " << m_varsMax << "\n";
 	Logger::ssout() << "#Vars-cut: " << m_varsCut << "\n";
 	Logger::ssout() << "#Vars-kurarepair: " << m_varsKura << "\n";
-	Logger::ssout() << "#Vars-price: " << m_varsPrice << "\n";	
+	Logger::ssout() << "#Vars-price: " << m_varsPrice << "\n";
 	Logger::ssout() << "#Vars-branch: " << m_varsBranch << "\n";
 	Logger::ssout() << "#Vars-unused: " << m_inactiveVariables.size() << "\n";
 	Logger::ssout() << "KuraRepair-Stat: <";
@@ -926,7 +957,7 @@ void Master::terminateOptimization() {
 		Logger::ssout() << m_repairStat[i] << ",";
 	}
 	Logger::ssout() << ">\n";
-	
+
 	node n,m;
 	edge e;
 	forall_nodes(n, *m_G) {
@@ -938,7 +969,7 @@ void Master::terminateOptimization() {
 					continue;
 				}
 			}
-		}		
+		}
 	}
 	forall_nodes(n, *m_G) {
 		forall_nodes(m, *m_G) {
@@ -954,10 +985,10 @@ void Master::terminateOptimization() {
 				}
 			}
 			Logger::slout() << "CONN: " << n << "-" << m << "\n";
-			wup:;			
-		}		
+			wup:;
+		}
 	}
-	
+
 	globalPrimalBound = primalBound();
 	globalDualBound = dualBound();
 }
@@ -968,7 +999,7 @@ void Master::generateVariablesForFeasibility(const List<ChunkConnection*>& ccons
 //		(*ccit)->printMe();
 //	}
 
-	ArrayBuffer<ListIterator<nodePair> > creationBuffer(ccons.size()); 
+	ArrayBuffer<ListIterator<nodePair> > creationBuffer(ccons.size());
 	forall_nonconst_listiterators(nodePair, npit, m_inactiveVariables) {
 		bool select = false;
 //		(*npit).printMe();
@@ -987,7 +1018,7 @@ void Master::generateVariablesForFeasibility(const List<ChunkConnection*>& ccons
 			creationBuffer.push(npit);
 		}
 		if(cpy.size()==0) break;
-	}  
+	}
 //	forall_listiterators(ChunkConnection*, ccit, cpy) {
 //		(*ccit)->printMe();
 //	}
@@ -996,7 +1027,7 @@ void Master::generateVariablesForFeasibility(const List<ChunkConnection*>& ccons
 	m_varsInit = creationBuffer.size();
 	// realize creationList
 	for(int i = creationBuffer.size(); i-->0;) {
-	  connectVars.pushBack( createVariable( creationBuffer[i] ) );  
+	  connectVars.pushBack( createVariable( creationBuffer[i] ) );
 	}
 }
 
