@@ -1,52 +1,43 @@
 /*
- * $Revision: 2027 $
- * 
+ * $Revision: 2552 $
+ *
  * last checkin:
- *   $Author: gutwenger $ 
- *   $Date: 2010-09-01 11:55:17 +0200 (Wed, 01 Sep 2010) $ 
+ *   $Author: gutwenger $
+ *   $Date: 2012-07-05 16:45:20 +0200 (Do, 05. Jul 2012) $
  ***************************************************************/
- 
+
 /** \file
  * \brief Implements Hopcroft/Tarjan algorithm for finding the
  * triconnected components of a biconnected multi-graph
- * 
+ *
  * \author Carsten Gutwenger
- * 
+ *
  * \par License:
  * This file is part of the Open Graph Drawing Framework (OGDF).
  *
- * Copyright (C). All rights reserved.
+ * \par
+ * Copyright (C)<br>
  * See README.txt in the root directory of the OGDF installation for details.
- * 
+ *
  * \par
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
  *
  * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- * 
- * \par
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * \par
- * You should have received a copy of the GNU General Public 
+ * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- * 
+ *
  * \see  http://www.gnu.org/copyleft/gpl.html
  ***************************************************************/
 
@@ -359,7 +350,7 @@ void TricComp::splitMultiEdges()
 				minI == minIndex[*it] && maxI == maxIndex[*it];	++it)
 			{
 				C << *it;
-				m_TYPE[*it] = removed; 
+				m_TYPE[*it] = removed;
 			}
 		}
 	}
@@ -643,7 +634,7 @@ void TricComp::DFS1 (const Graph& G, node v, node u)
 			}
 
 			m_ND[v] += m_ND[w];
-		
+
 		} else {
 
 			m_TYPE[e] = frond;
@@ -702,7 +693,7 @@ void TricComp::DFS1 (const Graph& G, node v, node u, node &s1)
 			}
 
 			m_ND[v] += m_ND[w];
-		
+
 		} else {
 
 			m_TYPE[e] = frond;
@@ -871,7 +862,7 @@ void TricComp::pathSearch (const Graph& G, node v)
 							m_pGC->original(v) << ", " <<
 							m_pGC->original(m_A[w].front()->target());
 #endif
-						
+
 						edge e1 = m_ESTACK.pop();
 						edge e2 = m_ESTACK.pop();
 						m_A[w].del(m_IN_ADJ[e2]);
@@ -971,7 +962,7 @@ void TricComp::pathSearch (const Graph& G, node v)
 					xy = m_ESTACK.top();
 					x = m_NEWNUM[xy->source()];
 					y = m_NEWNUM[xy->target()];
-	
+
 					if (!((wnum <= x && x < wnum+m_ND[w]) || (wnum <= y && y < wnum+m_ND[w])))
 						break;
 
@@ -1174,7 +1165,7 @@ bool isTriconnected(const Graph &G, node &s1, node &s2)
 //                       debugging stuff
 //----------------------------------------------------------
 
-void TricComp::printOs(edge)
+void TricComp::printOs(edge e)
 {
 #ifdef TRIC_COMP_OUTPUT
 	cout << " (" << m_pGC->original(e->source()) << "," <<
