@@ -1,7 +1,49 @@
+/*
+ * $Revision: 2565 $
+ *
+ * last checkin:
+ *   $Author: gutwenger $
+ *   $Date: 2012-07-07 17:14:54 +0200 (Sa, 07. Jul 2012) $
+ ***************************************************************/
+
+/** \file
+ * \brief Definitions of various auxiliary classes for FME layout.
+ *
+ * \author Martin Gronemann
+ *
+ * \par License:
+ * This file is part of the Open Graph Drawing Framework (OGDF).
+ *
+ * \par
+ * Copyright (C)<br>
+ * See README.txt in the root directory of the OGDF installation for details.
+ *
+ * \par
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
+ *
+ * \par
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * \par
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ *
+ * \see  http://www.gnu.org/copyleft/gpl.html
+ ***************************************************************/
+
 #ifdef _MSC_VER
 #pragma once
 #endif
- 
+
 #ifndef OGDF_FME_FUNC_H
 #define OGDF_FME_FUNC_H
 
@@ -22,11 +64,11 @@ struct FMETreePartition
 	__uint32 pointCount;
 
 	template<typename Func>
-	void for_loop(Func& func) 
-	{ 
+	void for_loop(Func& func)
+	{
 		for (std::list<__uint32>::const_iterator it = nodes.begin();it!=nodes.end(); it++)
 			func(*it);
-	};
+	}
 };
 
 struct FMENodeChainPartition
@@ -35,6 +77,7 @@ struct FMENodeChainPartition
 	__uint32 numNodes;
 };
 
+
 //! the main global options for a run
 struct FMEGlobalOptions
 {
@@ -47,7 +90,7 @@ struct FMEGlobalOptions
 	float repForceFactor;				//!< repulsive force factor for the main step
 	float normEdgeLength;				//!< average edge length when desired edge length are normalized
 	float normNodeSize;					//!< average node size when node sizes are normalized
-	__uint32 maxNumIterations;			//!< maximum number of iterations in the main step 
+	__uint32 maxNumIterations;			//!< maximum number of iterations in the main step
 	__uint32 minNumIterations;			//!< minimum number of iterations to be done regardless of any other conditions
 
 	bool doPrepProcessing;				//!< enable preprocessing
@@ -60,6 +103,7 @@ struct FMEGlobalOptions
 	__uint32 multipolePrecision;
 };
 
+
 //! forward decl of local context struct
 struct FMELocalContext;
 
@@ -68,25 +112,26 @@ struct FMELocalContext;
 */
 struct FMEGlobalContext
 {
-	FMELocalContext** pLocalContext;		//!< all local contexts 
+	FMELocalContext** pLocalContext;		//!< all local contexts
 	__uint32 numThreads;					//!< number of threads, local contexts
 	ArrayGraph* pGraph;						//!< pointer to the array graph
 	LinearQuadtree* pQuadtree;				//!< pointer to the quadtree
-	LinearQuadtreeExpansion* pExpansion;	//!< pointer to the coeefficients 
+	LinearQuadtreeExpansion* pExpansion;	//!< pointer to the coeefficients
 	WSPD* pWSPD;							//!< pointer to the well separated pairs decomposition
 	float* globalForceX;					//!< the global node force x array
 	float* globalForceY;					//!< the global node force y array
 	FMEGlobalOptions* pOptions;				//!< pointer to the global options
 	bool earlyExit;							//!< var for the main thread to notify the other threads that they are done
-	float scaleFactor;						//!< var 
-	float coolDown;	
+	float scaleFactor;						//!< var
+	float coolDown;
 	float min_x;							//!< global point, node min x coordinate for bounding box calculations
 	float max_x;							//!< global point, node max x coordinate for bounding box calculations
 	float min_y;							//!< global point, node min y coordinate for bounding box calculations
 	float max_y;							//!< global point, node max y coordinate for bounding box calculations
-	double currAvgEdgeLength;				
+	double currAvgEdgeLength;
 };
 
+
 /*!
  * Local Thread Context
 */
@@ -95,37 +140,38 @@ struct FMELocalContext
 	FMEGlobalContext* pGlobalContext;		//!< pointer to the global context
 	float* forceX;							//!< local force array for all nodes, points
 	float* forceY;							//!< local force array for all nodes, points
-	double maxForceSq;						//!< local maximum force 
-	double avgForce;						//!< local maximum force 
+	double maxForceSq;						//!< local maximum force
+	double avgForce;						//!< local maximum force
 	float min_x;							//!< global point, node min x coordinate for bounding box calculations
 	float max_x;							//!< global point, node max x coordinate for bounding box calculations
 	float min_y;							//!< global point, node min y coordinate for bounding box calculations
 	float max_y;							//!< global point, node max y coordinate for bounding box calculations
-	double currAvgEdgeLength;				
+	double currAvgEdgeLength;
 	FMETreePartition treePartition;			  //!< tree partition assigned to the thread
 	FMENodeChainPartition innerNodePartition; //!< chain of inner nodes assigned to the thread
 	FMENodeChainPartition leafPartition;	  //!< chain of leaf nodes assigned to the thread
-	
+
 	LinearQuadtree::NodeID firstInnerNode;    //!< first inner nodes the thread prepared
 	LinearQuadtree::NodeID lastInnerNode;     //!< last inner nodes the thread prepared
 	__uint32 numInnerNodes;					  //!< number of inner nodes the thread prepared
-	
+
 	LinearQuadtree::NodeID firstLeaf;		  //!< first leaves the thread prepared
 	LinearQuadtree::NodeID lastLeaf;		  //!< last leaves the thread prepared
 	__uint32 numLeaves;						  //!< number of leaves the thread prepared
 };
 
+
 //! creates a min max functor for the x coords of the node
 static inline min_max_functor<float> min_max_x_function(FMELocalContext* pLocalContext)
 {
 	return min_max_functor<float>(pLocalContext->pGlobalContext->pGraph->nodeXPos(), pLocalContext->min_x, pLocalContext->max_x);
-};
+}
 
 //! creates a min max functor for the y coords of the node
 static inline min_max_functor<float> min_max_y_function(FMELocalContext* pLocalContext)
 {
 	return min_max_functor<float>(pLocalContext->pGlobalContext->pGraph->nodeYPos(), pLocalContext->min_y, pLocalContext->max_y);
-};
+}
 
 class LQMortonFunctor
 {
@@ -139,27 +185,28 @@ public:
 		translate_x = -quadtree->minX();
 		translate_y = -quadtree->minY();
 		scale = quadtree->scaleInv();
-	};
+	}
 
 	inline __uint32 operator()(void) const
 	{
 		return quadtree->numberOfPoints();
-	};
+	}
 
 	inline void operator()(__uint32 i)
 	{
 		LinearQuadtree::LQPoint& p = quadtree->point(i);
 		__uint32 ref = p.ref;
 		p.mortonNr = mortonNumber<__uint64, __uint32>((__uint32)((x[ref] + translate_x)*scale), (__uint32)((y[ref] + translate_y)*scale));
-	};
+	}
 
 	inline void operator()(__uint32 begin, __uint32 end)
 	{
 		for (__uint32 i = begin; i <= end; i++)
 		{
 			this->operator()(i);
-		};
-	};
+		}
+	}
+
 private:
 	LinearQuadtree* quadtree;
 	float translate_x;
@@ -170,13 +217,14 @@ private:
 	float* s;
 };
 
+
 //! Point-to-Multipole functor
 struct p2m_functor
 {
 	const LinearQuadtree& tree;
 	LinearQuadtreeExpansion& expansions;
 
-	p2m_functor(const LinearQuadtree& t, LinearQuadtreeExpansion& e) : tree(t), expansions(e) {};
+	p2m_functor(const LinearQuadtree& t, LinearQuadtreeExpansion& e) : tree(t), expansions(e) { }
 
 	inline void operator()(LinearQuadtree::NodeID nodeIndex)
 	{
@@ -185,15 +233,17 @@ struct p2m_functor
 		for (__uint32 pointIndex=firstPointOfLeaf; pointIndex < (firstPointOfLeaf+numPointsInLeaf); pointIndex++)
 		{
 			expansions.P2M(pointIndex, nodeIndex);
-		};		
-	};
+		}
+	}
 };
 
+
 //! creates a Point-to-Multipole functor
 static inline p2m_functor p2m_function(FMELocalContext* pLocalContext)
 {
 	return p2m_functor(*pLocalContext->pGlobalContext->pQuadtree, *pLocalContext->pGlobalContext->pExpansion);
-};
+}
+
 
 //! Multipole-to-Multipole functor
 struct m2m_functor
@@ -201,43 +251,47 @@ struct m2m_functor
 	const LinearQuadtree& tree;
 	LinearQuadtreeExpansion& expansions;
 
-	m2m_functor(const LinearQuadtree& t, LinearQuadtreeExpansion& e) : tree(t), expansions(e) {};
+	m2m_functor(const LinearQuadtree& t, LinearQuadtreeExpansion& e) : tree(t), expansions(e) { }
 
 	inline void operator()(LinearQuadtree::NodeID parent, LinearQuadtree::NodeID child)
 	{
 		expansions.M2M(child, parent);
-	};
+	}
 
 	inline void operator()(LinearQuadtree::NodeID nodeIndex)
 	{
 		tree.forall_children(pair_call(*this, nodeIndex))(nodeIndex);
-	};
+	}
 };
 
+
 //! creates Multipole-to-Multipole functor
 static inline m2m_functor m2m_function(FMELocalContext* pLocalContext)
 {
 	return m2m_functor(*pLocalContext->pGlobalContext->pQuadtree, *pLocalContext->pGlobalContext->pExpansion);
-};
+}
+
 
 //! Multipole-to-Local functor
 struct m2l_functor
 {
 	LinearQuadtreeExpansion& expansions;
 
-	m2l_functor(LinearQuadtreeExpansion& e) : expansions(e) {};
+	m2l_functor(LinearQuadtreeExpansion& e) : expansions(e) { }
 
 	inline void operator()(LinearQuadtree::NodeID nodeIndexSource, LinearQuadtree::NodeID nodeIndexReceiver)
 	{
 		expansions.M2L(nodeIndexSource, nodeIndexReceiver);
-	};
+	}
 };
 
+
 //! creates Multipole-to-Local functor
 static inline m2l_functor m2l_function(FMELocalContext* pLocalContext)
 {
 	return m2l_functor(*pLocalContext->pGlobalContext->pExpansion);
-};
+}
+
 
 //! Local-to-Local functor
 struct l2l_functor
@@ -245,24 +299,26 @@ struct l2l_functor
 	const LinearQuadtree& tree;
 	LinearQuadtreeExpansion& expansions;
 
-	l2l_functor(const LinearQuadtree& t, LinearQuadtreeExpansion& e) : tree(t), expansions(e) {};
+	l2l_functor(const LinearQuadtree& t, LinearQuadtreeExpansion& e) : tree(t), expansions(e) { }
 
 	inline void operator()(LinearQuadtree::NodeID parent, LinearQuadtree::NodeID child)
 	{
 		expansions.L2L(parent, child);
-	};
+	}
 
 	inline void operator()(LinearQuadtree::NodeID nodeIndex)
 	{
 		tree.forall_children(pair_call(*this, nodeIndex))(nodeIndex);
-	};
+	}
 };
 
+
 //! creates Local-to-Local functor
 static inline l2l_functor l2l_function(FMELocalContext* pLocalContext)
 {
 	return l2l_functor(*pLocalContext->pGlobalContext->pQuadtree, *pLocalContext->pGlobalContext->pExpansion);
-};
+}
+
 
 //! Local-to-Point functor
 struct l2p_functor
@@ -272,25 +328,27 @@ struct l2p_functor
 	float* fx;
 	float* fy;
 
-	l2p_functor(const LinearQuadtree& t, LinearQuadtreeExpansion& e, float* x, float* y) : tree(t), expansions(e), fx(x), fy(y) {};
+	l2p_functor(const LinearQuadtree& t, LinearQuadtreeExpansion& e, float* x, float* y) : tree(t), expansions(e), fx(x), fy(y) { }
 
 	inline void operator()(LinearQuadtree::NodeID nodeIndex, LinearQuadtree::PointID pointIndex)
 	{
 		expansions.L2P(nodeIndex, pointIndex, fx[pointIndex], fy[pointIndex]);
-	};
+	}
 
 	inline void operator()(LinearQuadtree::PointID pointIndex)
 	{
 		LinearQuadtree::NodeID nodeIndex = tree.pointLeaf(pointIndex);
-		this->operator ()(nodeIndex, pointIndex);		
-	};
+		this->operator ()(nodeIndex, pointIndex);
+	}
 };
 
+
 //! creates Local-to-Point functor
 static inline l2p_functor l2p_function(FMELocalContext* pLocalContext)
 {
 	return l2p_functor(*pLocalContext->pGlobalContext->pQuadtree, *pLocalContext->pGlobalContext->pExpansion, pLocalContext->forceX, pLocalContext->forceY);
-};
+}
+
 
 //! Local-to-Point functor
 struct p2p_functor
@@ -299,7 +357,7 @@ struct p2p_functor
 	float* fx;
 	float* fy;
 
-	p2p_functor(const LinearQuadtree& t, float* x, float* y) : tree(t), fx(x), fy(y) {};
+	p2p_functor(const LinearQuadtree& t, float* x, float* y) : tree(t), fx(x), fy(y) { }
 
 	inline void operator()(LinearQuadtree::NodeID nodeIndexA, LinearQuadtree::NodeID nodeIndexB)
 	{
@@ -309,21 +367,23 @@ struct p2p_functor
 		__uint32 numPointsB = tree.numberOfPoints(nodeIndexB);
 		eval_direct_fast(tree.pointX() + offsetA, tree.pointY() + offsetA, tree.pointSize() + offsetA, fx + offsetA, fy + offsetA, numPointsA,
 						 tree.pointX() + offsetB, tree.pointY() + offsetB, tree.pointSize() + offsetB, fx + offsetB, fy + offsetB, numPointsB);
-	};
+	}
 
 	inline void operator()(LinearQuadtree::NodeID nodeIndex)
 	{
 		__uint32 offset = tree.firstPoint(nodeIndex);
 		__uint32 numPoints = tree.numberOfPoints(nodeIndex);
-		eval_direct_fast(tree.pointX() + offset, tree.pointY() + offset, tree.pointSize() + offset, fx + offset, fy + offset, numPoints); 
-	};
+		eval_direct_fast(tree.pointX() + offset, tree.pointY() + offset, tree.pointSize() + offset, fx + offset, fy + offset, numPoints);
+	}
 };
 
+
 //! creates Local-to-Point functor
 static inline p2p_functor p2p_function(FMELocalContext* pLocalContext)
 {
 	return p2p_functor(*pLocalContext->pGlobalContext->pQuadtree, pLocalContext->forceX, pLocalContext->forceY);
-};
+}
+
 
 //! The partitioner which partitions the quadtree into subtrees and partitions the sequence of inner nodes and leaves
 class LQPartitioner
@@ -334,10 +394,10 @@ public:
 		numThreads = pLocalContext->pGlobalContext->numThreads;
 		tree = pLocalContext->pGlobalContext->pQuadtree;
 		localContexts = pLocalContext->pGlobalContext->pLocalContext;
-	};
+	}
 
 	void partitionNodeChains()
-	{		
+	{
 		__uint32 numInnerNodesPerThread = tree->numberOfInnerNodes() / numThreads;
 		if (numInnerNodesPerThread < 25)
 		{
@@ -346,7 +406,7 @@ public:
 			for (__uint32 i=1; i< numThreads; i++)
 			{
 				localContexts[i]->innerNodePartition.numNodes = 0;
-			};
+			}
 		} else
 		{
 
@@ -355,18 +415,18 @@ public:
 			localContexts[0]->innerNodePartition.begin = curr;
 			localContexts[0]->innerNodePartition.numNodes = 0;
 			for (__uint32 i=0; i< tree->numberOfInnerNodes(); i++)
-			{		
+			{
 				localContexts[currThread]->innerNodePartition.numNodes++;
 				curr = tree->nextNode(curr);
-				if ((localContexts[currThread]->innerNodePartition.numNodes>=numInnerNodesPerThread) && (currThread < numThreads-1)) 
+				if ((localContexts[currThread]->innerNodePartition.numNodes>=numInnerNodesPerThread) && (currThread < numThreads-1))
 				{
 					currThread++;
 					localContexts[currThread]->innerNodePartition.numNodes = 0;
-					localContexts[currThread]->innerNodePartition.begin = curr;				
-				};
-			};
+					localContexts[currThread]->innerNodePartition.begin = curr;
+				}
+			}
 
-		};
+		}
 
 		__uint32 numLeavesPerThread = tree->numberOfLeaves() / numThreads;
 		if (numLeavesPerThread < 25)
@@ -376,7 +436,7 @@ public:
 			for (__uint32 i=1; i< numThreads; i++)
 			{
 				localContexts[i]->leafPartition.numNodes = 0;
-			};
+			}
 		} else
 		{
 			LinearQuadtree::NodeID curr = tree->firstLeaf();
@@ -384,18 +444,18 @@ public:
 			localContexts[0]->leafPartition.begin = curr;
 			localContexts[0]->leafPartition.numNodes = 0;
 			for (__uint32 i=0; i< tree->numberOfLeaves(); i++)
-			{		
+			{
 				localContexts[currThread]->leafPartition.numNodes++;
 				curr = tree->nextNode(curr);
-				if ((localContexts[currThread]->leafPartition.numNodes>=numLeavesPerThread) && (currThread < numThreads-1)) 
+				if ((localContexts[currThread]->leafPartition.numNodes>=numLeavesPerThread) && (currThread < numThreads-1))
 				{
 					currThread++;
 					localContexts[currThread]->leafPartition.numNodes = 0;
-					localContexts[currThread]->leafPartition.begin = curr;				
-				};
-			};
-		};
-	};
+					localContexts[currThread]->leafPartition.begin = curr;
+				}
+			}
+		}
+	}
 
 	void partition()
 	{
@@ -406,23 +466,23 @@ public:
 		{
 			localContexts[i]->treePartition.nodes.clear();
 			localContexts[i]->treePartition.pointCount = 0;
-		};
+		}
 		if (numThreads>1)
 			newPartition();
-	};
+	}
 
-	void newPartition(__uint32 node) 
+	void newPartition(__uint32 node)
 	{
 		__uint32 bound = tree->numberOfPoints() / (numThreads*numThreads);
-		
+
 		if (tree->isLeaf(node) || (tree->numberOfPoints(node) < bound))
 			l_par.push_back(node);
 		else
-			for (__uint32 i = 0; i < tree->numberOfChilds(node); i++) 
+			for (__uint32 i = 0; i < tree->numberOfChilds(node); i++)
 				newPartition(tree->child(node, i));
-	};
+	}
 
-	void newPartition() 
+	void newPartition()
 	{
 		l_par.clear();
 		newPartition(tree->root());
@@ -441,14 +501,15 @@ public:
 			} else
 			{
 				currThread++;
-			};
-		};
-	};
+			}
+		}
+	}
 
 	FMETreePartition* currPartition()
 	{
 		return &localContexts[currThread]->treePartition;
-	};
+	}
+
 private:
 	__uint32 numPointsPerThread;
 	__uint32 numThreads;
@@ -459,6 +520,7 @@ private:
 	FMELocalContext** localContexts;
 };
 
+
 class LQPointUpdateFunctor
 {
 public:
@@ -468,27 +530,28 @@ public:
 		y = pLocalContext->pGlobalContext->pGraph->nodeYPos();
 		s = pLocalContext->pGlobalContext->pGraph->nodeSize();
 		quadtree = pLocalContext->pGlobalContext->pQuadtree;
-	};
+	}
 
 	inline __uint32 operator()(void) const
 	{
 		return quadtree->numberOfPoints();
-	};
+	}
 
 	inline void operator()(__uint32 i)
 	{
 		LinearQuadtree::LQPoint& p = quadtree->point(i);
 		__uint32 ref = p.ref;
 		quadtree->setPoint(i, x[ref], y[ref], s[ref]);
-	};
+	}
 
 	inline void operator()(__uint32 begin, __uint32 end)
 	{
 		for (__uint32 i = begin; i <= end; i++)
 		{
 			this->operator()(i);
-		};
-	};
+		}
+	}
+
 private:
 	LinearQuadtree* quadtree;
 	float* x;
@@ -507,32 +570,34 @@ public:
 	{
 		quadtree = pLocalContext->pGlobalContext->pQuadtree;
 		quadtreeExp = pLocalContext->pGlobalContext->pExpansion;
-	};
+	}
 
 	inline __uint32 operator()(void) const
 	{
 		return quadtree->numberOfNodes();
-	};
-	
+	}
+
 	inline void operator()( __uint32 i )
 	{
 		quadtree->computeCoords(i);
-	};
+	}
 
 	inline void operator()(__uint32 begin, __uint32 end)
 	{
 		for (__uint32 i = begin; i <= end; i++)
 		{
 			this->operator()(i);
-		};
-	};
+		}
+	}
+
 private:
 	LinearQuadtree* quadtree;
 	LinearQuadtreeExpansion* quadtreeExp;
 };
 
+
 /*!
- * Converts the multipole expansion coefficients from all nodes which are well separated from the i-th node 
+ * Converts the multipole expansion coefficients from all nodes which are well separated from the i-th node
  * to local expansion coefficients and adds them to the local expansion coefficients of the i-th node
  */
 class M2LFunctor
@@ -543,13 +608,13 @@ public:
 		quadtree = pLocalContext->pGlobalContext->pQuadtree;
 		quadtreeExp = pLocalContext->pGlobalContext->pExpansion;
 		wspd = pLocalContext->pGlobalContext->pWSPD;
-	};
+	}
 
 	inline __uint32 operator()(void) const
 	{
 		return quadtree->numberOfNodes();
-	};
-	
+	}
+
 	inline void operator()(__uint32 i)
 	{
 		__uint32 currEntryIndex = wspd->firstPairEntry(i);
@@ -558,22 +623,24 @@ public:
 			__uint32 j = wspd->wsNodeOfPair(currEntryIndex, i);
 			quadtreeExp->M2L(j, i);
 			currEntryIndex = wspd->nextPair(currEntryIndex, i);
-		};
-	};
+		}
+	}
 
 	inline void operator()(__uint32 begin, __uint32 end)
 	{
 		for (__uint32 i = begin; i <= end; i++)
 		{
 			this->operator()(i);
-		};
-	};
+		}
+	}
+
 private:
 	LinearQuadtree* quadtree;
 	LinearQuadtreeExpansion* quadtreeExp;
 	WSPD* wspd;
 };
 
+
 /*!
  * Calculates the repulsive forces acting between all nodes inside the cell of the i-th LinearQuadtree node.
  */
@@ -586,28 +653,29 @@ public:
 		quadtreeExp = pLocalContext->pGlobalContext->pExpansion;
 		forceArrayX = pLocalContext->forceX;
 		forceArrayY = pLocalContext->forceY;
-	};
+	}
 
 	inline __uint32 operator()(void) const
 	{
 		return quadtree->numberOfDirectNodes();
-	};
-	
+	}
+
 	inline void operator()(__uint32 i)
 	{
 		__uint32 node = quadtree->directNode(i);
 		__uint32 offset = quadtree->firstPoint(node);
 		__uint32 numPoints = quadtree->numberOfPoints(node);
-		eval_direct_fast(quadtree->pointX() + offset, quadtree->pointY() + offset, quadtree->pointSize() + offset, forceArrayX + offset, forceArrayY + offset, numPoints); 
-	};
+		eval_direct_fast(quadtree->pointX() + offset, quadtree->pointY() + offset, quadtree->pointSize() + offset, forceArrayX + offset, forceArrayY + offset, numPoints);
+	}
 
 	inline void operator()(__uint32 begin, __uint32 end)
 	{
 		for (__uint32 i = begin; i <= end; i++)
 		{
 			this->operator()(i);
-		};
-	};
+		}
+	}
+
 private:
 	LinearQuadtree* quadtree;
 	LinearQuadtreeExpansion* quadtreeExp;
@@ -628,13 +696,13 @@ public:
 		quadtreeExp = pLocalContext->pGlobalContext->pExpansion;
 		forceArrayX = pLocalContext->forceX;
 		forceArrayY = pLocalContext->forceY;
-	};
+	}
 
 	inline __uint32 operator()(void) const
 	{
 		return quadtree->numberOfDirectPairs();
-	};
-	
+	}
+
 	inline void operator()(__uint32 i)
 	{
 		__uint32 nodeA = quadtree->directNodeA(i);
@@ -644,16 +712,17 @@ public:
 		__uint32 numPointsA = quadtree->numberOfPoints(nodeA);
 		__uint32 numPointsB = quadtree->numberOfPoints(nodeB);
 		eval_direct_fast(quadtree->pointX() + offsetA, quadtree->pointY() + offsetA, quadtree->pointSize() + offsetA, forceArrayX + offsetA, forceArrayY + offsetA, numPointsA,
-						 quadtree->pointX() + offsetB, quadtree->pointY() + offsetB, quadtree->pointSize() + offsetB, forceArrayX + offsetB, forceArrayY + offsetB, numPointsB); 
-	};
+						 quadtree->pointX() + offsetB, quadtree->pointY() + offsetB, quadtree->pointSize() + offsetB, forceArrayX + offsetB, forceArrayY + offsetB, numPointsB);
+	}
 
 	inline void operator()(__uint32 begin, __uint32 end)
 	{
 		for (__uint32 i = begin; i <= end; i++)
 		{
 			this->operator()(i);
-		};
-	};
+		}
+	}
+
 private:
 	LinearQuadtree* quadtree;
 	LinearQuadtreeExpansion* quadtreeExp;
@@ -661,12 +730,14 @@ private:
 	float* forceArrayY;
 };
 
-enum 
+
+enum
 {
 	EDGE_FORCE_SUB_REP			= 0x2,
 	EDGE_FORCE_DIV_DEGREE		= 0x8
 };
 
+
 template<unsigned int FLAGS>
 class EdgeForceFunctor
 {
@@ -674,20 +745,20 @@ public:
 	inline EdgeForceFunctor( FMELocalContext* pLocalContext )
 	{
 		pGraph = pLocalContext->pGlobalContext->pGraph;
-		x = pGraph->nodeXPos(); 
-		y = pGraph->nodeYPos(); 
+		x = pGraph->nodeXPos();
+		y = pGraph->nodeYPos();
 		edgeInfo = pGraph->edgeInfo();
 		nodeInfo = pGraph->nodeInfo();
 		desiredEdgeLength = pGraph->desiredEdgeLength();
 		nodeSize = pGraph->nodeSize();
 		forceArrayX = pLocalContext->forceX;
 		forceArrayY = pLocalContext->forceY;
-	};
+	}
 
 	inline __uint32 operator()(void) const
 	{
 		return pGraph->numEdges();
-	};
+	}
 
 	inline void operator()(__uint32 i)
 	{
@@ -700,54 +771,57 @@ public:
 		float d_sq = d_x*d_x + d_y*d_y;
 
 		float f = (float)(logf(d_sq)*0.5f-logf(desiredEdgeLength[i]));
-	
+
 		float fa = f*0.25f;
 		float fb = f*0.25f;
-		
+
 		if (FLAGS & EDGE_FORCE_DIV_DEGREE)
 		{
 			fa = (float)(fa/((float)a_info.degree));
 			fb = (float)(fb/((float)b_info.degree));
-		};
+		}
 
 		if (FLAGS & EDGE_FORCE_SUB_REP)
 		{
 			fa += (nodeSize[e_info.b] / d_sq);
 			fb += (nodeSize[e_info.a] / d_sq);
-		};
+		}
 		forceArrayX[e_info.a] -= fa*d_x;
 		forceArrayY[e_info.a] -= fa*d_y;
 		forceArrayX[e_info.b] += fb*d_x;
 		forceArrayY[e_info.b] += fb*d_y;
-	};
+	}
 
 	inline void operator()(__uint32 begin, __uint32 end)
 	{
 		for (__uint32 i = begin; i <= end; i++)
 		{
 			this->operator()(i);
-		};
-	};
+		}
+	}
+
 private:
-	float* x; 
-	float* y; 
+	float* x;
+	float* y;
 	EdgeAdjInfo* edgeInfo;
 	NodeAdjInfo* nodeInfo;
 
 	ArrayGraph* pGraph;
-	float* desiredEdgeLength; 
+	float* desiredEdgeLength;
 	float* nodeSize;
 	float* forceArrayX;
 	float* forceArrayY;
 };
 
+
 template<unsigned int FLAGS>
 static inline EdgeForceFunctor<FLAGS> edge_force_function( FMELocalContext* pLocalContext )
 {
 	return EdgeForceFunctor<FLAGS>( pLocalContext );
-};
+}
 
-enum 
+
+enum
 {
 	COLLECT_NO_FACTOR			= 0x00,
 	COLLECT_EDGE_FACTOR			= 0x01,
@@ -757,11 +831,12 @@ enum
 	COLLECT_ZERO_THREAD_ARRAY	= 0x10
 };
 
+
 template<unsigned int FLAGS>
 class CollectForceFunctor
 {
 public:
-	
+
 	inline CollectForceFunctor( FMELocalContext* pLocalContext )
 	{
 		numContexts = pLocalContext->pGlobalContext->numThreads;
@@ -780,12 +855,12 @@ public:
 			factor = pLocalContext->pGlobalContext->pOptions->preProcEdgeForceFactor;
 		else
 			factor = 1.0;
-	};
+	}
 
 	inline __uint32 operator()(void) const
 	{
 		return pGraph->numNodes();
-	};
+	}
 
 
 	inline void operator()(__uint32 i)
@@ -793,7 +868,7 @@ public:
 		float sumX = 0.0f;
 		float sumY = 0.0f;
 		for (__uint32 j=0; j < numContexts; j++)
-		{			
+		{
 			float* localArrayX = localContexts[j]->forceX;
 			float* localArrayY = localContexts[j]->forceY;
 			sumX += localArrayX[i];
@@ -802,9 +877,9 @@ public:
 			{
 				localArrayX[i] = 0.0f;
 				localArrayY[i] = 0.0f;
-			};
-		};
-		
+			}
+		}
+
 		if (FLAGS & COLLECT_TREE_2_GRAPH_ORDER)
 		{
 			__uint32 l = (globalContext->pQuadtree->refOfPoint(i));
@@ -815,14 +890,14 @@ public:
 				{
 					sumX /= (float)pGraph->nodeInfo(l).degree;
 					sumY /= (float)pGraph->nodeInfo(l).degree;
-				};
-			};
+				}
+			}
 			globalArrayX[l] += sumX*factor;
 			globalArrayY[l] += sumY*factor;
-			
+
 		}
 		else
-		{	
+		{
 			if (FLAGS & COLLECT_REPULSIVE_FACTOR)
 			{
 				// prevent some evil effects
@@ -830,20 +905,21 @@ public:
 				{
 					sumX /= (float)pGraph->nodeInfo(i).degree;
 					sumY /= (float)pGraph->nodeInfo(i).degree;
-				};
-			};
+				}
+			}
 			globalArrayX[i] += sumX*factor;
 			globalArrayY[i] += sumY*factor;
-		};		
-	};
+		}
+	}
 
 	inline void operator()(__uint32 begin, __uint32 end)
 	{
 		for (__uint32 i = begin; i <= end; i++)
 		{
 			this->operator()(i);
-		};
-	};
+		}
+	}
+
 private:
 	ArrayGraph*	pGraph;
 	FMEGlobalContext* globalContext;
@@ -854,11 +930,13 @@ private:
 	float factor;
 };
 
+
 template<unsigned int FLAGS>
 static inline CollectForceFunctor<FLAGS> collect_force_function( FMELocalContext* pLocalContext )
 {
 	return CollectForceFunctor<FLAGS>( pLocalContext );
-};
+}
+
 
 enum {
 	TIME_STEP_NORMAL = 0x1,
@@ -866,6 +944,7 @@ enum {
 	ZERO_GLOBAL_ARRAY = 0x4,
 	USE_NODE_MOVE_RAD = 0x8
 };
+
 template<unsigned int FLAGS>
 class NodeMoveFunctor
 {
@@ -887,21 +966,17 @@ public:
 		forceArrayY = pLocalContext->pGlobalContext->globalForceY;
 		localContext = pLocalContext;
 		currentEdgeLength = pLocalContext->pGlobalContext->pGraph->desiredEdgeLength();
-	};
-
-	inline void operator()(void) const
-	{
-//              TODO this was commented because clang sees this as erroneous
-// 		return pGraph->numNodes();
-	};
+	}
 
+/*	inline void operator()(void) const
+	}; */
 	inline void operator()(__uint32 i)
 	{
 		float d_x = forceArrayX[i]* timeStep;
 		float d_y = forceArrayY[i]* timeStep;
 		double dsq = (d_x*d_x + d_y*d_y);
 		double d = sqrt(dsq);
-			
+
 		localContext->maxForceSq = max<double>(localContext->maxForceSq, (double)dsq );
 		localContext->avgForce += d;
 		if (d < FLT_MAX)
@@ -916,25 +991,26 @@ public:
 			{
 				forceArrayX[i] = (float)((d_x));;
 				forceArrayY[i] = (float)((d_y));;
-			};
-	  	} else
-	  	{	  
-	  		  forceArrayX[i] = 0.0;
-	  		  forceArrayY[i] = 0.0;
-	 	};		
-	};
+			}
+		} else
+		{
+			forceArrayX[i] = 0.0;
+			forceArrayY[i] = 0.0;
+		}
+	}
 
 	inline void operator()(__uint32 begin, __uint32 end)
 	{
 		for (__uint32 i = begin; i <= end; i++)
 		{
 			this->operator()(i);
-		};
-	};
+		}
+	}
+
 private:
 	float timeStep;
-	float* x; 
-	float* y; 
+	float* x;
+	float* y;
 	float* forceArrayX;
 	float* forceArrayY;
 	float* nodeMoveRadius;
@@ -943,11 +1019,13 @@ private:
 	FMELocalContext* localContext;
 };
 
+
 template<unsigned int FLAGS>
 static inline NodeMoveFunctor<FLAGS> node_move_function( FMELocalContext* pLocalContext )
 {
 	return NodeMoveFunctor<FLAGS>( pLocalContext );
-};
+}
+
 
 template<typename TYP>
 inline void for_loop_array_set(__uint32 threadNr, __uint32 numThreads, TYP* a, __uint32 n, TYP value)
@@ -956,9 +1034,9 @@ inline void for_loop_array_set(__uint32 threadNr, __uint32 numThreads, TYP* a, _
 	__uint32 o = s*threadNr;
 	if (threadNr == numThreads-1)
 		s = s + (n % numThreads);
-	
-	for (__uint32 i = 0; i < s; i++ ) { a[o+i] = value; };
-};
+
+	for (__uint32 i = 0; i < s; i++ ) { a[o+i] = value; }
+}
 
 } // end of namespace
 
