@@ -1,5 +1,47 @@
-#ifndef _LINEAR_QUADTREE_H_
-#define _LINEAR_QUADTREE_H_
+/*
+ * $Revision: 2559 $
+ *
+ * last checkin:
+ *   $Author: gutwenger $
+ *   $Date: 2012-07-06 15:04:28 +0200 (Fr, 06. Jul 2012) $
+ ***************************************************************/
+
+/** \file
+ * \brief Declaration of class LinearQuadtree.
+ *
+ * \author Martin Gronemann
+ *
+ * \par License:
+ * This file is part of the Open Graph Drawing Framework (OGDF).
+ *
+ * \par
+ * Copyright (C)<br>
+ * See README.txt in the root directory of the OGDF installation for details.
+ *
+ * \par
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
+ *
+ * \par
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * \par
+ * You should have received a copy of the GNU General Public
+ * License along with this program; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ *
+ * \see  http://www.gnu.org/copyleft/gpl.html
+ ***************************************************************/
+
+#ifndef OGDF_LINEAR_QUADTREE_H
+#define OGDF_LINEAR_QUADTREE_H
 
 #include "FastUtils.h"
 #include "FMEFunctional.h"
@@ -26,22 +68,22 @@ public:
 		MortonNR mortonNr;		// 8 byte
 		__uint32 node;			// 4 byte
 		__uint32 ref;			// 4 byte
-	};			
-	
+	};
+
 	struct LQNode				// 27 byte
 	{
-		__uint32 level;			// 4 byte  
+		__uint32 level;			// 4 byte
 		NodeID next;			// 4 byte
 		NodeID child[4];		// 4 byte *4 = 16 byte
-		__uint32 numChilds;		// 4 byte 
-		PointID firstPoint;		// 4 byte 
-		__uint32 numPoints;		// 4 byte 	
+		__uint32 numChilds;		// 4 byte
+		PointID firstPoint;		// 4 byte
+		__uint32 numPoints;		// 4 byte
 		bool fence;				// 1 byte
-	}; 
+	};
 
 	struct LQWSPair
 	{
-		LQWSPair(NodeID c, NodeID d) : a(c), b(d) {}; 
+		LQWSPair(NodeID c, NodeID d) : a(c), b(d) {};
 		NodeID a;
 		NodeID b;
 	};
@@ -49,46 +91,45 @@ public:
 	struct is_fence_condition_functor
 	{
 		const LinearQuadtree& tree;
-		is_fence_condition_functor(const LinearQuadtree& t) : tree(t) {};
-		inline bool operator()(NodeID u) {	return tree.isFence(u); };
+		is_fence_condition_functor(const LinearQuadtree& t) : tree(t) { }
+		inline bool operator()(NodeID u) {	return tree.isFence(u); }
 	};
 
 	//! creator
-	inline is_fence_condition_functor is_fence_condition() const { 	return is_fence_condition_functor(*this); };
+	inline is_fence_condition_functor is_fence_condition() const { 	return is_fence_condition_functor(*this); }
 
 
 	struct is_leaf_condition_functor
 	{
 		const LinearQuadtree& tree;
-		is_leaf_condition_functor(const LinearQuadtree& t) : tree(t) {};
-		inline bool operator()(NodeID u) {	return tree.isLeaf(u); };
+		is_leaf_condition_functor(const LinearQuadtree& t) : tree(t) { }
+		inline bool operator()(NodeID u) {	return tree.isLeaf(u); }
 	};
 
 	//! creator
-	inline is_leaf_condition_functor is_leaf_condition() const { return is_leaf_condition_functor(*this); };
+	inline is_leaf_condition_functor is_leaf_condition() const { return is_leaf_condition_functor(*this); }
 
 
 	//! simple functor for iterating over all nodes
 	template<typename F>
 	struct forall_tree_nodes_functor
 	{
+		const LinearQuadtree& tree;
 		F func;
 		NodeID begin;
 		__uint32 numNodes;
 
-		const LinearQuadtree& tree;
+		forall_tree_nodes_functor(const LinearQuadtree& t, F f, NodeID b, __uint32 num) : tree(t), func(f), begin(b), numNodes(num) { }
 
-                forall_tree_nodes_functor(const LinearQuadtree& t, F f, NodeID b, __uint32 num) : func(f), begin(b), numNodes(num), tree(t) {};
-
-		inline void operator()() 
-		{	
+		inline void operator()()
+		{
 			NodeID it = begin;
 			for (__uint32 i=0; i<numNodes; i++)
-			{				
+			{
 				func(it);
 				it = tree.nextNode(it);
-			};
-		};	
+			}
+		}
 	};
 
 	//! creator
@@ -96,22 +137,22 @@ public:
 	inline forall_tree_nodes_functor<F> forall_tree_nodes(F f, NodeID begin, __uint32 num) const
 	{
 		return forall_tree_nodes_functor<F>(*this, f, begin, num);
-	};
+	}
 
-	//! simple functor for iterating over all children of a node	
+	//! simple functor for iterating over all children of a node
 	template<typename F>
 	struct forall_children_functor
 	{
-		F func;
 		const LinearQuadtree& tree;
+		F func;
 
-                forall_children_functor(const LinearQuadtree& t, F f) : func(f), tree(t) {};
+		forall_children_functor(const LinearQuadtree& t, F f) : tree(t), func(f) { }
 
 		inline void operator()(NodeID u)
 		{
 			if (tree.isLeaf(u)) return;
 			for (__uint32 i = 0; i < tree.numberOfChilds(u); i++) func(tree.child(u, i));
-		};	
+		}
 	};
 
 	//! creator
@@ -119,25 +160,25 @@ public:
 	inline forall_children_functor<F> forall_children(F f) const
 	{
 		return forall_children_functor<F>(*this, f);
-	};
+	}
 
 
-	//! simple functor for iterating over all points of a node	
+	//! simple functor for iterating over all points of a node
 	template<typename Func>
 	struct forall_points_functor
 	{
-		Func func;
 		const LinearQuadtree& tree;
+		Func func;
 
-		forall_points_functor(const LinearQuadtree& t, const Func& f) : tree(t), func(f) {};
+		forall_points_functor(const LinearQuadtree& t, const Func& f) : tree(t), func(f) { }
 
 		inline void operator()(NodeID u)
 		{
 			PointID firstPoint = tree.firstPoint(u);
 			PointID end = firstPoint + tree.numberOfPoints(u);
-			for (PointID i = firstPoint; i < end; i++) 
+			for (PointID i = firstPoint; i < end; i++)
 				func(i);
-		};	
+		}
 	};
 
 	//! creator
@@ -145,24 +186,24 @@ public:
 	inline forall_points_functor<Func> forall_points(const Func& func) const
 	{
 		return forall_points_functor<Func>(*this, func);
-	};
+	}
 
 	//! functor for iterating over all ordered pairs of children of a node
 	template<typename F>
 	struct forall_ordered_pairs_of_children_functor
 	{
-		F func;
 		const LinearQuadtree& tree;
+		F func;
 
-                forall_ordered_pairs_of_children_functor(const LinearQuadtree& t, F f) : func(f), tree(t) {};
+		forall_ordered_pairs_of_children_functor(const LinearQuadtree& t, F f) : tree(t), func(f) { }
 
 		inline void operator()(NodeID u)
 		{
 			if (tree.isLeaf(u)) return;
-			for (__uint32 i = 0; i < tree.numberOfChilds(u); i++) 
-				for (__uint32 j = i+1; j < tree.numberOfChilds(u); j++) 
+			for (__uint32 i = 0; i < tree.numberOfChilds(u); i++)
+				for (__uint32 j = i+1; j < tree.numberOfChilds(u); j++)
 					func(tree.child(u, i), tree.child(u, j));
-		};	
+		}
 	};
 
 	//! creator
@@ -170,23 +211,23 @@ public:
 	inline forall_ordered_pairs_of_children_functor<F> forall_ordered_pairs_of_children(F f)  const
 	{
 		return forall_ordered_pairs_of_children_functor<F>(*this, f);
-	};
+	}
 
 	//! top down traversal of the subtree of a given node
 	template<typename F, typename CondType = true_condition>
 	struct top_down_traversal_functor
 	{
+		const LinearQuadtree& tree;
 		F func;
 		CondType cond;
-		const LinearQuadtree& tree;
 
-                top_down_traversal_functor(const LinearQuadtree& t, F f) : func(f), tree(t) {};
-                top_down_traversal_functor(const LinearQuadtree& t, F f, CondType c) : func(f), cond(c), tree(t) {};
+		top_down_traversal_functor(const LinearQuadtree& t, F f) : tree(t), func(f) { }
+		top_down_traversal_functor(const LinearQuadtree& t, F f, CondType c) : tree(t), func(f), cond(c) { }
 
-		inline void operator()(NodeID u) 
-		{	
+		inline void operator()(NodeID u)
+		{
 			if (cond(u)) {	func(u); tree.forall_children(*this)(u); };
-		};	
+		}
 	};
 
 	//! creator
@@ -194,31 +235,31 @@ public:
 	inline top_down_traversal_functor<F> top_down_traversal(F f) const
 	{
 		return top_down_traversal_functor<F>(*this, f);
-	};
+	}
 
 	//! creator
 	template<typename F, typename Cond>
 	inline top_down_traversal_functor<F, Cond> top_down_traversal(F f, Cond cond) const
 	{
 		return top_down_traversal_functor<F, Cond>(*this, f, cond);
-	};
+	}
 
 
 	//! bottom up traversal of the subtree of a given node
 	template<typename F, typename CondType = true_condition>
 	struct bottom_up_traversal_functor
 	{
+		const LinearQuadtree& tree;
 		F func;
 		CondType cond;
-		const LinearQuadtree& tree;
 
-                bottom_up_traversal_functor(const LinearQuadtree& t, F f) : func(f), tree(t) {};
-                bottom_up_traversal_functor(const LinearQuadtree& t, F f, CondType c) : func(f), cond(c), tree(t) {};
+		bottom_up_traversal_functor(const LinearQuadtree& t, F f) : tree(t), func(f) { }
+		bottom_up_traversal_functor(const LinearQuadtree& t, F f, CondType c) : tree(t), func(f), cond(c) { }
 
-		inline void operator()(NodeID u) 
-		{	
+		inline void operator()(NodeID u)
+		{
 			if (cond(u)) { tree.forall_children(*this)(u); func(u); };
-		};	
+		}
 	};
 
 	//! creator
@@ -226,28 +267,28 @@ public:
 	inline bottom_up_traversal_functor<F> bottom_up_traversal(F f) const
 	{
 		return bottom_up_traversal_functor<F>(*this, f);
-	};
+	}
 
 	//! creator
 	template<typename F, typename Cond>
 	inline bottom_up_traversal_functor<F, Cond> bottom_up_traversal(F f, Cond cond) const
 	{
 		return bottom_up_traversal_functor<F, Cond>(*this, f, cond);
-	};
+	}
+
 
-	
 	template<typename WSPairFuncType, typename DPairFuncType, typename DNodeFuncType, typename BranchCondType = true_condition>
 	struct wspd_functor
 	{
+		const LinearQuadtree& tree;
 		WSPairFuncType WSFunction;
 		DPairFuncType DPairFunction;
 		DNodeFuncType DNodeFunction;
 		BranchCondType BranchCondFunction;
-		const LinearQuadtree& tree;
 
-                wspd_functor(const LinearQuadtree& t, WSPairFuncType& wsf, DPairFuncType& dpf, DNodeFuncType& dnf) : WSFunction(wsf),  DPairFunction(dpf),  DNodeFunction(dnf), tree(t) {};
+		wspd_functor(const LinearQuadtree& t, WSPairFuncType& wsf, DPairFuncType& dpf, DNodeFuncType& dnf) : tree(t), WSFunction(wsf),  DPairFunction(dpf),  DNodeFunction(dnf) { }
 
-                wspd_functor(const LinearQuadtree& t, WSPairFuncType& wsf, DPairFuncType& dpf, DNodeFuncType& dnf, BranchCondType& bc) : WSFunction(wsf),  DPairFunction(dpf),  DNodeFunction(dnf), BranchCondFunction(bc), tree(t) {};
+		wspd_functor(const LinearQuadtree& t, WSPairFuncType& wsf, DPairFuncType& dpf, DNodeFuncType& dnf, BranchCondType& bc) : tree(t), WSFunction(wsf),  DPairFunction(dpf),  DNodeFunction(dnf), BranchCondFunction(bc) { }
 
 		inline void operator()(NodeID u)
 		{
@@ -259,16 +300,16 @@ public:
 						DNodeFunction(u);
 				} else
 				{
-					tree.forall_children(*this)(u);			
+					tree.forall_children(*this)(u);
 					tree.forall_ordered_pairs_of_children(*this)(u);
-				};
-			};
-		};
+				}
+			}
+		}
 
 
 		inline void operator()(NodeID u, NodeID v)
 		{
-			if (tree.isWS(u, v)) 
+			if (tree.isWS(u, v))
 			{
 				if ((tree.numberOfPoints(u) < M2L_MIN_BOUND) && (tree.numberOfPoints(v) < M2L_MIN_BOUND))
 					DPairFunction(u, v);
@@ -288,170 +329,170 @@ public:
 						tree.forall_children(pair_call(*this, v))(u);
 					else
 						tree.forall_children(pair_call(*this, u))(v);
-				};
-			};
-		};
+				}
+			}
+		}
 	};
 
 	template<typename A, typename B, typename C, typename ConditionType>
-	inline wspd_functor<A, B, C, ConditionType> forall_well_separated_pairs(A a, B b, C c, ConditionType cond) 
+	inline wspd_functor<A, B, C, ConditionType> forall_well_separated_pairs(A a, B b, C c, ConditionType cond)
 	{
 		return wspd_functor<A, B, C, ConditionType>(*this, a, b, c, cond);
-	};
+	}
 
 	template<typename A, typename B, typename C>
-	inline wspd_functor<A, B, C> forall_well_separated_pairs(A a, B b, C c) 
+	inline wspd_functor<A, B, C> forall_well_separated_pairs(A a, B b, C c)
 	{
 		return wspd_functor<A, B, C>(*this, a, b, c);
-	};
+	}
 
 	struct StoreWSPairFunctor
 	{
 		LinearQuadtree& tree;
-		StoreWSPairFunctor(LinearQuadtree& t) : tree(t) {};
-		inline void operator()(NodeID a, NodeID b) { tree.addWSPD(a, b); };
+		StoreWSPairFunctor(LinearQuadtree& t) : tree(t) { }
+		inline void operator()(NodeID a, NodeID b) { tree.addWSPD(a, b); }
 	};
 
-	StoreWSPairFunctor inline StoreWSPairFunction() {	return StoreWSPairFunctor(*this); };
+	StoreWSPairFunctor inline StoreWSPairFunction() { return StoreWSPairFunctor(*this); }
 
 
 	struct StoreDirectPairFunctor
 	{
 		LinearQuadtree& tree;
-		StoreDirectPairFunctor(LinearQuadtree& t) : tree(t) {};
-		inline void operator()(NodeID a, NodeID b) { tree.addDirectPair(a, b); };
+		StoreDirectPairFunctor(LinearQuadtree& t) : tree(t) { }
+		inline void operator()(NodeID a, NodeID b) { tree.addDirectPair(a, b); }
 	};
 
-	StoreDirectPairFunctor inline StoreDirectPairFunction() {	return StoreDirectPairFunctor(*this); };
+	StoreDirectPairFunctor inline StoreDirectPairFunction() { return StoreDirectPairFunctor(*this); }
 
 
 	struct StoreDirectNodeFunctor
 	{
 		LinearQuadtree& tree;
-		StoreDirectNodeFunctor(LinearQuadtree& t) : tree(t) {};
-		inline void operator()(NodeID a) { tree.addDirect(a); };
+		StoreDirectNodeFunctor(LinearQuadtree& t) : tree(t) { }
+		inline void operator()(NodeID a) { tree.addDirect(a); }
 	};
 
-	StoreDirectNodeFunctor inline StoreDirectNodeFunction() {	return StoreDirectNodeFunctor(*this); };
+	StoreDirectNodeFunctor inline StoreDirectNodeFunction() { return StoreDirectNodeFunctor(*this); }
 
 	inline NodeID level(NodeID node) const
 	{
 		return m_tree[node].level;
-	};
+	}
 
 	inline NodeID nextNode(NodeID node) const
 	{
 		return m_tree[node].next;
-	};
+	}
 
 	inline void setNextNode(NodeID node, NodeID next)
 	{
 		m_tree[node].next = next;
-	};
+	}
 
-	inline void setLevel(NodeID node, __uint32 level) 
+	inline void setLevel(NodeID node, __uint32 level)
 	{
 		m_tree[node].level = level;
-	};
+	}
 
 	inline PointID firstPoint(NodeID node) const
 	{
 		return m_tree[node].firstPoint;
-	};
+	}
 
-	inline void setFirstPoint(NodeID node, PointID firstPoint) 
+	inline void setFirstPoint(NodeID node, PointID firstPoint)
 	{
 		m_tree[node].firstPoint = firstPoint;
-	};
+	}
 
-	inline LQPoint& point(PointID pointID) 
+	inline LQPoint& point(PointID pointID)
 	{
 		return m_points[pointID];
-	};
+	}
 
 	inline const LQPoint& point(PointID pointID) const
 	{
 		return m_points[pointID];
-	};
+	}
 
 	inline MortonNR mortonNr(PointID point) const
 	{
 		return m_points[point].mortonNr;
-	};
+	}
 
 	//! returns the number of children of node node. for an inner node this is 1..4 and
-	//! can be accessed by child(i). For a leaf the number of points in this leaf is returned 
+	//! can be accessed by child(i). For a leaf the number of points in this leaf is returned
 	//! starting with point child(0)
 	inline __uint32 numberOfChilds(NodeID node) const
 	{
 		return m_tree[node].numChilds;
-	};
+	}
 
 	//! sets the number of children of a node
 	inline void setNumberOfChilds(NodeID node, __uint32 numChilds)
 	{
 		m_tree[node].numChilds = numChilds;
-	};
+	}
 
 	//! returns the i th child index of node node
 	inline NodeID child(NodeID node, __uint32 i) const
 	{
 		return m_tree[node].child[i];
-	};
+	}
 
 	//! sets the i-th child index of node node
 	inline void setChild(NodeID node, __uint32 i, NodeID c)
 	{
 		m_tree[node].child[i] = c;
-	};
+	}
 
-	//! returns true if the given node index is a leaf 
+	//! returns true if the given node index is a leaf
 	inline bool isLeaf(NodeID node) const
 	{
 		return !m_tree[node].numChilds;
-	};
+	}
 
-	//! sets the fence flag for node 
+	//! sets the fence flag for node
 	inline bool isFence(NodeID node) const
 	{
 		return m_tree[node].fence;
-	};
+	}
 
 	//! returns the number of points contained in the subtree of node
 	inline __uint32 numberOfPoints(NodeID node) const
 	{
 		return m_tree[node].numPoints;
-	};
+	}
 
 	//! sets the number of nodes containted in node
 	inline void setNumberOfPoints(NodeID node, __uint32 numPoints)
 	{
 		m_tree[node].numPoints = numPoints;
-	};
+	}
 
 	//! returns the index of the root
 	inline NodeID root() const
 	{
 		return m_root;
-	};
+	}
 
 	//! returns the number of points in this tree
 	inline __uint32 numberOfPoints() const
 	{
 		return m_numPoints;
-	};
+	}
 
 	//! returns the number of nodes in this tree
 	inline __uint32 numberOfNodes() const
 	{
 		return m_numInnerNodes + m_numLeaves;
-	};
+	}
 
 	//! the upper bound for a compressed quadtree (2*numPoints)
 	inline __uint32 maxNumberOfNodes() const
 	{
 		return m_maxNumNodes;
-	};
+	}
 
 	//! resets the tree
 	void clear();
@@ -464,46 +505,46 @@ public:
 
 	__uint64 sizeInBytes() const;
 
-	inline NodeID pointLeaf(PointID point) const 
-	{ 
-		return m_points[point].node; 
-	};
+	inline NodeID pointLeaf(PointID point) const
+	{
+		return m_points[point].node;
+	}
 
 	inline void setPointLeaf(PointID point, NodeID leaf)
 	{
 		m_points[point].node = leaf;
-	};
+	}
 
-	inline float pointX(PointID point) const { return m_pointXPos[point]; };
+	inline float pointX(PointID point) const { return m_pointXPos[point]; }
 
-	inline float pointY(PointID point) const { return m_pointYPos[point]; };
+	inline float pointY(PointID point) const { return m_pointYPos[point]; }
 
-	inline float pointSize(PointID point) const { return m_pointSize[point]; };
+	inline float pointSize(PointID point) const { return m_pointSize[point]; }
 
-	inline float* pointX() const { return m_pointXPos; };
+	inline float* pointX() const { return m_pointXPos; }
 
-	inline float* pointY() const { return m_pointYPos; };
+	inline float* pointY() const { return m_pointYPos; }
 
-	inline float* pointSize() const { return m_pointSize; };
+	inline float* pointSize() const { return m_pointSize; }
 
-	inline float nodeX(NodeID node) const { return m_nodeXPos[node]; };
+	inline float nodeX(NodeID node) const { return m_nodeXPos[node]; }
 
-	inline void setNodeX(NodeID node, float x) { m_nodeXPos[node] = x; };
+	inline void setNodeX(NodeID node, float x) { m_nodeXPos[node] = x; }
 
-	inline float nodeY(NodeID node) const {	return m_nodeYPos[node]; };
-		
-	inline void setNodeY(NodeID node, float y) { m_nodeYPos[node] = y; };
+	inline float nodeY(NodeID node) const {	return m_nodeYPos[node]; }
 
-	inline float nodeSize(NodeID node) const { return m_nodeSize[node]; };
+	inline void setNodeY(NodeID node, float y) { m_nodeYPos[node] = y; }
 
-	inline void setNodeSize(NodeID node, float size) { m_nodeSize[node] = size; };
+	inline float nodeSize(NodeID node) const { return m_nodeSize[node]; }
 
-	void setPoint(PointID id, float x, float y, __uint32 ref) 
-	{ 
+	inline void setNodeSize(NodeID node, float size) { m_nodeSize[node] = size; }
+
+	void setPoint(PointID id, float x, float y, __uint32 ref)
+	{
 		m_pointXPos[id] = x;
 		m_pointYPos[id] = y;
 		m_points[id].ref = ref;
-	};
+	}
 
 	void updatePointPositionSize(PointID id)
 	{
@@ -511,7 +552,7 @@ public:
 		m_pointXPos[id] = m_origXPos[ref];
 		m_pointYPos[id] = m_origYPos[ref];
 		m_pointSize[id] = m_origSize[ref];
-	};
+	}
 
 	void setPoint(PointID id, float x, float y, float r, __uint32 ref)
 	{
@@ -519,29 +560,29 @@ public:
 		m_pointYPos[id] = y;
 		m_pointSize[id] = r;
 		m_points[id].ref = ref;
-	};
+	}
 
 	void setPoint(PointID id, float x, float y, float r)
 	{
 		m_pointXPos[id] = x;
 		m_pointYPos[id] = y;
 		m_pointSize[id] = r;
-	};
+	}
 
 	inline __uint32 refOfPoint(PointID id) const
 	{
 		return m_points[id].ref;
-	};
+	}
 
 	inline NodeID nodeOfPoint(PointID id) const
 	{
 		return m_points[id].node;
-	};
+	}
 
 	inline void nodeFence(NodeID node)
 	{
 		m_tree[node].fence = true;
-	};
+	}
 
 	inline bool isWS(NodeID a, NodeID b) const
 	{
@@ -551,42 +592,42 @@ public:
 		float d_sq = dx*dx+dy*dy;
 		float l = max(nodeSize(a), nodeSize(b));
 		return (d_sq >(s*0.5 + 1)*(s*0.5 + 1)* 2 * l * l);
-	};
+	}
 
 	void computeWSPD();
-	
+
 	void computeWSPD(NodeID n);
 
-	inline NodeID firstInnerNode() const { return m_firstInner; };
+	inline NodeID firstInnerNode() const { return m_firstInner; }
 
-	inline __uint32 numberOfInnerNodes() const { return m_numInnerNodes; };
+	inline __uint32 numberOfInnerNodes() const { return m_numInnerNodes; }
 
-	inline NodeID firstLeaf() const { return m_firstLeaf; };
+	inline NodeID firstLeaf() const { return m_firstLeaf; }
 
-	inline __uint32 numberOfLeaves() const { return m_numLeaves; };
+	inline __uint32 numberOfLeaves() const { return m_numLeaves; }
 
 
-	__uint32 numberOfWSP() const { return m_numWSP; };
+	__uint32 numberOfWSP() const { return m_numWSP; }
 
-	__uint32 numberOfDirectPairs() const { return m_numNotWSP; };
+	__uint32 numberOfDirectPairs() const { return m_numNotWSP; }
 
-	__uint32 numberOfDirectNodes() const { return m_numDirectNodes; };
+	__uint32 numberOfDirectNodes() const { return m_numDirectNodes; }
 
-	inline NodeID directNode(__uint32 i) const { return m_directNodes[i]; };
+	inline NodeID directNode(__uint32 i) const { return m_directNodes[i]; }
 
-	inline NodeID directNodeA(__uint32 i) const { return m_notWspd[i].a; };
-	
-	inline NodeID directNodeB(__uint32 i) const { return m_notWspd[i].b; };
+	inline NodeID directNodeA(__uint32 i) const { return m_notWspd[i].a; }
+
+	inline NodeID directNodeB(__uint32 i) const { return m_notWspd[i].b; }
 
 
 	WSPD* wspd() const{ return m_WSPD; };
 
 	void init(float min_x, float min_y, float max_x, float max_y);
-	inline float minX() const { return m_min_x; };
-	inline float minY() const { return m_min_y; };
-	inline float maxX() const { return m_max_x; };
-	inline float maxY() const { return m_max_y; };
-	inline double scaleInv() const { return m_scaleInv; };
+	inline float minX() const { return m_min_x; }
+	inline float minY() const { return m_min_y; }
+	inline float maxX() const { return m_max_x; }
+	inline float maxY() const { return m_max_y; }
+	inline double scaleInv() const { return m_scaleInv; }
 
 
 	inline void computeCoords(NodeID nodeIndex)
@@ -600,10 +641,10 @@ public:
 		mnr = mnr << (level * 2);
 		mortonNumberInv<__uint64, __uint32>(mnr, ix, iy);
 		this->setNodeX(nodeIndex, (float)((m_sideLengthPoints*((float)ix)-0.5)/m_sideLengthGrid + (float)m_min_x + (float)s*0.5f));
-		this->setNodeY(nodeIndex, (float)((m_sideLengthPoints*((float)iy)-0.5)/m_sideLengthGrid + (float)m_min_y + (float)s*0.5f));	
-	};
+		this->setNodeY(nodeIndex, (float)((m_sideLengthPoints*((float)iy)-0.5)/m_sideLengthGrid + (float)m_min_y + (float)s*0.5f));
+	}
 
-	LQPoint* pointArray() { return m_points; }; 
+	LQPoint* pointArray() { return m_points; }
 
 	PointID findFirstPointInCell(PointID somePointInCell) const;
 
@@ -622,7 +663,7 @@ private:
 		m_tree[leaf].level = 0;
 		m_tree[leaf].firstPoint = firstPoint;
 		m_tree[leaf].numPoints = numPoints;
-	};
+	}
 
 	inline void initInnerNode(NodeID node, NodeID leftChild, NodeID rightChild, __uint32 level, NodeID next)
 	{
@@ -634,21 +675,21 @@ private:
 		m_tree[node].level = level;
 		m_tree[node].firstPoint = leftChild;
 		m_tree[node].numPoints = rightChild - leftChild;
-	};
+	}
 
 	//! appends one child index. Assumes childCount < 4 and not leaf
 	inline void nodeAppendChild(NodeID node, NodeID child)
 	{
 		m_tree[node].child[m_tree[node].numChilds++] = child;
 		m_tree[node].numPoints += m_tree[child].numPoints;
-	};
+	}
 
 	//! appends an successing point by simply increasing childcount of a leaf. Assumes isLeaf
 	inline void leafAppendPoint(NodeID leaf, PointID point)
 	{
 		m_points[point].node = leaf;
 		m_tree[leaf].numPoints++;
-	};
+	}
 
 	//! adds a well-separated pair to the wspd
 	void addWSPD(NodeID s, NodeID t);
@@ -662,7 +703,7 @@ private:
 	//! the x coordinate of the left most point
 	float m_min_x;
 
-	//! the y coordinate of the bottom most point 
+	//! the y coordinate of the bottom most point
 	float m_min_y;
 
 	//! the x coordinate of the right most point
@@ -674,7 +715,7 @@ private:
 	//! the height and width of a grid cell
 	double m_cellSize;
 
-	//! the inverse scale to transform 
+	//! the inverse scale to transform
 	double m_scaleInv;
 
 	//! the maximum of height and width
@@ -716,13 +757,13 @@ private:
 
 	//! the maximum number of nodes (2*n here instead of 2*n-1)
 	__uint32 m_maxNumNodes;
-	
+
 	//! the point order in tree order
 	LQPoint* m_points;
-	
+
 	//! number of points this quadtree is based on
 	__uint32 m_numPoints;
-	
+
 	__uint32 m_numWSP;
 
 	LQWSPair* m_notWspd;
@@ -739,7 +780,7 @@ private:
 
 	//! first leaf in the leaf chain
 	NodeID m_firstLeaf;
-	
+
 	//! number of leaves in the chain
 	__uint32 m_numLeaves;
 
@@ -756,12 +797,12 @@ inline void swap(ogdf::LinearQuadtree::LQPoint& b, ogdf::LinearQuadtree::LQPoint
 	ogdf::LinearQuadtree::LQPoint t = a;
 	a = b;
 	b = t;
-};
+}
 
 inline bool LQPointComparer(const LinearQuadtree::LQPoint& a, const LinearQuadtree::LQPoint& b)
 {
 	return a.mortonNr < b.mortonNr;
-};
+}
 
 } // end of namespace ogdf
 
