@@ -1,49 +1,42 @@
 /*
- * $Revision: 2014 $
- * 
+ * $Revision: 2565 $
+ *
  * last checkin:
- *   $Author: gutwenger $ 
- *   $Date: 2010-08-27 15:49:59 +0200 (Fri, 27 Aug 2010) $ 
+ *   $Author: gutwenger $
+ *   $Date: 2012-07-07 17:14:54 +0200 (Sa, 07. Jul 2012) $
  ***************************************************************/
- 
+
 /** \file
  * \brief Implementation of Kamada-Kaway layout algorithm.
- * 
+ *
  * \author Karsten Klein
- * 
+ *
  * \par License:
  * This file is part of the Open Graph Drawing Framework (OGDF).
- * Copyright (C) 2005-2009
- * 
+ *
+ * \par
+ * Copyright (C)<br>
+ * See README.txt in the root directory of the OGDF installation for details.
+ *
  * \par
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
  *
  * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- * 
- * \par
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * \par
- * You should have received a copy of the GNU General Public 
+ * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- * 
+ *
  * \see  http://www.gnu.org/copyleft/gpl.html
  ***************************************************************/
 
@@ -58,44 +51,45 @@ const double SpringEmbedderKK::startVal = DBL_MAX - 1.0;
 const double SpringEmbedderKK::minVal = DBL_MIN;
 const double SpringEmbedderKK::desMinLength = 0.0001;
 
-void SpringEmbedderKK::initialize(GraphAttributes& GA,
-								  NodeArray<dpair>&, 
-								  const EdgeArray<double>& eLength,
-								  NodeArray< NodeArray<double> >& oLength,
-								  NodeArray< NodeArray<double> >& sstrength,
-								  double & maxDist,
-								  bool simpleBFS)
+void SpringEmbedderKK::initialize(
+	GraphAttributes& GA,
+	NodeArray<dpair>& partialDer,
+	const EdgeArray<double>& eLength,
+	NodeArray< NodeArray<double> >& oLength,
+	NodeArray< NodeArray<double> >& sstrength,
+	double & maxDist,
+	bool simpleBFS)
 {
 	node v;
 	const Graph &G = GA.constGraph();
 	//hier if m_spread vorlayout oder muss der Nutzer das extern erledigen?
-	m_prevEnergy =  startVal; 
+	m_prevEnergy =  startVal;
 	m_prevLEnergy =  startVal;
-		
+
 	// all edges straight-line
 	GA.clearAllBends();
 	if (!m_useLayout)
 		shufflePositions(GA);
-		
+
 	//the shortest path lengths
 	forall_nodes (v, G) oLength[v].init(G, DBL_MAX);
-	
+
 	//-------------------------------------
 	//computes shortest path distances d_ij
 	//-------------------------------------
 	if (simpleBFS)
-	{	
+	{
 		//we use simply BFS n times
 		//TODO experimentally compare speed, also with bintree dijkstra
-#ifdef OGDF_DEBUG
-		double timeUsed;
-		usedTime(timeUsed);
-#endif		
+//#ifdef OGDF_DEBUG
+//		double timeUsed;
+//		usedTime(timeUsed);
+//#endif
 		maxDist = allpairsspBFS(G, oLength);
-#ifdef OGDF_DEBUG
-		timeUsed = usedTime(timeUsed);
-		cout << "\n******APSP BFS runtime: \n";
-#endif
+//#ifdef OGDF_DEBUG
+//		timeUsed = usedTime(timeUsed);
+//		cout << "\n******APSP BFS runtime: \n";
+//#endif
 	}
 	else
 	{
@@ -108,19 +102,19 @@ void SpringEmbedderKK::initialize(GraphAttributes& GA,
 	//------------------------------------
 	//computes original spring length l_ij
 	//------------------------------------
-	
+
 	//first we determine desirable edge length L
 	//nodes sizes may be non-uniform, we approximate the display size (grid)
 	//this part relies on the fact that node sizes are set != zero
 	//TODO check later if this is a good choice
-	double L = m_desLength; //desirable length 
+	double L = m_desLength; //desirable length
 	double Lzero; //Todo check with m_zeroLength
 	if (L < desMinLength)
 	{
 		double swidth = 0.0f, sheight = 0.0f;
-		
+
 		// Do all nodes lie on the same point? Check by computing BB of centers
-		// Then, perform simple shifting in layout 
+		// Then, perform simple shifting in layout
 		node vFirst = G.firstNode();
 		double minX = GA.x(vFirst), maxX = GA.x(vFirst),
 				minY = GA.y(vFirst), maxY = GA.y(vFirst);
@@ -128,29 +122,29 @@ void SpringEmbedderKK::initialize(GraphAttributes& GA,
 		//				add node sizes to estimate desirable length
 		//				compute BB to check degeneracy
 		forall_nodes(v, G)
-		{	
-			swidth += GA.width(v); 
+		{
+			swidth += GA.width(v);
 			sheight += GA.height(v);
-			
+
 			if(GA.x(v) < minX) minX = GA.x(v);
 			if(GA.x(v) > maxX) maxX = GA.x(v);
 			if(GA.y(v) < minY) minY = GA.y(v);
 			if(GA.y(v) > maxY) maxY = GA.y(v);
 		}
-		
+
 		double sroot = maxDist;//sqrt(G.numberOfNodes());
 		swidth = swidth / sroot;
 		sheight = sheight / sroot;
 		Lzero = max(2.0*sroot, 2.0*(swidth + sheight));
-		//test für multilevel
+		//test for multilevel
 		Lzero = max(max(maxX-minX, maxY-minY), 2.0*Lzero);
 		//cout << "Lzero: "<<Lzero<<"\n";
-		
-		
+
+
 		L = Lzero / maxDist;
-#ifdef OGDF_DEBUG
-		cout << "Desirable edge length computed: "<<L<<"\n";
-#endif
+//#ifdef OGDF_DEBUG
+//		cout << "Desirable edge length computed: "<<L<<"\n";
+//#endif
 	}//set L != 0
 	//--------------------------------------------------
 	// Having L we can compute the original lengths l_ij
@@ -179,14 +173,14 @@ void SpringEmbedderKK::initialize(GraphAttributes& GA,
 
 
 void SpringEmbedderKK::mainStep(GraphAttributes& GA,
-								NodeArray<dpair>& partialDer, 
+								NodeArray<dpair>& partialDer,
 								NodeArray< NodeArray<double> >& oLength,
 								NodeArray< NodeArray<double> >& sstrength,
-								const double)
+								const double maxDist)
 {
 	const Graph &G = GA.constGraph();
 	node v;
-	
+
 #ifdef OGDF_DEBUG
 	NodeArray<int> nodeCounts(G, 0);
 	int nodeCount = 0; //number of moved nodes
@@ -195,35 +189,35 @@ void SpringEmbedderKK::mainStep(GraphAttributes& GA,
 	double delta_m = 0.0f;
 	double delta_v;
 	node best_m = G.firstNode();
-	
+
 	// Compute the partial derivatives first
-	forall_nodes (v, G) 
+	forall_nodes (v, G)
 	{
 		dpair parder = computeParDers(v, GA, sstrength, oLength);
 		partialDer[v] = parder;
 		//delta_m is sqrt of squares of partial derivatives
 		delta_v = sqrt(parder.x1()*parder.x1() + parder.x2()*parder.x2());
-	
-        if (delta_v > delta_m) 
-        {	
-            best_m = v;
-            delta_m = delta_v;
-        }
+
+		if (delta_v > delta_m)
+		{
+			best_m = v;
+			delta_m = delta_v;
+		}
 	}
-	
+
 	int globalItCount, localItCount;
 	if (m_computeMaxIt)
 	{
 		globalItCount = m_gItBaseVal+m_gItFactor*G.numberOfNodes();
 		localItCount = 2*G.numberOfNodes();
 	}
-	else 
+	else
 	{
 		globalItCount = m_maxGlobalIt;
 		localItCount = m_maxLocalIt;
 	}
-	
-	 
+
+
 	while (globalItCount-- > 0 && !finished(delta_m))
 	{
 #ifdef OGDF_DEBUG
@@ -232,98 +226,99 @@ void SpringEmbedderKK::mainStep(GraphAttributes& GA,
 		nodeCount++;
 		nodeCounts[best_m]++;
 #endif
-      	// The contribution best_m makes to the partial derivatives of
-      	// each vertex. 
-      	NodeArray<dpair> p_partials(G);
-      	forall_nodes(v, G)
-      	{
-      		p_partials[v] = computeParDer(v, best_m, GA, sstrength, oLength);
-      	}
-      	
+		// The contribution best_m makes to the partial derivatives of
+		// each vertex.
+		NodeArray<dpair> p_partials(G);
+		forall_nodes(v, G)
+		{
+			p_partials[v] = computeParDer(v, best_m, GA, sstrength, oLength);
+		}
+
 		localItCount = 0;
 		do {
 #ifdef OGDF_DEBUG
 //			cout <<"  New local iteration\n";
 //			cout <<"   L: "<<localItCount <<"\n";
 #endif
-            // Compute the 4 elements of the Jacobian
-            double dE_dx_dx = 0.0f, dE_dx_dy = 0.0f, dE_dy_dx = 0.0f, dE_dy_dy = 0.0f;
-            forall_nodes(v, G)
-            {
-              if (v != best_m) {
-                double x_diff = GA.x(best_m) - GA.x(v);
-                double y_diff = GA.y(best_m) - GA.y(v);
-                double dist = sqrt(x_diff * x_diff + y_diff * y_diff);
-                double dist3 = dist * dist * dist;
-                OGDF_ASSERT(dist3 != 0.0);
-                double k_mi = sstrength[best_m][v];
-                double l_mi = oLength[best_m][v];
-                dE_dx_dx += k_mi * (1 - (l_mi * y_diff * y_diff)/dist3);
-                dE_dx_dy += k_mi * l_mi * x_diff * y_diff / dist3;
-                dE_dy_dx += k_mi * l_mi * x_diff * y_diff / dist3;
-                dE_dy_dy += k_mi * (1 - (l_mi * x_diff * x_diff)/dist3);
-              }
-            }
+			// Compute the 4 elements of the Jacobian
+			double dE_dx_dx = 0.0f, dE_dx_dy = 0.0f, dE_dy_dx = 0.0f, dE_dy_dy = 0.0f;
+			forall_nodes(v, G)
+			{
+				if (v != best_m) {
+					double x_diff = GA.x(best_m) - GA.x(v);
+					double y_diff = GA.y(best_m) - GA.y(v);
+					double dist = sqrt(x_diff * x_diff + y_diff * y_diff);
+					double dist3 = dist * dist * dist;
+					OGDF_ASSERT(dist3 != 0.0);
+					double k_mi = sstrength[best_m][v];
+					double l_mi = oLength[best_m][v];
+					dE_dx_dx += k_mi * (1 - (l_mi * y_diff * y_diff)/dist3);
+					dE_dx_dy += k_mi * l_mi * x_diff * y_diff / dist3;
+					dE_dy_dx += k_mi * l_mi * x_diff * y_diff / dist3;
+					dE_dy_dy += k_mi * (1 - (l_mi * x_diff * x_diff)/dist3);
+				}
+			}
 
-            // Solve for delta_x and delta_y
-            double dE_dx = partialDer[best_m].x1();
-            double dE_dy = partialDer[best_m].x2();
+			// Solve for delta_x and delta_y
+			double dE_dx = partialDer[best_m].x1();
+			double dE_dy = partialDer[best_m].x2();
 
-            double delta_x = 
-              (dE_dx_dy * dE_dy - dE_dy_dy * dE_dx)
-              / (dE_dx_dx * dE_dy_dy - dE_dx_dy * dE_dy_dx);
+			double delta_x =
+				(dE_dx_dy * dE_dy - dE_dy_dy * dE_dx)
+				/ (dE_dx_dx * dE_dy_dy - dE_dx_dy * dE_dy_dx);
 
-            double delta_y = 
-              (dE_dx_dx * dE_dy - dE_dy_dx * dE_dx)
-              / (dE_dy_dx * dE_dx_dy - dE_dx_dx * dE_dy_dy);
+			double delta_y =
+				(dE_dx_dx * dE_dy - dE_dy_dx * dE_dx)
+				/ (dE_dy_dx * dE_dx_dy - dE_dx_dx * dE_dy_dy);
 
 
-            // Move p by (delta_x, delta_y)
+			// Move p by (delta_x, delta_y)
 #ifdef OGDF_DEBUG
-//            cout <<"   x"<< delta_x<<"\n";
-//            cout <<"   y" <<delta_y<<"\n";
+			// cout <<"   x"<< delta_x<<"\n";
+			// cout <<"   y" <<delta_y<<"\n";
 #endif
-            GA.x(best_m) += delta_x;
-            GA.y(best_m) += delta_y;
+			GA.x(best_m) += delta_x;
+			GA.y(best_m) += delta_y;
 
-            // Recompute partial derivatives and delta_p
-            dpair deriv = computeParDers(best_m, GA, sstrength, oLength);
-            partialDer[best_m] = deriv;
+			// Recompute partial derivatives and delta_p
+			dpair deriv = computeParDers(best_m, GA, sstrength, oLength);
+			partialDer[best_m] = deriv;
 
-            delta_m = 
-              sqrt(deriv.x1()*deriv.x1() + deriv.x2()*deriv.x2());
-          } while (localItCount-- > 0 && !finishedNode(delta_m));
+			delta_m =
+				sqrt(deriv.x1()*deriv.x1() + deriv.x2()*deriv.x2());
+		} while (localItCount-- > 0 && !finishedNode(delta_m));
 
-          // Select new best_m by updating each partial derivative and delta
-          node old_p = best_m;
-          forall_nodes(v, G)
-          {
-            dpair old_deriv_p = p_partials[v];
-          	dpair old_p_partial = 
-              computeParDer(v, old_p, GA, sstrength, oLength);
-            dpair deriv = partialDer[v];
+		// Select new best_m by updating each partial derivative and delta
+		node old_p = best_m;
+		forall_nodes(v, G)
+		{
+			dpair old_deriv_p = p_partials[v];
+			dpair old_p_partial =
+				computeParDer(v, old_p, GA, sstrength, oLength);
+			dpair deriv = partialDer[v];
 
-            deriv.x1() += old_p_partial.x1() - old_deriv_p.x1();
-            deriv.x2() += old_p_partial.x2() - old_deriv_p.x2();
+			deriv.x1() += old_p_partial.x1() - old_deriv_p.x1();
+			deriv.x2() += old_p_partial.x2() - old_deriv_p.x2();
 
-            partialDer[v] = deriv;
-            double delta = sqrt(deriv.x1()*deriv.x1() + deriv.x2()*deriv.x2());
+			partialDer[v] = deriv;
+			double delta = sqrt(deriv.x1()*deriv.x1() + deriv.x2()*deriv.x2());
 
-            if (delta > delta_m) {
-              best_m = v;
-              delta_m = delta;
-            }
-          }
-        }//while	
+			if (delta > delta_m) {
+				best_m = v;
+				delta_m = delta;
+			}
+		}
+	}//while
 #ifdef OGDF_DEBUG
-        cout << "NodeCount: "<<nodeCount<<"\n";
-//        forall_nodes(v, G)
-//        {
-//        	cout<<"Counts "<<v->index()<<": "<<nodeCounts[v]<<"\n";
-//        }
+//  cout << "NodeCount: "<<nodeCount<<"\n";
+//  forall_nodes(v, G)
+//  {
+//   	cout<<"Counts "<<v->index()<<": "<<nodeCounts[v]<<"\n";
+//  }
 #endif
 }//mainStep
 
+
 void SpringEmbedderKK::doCall(GraphAttributes& GA, const EdgeArray<double>& eLength, bool simpleBFS)
 {
 	const Graph& G = GA.constGraph();
@@ -331,25 +326,26 @@ void SpringEmbedderKK::doCall(GraphAttributes& GA, const EdgeArray<double>& eLen
 	double maxDist; //maximum distance between nodes
 	NodeArray< NodeArray<double> > oLength(G);//first distance, then original length
 	NodeArray< NodeArray<double> > sstrength(G);//the spring strength
-	
+
 	//only for debugging
 	OGDF_ASSERT(isConnected(G));
-	
+
 	//compute relevant values
 	initialize(GA, partialDer, eLength, oLength, sstrength, maxDist, simpleBFS);
-	
+
 	//main loop with node movement
 	mainStep(GA, partialDer, oLength, sstrength, maxDist);
-	
+
 	if (simpleBFS) scale(GA);
 }
 
+
 void SpringEmbedderKK::call(GraphAttributes& GA)
 {
 	const Graph &G = GA.constGraph();
 	if(G.numberOfEdges() < 1)
 		return;
-	
+
 	EdgeArray<double> eLength(G);//, 1.0);is not used
 	doCall(GA, eLength, true);
 }//call
@@ -359,20 +355,21 @@ void SpringEmbedderKK::call(GraphAttributes& GA,  const EdgeArray<double>& eLeng
 	const Graph &G = GA.constGraph();
 	if(G.numberOfEdges() < 1)
 		return;
-		
+
 	doCall(GA, eLength, false);
 }//call with edge lengths
 
 
 //changes given edge lengths (interpreted as weight factors)
 //according to additional parameters like node size etc.
-void SpringEmbedderKK::adaptLengths(const Graph& G,
-				  const GraphAttributes& GA,
-				  const EdgeArray<double>& eLengths, 
-				  EdgeArray<double>& adaptedLengths)
+void SpringEmbedderKK::adaptLengths(
+	const Graph& G,
+	const GraphAttributes& GA,
+	const EdgeArray<double>& eLengths,
+	EdgeArray<double>& adaptedLengths)
 {
-	//we use the edge lengths as factor and try to respect 
-	//the node sizes such that each node has enough distance 
+	//we use the edge lengths as factor and try to respect
+	//the node sizes such that each node has enough distance
 	edge e;
 	//adapt to node sizes
 	forall_edges(e, G)
@@ -381,85 +378,88 @@ void SpringEmbedderKK::adaptLengths(const Graph& G,
 		double tmax = max(GA.width(e->target()), GA.height(e->target()));
 		if (smax+tmax > 0.0)
 			adaptedLengths[e] = (1+eLengths[e])*((smax+tmax));///2.0);
-		else adaptedLengths[e] = 5.0*eLengths[e]; 
+		else adaptedLengths[e] = 5.0*eLengths[e];
 	}
 }//adaptLengths
 
-void SpringEmbedderKK::shufflePositions(GraphAttributes&)
+void SpringEmbedderKK::shufflePositions(GraphAttributes& GA)
 {
 //first check if degenerated or
 //just position all on a circle or random layout?
 }//shufflePositions
-	
+
 
 
 // Compute contribution of vertex u to the first partial
 // derivatives (dE/dx_m, dE/dy_m) (for vertex m) (eq. 7 and 8 in paper)
-SpringEmbedderKK::dpair SpringEmbedderKK::computeParDer(node m, 
-					node u,
-					GraphAttributes& GA, 
-					NodeArray< NodeArray<double> >& ss,
-					NodeArray< NodeArray<double> >& dist)
+SpringEmbedderKK::dpair SpringEmbedderKK::computeParDer(
+	node m,
+	node u,
+	GraphAttributes& GA,
+	NodeArray< NodeArray<double> >& ss,
+	NodeArray< NodeArray<double> >& dist)
 {
-	dpair result(0.0, 0.0); 
-    if (m != u) 
-    {
-    	double x_diff = GA.x(m) - GA.x(u);
-        double y_diff = GA.y(m) - GA.y(u);
-        double distance = sqrt(x_diff * x_diff + y_diff * y_diff);
-        result.x1() = (ss[m][u]) * (x_diff - (dist[m][u])*x_diff/distance);
-        result.x2() = (ss[m][u]) * (y_diff - (dist[m][u])*y_diff/distance);
-    }
+	dpair result(0.0, 0.0);
+	if (m != u)
+	{
+		double x_diff = GA.x(m) - GA.x(u);
+		double y_diff = GA.y(m) - GA.y(u);
+		double distance = sqrt(x_diff * x_diff + y_diff * y_diff);
+		result.x1() = (ss[m][u]) * (x_diff - (dist[m][u])*x_diff/distance);
+		result.x2() = (ss[m][u]) * (y_diff - (dist[m][u])*y_diff/distance);
+	}
 
-    return result;
+	return result;
 }
 
+
 //compute partial derivative for v
-SpringEmbedderKK::dpair SpringEmbedderKK::computeParDers(node v, 
-					 GraphAttributes& GA,
-					 NodeArray< NodeArray<double> >& ss, 
-					 NodeArray< NodeArray<double> >& dist)
+SpringEmbedderKK::dpair SpringEmbedderKK::computeParDers(node v,
+	GraphAttributes& GA,
+	NodeArray< NodeArray<double> >& ss,
+	NodeArray< NodeArray<double> >& dist)
 {
 	node u;
-    dpair result(0.0, 0.0);
-    forall_nodes(u, GA.constGraph())
-    {
-    	dpair deriv = computeParDer(v, u, GA, ss, dist);
-    	result.x1() += deriv.x1();
-        result.x2() += deriv.x2();
-    }
+	dpair result(0.0, 0.0);
+	forall_nodes(u, GA.constGraph())
+	{
+		dpair deriv = computeParDer(v, u, GA, ss, dist);
+		result.x1() += deriv.x1();
+		result.x2() += deriv.x2();
+	}
 
-    return result;
+	return result;
 }
 
+
 /**
  * Initialise the original estimates from nodes and edges.
  */
- 
-//we could speed this up by not using nested NodeArrays and 
+
+//we could speed this up by not using nested NodeArrays and
 //by not doing the fully symmetrical computation on undirected graphs
 //All Pairs Shortest Path Floyd, initializes the whole matrix
 //returns maximum distance. Does not detect negative cycles (lead to neg. values on diagonal)
 //threshold is the value for the distance of non-adjacent nodes, distance has to be
 //initialized with
 double SpringEmbedderKK::allpairssp(const Graph& G, const EdgeArray<double>& eLengths, NodeArray< NodeArray<double> >& distance,
-const double threshold)
+	const double threshold)
 {
-	node v; 
+	node v;
 	edge e;
 	double maxDist = -threshold;
-	
+
 	forall_nodes(v, G)
 	{
-    	distance[v][v] = 0.0f;
+		distance[v][v] = 0.0f;
 	}
 
 	//TODO: Experimentally compare this against
 	// all nodes and incident edges (memory access) on huge graphs
 	forall_edges(e, G)
 	{
-    	distance[e->source()][e->target()] = eLengths[e];
-    	distance[e->target()][e->source()] = eLengths[e];
+		distance[e->source()][e->target()] = eLengths[e];
+		distance[e->target()][e->source()] = eLengths[e];
 	}
 
 ///**
@@ -468,53 +468,54 @@ const double threshold)
 	node u, w;
 	forall_nodes(v, G)
 	{
-	    forall_nodes(u, G)
-	    {
-	        forall_nodes(w, G)
-	        {
-	        	if ((distance[u][v] < threshold) && (distance[v][w] < threshold))
-	        	{
-	            	distance[u][w] = min( distance[u][w], distance[u][v] + distance[v][w] );
-	            	//distance[w][u] = distance[u][w]; //is done anyway afterwards
-	        	}
-	            if (distance[u][w] < threshold)
-	            	maxDist = max(maxDist,distance[u][w]);
-	        }
-	    }
+		forall_nodes(u, G)
+		{
+			forall_nodes(w, G)
+			{
+				if ((distance[u][v] < threshold) && (distance[v][w] < threshold))
+				{
+					distance[u][w] = min( distance[u][w], distance[u][v] + distance[v][w] );
+					//distance[w][u] = distance[u][w]; //is done anyway afterwards
+				}
+				if (distance[u][w] < threshold)
+					maxDist = max(maxDist,distance[u][w]);
+			}
+		}
 	}
 	//debug output
-#ifdef OGDF_DEBUG
-	forall_nodes(v, G)
-	{
-		if (distance[v][v] < 0.0) cerr << "\n###Error in shortest path computation###\n\n";
-	}
-	cout << "Maxdist: "<<maxDist<<"\n";
-	forall_nodes(u, G)
-	{
-	forall_nodes(w, G)
-	{
-//		cout << "Distance " << u->index() << " -> "<<w->index()<<" "<<distance[u][w]<<"\n"; 
-	}
-	}
-#endif
+//#ifdef OGDF_DEBUG
+//	forall_nodes(v, G)
+//	{
+//		if (distance[v][v] < 0.0) cerr << "\n###Error in shortest path computation###\n\n";
+//	}
+//	cout << "Maxdist: "<<maxDist<<"\n";
+//	forall_nodes(u, G)
+//	{
+//	forall_nodes(w, G)
+//	{
+////		cout << "Distance " << u->index() << " -> "<<w->index()<<" "<<distance[u][w]<<"\n";
+//	}
+//	}
+//#endif
 	return maxDist;
 }//allpairssp
 
+
 //the same without weights, i.e. all pairs shortest paths with BFS
-//Runs in time |V|² 
-//for compatibility, distances are double 
+//Runs in time |V|²
+//for compatibility, distances are double
 double SpringEmbedderKK::allpairsspBFS(const Graph& G, NodeArray< NodeArray<double> >& distance)
 {
-	node v; 
+	node v;
 	double maxDist = 0;
-	
+
 	forall_nodes(v, G)
 	{
-    	distance[v][v] = 0.0f;
+		distance[v][v] = 0.0f;
 	}
-	
+
 	v = G.firstNode();
-	
+
 	//start in each node once
 	while (v != 0)
 	{
@@ -523,7 +524,7 @@ double SpringEmbedderKK::allpairsspBFS(const Graph& G, NodeArray< NodeArray<doub
 		SListPure<node> bfs;
 		bfs.pushBack(v);
 		mark[v] = false;
-		
+
 		while (!bfs.empty())
 		{
 			node w = bfs.popFrontRet();
@@ -541,30 +542,32 @@ double SpringEmbedderKK::allpairsspBFS(const Graph& G, NodeArray< NodeArray<doub
 				}
 			}
 		}//while
-		
+
 		v = v->succ();
 	}//while
-	//check for negative cycles 
+	//check for negative cycles
 	forall_nodes(v, G)
 	{
 		if (distance[v][v] < 0.0) cerr << "\n###Error in shortest path computation###\n\n";
 	}
-	
+
 //debug output
-#ifdef OGDF_DEBUG
-	node u, w;
-	cout << "Maxdist: "<<maxDist<<"\n";
-	forall_nodes(u, G)
-	{
-	forall_nodes(w, G)
-	{
-//		cout << "Distance " << u->index() << " -> "<<w->index()<<" "<<distance[u][w]<<"\n"; 
-	}
-	}
-#endif
+//#ifdef OGDF_DEBUG
+//	node u, w;
+//	cout << "Maxdist: "<<maxDist<<"\n";
+//	forall_nodes(u, G)
+//	{
+//	forall_nodes(w, G)
+//	{
+////		cout << "Distance " << u->index() << " -> "<<w->index()<<" "<<distance[u][w]<<"\n";
+//	}
+//	}
+//#endif
 	return maxDist;
 }//allpairsspBFS
-void SpringEmbedderKK::scale(GraphAttributes& GA) 
+
+
+void SpringEmbedderKK::scale(GraphAttributes& GA)
 {
 //Simple version: Just scale to max needed
 //We run over all edges, find the largest distance needed and scale
@@ -601,7 +604,7 @@ void SpringEmbedderKK::scale(GraphAttributes& GA)
 				maxFac = w2;
 		}
 	}
-	
+
 
 	if (maxFac > 1.0 && (maxFac < (DBL_MAX/2.0)-1) && scale) //only scale to increase distance
 	{
@@ -611,11 +614,11 @@ void SpringEmbedderKK::scale(GraphAttributes& GA)
 			double scaleF = maxFac+0.00001;
 			double base = 2.0;
 			maxFac = base;
-		
+
 			while (scale && maxFac<scaleF)
 			{
 			forall_nodes(v, GA.constGraph())
-			{	
+			{
 				GA.x(v) = GA.x(v)*base;
 				GA.y(v) = GA.y(v)*base;
 				if (GA.x(v) > (DBL_MAX / base)-1 || GA.y(v) > (DBL_MAX / base) - 1)
@@ -627,14 +630,14 @@ void SpringEmbedderKK::scale(GraphAttributes& GA)
 		else
 		{
 			forall_nodes(v, GA.constGraph())
-			{	
+			{
 				GA.x(v) = GA.x(v)*maxFac;
 				GA.y(v) = GA.y(v)*maxFac;
 			}
 		}
-#ifdef OGDF_DEBUG
-		cout << "Scaled by factor "<<maxFac<<"\n";
-#endif 
+//#ifdef OGDF_DEBUG
+//		cout << "Scaled by factor "<<maxFac<<"\n";
+//#endif
 	}
 }//Scale
 
