@@ -1,52 +1,43 @@
 /*
- * $Revision: 2047 $
- * 
+ * $Revision: 2565 $
+ *
  * last checkin:
- *   $Author: klein $ 
- *   $Date: 2010-10-13 17:12:21 +0200 (Wed, 13 Oct 2010) $ 
+ *   $Author: gutwenger $
+ *   $Date: 2012-07-07 17:14:54 +0200 (Sa, 07. Jul 2012) $
  ***************************************************************/
- 
+
 /** \file
  * \brief Implementation of Sugiyama algorithm (classes Hierarchy,
  * Level, SugiyamaLayout)
- * 
+ *
  * \author Carsten Gutwenger
- * 
+ *
  * \par License:
  * This file is part of the Open Graph Drawing Framework (OGDF).
  *
- * Copyright (C). All rights reserved.
+ * \par
+ * Copyright (C)<br>
  * See README.txt in the root directory of the OGDF installation for details.
- * 
+ *
  * \par
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
  *
  * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- * 
- * \par
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * \par
- * You should have received a copy of the GNU General Public 
+ * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- * 
+ *
  * \see  http://www.gnu.org/copyleft/gpl.html
  ***************************************************************/
 
@@ -64,6 +55,7 @@
 #include <ogdf/packing/TileToRowsCCPacker.h>
 #include <ogdf/basic/simple_graph_alg.h>
 
+#include <algorithm>
 
 
 namespace ogdf {
@@ -98,7 +90,7 @@ void GraphCopyAttributes::transform()
 
 		DPolyline &dpl = m_pAG->bends(eG);
 		dpl.clear();
-		
+
 		ListConstIterator<edge> itE = m_pGC->chain(eG).begin();
 		node v      = (*itE)->source();
 		node vAfter = (*itE)->target();
@@ -111,7 +103,7 @@ void GraphCopyAttributes::transform()
 
 			// filter real bend points
 			if((m_x[v] != m_x[vBefore] || m_x[v] != m_x[vAfter]) &&
-			   (m_y[v] != m_y[vBefore] || m_y[v] != m_y[vAfter]))
+				(m_y[v] != m_y[vBefore] || m_y[v] != m_y[vAfter]))
 				dpl.pushBack(DPoint(m_x[v],m_y[v]));
 		}
 
@@ -150,7 +142,7 @@ void ClusterGraphCopyAttributes::transform()
 
 		DPolyline &dpl = m_pACG->bends(eG);
 		dpl.clear();
-		
+
 		ListConstIterator<edge> itE = m_pH->chain(eG).begin();
 		node v      = (*itE)->source();
 		node vAfter = (*itE)->target();
@@ -163,7 +155,7 @@ void ClusterGraphCopyAttributes::transform()
 
 			// filter real bend points
 			if((m_x[v] != m_x[vBefore] || m_x[v] != m_x[vAfter]) &&
-			   (m_y[v] != m_y[vBefore] || m_y[v] != m_y[vAfter]))
+				(m_y[v] != m_y[vBefore] || m_y[v] != m_y[vAfter]))
 				dpl.pushBack(DPoint(m_x[v],m_y[v]));
 		}
 
@@ -193,9 +185,6 @@ void Level::swap(int i, int j)
 
 
 
-
-
-
 class WeightBucket : public BucketFunc<node> {
 	const NodeArray<int> *m_pWeight;
 
@@ -227,23 +216,27 @@ void Level::getIsolatedNodes(SListPure<Tuple2<node,int> > &isolated)
 
 void Level::setIsolatedNodes(SListPure<Tuple2<node,int> > &isolated)
 {
-	SListPure<node> sortedNodes;
+	const int sizeL = size();
+	Array<node> sortedNodes(sizeL);
+	isolated.pushBack(Tuple2<node,int>(0,sizeL));
 	SListConstIterator<Tuple2<node,int> > itIsolated = isolated.begin();
 
-	int i;
-	for(i = 0; true; ++itIsolated) {
-		int nextPos = (itIsolated.valid()) ? (*itIsolated).x2() : (high()+1);
-		for(; i < nextPos; ++i) {
-			if (adjNodes(m_nodes[i]).high() >= 0)
-				sortedNodes.pushBack(m_nodes[i]);
+	int nextPos = (*itIsolated).x2();
+	for( int iNodes = 0, iSortedNodes = 0; nextPos <= sizeL; ) {
+		if( iSortedNodes == nextPos ) {
+			if( iSortedNodes == sizeL )
+				break;
+			sortedNodes[iSortedNodes++] = (*itIsolated).x1();
+			nextPos = (*(++itIsolated)).x2();
+		} else {
+			node v = m_nodes[iNodes++];
+			if( adjNodes(v).size() > 0 )
+				sortedNodes[iSortedNodes++] = v;
 		}
-		if (i > high()) break;
-		sortedNodes.pushBack((*itIsolated).x1());
 	}
 
-	SListConstIterator<node> itSorted = sortedNodes.begin();
-	for(i = 0; itSorted.valid(); ++itSorted)
-		m_nodes[i++] = *itSorted;
+	for( int i = 0; i < sizeL; ++i)
+		m_nodes[i] = sortedNodes[i];
 }
 
 
@@ -253,19 +246,28 @@ void Level::sort(NodeArray<double> &weight)
 	getIsolatedNodes(isolated);
 
 	WeightComparer<> cmp(&weight);
-	m_nodes.quicksort(cmp);
+	//m_nodes.quicksort(cmp);
+	std::stable_sort(&m_nodes[0], &m_nodes[0]+m_nodes.size(), cmp);
 
 	if (!isolated.empty()) setIsolatedNodes(isolated);
 	recalcPos();
 }
 
 
+void Level::sortByWeightOnly(NodeArray<double> &weight)
+{
+	WeightComparer<> cmp(&weight);
+	std::stable_sort(&m_nodes[0], &m_nodes[0]+m_nodes.size(), cmp);
+	recalcPos();
+}
+
+
 void Level::sort(NodeArray<int> &weight, int minBucket, int maxBucket)
 {
 	SListPure<Tuple2<node,int> > isolated;
 	getIsolatedNodes(isolated);
 
-WeightBucket bucketFunc(&weight);
+	WeightBucket bucketFunc(&weight);
 	bucketSort(m_nodes,minBucket,maxBucket,bucketFunc);
 
 	if (!isolated.empty()) setIsolatedNodes(isolated);
@@ -311,7 +313,7 @@ void Hierarchy::doInit(const NodeArray<int> &rank)
 		if (rankSrc > rankTgt) {
 			m_GC.reverseEdge(e); std::swap(rankSrc,rankTgt);
 		}
-		
+
 		if (rankSrc == rankTgt) {
 			e = m_GC.split(e);
 			m_GC.reverseEdge(e);
@@ -332,7 +334,7 @@ void Hierarchy::doInit(const NodeArray<int> &rank)
 	for(i = 0; i <= m_pLevel.high(); ++i)
 		delete m_pLevel[i];
 	m_pLevel.init(0,maxRank);
-	
+
 	for(i = 0; i <= maxRank; ++i)
 		m_pLevel[i] = new Level(this,i,length[i]);
 
@@ -407,7 +409,7 @@ void Hierarchy::buildAdjNodes(int i)
 		node v = level[j];
 		edge e;
 		forall_adj_edges(e,v) {
-			if (e->source() == v) {			
+			if (e->source() == v) {
 				(m_lowerAdjNodes[e->target()])[m_nSet[e->target()]++] = v;
 			} else {
 				(m_upperAdjNodes[e->source()])[m_nSet[e->source()]++] = v;
@@ -496,10 +498,8 @@ int Hierarchy::calculateCrossings()
 
 
 // calculation of edge crossings between level i and i+1
-// implementation by Michael Juenger (juenger@oreas.de), Decembre 2000
-//   adapted by Carsten Gutwenger (gutwenger@oreas.de)
-// implements a (yet unpublished) algorithm by Barth
-// refer to Graph Drawing script by Michael Juenger
+// implementation by Michael Juenger, Decembre 2000, adapted by Carsten Gutwenger
+// implements the algorithm by Barth, Juenger, Mutzel
 
 int Hierarchy::calculateCrossings(int i)
 {
@@ -508,7 +508,7 @@ int Hierarchy::calculateCrossings(int i)
 
 	int nc = 0; // number of crossings
 
-	int fa = 1; 
+	int fa = 1;
 	while (fa < nUpper)
 		fa *= 2;
 
@@ -542,7 +542,7 @@ int Hierarchy::calculateCrossings(int i)
 
 
 //-----------------------------------------------
-// The following code 
+// The following code
 //   calculateCrossingsPlaneSweep() and
 //   calculateCrossingsPlaneSweep(int i)
 // is the old implementation of the crossing calculation using a
@@ -785,6 +785,7 @@ SugiyamaLayout::SugiyamaLayout()
 	m_fails = 4;
 	m_runs = 15;
 	m_transpose = true;
+	m_permuteFirst = false;
 
 	m_arrangeCCs = true;
 	m_minDistCC = 20;
@@ -793,8 +794,10 @@ SugiyamaLayout::SugiyamaLayout()
 	m_alignBaseClasses = false;
 	m_alignSiblings = false;
 	m_subgraphs = 0;
+
 	m_maxLevelSize = -1;
 	m_numLevels = -1;
+	m_timeReduceCrossings = 0.0;
 }
 
 
@@ -862,6 +865,8 @@ void SugiyamaLayout::doCall(GraphAttributes &AG, bool umlCall, NodeArray<int> &r
 		Array<DPoint> offset1(m_numCC);
 		NodeArray<bool> mark(GC);
 
+		m_numLevels = m_maxLevelSize = 0;
+
 		int totalCrossings = 0;
 		for(int i = 0; i < m_numCC; ++i)
 		{
@@ -953,6 +958,12 @@ void SugiyamaLayout::doCall(GraphAttributes &AG, bool umlCall, NodeArray<int> &r
 
 			boundingBox[i] = DPoint(maxX - minX, maxY - minY);
 			offset1    [i] = DPoint(minX,minY);
+
+			m_numLevels = max(m_numLevels, H.size());
+			for(int i = 0; i <= H.high(); i++) {
+				Level &l = H[i];
+				m_maxLevelSize = max(m_maxLevelSize, l.size());
+			}
 		}
 
 		m_nCrossings = totalCrossings;
@@ -971,7 +982,7 @@ void SugiyamaLayout::doCall(GraphAttributes &AG, bool umlCall, NodeArray<int> &r
 
 			const double dx = offset[i].m_x - offset1[i].m_x;
 			const double dy = offset[i].m_y - offset1[i].m_y;
-			
+
 			// iterate over all nodes in ith CC
 			ListConstIterator<node> it;
 			for(it = nodes.begin(); it.valid(); ++it)
@@ -995,14 +1006,6 @@ void SugiyamaLayout::doCall(GraphAttributes &AG, bool umlCall, NodeArray<int> &r
 					}
 				}
 			}
-		}		
-		
-		m_numLevels = H.size();
-		m_maxLevelSize = 0;
-		for(int i = 0; i <= H.high(); i++) {
-			Level &l = H[i];
-			if (l.size() > m_maxLevelSize)
-				m_maxLevelSize = l.size();			
 		}
 
 	} else {
@@ -1026,7 +1029,7 @@ void SugiyamaLayout::doCall(GraphAttributes &AG, bool umlCall, NodeArray<int> &r
 			if(vOrig == 0)
 				vOrig = GC.original(v->firstAdj()->theEdge())->source();
 
-			m_compGC[v] = component[vOrig];	
+			m_compGC[v] = component[vOrig];
 		}
 
 		reduceCrossings(H);
@@ -1067,16 +1070,16 @@ void SugiyamaLayout::doCall(GraphAttributes &AG, bool umlCall, NodeArray<int> &r
 			}
 		}
 
-		m_numLevels = H.size();		
+		m_numLevels = H.size();
 		m_maxLevelSize = 0;
 		for(int i = 0; i <= H.high(); i++) {
 			Level &l = H[i];
 			if (l.size() > m_maxLevelSize)
-				m_maxLevelSize = l.size();			
+				m_maxLevelSize = l.size();
 		}
 
 	}
-	
+
 }
 
 
@@ -1136,16 +1139,13 @@ int SugiyamaLayout::traverseTopDown(Hierarchy& H)
 	H.direction(Hierarchy::downward);
 
 	for (int i = 1; i <= H.high(); ++i) {
-	  if(!useSubgraphs())
-	    {
-	      TwoLayerCrossMin &minimizer = m_crossMin.get();
-	      minimizer(H[i]);
-	    }
-	  else
-	    {
-	      TwoLayerCrossMinSimDraw &minimizer = m_crossMinSimDraw.get();
-	      minimizer.call(H[i],m_subgraphs);
-	    }
+		if(!useSubgraphs()) {
+			TwoLayerCrossMin &minimizer = m_crossMin.get();
+			minimizer(H[i]);
+		} else {
+			TwoLayerCrossMinSimDraw &minimizer = m_crossMinSimDraw.get();
+			minimizer.call(H[i],m_subgraphs);
+		}
 	}
 
 	if (m_transpose)
@@ -1166,15 +1166,15 @@ int SugiyamaLayout::traverseBottomUp(Hierarchy& H)
 
 	for (int i = H.high()-1; i >= 0; i--) {
 		if(!useSubgraphs())
-	    {
+		{
 			TwoLayerCrossMin &minimizer = m_crossMin.get();
 			minimizer(H[i]);
-	    }
+		}
 		else
-	    {
+		{
 			TwoLayerCrossMinSimDraw &minimizer = m_crossMinSimDraw.get();
 			minimizer.call(H[i],m_subgraphs);
-	    }
+		}
 	}
 
 	if (m_transpose)
@@ -1191,9 +1191,15 @@ int SugiyamaLayout::traverseBottomUp(Hierarchy& H)
 
 void SugiyamaLayout::reduceCrossings(Hierarchy &H)
 {
+	__int64 t;
+	System::usedRealTime(t);
+
 	TwoLayerCrossMin &minimizer = m_crossMin.get();
 	TwoLayerCrossMinSimDraw &sdminimizer = m_crossMinSimDraw.get();
 
+	if(m_permuteFirst)
+		H.permute();
+
 	int nCrossingsOld, nCrossingsNew;
 	NodeArray<int> bestPos;
 
@@ -1203,8 +1209,11 @@ void SugiyamaLayout::reduceCrossings(Hierarchy &H)
 		m_nCrossings = nCrossingsOld = H.calculateCrossingsSimDraw(m_subgraphs);
 	H.storePos(bestPos);
 
-	
-	if (m_nCrossings == 0) return;
+	if (m_nCrossings == 0) {
+		t = System::usedRealTime(t);
+		m_timeReduceCrossings = double(t) / 1000;
+		return;
+	}
 
 	if(!useSubgraphs())
 		minimizer.init(H);
@@ -1221,6 +1230,7 @@ void SugiyamaLayout::reduceCrossings(Hierarchy &H)
 
 		do {
 			nCrossingsNew = traverseTopDown(H);
+			//cout << nCrossingsNew << endl;
 
 			if (nCrossingsNew < nCrossingsOld) {
 				if (nCrossingsNew < m_nCrossings) {
@@ -1235,6 +1245,7 @@ void SugiyamaLayout::reduceCrossings(Hierarchy &H)
 				--nFails;
 
 			nCrossingsNew = traverseBottomUp(H);
+			//cout << nCrossingsNew << endl;
 
 			if (nCrossingsNew < nCrossingsOld) {
 				if (nCrossingsNew < m_nCrossings) {
@@ -1256,9 +1267,9 @@ void SugiyamaLayout::reduceCrossings(Hierarchy &H)
 		H.permute();
 
 		if(!useSubgraphs())
-		  nCrossingsOld = H.calculateCrossings();
+			nCrossingsOld = H.calculateCrossings();
 		else
-		  nCrossingsOld = H.calculateCrossings();
+			nCrossingsOld = H.calculateCrossings();
 		if (nCrossingsOld < m_nCrossings) {
 			H.storePos(bestPos);
 
@@ -1269,10 +1280,13 @@ void SugiyamaLayout::reduceCrossings(Hierarchy &H)
 	H.restorePos(bestPos);
 
 	if(!useSubgraphs())
-	  minimizer.cleanup();
+		minimizer.cleanup();
 	else
-	  sdminimizer.cleanup();
+		sdminimizer.cleanup();
 	m_levelChanged.init();
+
+	t = System::usedRealTime(t);
+	m_timeReduceCrossings = double(t) / 1000;
 }
 
 
