@@ -1,61 +1,52 @@
 /*
- * $Revision: 2027 $
- * 
+ * $Revision: 2573 $
+ *
  * last checkin:
- *   $Author: gutwenger $ 
- *   $Date: 2010-09-01 11:55:17 +0200 (Wed, 01 Sep 2010) $ 
+ *   $Author: gutwenger $
+ *   $Date: 2012-07-10 18:48:33 +0200 (Di, 10. Jul 2012) $
  ***************************************************************/
- 
+
 /** \file
- * \brief BalloonLayout for trees that can also be applied to 
+ * \brief BalloonLayout for trees that can also be applied to
  * general graphs.
- * 
+ *
  * Partially based on the papers by Lin/Yen and Carriere/Kazman
- * 
+ *
  * \author Karsten Klein
- * 
+ *
  * \par License:
  * This file is part of the Open Graph Drawing Framework (OGDF).
  *
- * Copyright (C). All rights reserved.
+ * \par
+ * Copyright (C)<br>
  * See README.txt in the root directory of the OGDF installation for details.
- * 
+ *
  * \par
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
  *
  * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- * 
- * \par
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * \par
- * You should have received a copy of the GNU General Public 
+ * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- * 
+ *
  * \see  http://www.gnu.org/copyleft/gpl.html
  ***************************************************************/
 
 //There are two radii at each node: The outer radius of the circle
 //surrounding its subtree, and the inner radius of the circle
 //on which the children of the node are placed
-//For each angle assignment at a node p (parent), its own angle is 
+//For each angle assignment at a node p (parent), its own angle is
 //used as offset, so that the children are correctly oriented
 
 #include <ogdf/misclayout/BalloonLayout.h>
@@ -64,6 +55,7 @@
 #include <ogdf/basic/simple_graph_alg.h>
 #include <ogdf/basic/Queue.h>
 #include <ogdf/basic/Stack.h>
+#include <ogdf/basic/Math.h>
 
 #include <math.h>
 
@@ -77,14 +69,14 @@ BalloonLayout::BalloonLayout() :
 	 m_childOrder(orderFixed),    //how to arrange the children
 	 m_treeComputation(BalloonLayout::treeBfs),  //spanning tree by...
 	 m_evenAngles(false)
-{ 
+{
 	#ifdef OGDF_DEBUG
 	m_treeEdge = 0;
 	#endif
 }
 
-BalloonLayout::~BalloonLayout() 
-{ 
+BalloonLayout::~BalloonLayout()
+{
 #ifdef OGDF_DEBUG
 if (m_treeEdge != 0) delete m_treeEdge;
 #endif
@@ -102,29 +94,29 @@ BalloonLayout &BalloonLayout::operator=(const BalloonLayout &bl)
 }
 
 
-void BalloonLayout::call(GraphAttributes &AG) 
+void BalloonLayout::call(GraphAttributes &AG)
 {
 	const Graph &G = AG.constGraph();
 	if(G.numberOfNodes() == 0) return;
-	
+
 	#ifdef OGDF_DEBUG
-	if (!isConnected(G)) 
+	if (!isConnected(G))
 		OGDF_THROW_PARAM(PreconditionViolatedException, pvcConnected);
 	if (m_treeEdge != 0) delete m_treeEdge;
 	m_treeEdge = OGDF_NEW EdgeArray<bool>();
 	m_treeEdge->init(G, false);
 	#endif
-	
+
 	m_rootSelection = rootCenter;
 	m_treeComputation = treeBfs;
 	m_childOrder = orderFixed;
-	
+
 	computeTree(G);
 	#ifdef OGDF_DEBUG
 	AG.colorNode(m_treeRoot) = "#0000CD";
 	cout << "Treeroot is blue\n";
 	#endif
-	 
+
 	// determine root of tree (m_root)
 	m_root = m_treeRoot;
 	selectRoot(G);
@@ -136,7 +128,7 @@ void BalloonLayout::call(GraphAttributes &AG)
 		if ((*m_treeEdge)[e]) AG.colorEdge(e) = "#AA00AA";
 	}
 	#endif
-	
+
 	computeRadii(AG);
 
 	// computes m_angle[v]
@@ -155,12 +147,12 @@ void BalloonLayout::selectRoot(const Graph &G)
 	#endif
 	node v;
 
-	switch(m_rootSelection) 
+	switch(m_rootSelection)
 	{
-	
-		case BalloonLayout::rootHighestDegree:
+
+	case BalloonLayout::rootHighestDegree:
 		{
-		    int maxDeg = -1;
+			int maxDeg = -1;
 			forall_nodes(v,G)
 				if(v->degree() > maxDeg)
 				{
@@ -168,90 +160,91 @@ void BalloonLayout::selectRoot(const Graph &G)
 					maxDeg = v->degree();
 				}
 		}
-			break;
+		break;
 
-		case BalloonLayout::rootCenter:
+	case BalloonLayout::rootCenter:
+		{
+			NodeArray<int> degree(G);
+			Queue<node> leaves;
+
+			if (G.numberOfNodes() == 1)
+				leaves.append(G.firstNode());
+			else
+				forall_nodes(v,G) {
+					degree[v] = m_childCount[v];
+					if (m_parent[v] != 0) degree[v]++;
+					if(degree[v] == 1)
+						leaves.append(v);
+			}
+
+			while(!leaves.empty()) {
+				v = leaves.pop();
+
+				node p = m_parent[v];
+				if (p != 0)
+					if (--degree[p] == 1)
+						leaves.append(p);
+				ListConstIterator<node> it = m_childList[v].begin();
+				while (it.valid())
+				{
+					if (--degree[(*it)] == 1)
+						leaves.append((*it));
+					it++;
+				}
+			}//while leaves
+
+
+			m_root = v;
+			//we swap the parent relationship on the path
+			//from m_treeRoot to m_root
+
+
+			//---------------
+			node u = m_root;
+			v = 0;
+			while (u != 0)
 			{
-				NodeArray<int> degree(G);
-				Queue<node> leaves;
-
-				if (G.numberOfNodes() == 1)
-					leaves.append(G.firstNode());
-				else
-					forall_nodes(v,G) {
-						degree[v] = m_childCount[v];
-						if (m_parent[v] != 0) degree[v]++;
-						if(degree[v] == 1)
-							leaves.append(v);
-					}
-
-				while(!leaves.empty()) {
-					v = leaves.pop();
-
-					node p = m_parent[v];
-					if (p != 0) 
-						if (--degree[p] == 1)  
-							leaves.append(p);
-					ListConstIterator<node> it = m_childList[v].begin();
+				node w = m_parent[u];
+				m_parent[u] = v;
+				if (v != 0)
+				{
+					//may change the child order
+					m_childCount[v]++;
+					m_childList[v].pushBack(u);
+				}//if v
+				if (w != 0)
+				{
+					m_childCount[w]--;
+					ListIterator<node> it = m_childList[w].begin();
 					while (it.valid())
 					{
-						if (--degree[(*it)] == 1)
-							leaves.append((*it));
-						it++;
-					}
-					}//while leaves
-				
-
-				m_root = v;
-				//we swap the parent relationship on the path
-				//from m_treeRoot to m_root
-				
-				
-				//---------------
-				node u = m_root;
-				v = 0;
-				while (u != 0)
-				{
-					node w = m_parent[u];
-				    m_parent[u] = v;
-				    if (v != 0)
-				    {
-				    	//may change the child order
-				    	m_childCount[v]++;
-				    	m_childList[v].pushBack(u);
-				    }//if v
-				    if (w != 0)
-				    {
-				    	m_childCount[w]--;
-				    	ListIterator<node> it = m_childList[w].begin();
-						while (it.valid())
+						if ((*it)==u)
 						{
-							if ((*it)==u) 
-							{
-								m_childList[w].del(it);
-								break; 
-							}
-							it++;
-						}//while children
-				    }//if w
-				    v = u;
-				    u = w;
-				    
-				}//while
-				
-			}
-			break;
-			default: {cout << BalloonLayout::rootCenter<<" "<<m_rootSelection<<"\n";
-			throw AlgorithmFailureException(afcUnknown);} break;
+							m_childList[w].del(it);
+							break;
+						}
+						it++;
+					}//while children
+				}//if w
+				v = u;
+				u = w;
+
+			}//while
+
+		}
+		break;
+	default: {cout << BalloonLayout::rootCenter<<" "<<m_rootSelection<<"\n";
+		throw AlgorithmFailureException(afcUnknown);} break;
 	}//switch
-	#ifdef OGDF_DEBUG
+
+#ifdef OGDF_DEBUG
 	checkTree(G, false);
 	#endif
 }//selectroot
 
 #ifdef OGDF_DEBUG
 void BalloonLayout::computeRadii(GraphAttributes &AG)
-#else 
+#else
 void BalloonLayout::computeRadii(const GraphAttributes &AG)
 #endif
 {
@@ -261,7 +254,7 @@ void BalloonLayout::computeRadii(const GraphAttributes &AG)
 	m_estimate.init(G, 0.0);
 	m_maxChildRadius.init(G, 0.0);
 	m_size.init(G, 0.0);
-	
+
 	node u;
 	forall_nodes(u, G)
 	{
@@ -269,11 +262,11 @@ void BalloonLayout::computeRadii(const GraphAttributes &AG)
 		double h = AG.height(u);
 		double t = 0.5*sqrt(w*w+h*h);
 		m_size[u] = max(0.007, t); //assure we  don't have zero values, some default
-		
+
 	}
-	
+
 	Queue<node> level;
-	
+
 	switch (m_childOrder)
 	{
 		case orderOptimized: //todo
@@ -285,24 +278,24 @@ void BalloonLayout::computeRadii(const GraphAttributes &AG)
 			//r = 0.5*sqrt(w*w + h*h)
 			NodeArray<int> children(G);
 			Queue<node> leaves;
-			
-            if (G.numberOfNodes() > 1)
-            {
-            	node v;
+
+			if (G.numberOfNodes() > 1)
+			{
+				node v;
 				forall_nodes(v,G) {
 					if((children[v] = m_childCount[v]) == 0)
 					{
-						leaves.append(v);		
+						leaves.append(v);
 						m_oRadius[v] = m_size[v];
 					}
 				}//forallnodes
-				//kann man wieder zusammenfassen mit unterer Schleife, 
+				//kann man wieder zusammenfassen mit unterer Schleife,
 				//da Berechnung geaendert
 				while(!leaves.empty()) {
 					v = leaves.pop();
 
 					node p = m_parent[v];
-					  
+
 					if (p != 0)
 					{
 						double t = m_oRadius[v];
@@ -314,14 +307,14 @@ void BalloonLayout::computeRadii(const GraphAttributes &AG)
 						if (m_maxChildRadius[p] < t)
 							m_maxChildRadius[p] = t;
 						//if all children are processed, push p into queue
-						if (--children[p] == 0)  
+						if (--children[p] == 0)
 						{
 							//we processed all children of p
 							//and can derive the radius value
 							level.append(p);
 						}//if children == 0
 					}//if parent
-					//inner radius estimate 
+					//inner radius estimate
 					m_radius[v] =  m_oRadius[v];
 					//cout <<"Child-Radius: "<<m_radius[v]<<"\n";
 				}//while
@@ -335,13 +328,13 @@ void BalloonLayout::computeRadii(const GraphAttributes &AG)
 					//compute radii
 					//inner radius estimate, outer currently holds sum of children
 					//we add the node object size to the radii
-					 
+
 					//even angles: just sum up size of largest child
 					if (m_evenAngles)
 					{
-						m_radius[v] = max((m_maxChildRadius[v]/max(m_childCount[v], 1) + 
+						m_radius[v] = max((m_maxChildRadius[v]/max(m_childCount[v], 1) +
 									m_estimateFactor*2.0*(m_childCount[v]*m_maxChildRadius[v]))/
-									(2*ogdf::pi), 2.0*m_size[v]);
+									(2*Math::pi), 2.0*m_size[v]);
 						#ifdef OGDF_DEBUG
 						cout <<"Even angles \n";
 						#endif
@@ -353,36 +346,36 @@ void BalloonLayout::computeRadii(const GraphAttributes &AG)
 							m_radius[v] = max(2.0*m_size[v], 1.1*m_maxChildRadius[v]);
 							#ifdef OGDF_DEBUG
 							AG.colorNode(v) = "#330000";
-							
-							cout << "Radien mit einem Kind: "<< v->degree() <<" : "<<m_radius[v] << " "<< (m_maxChildRadius[v]/max(m_childCount[v], 4) + 
+
+							cout << "Radien mit einem Kind: "<< v->degree() <<" : "<<m_radius[v] << " "<< (m_maxChildRadius[v]/max(m_childCount[v], 4) +
 									m_estimateFactor*2.0*m_estimate[v])/
-									(2.0*ogdf::pi)<<" "<< 1.1*m_maxChildRadius[v]<<"\n";
-							
+									(2.0*Math::pi)<<" "<< 1.1*m_maxChildRadius[v]<<"\n";
+
 							#endif
 						}
 						else
 						{
 						//better version:
-						m_radius[v] = max(max((m_maxChildRadius[v]/max(m_childCount[v], 4) + 
+						m_radius[v] = max(max((m_maxChildRadius[v]/max(m_childCount[v], 4) +
 									m_estimateFactor*2.0*m_estimate[v])/
-									(2.0*ogdf::pi), 2*m_size[v]), 1.1*m_maxChildRadius[v]);
+									(2.0*Math::pi), 2*m_size[v]), 1.1*m_maxChildRadius[v]);
 							#ifdef OGDF_DEBUG
-							cout << "Radien: "<< v->degree() <<" : "<<m_radius[v] << " "<< (m_maxChildRadius[v]/max(m_childCount[v], 4) + 
+							cout << "Radien: "<< v->degree() <<" : "<<m_radius[v] << " "<< (m_maxChildRadius[v]/max(m_childCount[v], 4) +
 									m_estimateFactor*2.0*m_estimate[v])/
-									(2.0*ogdf::pi)<<" "<< 1.1*m_maxChildRadius[v]<<"\n";
+									(2.0*Math::pi)<<" "<< 1.1*m_maxChildRadius[v]<<"\n";
 							#endif
 						//else
-						//m_radius[v] = max((m_maxChildRadius[v]/max(m_childCount[v], 2) + 
+						//m_radius[v] = max((m_maxChildRadius[v]/max(m_childCount[v], 2) +
 						//			m_estimateFactor*2.0*m_estimate[v])/
-						//			(2.0*ogdf::pi), 2*m_size[v]);
+						//			(2.0*Math::pi), 2*m_size[v]);
 						}
-					}//if even angles  
-					
+					}//if even angles
+
 					//outer radius is inner radius + radius of largest child
 					double t;
 					//if there is only a single child, it will be placed
 					//on the same ray, therefore we do not need to reserve
-					//space for a circle (we only estimate the space needed 
+					//space for a circle (we only estimate the space needed
 					//here by taking the maximum instead of computing the
 					//real value, which would take the distance into account
 					if (m_childCount[v] == 1)
@@ -398,7 +391,7 @@ void BalloonLayout::computeRadii(const GraphAttributes &AG)
 					//---------------------
 					//adjust parent values
 					node p = m_parent[v];
-					//Invariant: outer radius of children of p is already computed  
+					//Invariant: outer radius of children of p is already computed
 					if (p != 0)
 					{
 						//we sum up the outer radius values here at
@@ -409,7 +402,7 @@ void BalloonLayout::computeRadii(const GraphAttributes &AG)
 						if (m_maxChildRadius[p] < t)
 							m_maxChildRadius[p] = t;
 						//if all children are processed, push p into queue
-						if (--children[p] == 0)  
+						if (--children[p] == 0)
 						{
 							//we processed all children of p
 							//and can derive the radius value
@@ -417,10 +410,10 @@ void BalloonLayout::computeRadii(const GraphAttributes &AG)
 						}//if children == 0
 					}//if parent
 					m_oRadius[v] = t;
-				
+
 				}
 			}//if more than one node
-			
+
 		}
 		break;
 	}//switch childorder
@@ -435,7 +428,7 @@ void BalloonLayout::computeTree(const Graph &G)
 	m_parent.init(G, 0);
 	m_childCount.init(G, 0);
 	m_childList.init(G);
-	
+
 	//if the graph is not a tree, compute some spanning tree
 	//and store the corresponding pointers in m_parent
 	switch (m_treeComputation)
@@ -447,7 +440,7 @@ void BalloonLayout::computeTree(const Graph &G)
 			computeBFSTree(G, v);
 		}
 		break;
-	
+
 	}//switch
 }//computeTree
 
@@ -456,21 +449,21 @@ void BalloonLayout::computeBFSTree(const Graph &G, node v)
 {
 	SListPure<node> bfsqueue;
 	NodeArray<bool> marked(G, false);
-	
+
 	bfsqueue.pushBack(v);
-	
+
 	marked[v] =  true;
-	
+
 	m_treeRoot = v;
-	
+
 	node w;
-	
+
 	while (!bfsqueue.empty())
 	{
 		w = bfsqueue.popFrontRet();
-	
+
 		edge e;
-	
+
 		forall_adj_edges(e, w)
 		{
 			node u = e->opposite(w);
@@ -480,7 +473,7 @@ void BalloonLayout::computeBFSTree(const Graph &G, node v)
 				m_childCount[w]++;
 				bfsqueue.pushBack(u);
 				m_childList[w].pushBack(u);
-				
+
 				marked[u] = true;
 				#ifdef OGDF_DEBUG
 				(*m_treeEdge)[e] = true;
@@ -512,7 +505,7 @@ void BalloonLayout::checkTree(const Graph &G, bool treeRoot)
 			listchecker++;
 			testqueue.pushBack((*it));
 			it++;
-		}//while 
+		}//while
 	}//while
 	if (G.numberOfNodes() != testchecker)
 	{
@@ -528,30 +521,30 @@ void BalloonLayout::computeAngles(const Graph &G)
 	checkTree(G, false);
 	int checker = 0;
 	#endif
-	
-	
+
+
 	m_angle.init(G, 0.0);
 	node v;
 
 	v = m_root;
 	SListPure<node> queue;
 	queue.pushBack(v);
-	
+
 	while (!queue.empty())
 	{
 		node p = queue.popFrontRet();
-		
+
 		//process children
-		
+
 		if (m_childCount[p] > 0)
 		{
-			double anglesum = 0.0; 
+			double anglesum = 0.0;
 			double pestimate = m_estimate[p]; //the circumference estimate of the parent
-			double fullAngle = 2.0*ogdf::pi;  //angle that has to be shared by children
+			double fullAngle = 2.0*Math::pi;  //angle that has to be shared by children
 			ListConstIterator<node> it = m_childList[p].begin();
 			if (m_childCount[p] == 1)
 			{
-				m_angle[(*it)] = ogdf::pi;//not used currently, fixed to parent angle
+				m_angle[(*it)] = Math::pi;//not used currently, fixed to parent angle
 				queue.pushBack((*it));
 				#ifdef OGDF_DEBUG
 				checker++;
@@ -560,8 +553,8 @@ void BalloonLayout::computeAngles(const Graph &G)
 			else
 			{
 				//The outer radius of ONE of the children may be larger
-				//than half of the estimate, but we never assign more than 
-				//pi, therefore we have to make two runs to check and correct 
+				//than half of the estimate, but we never assign more than
+				//pi, therefore we have to make two runs to check and correct
 				//this. If the outer radius is more than half of the parent's
 				//estimate, we only assign pi
 				if (!m_evenAngles)
@@ -575,57 +568,57 @@ void BalloonLayout::computeAngles(const Graph &G)
 						if (m_oRadius[(*it2)]/m_estimate[p]>0.501)
 						{
 							#ifdef OGDF_DEBUG
-							if (checkMulti) 
+							if (checkMulti)
 								cout << "More than one large child vertex!\n";
 							checkMulti = true;
-							#endif	
+							#endif
 							pestimate = pestimate - m_oRadius[(*it2)];
-							fullAngle = ogdf::pi;
+							fullAngle = Math::pi;
 							#ifndef OGDF_DEBUG
 							break;
 							#endif
 						}
 						it2++;
 					}
-				} 
+				}
 				while (it.valid())
 				{
 					v = (*it);
 					it++;
-					
+
 					#ifdef OGDF_DEBUG
 					checker++;
 					#endif
-					
+
 					if (m_evenAngles)
 					{
-						m_angle[v] = ogdf::pi*2.0/m_childCount[p];
+						m_angle[v] = Math::pi*2.0/m_childCount[p];
 						queue.pushBack(v);
 					}
 					else
-					{	
+					{
 						//erst alle Winkel aufaddieren und dann anteilig
 						//auf 2pi bzw. 100%
 						//m_angle[v] = anglesum;
-						
+
 						queue.pushBack(v);
-						
+
 						//Anteil an Plazierungsradius des Parent
 						//we use the diameter fraction of the estimate value
 						double ratio = m_oRadius[v]/m_estimate[p];
 						//restrict vertices to at most half of the space, otherwise.
 						//there will be an overlap
-						if (ratio > 0.501) anglesum = ogdf::pi;
+						if (ratio > 0.501) anglesum = Math::pi;
 						else anglesum = fullAngle*m_oRadius[v]/pestimate;
 						//cout<<"\nAnteil : "<<m_oRadius[v]/m_estimate[p]<<" bei Kindern: "<<m_childCount[p]<<"\n";
-												
+
 						m_angle[v] = anglesum;
 						#ifdef OGDF_DEBUG
-						if (anglesum >ogdf::pi) cout << "Angle large than pi!!"<<anglesum<<"children"<< m_childCount[p]<<" full: "<<fullAngle<<"\n";
+						if (anglesum >Math::pi) cout << "Angle large than pi!!"<<anglesum<<"children"<< m_childCount[p]<<" full: "<<fullAngle<<"\n";
 						#endif
 						//cout <<"Set angle at "<<v->index()<<" "<<m_angle[v]<<"\n";
 					}//else
-					
+
 					//it++;
 				}//while children
 			}//else
@@ -634,7 +627,7 @@ void BalloonLayout::computeAngles(const Graph &G)
 	#ifdef OGDF_DEBUG
 	cout << "Checker computeAngles: "<<checker<<" Non: "<<G.numberOfNodes()<<"\n";
 	#endif
-	
+
 	return;
 }
 
@@ -647,7 +640,7 @@ void BalloonLayout::computeCoordinates(GraphAttributes &AG)
 	v = m_root;
 	AG.x(v) = 0.0;
 	AG.y(v) = 0.0;
-	
+
 	SListPure<node> queue;
 	queue.pushBack(v);
 	#ifdef OGDF_DEBUG
@@ -663,14 +656,14 @@ void BalloonLayout::computeCoordinates(GraphAttributes &AG)
 		double x = AG.x(p);
 		double y = AG.y(p);
 		//process children
-		
+
 		//cout <<"Pop Queue\n";
 		if (m_childCount[p] > 0)
 		{
 			//we start at the parent's angle and skip half of the angle
 			//of the last element
-			double anglesum = fmod(m_angle[p]-ogdf::pi+
-				m_angle[*m_childList[p].begin()]/2.0, 2.0*ogdf::pi);//0.0;
+			double anglesum = fmod(m_angle[p]-Math::pi+
+				m_angle[*m_childList[p].begin()]/2.0, 2.0*Math::pi);//0.0;
 			//double sumchecker = 0.0;// debug value
 			//cout<<"Angle start offset: "<<anglesum<<"\n";
 			ListConstIterator<node> it = m_childList[p].begin();
@@ -686,9 +679,9 @@ void BalloonLayout::computeCoordinates(GraphAttributes &AG)
 				m_angle[w] = anglesum;
 				AG.x(w) = x+cos(anglesum)*m_radius[p];
 				AG.y(w) = y+sin(anglesum)*m_radius[p];
-				#ifdef OGDF_DEBUG
-                AG.colorNode(w) = "#00AB00";
-                #endif
+#ifdef OGDF_DEBUG
+				AG.colorNode(w) = "#00AB00";
+#endif
 			}
 			else
 			while (it.valid())
@@ -696,30 +689,30 @@ void BalloonLayout::computeCoordinates(GraphAttributes &AG)
 				//cout<<"Next child\n";
 				node w = (*it);
 				queue.pushBack(w);
-				
+
 				it++;
-				
+
 				node z;
 				if (it.valid()) z = (*it);
 				else z =  (*m_childList[p].begin());
-				
+
 				//cout <<w<<" "<< w->degree()<<" Winkel: "<<m_angle[w]<<" anglesum "<<anglesum <<"\n";
-				
+
 				//cout<<"angles..."<<anglesum<<"\n";
-				
+
 				AG.x(w) = x+cos(anglesum)*m_radius[p];
-				
+
 				AG.y(w) = y+sin(anglesum)*m_radius[p];
-				
+
 				//sumchecker += m_angle[w];
 				double s = m_angle[w];
 				//assign the direction to w to allow its children to use it
 				m_angle[w] = anglesum;
-				
+
 				//z's value is the required angle, not the direction
-				anglesum = fmod((anglesum + (s+m_angle[z])/2.0), 2.0*ogdf::pi);
+				anglesum = fmod((anglesum + (s+m_angle[z])/2.0), 2.0*Math::pi);
 				//cout <<"Finished...\n";
-				
+
 			}//while children
 			//cout<<"\nWinkelgesamtsumme: "<<sumchecker<<" Anzahl Kinder: "<<m_childCount[p] <<"\n\n";
 		}//if children
