@@ -1,51 +1,42 @@
 /*
- * $Revision: 2027 $
- * 
+ * $Revision: 2559 $
+ *
  * last checkin:
- *   $Author: gutwenger $ 
- *   $Date: 2010-09-01 11:55:17 +0200 (Wed, 01 Sep 2010) $ 
+ *   $Author: gutwenger $
+ *   $Date: 2012-07-06 15:04:28 +0200 (Fr, 06. Jul 2012) $
  ***************************************************************/
- 
+
 /** \file
  * \brief implementation of FixedEmbeddingInserter class
- * 
+ *
  * \author Carsten Gutwenger
- * 
+ *
  * \par License:
  * This file is part of the Open Graph Drawing Framework (OGDF).
  *
- * Copyright (C). All rights reserved.
+ * \par
+ * Copyright (C)<br>
  * See README.txt in the root directory of the OGDF installation for details.
- * 
+ *
  * \par
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
+ * Version 2 or 3 as published by the Free Software Foundation;
+ * see the file LICENSE.txt included in the packaging of this file
+ * for details.
  *
  * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- * 
- * \par
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * \par
- * You should have received a copy of the GNU General Public 
+ * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
- * 
+ *
  * \see  http://www.gnu.org/copyleft/gpl.html
  ***************************************************************/
 
@@ -67,6 +58,8 @@ FixedEmbeddingInserter::FixedEmbeddingInserter()
 {
 	m_rrOption = rrNone;
 	m_percentMostCrossed = 25;
+	m_keepEmbedding = false;
+	m_runsPostprocessing = 0;
 }
 
 
@@ -102,14 +95,14 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 	const EdgeArray<bool> *forbiddenEdgeOrig,
 	const EdgeArray<unsigned int> *edgeSubGraph)
 {
-  
+
 	double T;
 	usedTime(T);
-	
+
 	ReturnType retValue = retFeasible;
 	m_runsPostprocessing = 0;
 
-	PG.embed(); 
+	if(!m_keepEmbedding) PG.embed();
 	OGDF_ASSERT(PG.representsCombEmbedding() == true);
 
 	if (origEdges.size() == 0)
@@ -181,29 +174,29 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 		}
 
 		insertEdge(PG,E,eOrig,crossed,forbidCrossingGens,forbiddenEdgeOrig);
-		
-		if(removeReinsert() == rrIncremental) {
+
+		if(removeReinsert() == rrIncremental || removeReinsert() == rrIncInserted) {
 			currentOrigEdges.pushBack(eOrig);
 
 			bool improved;
 			do {
 				++m_runsPostprocessing;
 				improved = false;
-				
+
 				SListConstIterator<edge> itRR;
 				for(itRR = currentOrigEdges.begin(); itRR.valid(); ++itRR)
 				{
 					edge eOrigRR = *itRR;
-		
+
 					int pathLength;
 					if(costOrig != 0)
 						pathLength = costCrossed(eOrigRR,PG,*costOrig,edgeSubGraph);
 					else
 						pathLength = PG.chain(eOrigRR).size() - 1;
 					if (pathLength == 0) continue; // cannot improve
-		
+
 					removeEdge(PG,E,eOrigRR,forbidCrossingGens,forbiddenEdgeOrig);
-		
+
 					// try to find a better insertion path
 					SList<adjEntry> crossed;
 					if(costOrig != 0) {
@@ -220,13 +213,13 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 							forbidCrossingGens ? ((const PlanRepUML&)PG).typeOrig(eOrigRR) : Graph::association,
 							crossed);
 					}
-					
+
 					// re-insert edge (insertion path cannot be longer)
 					insertEdge(PG,E,eOrigRR,crossed,forbidCrossingGens,forbiddenEdgeOrig);
-		
+
 					int newPathLength = (costOrig != 0) ? costCrossed(eOrigRR,PG,*costOrig,edgeSubGraph) : (PG.chain(eOrigRR).size() - 1);
 					OGDF_ASSERT(newPathLength <= pathLength);
-					
+
 					if(newPathLength < pathLength)
 						improved = true;
 				}
@@ -235,17 +228,17 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 	}
 
 	const Graph &G = PG.original();
-	if(removeReinsert() != rrIncremental) {
+	if(removeReinsert() != rrIncremental && removeReinsert() != rrIncInserted) {
 		// postprocessing (remove-reinsert heuristc)
 		SListPure<edge> rrEdges;
-	
+
 		switch(removeReinsert())
 		{
 		case rrAll:
 		case rrMostCrossed: {
 				const List<node> &origInCC = PG.nodesInCC();
 				ListConstIterator<node> itV;
-	
+
 				for(itV = origInCC.begin(); itV.valid(); ++itV) {
 					node vG = *itV;
 					adjEntry adj;
@@ -257,7 +250,7 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 				}
 			}
 			break;
-	
+
 		case rrInserted:
 			for(ListConstIterator<edge> it = origEdges.begin(); it.valid(); ++it)
 				rrEdges.pushBack(*it);
@@ -265,13 +258,14 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 
 		case rrNone:
 		case rrIncremental:
+		case rrIncInserted:
 			break;
 		}
-	
+
 		// marks the end of the interval of rrEdges over which we iterate
 		// initially set to invalid iterator which means all edges
 		SListConstIterator<edge> itStop;
-	
+
 		bool improved;
 		do {
 			// abort postprocessing if time limit reached
@@ -279,24 +273,24 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 				retValue = retTimeoutFeasible;
 				break;
 			}
-				
+
 			++m_runsPostprocessing;
 			improved = false;
-	
+
 			if(removeReinsert() == rrMostCrossed)
 			{
 				FEICrossingsBucket bucket(&PG);
 				rrEdges.bucketSort(bucket);
-	
+
 				const int num = int(0.01 * percentMostCrossed() * G.numberOfEdges());
 				itStop = rrEdges.get(num);
 			}
-	
+
 			SListConstIterator<edge> it;
 			for(it = rrEdges.begin(); it != itStop; ++it)
 			{
 				edge eOrig = *it;
-							
+
 				// remove only if crossings on edge;
 				// in especially: forbidden edges are never handled by postprocessing
 				//   since there are no crossings on such edges
@@ -306,9 +300,9 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 				else
 					pathLength = PG.chain(eOrig).size() - 1;
 				if (pathLength == 0) continue; // cannot improve
-	
+
 				removeEdge(PG,E,eOrig,forbidCrossingGens,forbiddenEdgeOrig);
-	
+
 				// try to find a better insertion path
 				SList<adjEntry> crossed;
 				if(costOrig != 0) {
@@ -325,13 +319,13 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 						forbidCrossingGens ? ((const PlanRepUML&)PG).typeOrig(eOrig) : Graph::association,
 						crossed);
 				}
-	
+
 				// re-insert edge (insertion path cannot be longer)
 				insertEdge(PG,E,eOrig,crossed,forbidCrossingGens,forbiddenEdgeOrig);
-	
+
 				int newPathLength = (costOrig != 0) ? costCrossed(eOrig,PG,*costOrig,edgeSubGraph) : (PG.chain(eOrig).size() - 1);
 				OGDF_ASSERT(newPathLength <= pathLength);
-				
+
 				if(newPathLength < pathLength)
 					improved = true;
 			}
@@ -357,11 +351,11 @@ Module::ReturnType FixedEmbeddingInserter::doCall(
 edge FixedEmbeddingInserter::crossedEdge(adjEntry adj) const
 {
 	edge e = adj->theEdge();
-	
+
 	adj = adj->cyclicSucc();
 	while(adj->theEdge() == e)
 		adj = adj->cyclicSucc();
-		
+
 	return adj->theEdge();
 }
 
@@ -372,9 +366,9 @@ int FixedEmbeddingInserter::costCrossed(edge eOrig,
 	const EdgeArray<unsigned int> *subgraphs) const
 {
 	int c = 0;
-	
+
 	const List<edge> &L = PG.chain(eOrig);
-	
+
 	ListConstIterator<edge> it = L.begin();
 	for(++it; it.valid(); ++it) {
 		edge e = PG.original(crossedEdge((*it)->adjSource()));
@@ -388,7 +382,7 @@ int FixedEmbeddingInserter::costCrossed(edge eOrig,
 			c += costOrig[e];
 		}
 	}
-	
+
 	return c;
 }
 
@@ -582,7 +576,7 @@ inline int getCost(const PlanRep &PG, const EdgeArray<int> &cost, edge e, const
 		}
 		edgeCost *= cost[eOrig];
 		edgeCost *= 10000;
-		if(edgeCost == 0) 
+		if(edgeCost == 0)
 			edgeCost = 1;
 	}
 	return edgeCost;
@@ -647,7 +641,7 @@ void FixedEmbeddingInserter::findShortestPath(
 
 	// actual search (using extended bfs on directed dual)
 	int currentDist = 0;
-	
+
 	for( ; ; )
 	{
 		// next candidate edge
